#
# spec file for package kernel-rt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# needssslcertforbuild


%define srcversion 6.4
%define patchversion 6.4.0
%define git_commit c2cf5f15e346344a960c60fa1bed9f79c25eaa85
%define variant -rt%{nil}
%define compress_modules zstd
%define compress_vmlinux gz
%define livepatch livepatch%{nil}
%define livepatch_rt %{nil}
%define sb_efi_only 0
%define split_base 0
%define split_optional 1
%define supported_modules_check 1
%define build_flavor rt
%define generate_compile_commands 1

%include %_sourcedir/kernel-spec-macros

%(chmod +x %_sourcedir/{guards,apply-patches,check-for-config-changes,group-source-files.pl,split-modules,modversions,kabi.pl,mkspec,compute-PATCHVERSION.sh,arch-symbols,log.sh,try-disable-staging-driver,compress-vmlinux.sh,mkspec-dtb,check-module-license,splitflist,mergedep,moddep,modflist,kernel-subpackage-build})

Name:           kernel-rt
Version:        6.4.0
%if 0%{?is_kotd}
Release:        150700.16.1.gc2cf5f1
%else
Release:        150700.16.1
%endif
Summary:        The Linux Kernel
License:        GPL-2.0-only
Group:          System/Kernel
URL:            https://www.kernel.org/
%if 0%{?suse_version} > 1500 || 0%{?sle_version} > 150300
BuildRequires:  bash-sh
%endif
BuildRequires:  bc
BuildRequires:  bison
BuildRequires:  coreutils
BuildRequires:  fdupes
BuildRequires:  flex
# Cannot test %%CONFIG_GCC_PLUGINS here because the buildservice parser
# does not expand %%(...)
%if "%build_flavor" == "syzkaller"
# Needed by scripts/gcc-plugin.sh
BuildRequires:  gcc-c++
BuildRequires:  gcc-devel
%endif
BuildRequires:  hmaccalc
BuildRequires:  libopenssl-devel
BuildRequires:  modutils
BuildRequires:  python3-base
# Used to sign the kernel in the buildservice
BuildRequires:  openssl
BuildRequires:  pesign-obs-integration
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
# pahole for CONFIG_DEBUG_INFO_BTF
BuildRequires:  dwarves >= 1.22
%endif
# for objtool
BuildRequires:  libelf-devel
# required for 50-check-kernel-build-id rpm check
BuildRequires:  elfutils
%ifarch %arm
BuildRequires:  u-boot-tools
%endif
# Do not install p-b and dracut for the install check, the %post script is
# able to handle this
#!BuildIgnore: perl-Bootloader dracut distribution-release suse-kernel-rpm-scriptlets
# Remove some packages that are installed automatically by the build system,
# but are not needed to build the kernel
#!BuildIgnore: autoconf automake gettext-runtime libtool cvs gettext-tools udev insserv
%if ! 0%{?is_kotd} || ! %{?is_kotd_qa}%{!?is_kotd_qa:0}
ExclusiveArch:  x86_64
%else
ExclusiveArch:  do_not_build
%endif

%ifarch %ix86 x86_64
%define image vmlinuz
%endif
%ifarch ppc ppc64 ppc64le
%define image vmlinux
%endif
%ifarch s390 s390x
%define image image
%endif
%ifarch %arm
%define image zImage
%endif
%ifarch aarch64 riscv64
%define image Image
%endif

%ifarch %ix86 x86_64
%define install_vdso 1
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150500
%define separate_vdso 1
%endif
%else
%define install_vdso 0
%endif

%define build_default	("%build_flavor" == "default")
%define build_vanilla	("%build_flavor" == "vanilla")
%define vanilla_only    %{lua: if (rpm.expand("%variant") == "-vanilla") then print(1) else print(0) end}

%if ! %build_vanilla
%define src_install_dir /usr/src/linux-%kernelrelease%variant
%else
%define src_install_dir /usr/src/linux-%kernelrelease-vanilla
%endif
%define obj_install_dir /usr/src/linux-%kernelrelease%variant-obj
%define rpm_install_dir %buildroot%obj_install_dir
%define kernel_build_dir %my_builddir/linux-%srcversion/linux-obj
%define modules_dir %kernel_module_directory/%kernelrelease-%build_flavor

%global cpu_arch %(%_sourcedir/arch-symbols %_target_cpu)
%define cpu_arch_flavor %cpu_arch/%build_flavor

%if 0%{?_project:1} && ( %(echo %_project | grep -Ex -f %_sourcedir/release-projects | grep -vc ^PTF) || %(echo %_project | grep -Ec "^(Devel:)?Kernel:") )
	%define klp_ipa_clones 1
%endif

# Define some CONFIG variables as rpm macros as well. (rpm cannot handle
# defining them all at once.)
%define config_vars CONFIG_MODULES CONFIG_MODULE_SIG CONFIG_MODULE_SIG_HASH CONFIG_KMSG_IDS CONFIG_SUSE_KERNEL_SUPPORTED CONFIG_EFI_STUB CONFIG_LIVEPATCH_IPA_CLONES CONFIG_DEBUG_INFO_BTF_MODULES CONFIG_PREEMPT_DYNAMIC
%{expand:%(eval "$(test -n "%cpu_arch_flavor" && tar -xjf %_sourcedir/config.tar.bz2 --to-stdout config/%cpu_arch_flavor)"; for config in %config_vars; do echo "%%global $config ${!config:-n}"; done)}
%define split_extra ("%CONFIG_MODULES" == "y" && "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y")

%if "%CONFIG_MODULES" != "y"
	%define klp_ipa_clones 0
%endif

%global certs %( space="" ; for f in %_sourcedir/*.crt; do                                              \
    if ! test -e "$f"; then                                                                             \
        continue                                                                                        \
    fi                                                                                                  \
    h=$(openssl x509 -inform PEM -fingerprint -noout -in "$f")                                          \
    if [ -z "$h" ] ; then                                                                               \
        echo Cannot parse "$f" >&2                                                                      \
        confinue                                                                                        \
    fi                                                                                                  \
    cert=$(echo "$h" | sed -rn 's/^SHA1 Fingerprint=//; T; s/://g; s/(.{8}).*/\\1/p')                   \
    echo Found signing certificate "$f" "($cert)" >&2                                                   \
    cat "$f" >>%_sourcedir/.kernel_signing_key.pem                                                      \
    mkdir -p %_sourcedir/.kernel_signing_certs                                                          \
    openssl x509 -inform PEM -in "$f" -outform DER -out %_sourcedir/.kernel_signing_certs/"$cert".crt   \
    echo -n "$space$cert" ; space=" "                                                                   \
done )

Source0:        https://www.kernel.org/pub/linux/kernel/v6.x/linux-%srcversion.tar.xz
Source3:        kernel-source.rpmlintrc
Source14:       series.conf
Source16:       guards
Source17:       apply-patches
Source19:       kernel-binary-conflicts
Source20:       obsolete-kmps
Source21:       config.conf
Source23:       supported.conf
Source33:       check-for-config-changes
Source35:       group-source-files.pl
Source36:       README.PATCH-POLICY.SUSE
Source37:       README.SUSE
Source38:       README.KSYMS
Source40:       source-timestamp
Source46:       split-modules
Source47:       modversions
Source48:       macros.kernel-source
Source49:       kernel-module-subpackage
Source50:       kabi.pl
Source51:       mkspec
Source52:       kernel-source%variant.changes
Source53:       kernel-source.spec.in
Source54:       kernel-binary.spec.in
Source55:       kernel-syms.spec.in
Source56:       kernel-docs.spec.in
Source57:       kernel-cert-subpackage
Source58:       constraints.in
Source60:       config.sh
Source61:       compute-PATCHVERSION.sh
Source62:       old-flavors
Source63:       arch-symbols
Source64:       package-descriptions
Source65:       kernel-spec-macros
Source67:       log.sh
Source68:       host-memcpy-hack.h
Source69:       try-disable-staging-driver
Source70:       kernel-obs-build.spec.in
Source71:       kernel-obs-qa.spec.in
Source72:       compress-vmlinux.sh
Source73:       dtb.spec.in.in
Source74:       mkspec-dtb
Source75:       release-projects
Source76:       check-module-license
Source78:       modules.fips
Source79:       splitflist
Source80:       mergedep
Source81:       moddep
Source82:       modflist
Source83:       kernel-subpackage-build
Source84:       kernel-subpackage-spec
Source85:       kernel-default-base.spec.txt
Source86:       old_changelog.txt
Source100:      config.tar.bz2
Source101:      config.addon.tar.bz2
Source102:      patches.arch.tar.bz2
Source103:      patches.drivers.tar.bz2
Source104:      patches.fixes.tar.bz2
Source105:      patches.rpmify.tar.bz2
Source106:      patches.suse.tar.bz2
Source108:      patches.addon.tar.bz2
Source109:      patches.kernel.org.tar.bz2
Source110:      patches.apparmor.tar.bz2
Source111:      patches.rt.tar.bz2
Source113:      patches.kabi.tar.bz2
Source114:      patches.drm.tar.bz2
Source120:      kabi.tar.bz2
Source121:      sysctl.tar.bz2
# These files are found in the kernel-source package:
NoSource:       0
NoSource:       3
NoSource:       14
NoSource:       16
NoSource:       17
NoSource:       19
NoSource:       20
NoSource:       21
NoSource:       23
NoSource:       33
NoSource:       35
NoSource:       36
NoSource:       37
NoSource:       38
NoSource:       40
NoSource:       46
NoSource:       47
NoSource:       48
NoSource:       49
NoSource:       50
NoSource:       51
NoSource:       52
NoSource:       53
NoSource:       54
NoSource:       55
NoSource:       56
NoSource:       57
NoSource:       58
NoSource:       60
NoSource:       61
NoSource:       62
NoSource:       63
NoSource:       64
NoSource:       65
NoSource:       67
NoSource:       68
NoSource:       69
NoSource:       70
NoSource:       71
NoSource:       72
NoSource:       73
NoSource:       74
NoSource:       75
NoSource:       76
NoSource:       78
NoSource:       79
NoSource:       80
NoSource:       81
NoSource:       82
NoSource:       83
NoSource:       84
NoSource:       85
NoSource:       86
NoSource:       100
NoSource:       101
NoSource:       102
NoSource:       103
NoSource:       104
NoSource:       105
NoSource:       106
NoSource:       108
NoSource:       109
NoSource:       110
NoSource:       111
NoSource:       113
NoSource:       114
NoSource:       120
NoSource:       121

%ifarch %ix86
# Only i386/default supports i586, mark other flavors' packages as i686
%if ! %build_default
BuildArch:      i686
%endif
%endif
# Force bzip2 instead of lzma compression to
# 1) allow install on older dist versions, and
# 2) decrease build times (bsc#962356 boo#1175882)
%define _binary_payload w9.bzdio
# Do not recompute the build-id of vmlinux in find-debuginfo.sh (bsc#964063)
%undefine _unique_build_ids
%define _no_recompute_build_ids 1
# prevent usr/lib/debug/boot/vmlinux-4.12.14-11.10-default-4.12.14-11.10.ppc64le.debug
%undefine _unique_debug_names

%if "%{compress_modules}" == "zstd"
BuildRequires:  zstd
# Make sure kmod supports zstd compressed modules
Requires(post): kmod-zstd
%endif
Provides:       %name = %version-%source_rel
# bnc#901925
Provides:       %name-%version-%source_rel
Provides:       %{name}_%_target_cpu = %version-%source_rel
Provides:       kernel-base = %version-%source_rel
Provides:       multiversion(kernel)
# In SLE11, kernel-$flavor complemented kernel-$flavor-base. With SLE12,
# kernel-$flavor itself contains all the needed files and kernel-$flavor-base
# is a subset that can replace kernel-$flavor in some scenarios. We need to
# obsolete the -base subpackage from SLE11, so that the base files are not
# owned by multiple packages now. The dependency is not correct wrt openSUSE
# 11.2 - 11.4, but we primarily care about the supported upgrade path.
Obsoletes:      %name-base < 3.1
%if ("%build_flavor" != "kvmsmall") && ("%build_flavor" != "azure")
Recommends: kernel-firmware
%endif
# The following is copied to the -base subpackage as well
# BEGIN COMMON DEPS
Requires(pre):  suse-kernel-rpm-scriptlets
Requires(post): suse-kernel-rpm-scriptlets
Requires:       suse-kernel-rpm-scriptlets
Requires(preun): suse-kernel-rpm-scriptlets
Requires(postun): suse-kernel-rpm-scriptlets
Requires(pre):  coreutils awk
# For /usr/lib/module-init-tools/weak-modules2 and /usr/lib/modprobe.d/*.conf
Requires(post): suse-module-tools
Requires:       suse-module-tools
# For depmod (modutils is a dependency provided by both module-init-tools and
# kmod-compat)
Requires(post): modutils
# This Requires is wrong, because the post/postun scripts have a
# test -x update-bootloader, having perl-Bootloader is not a hard requirement.
# But, there is no way to tell rpm or yast to schedule the installation
# of perl-Bootloader before kernel-binary.rpm if both are in the list of
# packages to install/update. Likewise, this is true for dracut.
# Need a perl-Bootloader with /usr/lib/bootloader/bootloader_entry
Requires(post): perl-Bootloader >= 0.4.15
Requires(post): dracut
# Install the package providing /etc/SuSE-release early enough, so that
# the grub entry has correct title (bnc#757565)
Requires(post): distribution-release

%if %{usrmerged}
# make sure we have a post-usrmerge system
Conflicts:      filesystem < 16
%endif

Obsoletes:      microcode_ctl < 1.18

%{lua:	fd, err = io.open(rpm.expand('%_sourcedir') .. '/kernel-binary-conflicts')
	if not fd then io.stderr:write(err) end
	unpack = table.unpack or unpack
	for l in fd:lines() do
		if #l > 0 and l:sub(1,1) ~= '#' then
			words = {} ; for w in l:gmatch("([^%s]+)%s*") do table.insert(words, w) end
			package, version = unpack(words)
			print('Conflicts: ' .. package .. ' < '.. version .. '\n')
		end
	end
	fd:close()
}

%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
Provides:       kernel = %version-%source_rel
Provides:       kernel-%build_flavor-base-srchash-%git_commit
Provides:       kernel-srchash-%git_commit
# END COMMON DEPS
Provides:       %name-srchash-%git_commit
%ifarch x86_64
Provides:       kernel-compute = 3.13
Obsoletes:      kernel-compute <= 3.13
%endif
%ifarch x86_64
Provides:       kernel-compute-base = 3.13
Obsoletes:      kernel-compute-base <= 3.13
%endif
%obsolete_rebuilds %name

%define kmp_target_cpu %_target_cpu
%ifarch %ix86
# KMPs are always built as i586, because rpm does not allow to build
# subpackages for different architectures. Therefore, we change the
# /usr/src/linux-obj/<arch> symlink to i586.
%define kmp_target_cpu i586
%endif

%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kernel-preempt = %version-%release
Provides:       kernel-preempt_%_target_cpu = %version-%source_rel
%endif
%endif

%{lua:	fd, err = io.open(rpm.expand('%_sourcedir') .. '/obsolete-kmps')
	if not fd then io.stderr:write(err) end
	unpack = table.unpack or unpack
	for l in fd:lines() do
		if #l > 0 and l:sub(1,1) ~= '#' then
			words = {} ; for w in l:gmatch("([^%s]+)%s*") do table.insert(words, w) end
			package, version = unpack(words)
			print('Obsoletes: ' .. package .. '-kmp-' .. rpm.expand('%build_flavor') .. ' <= '.. version .. '\n')
			print('Provides: ' .. package .. '-kmp = ' .. version .. '.1\n')
			print('Provides: ' .. package .. '-kmp-' .. rpm.expand('%build_flavor') .. ' = '.. version .. '.1\n')
		end
	end
	fd:close()
}

%description
The Linux Kernel.


%source_timestamp

%pre
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-pre --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%post
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-post --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%preun
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-preun --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%postun
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-postun --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%posttrans
%if "%build_flavor" != "zfcpdump"
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-posttrans --name "%name" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"
%endif
%files -f kernel-main.files

%if "%CONFIG_MODULES" == "y" && %split_base
%package base
Summary:        The Linux Kernel - base modules
Group:          System/Kernel
Url:            http://www.kernel.org/
Provides:       kernel-base = %version-%source_rel
Provides:       multiversion(kernel)
Conflicts:      %name = %version-%source_rel
Requires(pre):  suse-kernel-rpm-scriptlets
Requires(post): suse-kernel-rpm-scriptlets
Requires:       suse-kernel-rpm-scriptlets
Requires(preun): suse-kernel-rpm-scriptlets
Requires(postun): suse-kernel-rpm-scriptlets
Requires(pre):  coreutils awk
# For /usr/lib/module-init-tools/weak-modules2 and /usr/lib/modprobe.d/*.conf
Requires(post): suse-module-tools
Requires:       suse-module-tools
# For depmod (modutils is a dependency provided by both module-init-tools and
# kmod-compat)
Requires(post): modutils
# This Requires is wrong, because the post/postun scripts have a
# test -x update-bootloader, having perl-Bootloader is not a hard requirement.
# But, there is no way to tell rpm or yast to schedule the installation
# of perl-Bootloader before kernel-binary.rpm if both are in the list of
# packages to install/update. Likewise, this is true for dracut.
# Need a perl-Bootloader with /usr/lib/bootloader/bootloader_entry
Requires(post): perl-Bootloader >= 0.4.15
Requires(post): dracut
# Install the package providing /etc/SuSE-release early enough, so that
# the grub entry has correct title (bnc#757565)
Requires(post): distribution-release

%if %{usrmerged}
# make sure we have a post-usrmerge system
Conflicts:      filesystem < 16
%endif

Obsoletes:      microcode_ctl < 1.18

%{lua:	fd, err = io.open(rpm.expand('%_sourcedir') .. '/kernel-binary-conflicts')
	if not fd then io.stderr:write(err) end
	unpack = table.unpack or unpack
	for l in fd:lines() do
		if #l > 0 and l:sub(1,1) ~= '#' then
			words = {} ; for w in l:gmatch("([^%s]+)%s*") do table.insert(words, w) end
			package, version = unpack(words)
			print('Conflicts: ' .. package .. ' < '.. version .. '\n')
		end
	end
	fd:close()
}

%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
Provides:       kernel = %version-%source_rel
Provides:       kernel-%build_flavor-base-srchash-%git_commit
Provides:       kernel-srchash-%git_commit

%ifarch x86_64
Provides:       kernel-compute-base = 3.13
Obsoletes:      kernel-compute-base <= 3.13
%endif
%obsolete_rebuilds %name-base
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif

%description base
The Linux Kernel.

This package contains only the base modules, required in all installs.


%source_timestamp
%pre base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-pre --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-post --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-preun --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-postun --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans base
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/rpm-posttrans --name "%name-base" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files base -f kernel-base.files
%endif

%package extra
Summary:        The Linux Kernel - Unsupported kernel modules
Group:          System/Kernel
URL:            https://www.kernel.org/
Provides:       %name-extra_%_target_cpu = %version-%source_rel
Provides:       kernel-extra = %version-%source_rel
Provides:       multiversion(kernel)
Requires:       %{name}_%_target_cpu = %version-%source_rel
Requires(pre):  coreutils awk
Requires(post): modutils
Requires(post): perl-Bootloader
Requires(post): dracut
%ifarch x86_64
Provides:       kernel-compute-extra = 3.13
Obsoletes:      kernel-compute-extra <= 3.13
%endif
%obsolete_rebuilds %name-extra
Supplements:    packageand(product(SLED):%{name}_%_target_cpu)
Supplements:    packageand(product(sle-we):%{name}_%_target_cpu)
Supplements:    packageand(product(Leap):%{name}_%_target_cpu)
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kernel-preempt-extra = %version-%release
Provides:       kernel-preempt-extra_%_target_cpu = %version-%source_rel
%endif
%endif

%description extra
The Linux Kernel.

This package contains additional modules not supported by SUSE.


%source_timestamp

%pre extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans extra
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "%name-extra" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%if %split_extra

%files extra -f kernel-extra.files
%endif

%if %split_extra && %split_optional
%package optional
Summary:        The Linux Kernel - Optional kernel modules
Group:          System/Kernel
URL:            https://www.kernel.org/
Provides:       %name-optional_%_target_cpu = %version-%source_rel
Provides:       kernel-optional = %version-%source_rel
Provides:       multiversion(kernel)
Requires:       %name-extra_%_target_cpu = %version-%source_rel
Requires(pre):  coreutils awk
Requires(post): modutils
Requires(post): perl-Bootloader
Requires(post): dracut
%ifarch x86_64
Provides:       kernel-compute-optional = 3.13
Obsoletes:      kernel-compute-optional <= 3.13
%endif
%obsolete_rebuilds %name-optional
Supplements:    packageand(product(Leap):%{name}_%_target_cpu)
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kernel-preempt-optional = %version-%release
Provides:       kernel-preempt-optional_%_target_cpu = %version-%source_rel
%endif
%endif

%description optional
The Linux Kernel.

This package contains optional modules only for openSUSE Leap.


%source_timestamp

%pre optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans optional
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "%name-optional" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files optional -f kernel-optional.files
%endif

%if "%CONFIG_KMSG_IDS" == "y"

%package man
Summary:        The collection of man pages generated by the kmsg script
Group:          System/Kernel

%description man
This package includes the man pages that have been generated from the
kmsg message documentation comments.


%source_timestamp
%files man
/usr/share/man/man9/*
%endif

%if 0%{?separate_vdso}
%package vdso
Summary:        vdso binaries for debugging purposes
Group:          System/Kernel

%description vdso
This package includes the vdso binaries. They can be used for debugging. The
actual binary linked to the programs is loaded from the in-memory image, not
from this package.


%source_timestamp
%files vdso
%dir %modules_dir
%modules_dir/vdso/
%endif

%package devel
Summary:        Development files necessary for building kernel modules
Group:          Development/Sources
Provides:       %name-devel = %version-%source_rel
Provides:       multiversion(kernel)
%if ! %build_vanilla && ! %vanilla_only
Requires:       kernel-devel%variant = %version-%source_rel
Recommends:     make
Recommends:     gcc
Recommends:     perl
# for objtool
Requires:	libelf-devel
Supplements:    packageand(%name:kernel-devel%variant)
%else
Requires:       kernel-source-vanilla = %version-%source_rel
Supplements:    packageand(%name:kernel-source-vanilla)
%endif
%if "%CONFIG_DEBUG_INFO_BTF_MODULES" == "y"
Requires:       dwarves >= 1.22
%endif
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kernel-preempt-devel = %version-%release
%endif
%endif
%ifarch x86_64
Provides:       kernel-compute-devel = 3.13
Obsoletes:      kernel-compute-devel <= 3.13
%endif
%obsolete_rebuilds %name-devel
PreReq:         coreutils

%description devel
This package contains files necessary for building kernel modules (and
kernel module packages) against the %build_flavor flavor of the kernel.


%source_timestamp

%if "%CONFIG_MODULES" == "y"

%pre devel

# handle update from an older kernel-source with linux-obj as symlink
if [ -h /usr/src/linux-obj ]; then
    rm -vf /usr/src/linux-obj
fi

%post devel
%relink_function

relink ../../linux-%{kernelrelease}%{variant}-obj/"%cpu_arch_flavor" /usr/src/linux-obj/"%cpu_arch_flavor"

%files devel -f kernel-devel.files
%dir /usr/src/linux-obj
%dir /usr/src/linux-obj/%cpu_arch
%ghost /usr/src/linux-obj/%cpu_arch_flavor
%if %generate_compile_commands
%exclude %obj_install_dir/%cpu_arch_flavor/compile_commands.json
%endif
%if "%kmp_target_cpu" != "%cpu_arch"
%obj_install_dir/%kmp_target_cpu
/usr/src/linux-obj/%kmp_target_cpu
%endif

%if "%livepatch" != "" && "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y" && (("%variant" == "" && %build_default) || ("%variant" == "-rt" && 0%livepatch_rt))
%if "%livepatch" == "kgraft"
%define patch_package %{livepatch}-patch
%else
%define patch_package kernel-%{livepatch}
%endif
%package %{livepatch}
Summary:        Metapackage to pull in matching %patch_package package
Group:          System/Kernel
Requires:       %{patch_package}-%(echo %{version}-%{source_rel} | sed 'y/\./_/')-%{build_flavor}
Provides:       multiversion(kernel)
%if "%variant" != "-rt"
Provides:	kernel-default-kgraft = %version
Provides:	kernel-xen-kgraft = %version
%if "%livepatch" != "kgraft"
Obsoletes:	kernel-default-kgraft < %version
Obsoletes:	kernel-xen-kgraft < %version
%endif
%endif

%description %{livepatch}
This is a metapackage that pulls in the matching %patch_package package for a
given kernel version. The advantage of the metapackage is that its name is
static, unlike the %{patch_package}-<kernel-version>-flavor package names.

%files %{livepatch}
# rpmlint complains about empty packages, so lets own something
%dir %modules_dir
%endif

%if 0%{?klp_ipa_clones} && "%livepatch" != "" && "%CONFIG_LIVEPATCH_IPA_CLONES" == "y"
%package %{livepatch}-devel
Summary:	Kernel symbols file used during kGraft patch development
Group:		System/Kernel

%description %{livepatch}-devel
This package brings ipa-clones files, which are used to to track
set of functions where a code from another function can eventually occur.

%files %{livepatch}-devel -f livepatch-files
%endif

%if "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y"
%package -n cluster-md-kmp-%build_flavor
Summary:        Clustering support for MD devices
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       cluster-md-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       cluster-md-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:cluster-md-kmp-%build_flavor)
Requires:       dlm-kmp-%build_flavor = %version-%release

%description -n cluster-md-kmp-%build_flavor
Clustering support for MD devices. This enables locking and
synchronization across multiple systems on the cluster, so all
nodes in the cluster can access the MD devices simultaneously.

%pre -n cluster-md-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "cluster-md-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n cluster-md-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "cluster-md-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n cluster-md-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "cluster-md-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n cluster-md-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "cluster-md-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n cluster-md-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "cluster-md-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n cluster-md-kmp-%build_flavor -f cluster-md-kmp.files

%package -n dlm-kmp-%build_flavor
Summary:        DLM kernel modules
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       dlm-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       dlm-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:dlm-kmp-%build_flavor)

%description -n dlm-kmp-%build_flavor
DLM stands for Distributed Lock Manager, a means to synchronize access to
shared resources over the cluster.

%pre -n dlm-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "dlm-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n dlm-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "dlm-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n dlm-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "dlm-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n dlm-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "dlm-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n dlm-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "dlm-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n dlm-kmp-%build_flavor -f dlm-kmp.files

%package -n gfs2-kmp-%build_flavor
Summary:        GFS2 kernel modules
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       gfs2-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       gfs2-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:gfs2-kmp-%build_flavor)
Requires:       dlm-kmp-%build_flavor = %version-%release

%description -n gfs2-kmp-%build_flavor
GFS2 is Global Filesystem, a shared device filesystem.

%pre -n gfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "gfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n gfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "gfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n gfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "gfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n gfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "gfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n gfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "gfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n gfs2-kmp-%build_flavor -f gfs2-kmp.files

%package -n kselftests-kmp-%build_flavor
Summary:        Kernel sefltests
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       kselftests-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       kselftests-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:kselftests-kmp-%build_flavor)

%description -n kselftests-kmp-%build_flavor
This package contains kernel modules which are part of the upstream kernel
selftest effort. kselftest is the name of the upstream kernel target to build
and run all selftests. You can also run each test individually from the
respective upstream tools/testing/selftests/ directory, this package is
intended to be used using individial upstream selftest scripts given only
select supported selftest drivers are enabled.

It should always be possible to always run the latest linux-next version of the
selftest scripts and tests against any older kernel selftest driver.  Certain
tests facilities may be backported onto older kernels to enable further
testing.

Selftests also provide for a vehicle or proof of concept issues to be
reproduced, verified and corrected.

Selftest drivers are intended to be supported only in testing and QA
environments, they are not intended to be run on production systems.

%pre -n kselftests-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "kselftests-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n kselftests-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "kselftests-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n kselftests-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "kselftests-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n kselftests-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "kselftests-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n kselftests-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "kselftests-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n kselftests-kmp-%build_flavor -f kselftests-kmp.files

%package -n ocfs2-kmp-%build_flavor
Summary:        OCFS2 kernel modules
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       ocfs2-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       ocfs2-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:ocfs2-kmp-%build_flavor)
Requires:       dlm-kmp-%build_flavor = %version-%release

%description -n ocfs2-kmp-%build_flavor
OCFS2 is the Oracle Cluster Filesystem, a filesystem for shared devices
accessible simultaneously from multiple nodes of a cluster.

%pre -n ocfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "ocfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n ocfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "ocfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n ocfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "ocfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n ocfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "ocfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n ocfs2-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "ocfs2-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n ocfs2-kmp-%build_flavor -f ocfs2-kmp.files

%package -n reiserfs-kmp-%build_flavor
Summary:        Reiserfs kernel module
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       reiserfs-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
%if %build_default
%if "%CONFIG_PREEMPT_DYNAMIC" == "y"
Provides:       reiserfs-kmp-preempt = %version-%release
%endif
%endif
Enhances:	%name
Supplements:	packageand(%name:reiserfs-kmp-%build_flavor)

%description -n reiserfs-kmp-%build_flavor
The reiserfs file system is no longer supported in SLE15.  This package
provides the reiserfs module for the installation system.

%pre -n reiserfs-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-pre --name "reiserfs-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%post -n reiserfs-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-post --name "reiserfs-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%preun -n reiserfs-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-preun --name "reiserfs-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%postun -n reiserfs-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-postun --name "reiserfs-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%posttrans -n reiserfs-kmp-%build_flavor
%run_if_exists /usr/lib/module-init-tools/kernel-scriptlets/inkmp-posttrans --name "reiserfs-kmp-%build_flavor" \
  --version "%version" --release "%release" --kernelrelease "%kernelrelease" \
  --image "%image" --flavor "%build_flavor" --variant "%variant" \
  --usrmerged "%{usrmerged}" --certs "%certs" "$@"

%files -n reiserfs-kmp-%build_flavor -f reiserfs-kmp.files

%endif # %CONFIG_SUSE_KERNEL_SUPPORTED
%endif # %CONFIG_MODULES

%prep
if ! [ -e %{S:0} ]; then
    echo "The %name-%version.nosrc.rpm package does not contain the" \
	 "complete sources. Please install kernel-source-%version.src.rpm."
    exit 1
fi

SYMBOLS=
if test -e %_sourcedir/extra-symbols; then
	SYMBOLS=$(cat %_sourcedir/extra-symbols)
	echo "extra symbol(s):" $SYMBOLS
fi

# Unpack all sources and patches
%setup -q -c -T -a 0 -a 100 -a 101 -a 102 -a 103 -a 104 -a 105 -a 106 -a 108 -a 109 -a 110 -a 111 -a 113 -a 114 -a 120 -a 121

mkdir -p %kernel_build_dir

# Generate a list of modules with their support status marking
# The first marker is supposed to be either "+external", "-" or "-!optional",
# where "+external" is for an externally supported module, "-" is for an
# unsuppored module, "-!optional" is for Leap-only unsupported module.
# There can be an optional arch-specific second marker with "+arch" (e.g.
# +arm64), which enforces the module to be supported on the specific arch.
%_sourcedir/guards --list --with-guards <%_sourcedir/supported.conf | \
awk '{
    t = "";
    for (i = 1; i < NF; i++) {
	if ($i == "+external") {
		t = " external";
	} else if ($i == "+'%cpu_arch'") {
		t = "";
	} else if ($i ~ "^-") {
		t = " no";
	}
    }
    print $(NF) t;
}' >%kernel_build_dir/Module.supported
subpackages=(
	base
%if "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y"
	cluster-md-kmp dlm-kmp gfs2-kmp kselftests-kmp ocfs2-kmp reiserfs-kmp
%endif
)
for package in "${subpackages[@]}"; do
	%_sourcedir/guards --default=0 "$package" \
		<%_sourcedir/supported.conf | sed 's,.*/,,; s,\.ko$,,' | \
		sort -u >%kernel_build_dir/Module."$package"
done
%if %split_extra && %split_optional
# Module.optional is in a special form, containing guard markers for
# both extra and optional modules, which is processed by split-modules
%_sourcedir/guards --list --with-guards <%_sourcedir/supported.conf | \
awk '{
    t = "";
    for (i = 1; i < NF; i++) {
	if ($i == "+'%cpu_arch'") {
		t = "";
	} else if ($i ~ "^-") {
		t = $i
	}
    }
    if (t != "") {print t,$(NF);}
}' >%kernel_build_dir/Module.optional
%endif

cd linux-%srcversion

%_sourcedir/apply-patches \
%if %{build_vanilla} && ! %vanilla_only
	--vanilla \
%endif
	%_sourcedir/series.conf .. $SYMBOLS

cd %kernel_build_dir

# Override the timestamp 'uname -v' reports with the source timestamp and
# the commit hash.
date=$(head -n 1 %_sourcedir/source-timestamp)
commit=$(sed -n 's/GIT Revision: //p' %_sourcedir/source-timestamp)
cat > .kernel-binary.spec.buildenv <<EOF
export KBUILD_BUILD_TIMESTAMP="$(LANG=C date -d "$date") (${commit:0:7})"
export KBUILD_VERBOSE=0
export KBUILD_SYMTYPES=1
export KBUILD_BUILD_USER=geeko
export KBUILD_BUILD_HOST=buildhost
export HOST_EXTRACFLAGS="-include %_sourcedir/host-memcpy-hack.h"
EOF
source .kernel-binary.spec.buildenv

if [ -f %_sourcedir/localversion ] ; then
    cat %_sourcedir/localversion > localversion
fi

config_base="default"
%ifarch %ix86
config_base="pae"
%endif
if ! [ -f %my_builddir/config/%cpu_arch/$config_base ] ; then
    config_base=%variant
    config_base=${config_base#-}
fi
if ! grep -q CONFIG_MMU= "%my_builddir/config/%cpu_arch_flavor"; then
cp "%my_builddir/config/%cpu_arch/$config_base" .config
../scripts/kconfig/merge_config.sh -m .config \
                                   %my_builddir/config/%cpu_arch_flavor
else
cp %my_builddir/config/%cpu_arch_flavor .config
fi
if test -e %my_builddir/config.addon/%cpu_arch_flavor; then
	# FIXME: config.addon doesn't affect the %CONFIG_ macros defined at
	# the top of the specfile
	../scripts/kconfig/merge_config.sh -m .config %my_builddir/config.addon/%cpu_arch_flavor
fi

CONFIG_SUSE_KERNEL_RELEASED="--disable CONFIG_SUSE_KERNEL_RELEASED"
%if 0%{?_project:1}
if echo %_project | grep -Eqx -f %_sourcedir/release-projects; then
	CONFIG_SUSE_KERNEL_RELEASED="--enable CONFIG_SUSE_KERNEL_RELEASED"
fi
%endif

DEBUG_INFO_TYPE="$(grep "CONFIG_DEBUG_INFO_DWARF.*=y" .config)"
DEBUG_INFO_TYPE="${DEBUG_INFO_TYPE%%=y}"
DEBUG_INFO_TYPE="${DEBUG_INFO_TYPE##CONFIG_DEBUG_INFO_}"
echo "Kernel debuginfo type: ${DEBUG_INFO_TYPE}"

../scripts/config \
	--set-str CONFIG_LOCALVERSION -%source_rel-%build_flavor \
	--enable  CONFIG_SUSE_KERNEL \
	$CONFIG_SUSE_KERNEL_RELEASED \
%if 0%{?__debug_package:1}
	--enable  CONFIG_DEBUG_INFO
%else
	--disable CONFIG_DEBUG_INFO \
	--disable CONFIG_DEBUG_INFO_"${DEBUG_INFO_TYPE}" \
	--enable  CONFIG_DEBUG_INFO_NONE
%endif

if [ %CONFIG_MODULE_SIG = "y" ]; then
	if [ -n "%certs" ] ; then
		ln -s %_sourcedir/.kernel_signing_key.pem .
	else
		if ! [ -f .kernel.genkey ] ; then
			cat > .kernel.genkey <<EOF
[ req ]
default_bits = 4096
distinguished_name = req_distinguished_name
prompt = no
string_mask = utf8only
x509_extensions = myexts

[ req_distinguished_name ]
CN = Build time autogenerated kernel key

[ myexts ]
basicConstraints=critical,CA:FALSE
keyUsage=digitalSignature
subjectKeyIdentifier=hash
authorityKeyIdentifier=keyid
extendedKeyUsage=codeSigning
EOF
		fi
		openssl req -new -nodes -utf8 -%CONFIG_MODULE_SIG_HASH -days 36500 \
			-batch -x509 -config .kernel.genkey \
			-outform PEM -out .kernel_signing_key.pem \
			-keyout .kernel_signing_key.pem
	fi
	../scripts/config --set-str CONFIG_MODULE_SIG_KEY ".kernel_signing_key.pem"
fi

case %cpu_arch in
    x86_64 | i386)
        MAKE_ARGS="$MAKE_ARGS ARCH=x86"
        ;;
    ppc*)
        MAKE_ARGS="$MAKE_ARGS ARCH=powerpc"
        ;;
    s390x)
        MAKE_ARGS="$MAKE_ARGS ARCH=s390"
        ;;
    arm64)
        MAKE_ARGS="$MAKE_ARGS ARCH=arm64"
        ;;
    armv*)
        MAKE_ARGS="$MAKE_ARGS ARCH=arm"
        ;;
    riscv*)
        MAKE_ARGS="$MAKE_ARGS ARCH=riscv"
        ;;
    *)
        MAKE_ARGS="$MAKE_ARGS ARCH=%cpu_arch"
        ;;
esac

makeoutputsync=
if make --output-sync --help >/dev/null 2>&1 ; then
        makeoutputsync=--output-sync
else
        echo make does not support --output-sync flag. Build messages may be mangled. 1>&2
fi
MAKE_ARGS="$MAKE_ARGS $makeoutputsync %{?_smp_mflags}"
echo export MAKE_ARGS=\""$MAKE_ARGS"\" >> .kernel-binary.spec.buildenv

KERN_DIRS="-C .. O=$PWD"
if test -e %_sourcedir/TOLERATE-UNKNOWN-NEW-CONFIG-OPTIONS; then
    yes '' | make oldconfig $MAKE_ARGS $KERN_DIRS
else
    cp .config .config.orig
    if test -f ../scripts/kconfig/Makefile && \
       grep -q syncconfig ../scripts/kconfig/Makefile; then
        syncconfig="syncconfig"
    else
        syncconfig="silentoldconfig"
    fi
    make $syncconfig $MAKE_ARGS $KERN_DIRS < /dev/null
    %_sourcedir/check-for-config-changes .config.orig .config
    rm .config.orig
fi

make prepare $MAKE_ARGS
make scripts $MAKE_ARGS
krel=$(make -s kernelrelease $MAKE_ARGS)

if [ "$krel" != "%kernelrelease-%build_flavor" ]; then
    echo "Kernel release mismatch: $krel != %kernelrelease-%build_flavor" >&2
    exit 1
fi

make clean $MAKE_ARGS

rm -f source
find . ! -type d ! -name 'Module.base' ! -name 'Module.*-kmp' ! -name 'Module.optional' -printf '%%P\n' \
	> %my_builddir/obj-files

%build
cd %kernel_build_dir
source .kernel-binary.spec.buildenv

# create *.symref files in the tree
if test -e %my_builddir/kabi/%cpu_arch/symtypes-%build_flavor; then
    %_sourcedir/modversions --unpack . < $_
fi

%if "%CONFIG_KMSG_IDS" == "y"
    chmod +x ../scripts/kmsg-doc
    MAKE_ARGS="$MAKE_ARGS D=2"
%endif

mkdir -p %_topdir/OTHER
log=%_topdir/OTHER/make-stderr.log
while true; do
    make all $MAKE_ARGS 2> >(tee "$log")
    if test "${PIPESTATUS[0]}" -eq 0; then
        break
    fi
    # In the linux-next and vanilla branches, we try harder to build a
    # package.
    if test 0%vanilla_only -gt 0 &&
			%_sourcedir/try-disable-staging-driver "$log"; then
        echo "Retrying make"
    else
        exit 1
    fi
done

%if 0%{?klp_ipa_clones} && %generate_compile_commands
    # Generate compile_commands.json
    make compile_commands.json
%endif

%install

# get rid of /usr/lib/rpm/brp-strip-debug
# strip removes too much from the vmlinux ELF binary
export NO_BRP_STRIP_DEBUG=true
export STRIP_KEEP_SYMTAB='*/vmlinux*'

# %kernel_module_directory/%kernelrelease-%build_flavor/source points to the source
# directory installed by kernel-devel. The kernel-%build_flavor-devel package
# has a correct dependency on kernel-devel, but the brp check does not see
# kernel-devel during build.
export NO_BRP_STALE_LINK_ERROR=yes

cd %kernel_build_dir
source .kernel-binary.spec.buildenv

mkdir -p %buildroot/boot
# (Could strip out non-public symbols.)
cp -p System.map %buildroot/boot/System.map-%kernelrelease-%build_flavor

add_vmlinux()
{
    local vmlinux=boot/vmlinux-%kernelrelease-%build_flavor

    cp vmlinux %buildroot/$vmlinux
    # make sure that find-debuginfo.sh picks it up. In the filelist, we
    # mark the file 0644 again
    chmod +x %buildroot/$vmlinux
    if test $1 == "--compressed"; then
        # avoid using the gzip -n option to make kdump happy (bnc#880848#c20)
        ts="$(head -n1 %_sourcedir/source-timestamp)"
        touch -d "$ts" %buildroot/$vmlinux
        touch %buildroot/$vmlinux.%{compress_vmlinux}
%if 0%{?__debug_package:1}
        # compress the vmlinux image after find-debuginfo.sh has processed it
%global __debug_install_post %__debug_install_post \
%_sourcedir/compress-vmlinux.sh %buildroot/boot/vmlinux-%kernelrelease-%build_flavor
%else
        %_sourcedir/compress-vmlinux.sh %buildroot/$vmlinux
%endif
        ghost_vmlinux=true
    else
        ghost_vmlinux=false
    fi
}

# architecture specifics
%ifarch %ix86 x86_64
    add_vmlinux --compressed
    cp -p arch/x86/boot/bzImage %buildroot/boot/%image-%kernelrelease-%build_flavor
%endif
%ifarch ppc ppc64 ppc64le
    add_vmlinux
%endif
%ifarch s390 s390x
    add_vmlinux --compressed
    image=image
    if test ! -f arch/s390/boot/$image; then
        image=bzImage
    fi
    cp -p arch/s390/boot/$image %buildroot/boot/%image-%kernelrelease-%build_flavor
%if "%CONFIG_KMSG_IDS" == "y"
    mkdir -p %buildroot/usr/share/man/man9
    find man -name '*.9' -exec install -m 644 -D '{}' %buildroot/usr/share/man/man9/ ';'
%endif
%if 0%{?suse_version} > 1500 || 0%{?sle_version} >= 150300
    s390x_vmlinux=arch/s390/boot/compressed/vmlinux
    if [ ! -f "$s390x_vmlinux" ]; then
        s390x_vmlinux=arch/s390/boot/vmlinux
    fi
    objcopy -R .rodata.compressed "$s390x_vmlinux" %buildroot/boot/zdebug-%kernelrelease-%build_flavor
%endif
%endif
%ifarch %arm
    add_vmlinux --compressed
    cp -p arch/arm/boot/%image %buildroot/boot/%image-%kernelrelease-%build_flavor
%endif
%ifarch aarch64
    add_vmlinux --compressed
    cp -p arch/arm64/boot/%image %buildroot/boot/%image-%kernelrelease-%build_flavor
%endif
%ifarch riscv64
    add_vmlinux --compressed
    cp -p arch/riscv/boot/%image %buildroot/boot/%image-%kernelrelease-%build_flavor
%endif

# sign the modules, firmware and possibly the kernel in the buildservice
BRP_PESIGN_FILES=""
%if "%CONFIG_EFI_STUB" == "y"
%if %{usrmerged}
BRP_PESIGN_FILES="%modules_dir/%image"
%else
BRP_PESIGN_FILES="/boot/%image-%kernelrelease-%build_flavor"
%endif
%endif
%if ! %sb_efi_only
%ifarch s390x ppc64 ppc64le
%if %{usrmerged}
BRP_PESIGN_FILES="%modules_dir/%image"
%else
BRP_PESIGN_FILES="/boot/%image-%kernelrelease-%build_flavor"
%endif
%endif
%endif
%if "%CONFIG_MODULE_SIG" == "y"
BRP_PESIGN_FILES="$BRP_PESIGN_FILES *.ko"
%endif
%ifarch %ix86
# XXX: do not sign on x86, as the repackaging changes kernel-pae
# from i686 to i586
BRP_PESIGN_FILES=""
%endif
export BRP_PESIGN_FILES
%if "%{compress_modules}" != "none"
export BRP_PESIGN_COMPRESS_MODULE=%{compress_modules}
%endif
# Do not sign vanilla kernels released in official projects
%if %build_vanilla && ! %vanilla_only
BRP_PESIGN_FILES=""
%endif

if test -x /usr/lib/rpm/pesign/gen-hmac; then
	$_ -r %buildroot /boot/%image-%kernelrelease-%build_flavor
fi

# Package the compiled-in certificates as DER files in /etc/uefi/certs
# and have mokutil enroll them when the kernel is installed
echo Signing certificates "%certs"
if test %CONFIG_MODULE_SIG = "y" -a -d %_sourcedir/.kernel_signing_certs ; then
    for f in %_sourcedir/.kernel_signing_certs/*.crt; do
            mkdir -p %buildroot/etc/uefi/certs
            cp -v $f %buildroot/etc/uefi/certs
    done
fi

cp -p .config %buildroot/boot/config-%kernelrelease-%build_flavor
sysctl_file=%buildroot/boot/sysctl.conf-%kernelrelease-%build_flavor
for file in %my_builddir/sysctl/{defaults,%cpu_arch/arch-defaults,%cpu_arch_flavor}; do
	if [ -f "$file" ]; then
		cat "$file"
	fi
done | sed '1i # Generated file - do not edit.' >$sysctl_file
if [ ! -s $sysctl_file ]; then
	rm $sysctl_file
fi

%if %install_vdso
# Install the unstripped vdso's that are linked in the kernel image
make vdso_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot
rm -rf %buildroot%kernel_module_directory/%kernelrelease-%build_flavor/vdso/.build-id
%endif

# Create a dummy initrd with roughly the size the real one will have.
# That way, YaST will know that this package requires some additional
# space in /boot.
dd if=/dev/zero of=%buildroot/boot/initrd-%kernelrelease-%build_flavor \
	bs=1024 seek=2047 count=1
# Also reserve some space for the kdump initrd
cp %buildroot/boot/initrd-%kernelrelease-%build_flavor{,-kdump}
%if 0%{?suse_version} >= 1500
# Use same permissions as dracut
chmod 0600 %buildroot/boot/initrd-%kernelrelease-%build_flavor{,-kdump}
%endif

if [ %CONFIG_MODULES = y ]; then
    mkdir -p %rpm_install_dir/%cpu_arch_flavor
    mkdir -p %buildroot/usr/src/linux-obj/%cpu_arch
    install -m 755 -D -t %rpm_install_dir/%cpu_arch_flavor/scripts/mod/ scripts/mod/ksym-provides

    gzip -n -c9 < Module.symvers > %buildroot/boot/symvers-%kernelrelease-%build_flavor.gz

    make modules_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot

%ifarch s390 s390x
    expoline=arch/s390/lib/expoline/expoline.o
    if test -f arch/s390/lib/expoline/expoline.o ; then
	install -m 644 -D -t %rpm_install_dir/%cpu_arch_flavor/$(dirname $expoline) $expoline
    fi
%endif

    # Also put the resulting file in %rpm_install_dir/%cpu_arch/%build_flavor
    # so that kernel-devel + kernel-%build_flavor is sufficient for building
    # modules that have modversions as well.
    mkdir -p %rpm_install_dir/%cpu_arch/%build_flavor
    cp Module.symvers %rpm_install_dir/%cpu_arch/%build_flavor

    # List of ipa-clones that are used to to track set of functions where a code from another function can eventually occur.
    %if 0%{?klp_ipa_clones} && "%CONFIG_LIVEPATCH_IPA_CLONES" == "y"
        %if %generate_compile_commands
		    cp compile_commands.json %rpm_install_dir/%cpu_arch/%build_flavor
		    echo %obj_install_dir/%cpu_arch/%build_flavor/compile_commands.json >> %my_builddir/livepatch-files.no_dir
        %endif

        find %kernel_build_dir -name "*.ipa-clones" ! -size 0 | sed -e 's|^%kernel_build_dir/||' | sort > ipa-clones.list
        cp ipa-clones.list %rpm_install_dir/%cpu_arch/%build_flavor
        echo %obj_install_dir/%cpu_arch/%build_flavor/ipa-clones.list >> %my_builddir/livepatch-files.no_dir
        tar -C %kernel_build_dir \
%if ! 0%{?suse_version} || 0%{?suse_version} >= 1500
            --verbatim-files-from \
%endif
            -T ipa-clones.list -cf- | tar -C %rpm_install_dir/%cpu_arch/%build_flavor -xvf-
        cat ipa-clones.list | sed -e 's|^|%obj_install_dir/%cpu_arch/%build_flavor/|' >> %my_builddir/livepatch-files.no_dir
    %endif

    # Table of types used in exported symbols (for modversion debugging).
    %_sourcedir/modversions --pack . > %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    if [ -s %buildroot/boot/symtypes-%kernelrelease-%build_flavor ]; then
	gzip -n -9 %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    else
	rm -f %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    fi

    # Some architecture's $(uname -m) output is different from the ARCH
    # parameter that needs to be passed to kbuild. Create symlinks from
    # $(uname -m) to the ARCH directory.
    if [ ! -e %rpm_install_dir/%kmp_target_cpu ]; then
        ln -sf %cpu_arch %rpm_install_dir/%kmp_target_cpu
        ln -sf %cpu_arch %buildroot/usr/src/linux-obj/%kmp_target_cpu
    fi

    # We were building in %my_builddir/linux-%srcversion, but the sources will
    # later be installed in /usr/src/linux-%srcversion-%source_rel. Fix up the
    # build symlink.
    rm -f %buildroot%kernel_module_directory/%kernelrelease-%build_flavor/{source,build}
    ln -s %src_install_dir \
	%buildroot%kernel_module_directory/%kernelrelease-%build_flavor/source
    ln -s %obj_install_dir/%cpu_arch/%build_flavor \
	%buildroot%kernel_module_directory/%kernelrelease-%build_flavor/build

    # Abort if there are any undefined symbols
    msg="$(/sbin/depmod -F %buildroot/boot/System.map-%kernelrelease-%build_flavor \
			-b %buildroot -ae %kernelrelease-%build_flavor 2>&1)"
    if [ $? -ne 0 ] || echo "$msg" | grep  'needs unknown symbol'; then
	exit 1
    fi

    %_sourcedir/split-modules -d %buildroot \
	-o %my_builddir \
	-b %kernel_build_dir \
%if "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y"
	-e \
%endif
%if ! %supported_modules_check
	-i \
%endif
	%nil
%if ! %split_extra
    cat %my_builddir/unsupported-modules >>%my_builddir/main-modules
%endif

    # The modules.dep file is sorted randomly which produces strange file
    # checksums. As the file is not included in the resulting RPM, it's
    # pointless to rely on its contents. Replacing by zeros to make the
    # checksums always the same for several builds of the same package.
    test -s %buildroot%kernel_module_directory/%kernelrelease-%build_flavor/modules.dep && \
    dd if=/dev/zero of=%buildroot%kernel_module_directory/%kernelrelease-%build_flavor/modules.dep ibs=$(stat -c%s %buildroot%kernel_module_directory/%kernelrelease-%build_flavor/modules.dep) count=1

    res=0
    if test -e %my_builddir/kabi/%cpu_arch/symvers-%build_flavor; then
        # check for kabi changes
        %_sourcedir/kabi.pl --rules %my_builddir/kabi/severities \
            %my_builddir/kabi/%cpu_arch/symvers-%build_flavor \
            Module.symvers || res=$?
    fi
    if [ $res -ne 0 ]; then
	# %ignore_kabi_badness is defined in the Kernel:* projects in the
	# OBS to be able to build the KOTD in spite of kabi errors
	if [ 0%{?ignore_kabi_badness} -eq 0 -a \
	     ! -e %my_builddir/kabi/%cpu_arch/ignore-%build_flavor -a \
	     ! -e %_sourcedir/IGNORE-KABI-BADNESS ]; then
	    echo "Create a file IGNORE-KABI-BADNESS in the kernel-source" \
		 "directory to build this kernel even though its badness is" \
		 "higher than allowed for an official kernel."
	   exit 1
	fi
    fi

    # Check the license in each module
    if ! sh %_sourcedir/check-module-license %buildroot; then
	echo "Please fix the missing licenses!"
%if "%CONFIG_SUSE_KERNEL_SUPPORTED" == "y"
	exit 1
%endif
    fi

    # These files are required for building external modules
    for FILE in arch/powerpc/lib/crtsavres.o arch/arm64/kernel/ftrace-mod.o \
		arch/*/kernel/macros.s scripts/module.lds
    do
	    if [ -f %kernel_build_dir/$FILE ]; then
		echo $FILE >> %my_builddir/obj-files
	    fi
    done

    tar --exclude=\*.ipa-clones --exclude=.config.old --exclude=.kernel-binary.spec.buildenv \
        --exclude=.kernel_signing_key.pem --exclude=.kernel.genkey \
        -cf - -T %my_builddir/obj-files | \
	tar -xf - -C %rpm_install_dir/%cpu_arch_flavor
    # bnc#507084
    find %rpm_install_dir/%cpu_arch_flavor/scripts -type f -perm -111 | \
        while read f; do
            case "$(file -b "$f")" in
            ELF\ *\ executable*)
                strip "$f"
            esac
        done

    # Recreate the generated Makefile with correct path
    #
    # Linux 5.13 no longer has mkmakefile
    if [ -f ../scripts/mkmakefile ] ; then
        sh ../scripts/mkmakefile ../../../%{basename:%src_install_dir} \
            %rpm_install_dir/%cpu_arch_flavor \
            $(echo %srcversion | sed -r 's/^([0-9]+)\.([0-9]+).*/\1 \2/')
    else
       echo include ../../../%{basename:%src_install_dir}/Makefile > %rpm_install_dir/%cpu_arch_flavor/Makefile
    fi
fi

# CONFIG_GDB_SCRIPTS
if [ -e vmlinux-gdb.py ]; then
    DEST=%rpm_install_dir/%cpu_arch_flavor/
    install -m 755 -d "$DEST"
    # set sys.path to our devel.rpm scripts
    sed 's@\(sys\.path\.insert(0, \).*@\1"%obj_install_dir/%cpu_arch_flavor/scripts/gdb/")@' vmlinux-gdb.py > "$DEST/vmlinux-gdb.py"

    DEST=%rpm_install_dir/%cpu_arch_flavor/scripts/gdb/linux
    install -m 755 -d "$DEST"
    pushd scripts/gdb/linux/
    for file in *.py; do
	if test -L "$file"; then
	    # relink against our devel.rpm sources, not of buildroot's
	    ln -s "%src_install_dir/scripts/gdb/linux/$file" "$DEST/$file"
	else
	    cp -p "$file" "$DEST"
	fi
    done
    popd

    DEST=%{buildroot}%{_datadir}/gdb/auto-load%modules_dir
    install -m 755 -d "$DEST"
    ln -s %obj_install_dir/%cpu_arch_flavor/vmlinux-gdb.py "$DEST/vmlinux-gdb.py"
fi

rm -rf %{buildroot}/lib/firmware

add_dirs_to_filelist() {
    sed -rn '
        # print file name
        p
        # remove filelist macros
        s:%%[a-z]+(\([^)]+\))? ?::g
        # add %%dir prefix
        s:^:%%dir :
        # print all parents
        :a
            # skip directories owned by other packages
            s:^%%dir (/boot|/etc|(/usr)?/lib/(modules|firmware)|/usr/share|/usr/src)/[^/]+$::
            s:/[^/]+$::p
        ta
    ' "$@" | sort -u
}

# Collect the file lists.
if [ -f %my_builddir/livepatch-files.no_dir ] ; then
    cat %my_builddir/livepatch-files.no_dir | add_dirs_to_filelist > %my_builddir/livepatch-files
fi

# does not exist for non-modularized kernels
%if %{usrmerged}
        mkdir -p %{buildroot}%modules_dir
%endif
shopt -s nullglob dotglob
> %my_builddir/kernel-devel.files
{
    echo "%modules_dir/build"
    echo "%modules_dir/source"
    cd %buildroot
    for file in boot/symtypes*; do
%if %{usrmerged}
        l="${file##*/}"
        l="%modules_dir/${l//-%kernelrelease-%build_flavor}"
        mv "$file" "%{buildroot}$l"
        ln -s "..$l" $file
        echo "$l"
        echo "%%ghost /$file"
%else
        echo "/$file"
%endif
    done
    if test -d .%{_datadir}/gdb/; then
	find .%obj_install_dir/%cpu_arch_flavor/scripts/gdb/linux/ -name '*.py' -type l | sed -e 's/^[.]//'
	echo "%{_datadir}/gdb/auto-load%modules_dir/vmlinux-gdb.py"
    fi
} | add_dirs_to_filelist >%my_builddir/kernel-devel.files
( cd %buildroot ; find .%obj_install_dir/%cpu_arch_flavor -type f ; ) | \
sed -e 's/^[.]//' | grep -v -e '[.]ipa-clones$' -e '/ipa-clones[.]list$'| \
add_dirs_to_filelist >> %my_builddir/kernel-devel.files

{   echo %ghost /boot/%image
    echo %ghost /boot/initrd
    cd %buildroot
    for f in boot/*; do
        l="${f##*/}"
        l="%modules_dir/${l//-%kernelrelease-%build_flavor}"
        if test -L "$f"; then
            echo "%%ghost /$f"
            continue
        elif test ! -f "$f"; then
            continue
        fi
        case "$f" in
        boot/initrd-*)
            echo "%%ghost /$f"
            continue
            ;;
        boot/vmlinux-*.%{compress_vmlinux})
            ;;
        boot/vmlinux-*)
            if $ghost_vmlinux; then
                # fall through to mark next echo as %ghost
                echo -n "%%ghost "
            fi
            ;;
%if %{usrmerged}
        boot/vmlinuz-*)
            echo -n "%%attr(0644, root, root) "
            ;;
%endif
        boot/symtypes*)
%if %{usrmerged}
            echo "%exclude $l"
%endif
            continue
            ;;
        esac
%if %{usrmerged}
        mv "$f" "./$l"
        ln -s "..$l" $f
        # the find in the CONFIG_MODULES condition below also finds the files
        # but there's sort -u later, so this is ok
        echo "$l" # note: must be first after case statement above
        echo "%%ghost /$f"
%else
        echo "%%attr(0644, root, root) /$f"
%endif
    done

    if [ %CONFIG_MODULES = y ]; then
	MODULES=%{lua: print(rpm.expand('%kernel_module_directory'):sub(2))}/%kernelrelease-%build_flavor
	find "$MODULES" \
%if 0%{?separate_vdso}
	    -path "$MODULES/vdso" -prune -o \
%endif
	    -type d -o \
	    \( -path '*/modules.*' ! -path '*/modules.order' \
	     ! -path '*/modules.builtin' \
	     ! -path '*/modules.builtin.modinfo' \) -printf '%%%%ghost /%%p\n' \
	       -o -name '*.ko' -prune \
	       -o \( -type f \
%if %{usrmerged}
		! -path '*/symtypes*' ! -path '*/vmlinu*' \
%endif
		\) -printf '/%%p\n'
	cat %my_builddir/base-modules
    fi
    if test %CONFIG_MODULE_SIG = "y" -a -d etc/uefi/certs; then
        find etc/uefi/certs -type f -printf '/%%p\n'
    fi
    if test -d lib/firmware/%kernelrelease-%build_flavor; then
        echo "%%dir /lib/firmware/%kernelrelease-%build_flavor"
        cat %my_builddir/base-firmware
    fi
    if [ -e .%_docdir/%name ]; then
	echo "%%doc %_docdir/%name"
    fi
} | sort -u | add_dirs_to_filelist >%my_builddir/kernel-base.files

{
    add_dirs_to_filelist %my_builddir/kernel-base.files
    if [ %CONFIG_MODULES = y ]; then
        add_dirs_to_filelist %my_builddir/main-modules
    fi
    if test -d %buildroot/lib/firmware/%kernelrelease-%build_flavor; then
	echo "/lib/firmware/%kernelrelease-%build_flavor"
    fi
} > %my_builddir/kernel-main.files

%if %split_extra
    add_dirs_to_filelist %my_builddir/unsupported-modules > %my_builddir/kernel-extra.files
%if %split_extra && %split_optional
    add_dirs_to_filelist %my_builddir/optional-modules > %my_builddir/kernel-optional.files
%endif

%if 0%{?sle_version} >= 150000
    # By default, loading unsupported modules is disabled on SLE through
    # /etc/modprobe.d/10-unsupported-modules.conf from the suse-module-tools
    # package.
    # modules in kernel-$flavor-extra don't have the supported flag set,
    # yet loading them should be possible if the package is installed.
    # CAUTION PACKAGERS: The file content below must not change between
    # kernel versions, otherwise file conflicts might arise with
    # multiversion(kernel).

    modprobe_d_dir=/etc/modprobe.d
    %if 0%{?sle_version} > 150300
    modprobe_d_dir=/lib/modprobe.d
    %endif
    %if %{usrmerged}
    modprobe_d_dir=/usr/lib/modprobe.d
    %endif

    mkdir -p %buildroot$modprobe_d_dir
    cat >%buildroot$modprobe_d_dir/20-kernel-%{build_flavor}-extra.conf <<EOF
# This file overrides the default from 10-unsupported-modules.conf.
# This is necessary to load kernel modules from the
# kernel-%{build_flavor}-extra package.
#
# WARNING: loading unsupported modules may compromise SLE support.
# Please read the comments in 10-unsupported-modules.conf.
allow_unsupported_modules 1
EOF
    echo "%%dir $modprobe_d_dir" >> %my_builddir/kernel-extra.files
    echo "%%config(noreplace) $modprobe_d_dir/20-kernel-%{build_flavor}-extra.conf" >> %my_builddir/kernel-extra.files
%endif
%endif
for f in %my_builddir/*-kmp-modules; do
	f2=${f%%-modules}.files
	add_dirs_to_filelist "$f" >"$f2"
done

if [ %CONFIG_MODULES = y ]; then
  install -m 644 %_sourcedir/modules.fips %{buildroot}%modules_dir/modules.fips
  echo %modules_dir/modules.fips >> %my_builddir/kernel-base.files
  echo %modules_dir/modules.fips >> %my_builddir/kernel-main.files
fi

# Hardlink duplicate files automatically (from package fdupes): It doesn't save
# much, but it keeps rpmlint from breaking the package build. Note that we skip
# /usr/src/linux-obj intentionally, to not accidentally break timestamps there
%fdupes %buildroot%modules_dir

%changelog
* Fri Dec 13 2024 ptesarik@suse.com
- Refresh RT DRM patches to v6.12-rc4-rt6:
  - patches.suse/drm-i915-Don-t-disable-interrupts-on-PREEMPT_RT-during-atomic-updates.patch
  - patches.suse/drm-i915-Don-t-check-for-atomic-context-on-PREEMPT_RT.patch
  - patches.suse/drm-i915-Disable-tracing-points-on-PREEMPT_RT.patch
  - patches.suse/drm-i915-gt-Use-spin_lock_irq-instead-of-local_irq_disable-spin_lock.patch
  - patches.suse/drm-i915-Drop-the-irqs_disabled-check.patch
  - patches.suse/drm-i915-guc-Consider-also-RCU-depth-in-busy-loop.patch
  - patches.suse/Revert-drm-i915-Depend-on-PREEMPT_RT.patch
- commit c2cf5f1
* Fri Dec 13 2024 ptesarik@suse.com
- drm/i915: Use preempt_disable/enable_rt() where recommended
  (bsc#1232534).
- commit 0d05cec
* Fri Dec 13 2024 ptesarik@suse.com
- Delete
  patches.suse/preempt-Put-preempt_enable-within-an-instrumentation-section.patch
  (bsc#1234546).
- commit 362125b
* Wed Dec 11 2024 ptesarik@suse.com
- Delete RT patches dropped in v6.12-rc1-rt2:
  - patches.suse/sched-core-Provide-a-method-to-check-if-a-task-is-PI-boosted.patch
  - patches.suse/softirq-Add-function-to-preempt-serving-softirqs.patch
  - patches.suse/time-Allow-to-preempt-after-a-callback.patch
- commit 464cf12
* Wed Dec 11 2024 ptesarik@suse.com
- Delete
  patches.suse/sched-rt-Don-t-try-push-tasks-if-there-are-none.patch
  (dropped in v6.12-rc1-rt2).
- commit f370134
* Thu Dec  5 2024 tiwai@suse.de
- drm/fbdev-dma: Select FB_DEFERRED_IO (git-fixes).
- Update config files.
- commit 044a7cd
* Thu Dec  5 2024 tiwai@suse.de
- i2c: core: Lock address during client device instantiation
  (git-fixes).
- i3c: master: svc: rename read_len as actual_len (stable-fixes).
- i3c: add actual_len in i3c_priv_xfer (stable-fixes).
- commit 43b1255
* Thu Dec  5 2024 tiwai@suse.de
- Bluetooth: MGMT: Fix possible deadlocks (git-fixes).
- i3c: master: Remove i3c_dev_disable_ibi_locked(olddev) on
  device hotjoin (git-fixes).
- i3c: master: svc: fix possible assignment of the same address
  to two devices (git-fixes).
- accel/ivpu: Prevent recovery invocation during probe and resume
  (git-fixes).
- i2c: dev: Fix memory leak when underlying adapter does not
  support I2C (git-fixes).
- Bluetooth: ISO: Use kref to track lifetime of iso_conn
  (git-fixes).
- commit e4968a0
* Thu Dec  5 2024 tiwai@suse.de
- blacklist.conf: ignore the past upstream stable revert entries for drm
- commit a865582
* Thu Dec  5 2024 tiwai@suse.de
- Add cherry-picked ids to DRM patches
- commit 6e2367d
* Thu Dec  5 2024 tiwai@suse.de
- drm/xe/migrate: use XE_BO_FLAG_PAGETABLE (git-fixes).
- drm/xe/guc_submit: fix race around suspend_pending (git-fixes).
- Revert "drm/radeon: Delay Connector detecting when HPD singals
  is unstable" (stable-fixes).
- drm/radeon: Fix spurious unplug event on radeon HDMI
  (git-fixes).
- drm/xe: Mark preempt fence workqueue as reclaim (git-fixes).
- drm/xe/ufence: Wake up waiters after setting ufence->signalled
  (git-fixes).
- drm/amdgpu: Fix map/unmap queue logic (git-fixes).
- drm/amdgpu: fix ACA bank count boundary check error (git-fixes).
- drm/bridge: it6505: Fix inverted reset polarity (git-fixes).
- drm/amdgpu: fix comment about amdgpu.abmlevel defaults
  (git-fixes).
- drm/amdgpu: Fix the memory allocation issue in
  amdgpu_discovery_get_nps_info() (git-fixes).
- drm: xlnx: zynqmp_disp: layer may be null while releasing
  (git-fixes).
- drm: panel: nv3052c: correct spi_device_id for RG35XX panel
  (git-fixes).
- drm/xe: Revert "drm/i915: Disable DSB in Xe KMD" (stable-fixes).
- drm: panel: jd9365da-h3: Remove unused num_init_cmds structure
  member (git-fixes).
- drm/v3d: Flush the MMU before we supply more memory to the
  binner (git-fixes).
- drm/panel: nt35510: Make new commands optional (git-fixes).
- drm/panic: Fix uninitialized spinlock acquisition with
  CONFIG_DRM_PANIC=n (git-fixes).
- drm/v3d: Appease lockdep while updating GPU stats (git-fixes).
- drm/imagination: Use pvr_vm_context_get() (git-fixes).
- drm/imagination: Convert to use time_before macro (git-fixes).
- drm/v3d: Fix Indirect Dispatch configuration for V3D 7.1.6
  and later (git-fixes).
- commit faf121e
* Wed Dec  4 2024 mfranc@suse.cz
- s390/crypto: Add hardware acceleration for full AES-XTS mode
  (jsc#PED-10276).
- s390/crypto: Postpone the key split to key conversion
  (jsc#PED-10276).
- s390/crypto: Introduce function for tokenize clearkeys
  (jsc#PED-10276).
- s390/crypto: Generalize parameters for key conversion
  (jsc#PED-10276).
- s390/crypto: Use module-local structures for protected keys
  (jsc#PED-10276).
- s390/crypto: Convert to reverse x-mas tree, rename ret to rc
  (jsc#PED-10276).
- s390/pkey: Tolerate larger key blobs (jsc#PED-10276).
- s390/pkey: Rework pkey verify for protected keys
  (jsc#PED-10276).
- s390/pkey: Simplify protected key length calculation code
  (jsc#PED-10276).
- s390/crypto: use kfree_sensitive() instead of kfree()
  (jsc#PED-10276).
- commit a57ea69
* Wed Dec  4 2024 mfranc@suse.cz
- s390/cio: Externalize full CMG characteristics (jsc#PED-10252).
- s390/cio: export CHPID operating speed (jsc#PED-10252).
- s390/cio: export measurement data for all CMGs (jsc#PED-10252).
- s390/cio: export extended channel-path-measurement data
  (jsc#PED-10252).
- s390/cio: simplify measurement attribute registration
  (jsc#PED-10252).
- s390/cio: rework channel-utilization-block handling
  (jsc#PED-10252).
- commit 94461bd
* Wed Dec  4 2024 ohering@suse.de
- net: mana: use ethtool string helpers (git-fixes).
- net: mana: Enable debugfs files for MANA device (git-fixes).
- hv_netvsc: Don't assume cpu_possible_mask is dense (git-fixes).
- net: mana: Add get_link and get_link_ksettings in ethtool
  (git-fixes).
- net: mana: Increase the DEF_RX_BUFFERS_PER_QUEUE to 1024
  (git-fixes).
- commit 290e5af
* Wed Dec  4 2024 pjakobsson@suse.de
- Refresh patches.suse/1355-drm-amdgpu-handle-default-profile-on-on-devices-with.patch (git-fixes)
  Alt-commit
- commit b611fca
* Wed Dec  4 2024 trenn@suse.com
- powercap: intel_rapl: Add support for ArrowLake-U platform
  (jsc#PED-10194).
- commit 3c44138
* Wed Dec  4 2024 trenn@suse.com
- powercap: intel_rapl: Add support for ArrowLake-H platform
  (jsc#PED-9988).
- Refresh
  patches.suse/powercap-intel_rapl-Switch-to-new-Intel-CPU-model-defines.patch.
- commit 3425c9e
* Wed Dec  4 2024 trenn@suse.com
- powercap: intel_rapl: Add support for Arrow Lake
  (jsc#PED-10394).
- Refresh
  patches.suse/powercap-intel_rapl-Switch-to-new-Intel-CPU-model-defines.patch.
- commit b18dfb4
* Wed Dec  4 2024 trenn@suse.com
- powercap: intel_rapl: Add support for Lunar Lake-M paltform
  (jsc#PED-9988).
- Refresh
  patches.suse/powercap-intel_rapl-Switch-to-new-Intel-CPU-model-defines.patch.
- commit 56e88f1
* Wed Dec  4 2024 pjakobsson@suse.de
- drm/xe: Take PM ref in delayed snapshot capture worker (git-fixes).
- commit e3a684b
* Wed Dec  4 2024 pjakobsson@suse.de
- drm/xe/migrate: fix pat index usage (git-fixes).
- commit df22c3a
* Wed Dec  4 2024 pjakobsson@suse.de
- drm/amdkfd: Use dynamic allocation for CU occupancy array in 'kfd_get_cu_occupancy()' (git-fixes).
- commit efbb0bf
* Wed Dec  4 2024 pjakobsson@suse.de
- drm/xe/hdcp: Fix gsc structure check in fw check status (git-fixes).
- commit 2f18b43
* Wed Dec  4 2024 pjakobsson@suse.de
- Revert "drm/amdgpu/gfx9: put queue resets behind a debug option" (git-fixes).
- commit 38c5cc6
* Wed Dec  4 2024 pjakobsson@suse.de
- drm/panic: allow verbose version check (git-fixes).
- commit 3f7b9cf
* Wed Dec  4 2024 pjakobsson@suse.de
- drm/panic: allow verbose boolean for clarity (git-fixes).
- commit b97f9c2
* Wed Dec  4 2024 pjakobsson@suse.de
- drm/panic: correctly indent continuation of line in list item (git-fixes).
- commit e674eb4
* Wed Dec  4 2024 pjakobsson@suse.de
- drm/panic: remove redundant field when assigning value (git-fixes).
- commit 906bb06
* Wed Dec  4 2024 pjakobsson@suse.de
- drm/panic: prefer eliding lifetimes (git-fixes).
- commit 9d7c82f
* Wed Dec  4 2024 pjakobsson@suse.de
- drm/panic: remove unnecessary borrow in alignment_pattern (git-fixes).
- commit c5b606e
* Wed Dec  4 2024 pjakobsson@suse.de
- drm/panic: avoid reimplementing Iterator::find (git-fixes).
- commit 9ba7e9e
* Wed Dec  4 2024 pjakobsson@suse.de
- drm/panic: Select ZLIB_DEFLATE for DRM_PANIC_SCREEN_QR_CODE (git-fixes).
- commit 3fccd35
* Wed Dec  4 2024 pjakobsson@suse.de
- drm/amd/display: fix a memleak issue when driver is removed (git-fixes).
- commit bf99bbf
* Wed Dec  4 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9: Add Cleaner Shader Deinitialization in gfx_v9_0 Module (git-fixes).
- commit 3c83054
* Wed Dec  4 2024 pjakobsson@suse.de
- Refresh
  patches.suse/1117-drm-tegra-fix-potential-uninitialized-variable-use.patch.
- Refresh
  patches.suse/1118-drm-i915-display-Fix-BMG-CCS-modifiers.patch.
- Refresh
  patches.suse/1148-drm-xe-prevent-potential-UAF-in-pf_provision_vf_ggtt.patch.
- Refresh patches.suse/1151-drm-xe-fix-missing-xe_vm_put.patch.
- Refresh
  patches.suse/1152-drm-xe-Don-t-keep-stale-pointer-to-bo-ggtt_node.patch.
- Refresh
  patches.suse/1154-drm-xe-Fix-missing-conversion-to-xe_display_pm_runti.patch.
- Refresh
  patches.suse/1162-drm-xe-guc-Fix-GUC_-SUBMIT-FIRMWARE-_VER-helper-macr.patch.
- Refresh
  patches.suse/1277-drm-xe-queue-move-xa_alloc-to-prevent-UAF.patch.
- Refresh
  patches.suse/1280-drm-xe-Fix-memory-leak-when-aborting-binds.patch.
- Refresh
  patches.suse/1282-drm-radeon-add-late_register-for-connector.patch.
- Refresh
  patches.suse/1286-drm-radeon-always-set-GEM-function-pointer.patch.
- Refresh
  patches.suse/1313-drm-amdgpu-enable-enforce_isolation-sysfs-node-on-VF.patch.
- Refresh
  patches.suse/1314-drm-amdgpu-prevent-BO_HANDLES-error-from-being-overw.patch.
- Refresh
  patches.suse/1318-drm-amdgpu-smu13-always-apply-the-powersave-optimiza.patch.
- Refresh
  patches.suse/1321-drm-amdgpu-swsmu-default-to-fullscreen-3D-profile-fo.patch.
- Refresh
  patches.suse/1331-gpu-host1x-Fix-boot-regression-for-Tegra.patch.
- Refresh
  patches.suse/1337-drm-xe-fix-unbalanced-rpm-put-with-fence_fini.patch.
- Refresh
  patches.suse/1338-drm-xe-fix-unbalanced-rpm-put-with-declare_wedged.patch.
- Refresh
  patches.suse/1351-drm-amd-display-temp-w-a-for-dGPU-to-enter-idle-opti.patch.
- Refresh
  patches.suse/1352-drm-amd-display-temp-w-a-for-DP-Link-Layer-complianc.patch.
- Refresh
  patches.suse/1380-drm-amdgpu-smu13-fix-profile-reporting.patch.
- Refresh
  patches.suse/1428-drm-amd-display-Fix-Panel-Replay-not-update-screen-c.patch.
- Refresh
  patches.suse/drm-amdgpu-swsmu-Only-force-workload-setup-on-init.patch.
- commit 9b3b7de
* Wed Dec  4 2024 mgorman@suse.de
- block: change wait on bd_claiming to use a var_waitqueue
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit bf0174b
* Tue Dec  3 2024 mhocko@suse.com
- Update
  patches.suse/drm-amd-display-Adjust-VSDB-parser-for-replay-featur.patch
  (stable-fixes CVE-2024-53108 bsc#1234081).
- Update
  patches.suse/fs-ntfs3-Fixed-overflow-check-in-mi_enum_attr.patch
  (bsc#1233207 CVE-2024-27407 bsc#1224429).
- Update
  patches.suse/ima-fix-buffer-overrun-in-ima_eventdigest_init_commo.patch
  (git-fixes CVE-2024-53106 bsc#1234083).
- Update
  patches.suse/keys-Fix-overwrite-of-key-expiration-on-instantiation.patch
  (git-fixes CVE-2024-36031 bsc#1225713).
- Update
  patches.suse/media-uvcvideo-Skip-parsing-frames-of-type-UVC_VS_UN.patch
  (git-fixes CVE-2024-53104 bsc#1234025).
- Update
  patches.suse/net-relax-socket-state-check-at-accept-time.patch
  (git-fixes CVE-2024-36484 bsc#1226872).
- Update
  patches.suse/nvme-multipath-defer-partition-scanning.patch
  (bsc#122824 git-fixes CVE-2024-53093 bsc#1233640).
- Update
  patches.suse/nvme-tcp-avoid-race-between-queue_lock-lock-and-dest.patch
  (git-fixes CVE-2024-53100 bsc#1233771).
- Update
  patches.suse/ocfs2-uncache-inode-which-has-failed-entering-the-group.patch
  (git-fixes CVE-2024-53112 bsc#1234087).
- Update
  patches.suse/scsi-mpi3mr-Avoid-memcpy-field-spanning-write-WARNING.patch
  (git-fixes CVE-2024-36920 bsc#1225768).
- Update
  patches.suse/scsi-pm80xx-Set-phy-enable_completion-only-when-we-wait-for-it.patch
  (git-fixes CVE-2024-47666 bsc#1231453).
- Update
  patches.suse/tcp-Fix-refcnt-handling-in-__inet_hash_connect.patch
  (git-fixes CVE-2024-26864 bsc#1223112).
- Update
  patches.suse/tracing-osnoise-Use-a-cpumask-to-know-what-threads-are-kthreads.patch
  (git-fixes CVE-2024-46788 bsc#1230817).
- Update
  patches.suse/tracing-timerlat-Move-hrtimer_init-to-timerlat_fd-open.patch
  (git-fixes CVE-2024-26703 bsc#1222423).
- Update
  patches.suse/x86-CPU-AMD-Clear-virtualized-VMLOAD-VMSAVE-on-Zen4-client
  (bsc#1233443 CVE-2024-53114 bsc#1234072).
- commit 420eea1
* Tue Dec  3 2024 mhocko@suse.com
- Update
  patches.suse/0057-drm-xe-preempt_fence-enlarge-the-fence-critical-sect.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-44956 bsc#1230172).
- Update
  patches.suse/0184-drm-xe-reset-mmio-mappings-with-devm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-46705 bsc#1230583).
- Update
  patches.suse/0245-drm-xe-Don-t-overmap-identity-VRAM-mapping.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-46718 bsc#1230721).
- Update
  patches.suse/0271-drm-amd-display-Add-null-check-in-resource_log_pipe_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-43886 bsc#1229748).
- Update
  patches.suse/0416-drm-amd-display-Disable-idle-reallow-as-part-of-comm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-36024 bsc#1225702).
- Update
  patches.suse/0489-drm-amd-display-Add-otg_master-NULL-check-within-res.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-46727 bsc#1230707).
- Update
  patches.suse/0769-drm-xe-Fix-potential-integer-overflow-in-page-size-c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-42066 bsc#1228668).
- Update
  patches.suse/0781-drm-xe-Add-a-NULL-check-in-xe_ttm_stolen_mgr_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-42065 bsc#1228541).
- Update
  patches.suse/0820-drm-xe-xe_devcoredump-Check-NULL-before-assignments.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-42081 bsc#1228676).
- Update
  patches.suse/0859-drm-xe-Check-pat.ops-before-dumping-PAT-settings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-42091 bsc#1228678).
- Update
  patches.suse/0904-drm-xe-Add-outer-runtime_pm-protection-to-xe_live_kt.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-42146 bsc#1228751).
- Update
  patches.suse/1151-drm-amdgpu-fix-double-free-err_addr-pointer-warnings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-42123 bsc#1228702).
- Update
  patches.suse/1160-drm-amd-display-Do-not-return-negative-stream-id-for.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-42118 bsc#1228583).
- Update
  patches.suse/1173-drm-amdgpu-change-vm-task_info-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-41008 bsc#1228110).
- Update
  patches.suse/1272-drm-amdgpu-Init-zone-device-and-drm-client-after-mod.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-36022 bsc#1225700).
- Update
  patches.suse/1287-drm-amd-display-Add-a-dc_state-NULL-check-in-dc_stat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-26948 bsc#1223664).
- Update
  patches.suse/1311-drm-amd-display-Prevent-crash-when-disable-stream.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-35799 bsc#1224740).
- Update
  patches.suse/1333-drm-dp-Fix-divide-by-zero-regression-on-DP-MST-unplu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-26941 bsc#1223721).
- Update
  patches.suse/1352-drm-i915-vma-Fix-UAF-on-destroy-against-retire-race.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-26939 bsc#1223679).
- Update
  patches.suse/1410-drm-xe-Only-use-reserved-BCS-instances-for-usm-migra.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-37026 bsc#1226951).
- Update
  patches.suse/1431-drm-xe-xe_migrate-Cast-to-output-precision-before-mu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-36948 bsc#1225845).
- Update
  patches.suse/1461-drm-xe-Fix-bo-leak-in-intel_fb_bo_framebuffer_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-26985 bsc#1223636).
- Update
  patches.suse/1721-drm-amd-display-Don-t-refer-to-dc_sink-in-is_dsc_nee.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-44955 bsc#1230177).
- Update
  patches.suse/1776-drm-amd-display-Fix-NULL-pointer-dereference-for-DTN.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-43901 bsc#1229765).
- Update
  patches.suse/2119-drm-amd-display-Add-null-check-before-access-structs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-43827 bsc#1229293).
- Update
  patches.suse/2456-drm-v3d-Fix-potential-memory-leak-in-the-timestamp-e.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-42263 bsc#1229332).
- Update
  patches.suse/2457-drm-v3d-Fix-potential-memory-leak-in-the-performance.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-42262 bsc#1229331).
- Update
  patches.suse/2458-drm-v3d-Validate-passed-in-drm-syncobj-handles-in-th.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-42261 bsc#1229325).
- Update
  patches.suse/2459-drm-v3d-Validate-passed-in-drm-syncobj-handles-in-th.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-42260 bsc#1229295).
- Update
  patches.suse/2469-drm-client-Fix-error-code-in-drm_client_buffer_vmap_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-42275 bsc#1229412).
- Update
  patches.suse/2505-drm-amdgpu-mes-fix-mes-ring-buffer-overflow.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-46700 bsc#1230508).
- Update
  patches.suse/2527-drm-v3d-Fix-out-of-bounds-read-in-v3d_csd_job_run.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-44993 bsc#1230197).
- Update patches.suse/2557-drm-xe-Fix-opregion-leak.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-44980 bsc#1230219).
- Update
  patches.suse/2561-drm-xe-prevent-UAF-around-preempt-fence.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-46683 bsc#1230560).
- Update
  patches.suse/2573-drm-xe-Fix-missing-workqueue-destroy-in-xe_gt_pagefa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-44979 bsc#1230202).
- Update
  patches.suse/2575-drm-xe-Free-job-before-xe_exec_queue_put.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-44978 bsc#1230218).
- Update
  patches.suse/2593-drm-vmwgfx-Disable-coherent-dumb-buffers-without-3d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-46712 bsc#1230543).
- Update
  patches.suse/2594-drm-v3d-Disable-preemption-while-updating-GPU-stats.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-46699 bsc#1230509).
- Update
  patches.suse/2609-drm-imagination-Free-pvr_vm_gpuva-after-unlink.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-46779 bsc#1230770).
- Update
  patches.suse/Revert-serial-8250_omap-Set-the-console-genpd-always-on-if-no-console-suspend.patch
  (git fixes CVE-2024-46703 bsc#1230593).
- Update
  patches.suse/bnxt_en-Fix-memory-out-of-bounds-in-bnxt_fill_hw_rss.patch
  (jsc#PED-11221 CVE-2024-44933 bsc#1229791).
- Update
  patches.suse/crypto-qat-validate-slices-count-returned-by-FW
  (jsc#PED-9963 CVE-2024-38606 bsc#1226871).
- Update
  patches.suse/drivers-thermal-loongson2_thermal-Fix-incorrect-PTR_.patch
  (jsc#PED-11164 CVE-2023-52613 bsc#1221619).
- Update
  patches.suse/ice-protect-XDP-configuration-with-a-mutex.patch
  (jsc#PED-9947 CVE-2024-46765 bsc#1230807).
- Update
  patches.suse/iommu-Restore-lost-return-in-iommu_report_device_fault
  (jsc#PED-10539 CVE-2024-44994 bsc#1230198).
- Update
  patches.suse/iommu-arm-smmu-Use-the-correct-type-in-nvidia_smmu_context_fault
  (jsc#PED-10968 CVE-2024-36884 bsc#1225727).
- Update
  patches.suse/ionic-fix-kernel-panic-due-to-multi-buffer-handling.patch
  (jsc#PED-11379 CVE-2024-42083 bsc#1228514).
- Update
  patches.suse/ionic-fix-kernel-panic-in-XDP_TX-action.patch
  (jsc#PED-11379 CVE-2024-40907 bsc#1227765).
- Update
  patches.suse/ionic-use-dev_consume_skb_any-outside-of-napi.patch
  (jsc#PED-11379 CVE-2024-42071 bsc#1228517).
- Update
  patches.suse/media-v4l-async-Fix-duplicated-list-deletion.patch
  (jsc#PED-10837 CVE-2023-52459 bsc#1220318).
- Update
  patches.suse/msft-hv-3011-RDMA-mana_ib-boundary-check-before-installing-cq-cal.patch
  (git-fixes CVE-2024-38542 bsc#1226591).
- Update
  patches.suse/net-dsa-fix-netdev_priv-dereference-before-check-on-.patch
  (bsc#1232178 CVE-2024-26596 bsc#1220355).
- Update
  patches.suse/net-ethtool-Add-new-power-limit-get-and-set-features.patch
  (bsc#1232798 CVE-2024-43836 bsc#1229308).
- Update
  patches.suse/net-netdevsim-don-t-try-to-destroy-PHC-on-VFs.patch
  (bsc#1232798 CVE-2024-26587 bsc#1220246).
- Update
  patches.suse/perf-Fix-event-leak-upon-exec-and-file-release.patch
  (bsc#1229741 CVE-2024-43869 bsc#1229491).
- Update
  patches.suse/platform-x86-intel-vbtn-Protect-ACPI-notify-handler-.patch
  (jsc#PED-11164 CVE-2024-44937 bsc#1229812).
- Update
  patches.suse/thermal-debugfs-Add-missing-count-increment-to-therm.patch
  (jsc#PED-11164 CVE-2024-27006 bsc#1223801).
- Update
  patches.suse/thermal-debugfs-Fix-two-locking-issues-with-thermal-.patch
  (jsc#PED-11164 CVE-2024-36961 bsc#1225857).
- Update
  patches.suse/thermal-debugfs-Free-all-thermal-zone-debug-memory-o.patch
  (jsc#PED-11164 CVE-2024-36956 bsc#1225874).
- Update
  patches.suse/thermal-debugfs-Prevent-use-after-free-from-occurrin.patch
  (jsc#PED-11164 CVE-2024-36932 bsc#1225831).
- Update
  patches.suse/vfio-pci-Init-the-count-variable-in-collecting-hot-reset-devices
  (jsc#PED-10539 CVE-2024-41052 bsc#1228464).
- Update patches.suse/vfio-pci-Lock-external-INTx-masking-ops
  (jsc#PED-10968 CVE-2024-26810 bsc#1222803).
- Update patches.suse/vsock-fix-recursive-recvmsg-calls.patch
  (jsc#PED-11028 CVE-2024-44996 bsc#1230205).
- Update
  patches.suse/x86-efistub-Use-1-1-file-memory-mapping-for-PE-COFF-.patch
  (jsc#PED-11167 CVE-2024-26678 bsc#1222292).
- commit 9c0363b
* Tue Dec  3 2024 sjaeckel@suse.de
- Bluetooth: SCO: Fix UAF on sco_sock_timeout (CVE-2024-50125
  bsc#1232928).
- Refresh
  patches.suse/Bluetooth-ISO-Fix-UAF-on-iso_sock_timeout.patch.
  Revert Bluetooth-ISO-Fix-UAF-on-iso_sock_timeout.patch to the upstream
  version of the patch.
  The reverted version was a mix of 1bf4470a and 246b435a, since they were
  accidentally identified as two different commits doing the same changes.
  The changes are indeed mostly the same, but to different files.
- commit 5725fe5
* Tue Dec  3 2024 mkoutny@suse.com
- blacklist.conf: 3840cbe24cf0 sched: psi: fix bogus pressure spikes from aggregation race
- commit ba9f9d2
* Tue Dec  3 2024 mkoutny@suse.com
- cgroup/bpf: only cgroup v2 can be attached by bpf programs
  (bsc#1234108).
- Revert "cgroup: Fix memory leak caused by missing
  cgroup_bpf_offline" (bsc#1234108).
- commit 6a48bcc
* Tue Dec  3 2024 mkoutny@suse.com
- blacklist.conf: Add 3cc4e13bb161 cgroup: Fix potential overflow issue when checking max_depth
- commit 0e316e6
* Tue Dec  3 2024 mkoutny@suse.com
- blacklist.conf: Add 57b56d16800e cgroup: Protect css->cgroup write under css_set_lock
- commit 3e18e0a
* Tue Dec  3 2024 ptesarik@suse.com
- kexec_file: fix elfcorehdr digest exclusion when
  CONFIG_CRASH_HOTPLUG=y (git-fixes).
- commit 1b2a54a
* Tue Dec  3 2024 mkoutny@suse.com
- signal: restore the override_rlimit logic (CVE-2024-50271
  bsc#1233460).
- ucounts: fix counter leak in inc_rlimit_get_ucounts()
  (bsc#1233460).
- commit 232c2a6
* Tue Dec  3 2024 mhocko@suse.com
- drm/xe/ufence: Prefetch ufence addr to catch bogus address
  (CVE-2024-53098 bsc#1233775).
- commit 7bcdb7f
* Tue Dec  3 2024 ohering@suse.de
- hv_sock: Initializing vsk->trans to NULL to prevent a dangling pointer (git-fixes).
- commit 109e508
* Tue Dec  3 2024 mkoutny@suse.com
- posix-cpu-timers: Clear TICK_DEP_BIT_POSIX_TIMER on clone
  (bsc#1234098).
- commit 362812c
* Tue Dec  3 2024 mkoutny@suse.com
- signal: Replace BUG_ON()s (bsc#1234093).
- commit dad9530
* Tue Dec  3 2024 mfranc@suse.cz
- dm cache: fix out-of-bounds access to the dirty bitset when
  resizing (CVE-2024-50279 bsc#1233468).
- commit 2080b22
* Tue Dec  3 2024 pjakobsson@suse.de
- drm/amd/display: Check null pointer before try to access it (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-amd-display-Fix-null-check-for-pipe_ctx-plane_st.patch.
- commit 1cf9446
* Tue Dec  3 2024 mfranc@suse.cz
- ipv4: ip_tunnel: Fix suspicious RCU usage warning in
  ip_tunnel_init_flow() (CVE-2024-53042 bsc#1233540).
- commit 6649f10
* Tue Dec  3 2024 mgorman@suse.de
- futex: improve user space accesses (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- ring-buffer: Limit time with disabled interrupts in
  rb_check_pages() (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- softirq: use bit waits instead of var waits (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- sched: Add wait/wake interface for variable updated under a lock
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- sched: Add test_and_clear_wake_up_bit() and
  atomic_dec_and_wake_up() (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- sched: Document wait_var_event() family of functions and
  wake_up_var() (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- sched: Improve documentation for wake_up_bit/wait_on_bit family
  of functions (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- sched: change wake_up_bit() and related function to expect
  unsigned long * (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- ring-buffer: Correct stale comments related to non-consuming
  readers (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- ring-buffer: Check if absolute timestamp goes backwards
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- ring-buffer: Add interrupt information to dump of data
  sub-buffer (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- ring-buffer: Remove 32bit timestamp logic (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- tracing: Allow for max buffer data size trace_marker writes
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- ring-buffer: Add offset of events in dump on mismatch
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- ring_buffer: Use try_cmpxchg instead of cmpxchg in
  rb_insert_pages (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- ring-buffer: Fix kernel-doc warnings in ring_buffer.c
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit e4b343b
* Tue Dec  3 2024 tbogendoerfer@suse.de
- Update config files.
  Enabled IDPF for ARM64 (bsc#1221309)
- commit adee356
* Tue Dec  3 2024 shung-hsi.yu@suse.com
- selftests/bpf: validate fake register spill/fill precision
  backtracking logic (bsc#1232823 CVE-2023-52920).
- bpf: handle fake register spill to stack with BPF_ST_MEM
  instruction (bsc#1232823 CVE-2023-52920).
- commit 52cdf87
* Tue Dec  3 2024 neelx@suse.com
- btrfs: fix a NULL pointer dereference when failed to start a
  new trasacntion (CVE-2024-49868 bsc#1232272).
- commit cc68ee3
* Tue Dec  3 2024 jslaby@suse.cz
- blacklist.conf: add one PCI which is not enabled
- commit 66fa3e6
* Tue Dec  3 2024 jslaby@suse.cz
- PCI: j721e: Deassert PERST# after a delay of PCIE_T_PVPERL_MS
  milliseconds (git-fixes).
- PCI: Add T_PVPERL macro (git-fixes).
- commit 664a849
* Mon Dec  2 2024 vbabka@suse.cz
- mm/thp: fix deferred split unqueue naming and locking
  (CVE-2024-53079 bsc#1233570).
- commit b50ea3e
* Mon Dec  2 2024 vliaskovitis@suse.com
- cxl: downgrade a warning message to debug level in
  cxl_probe_component_regs() (bsc#1229165).
- commit 388d64b
* Mon Dec  2 2024 dwagner@suse.de
- nvme-fabrics: fix kernel crash while shutting down controller
  (git-fixes).
- nvme-pci: reverse request order in nvme_queue_rqs (git-fixes).
- nvme-pci: fix freeing of the HMB descriptor table (git-fixes).
- nvme/host: Fix RCU list traversal to use SRCU primitive
  (git-fixes).
- commit 9f9c907
* Mon Dec  2 2024 dwagner@suse.de
- nvme-loop: flush off pending I/O while shutting down loop
  controller (git-fixes).
- commit 85bcc27
* Mon Dec  2 2024 dwagner@suse.de
- Rename to
  patches.suse/nvme-multipath-defer-partition-scanning.patch. (git-fixes bsc#122824)
- commit 79fcf69
* Mon Dec  2 2024 dwagner@suse.de
- nvme: tcp: avoid race between queue_lock lock and destroy
  (git-fixes).
- commit 0d6537a
* Mon Dec  2 2024 dwagner@suse.de
- Update
  patches.suse/scsi-qla2xxx-Update-version-to-10.02.09.300-k.patch
  (bsc#1228850 jsc#PED-9943 jsc#PED-11316).
  This is the latest greatest version of qla2xxx. Add the jira
  reference so that it is tracked.
- commit 8eff9b2
* Mon Dec  2 2024 dwagner@suse.de
- scsi: lpfc: Copyright updates for 14.4.0.6 patches (bsc#1233241
  jsc#PED-9943).
- scsi: lpfc: Update lpfc version to 14.4.0.6 (bsc#1233241
  jsc#PED-9943).
- scsi: lpfc: Change lpfc_nodelist nlp_flag member into a bitmask
  (bsc#1233241 jsc#PED-9943).
- scsi: lpfc: Remove NLP_RELEASE_RPI flag from nodelist structure
  (bsc#1233241 jsc#PED-9943).
- scsi: lpfc: Prevent NDLP reference count underflow in
  dev_loss_tmo callback (bsc#1233241 jsc#PED-9943).
- scsi: lpfc: Add cleanup of nvmels_wq after HBA reset
  (bsc#1233241 jsc#PED-9943).
- scsi: lpfc: Check SLI_ACTIVE flag in FDMI cmpl before submitting
  follow up FDMI (bsc#1233241 jsc#PED-9943).
- scsi: lpfc: Update lpfc_els_flush_cmd() to check for SLI_ACTIVE
  before BSG flag (bsc#1233241 jsc#PED-9943).
- scsi: lpfc: Call lpfc_sli4_queue_unset() in restart and rmmod
  paths (bsc#1233241 jsc#PED-9943).
- scsi: lpfc: Check devloss callbk done flag for potential stale
  NDLP ptrs (bsc#1233241 jsc#PED-9943).
- scsi: lpfc: Modify CGN warning signal calculation based on
  EDC response (bsc#1233241 jsc#PED-9943).
- commit 566c7c9
* Mon Dec  2 2024 mfranc@suse.cz
- drm/panthor: Lock XArray when getting entries for the VM
  (CVE-2024-53080 bsc#1233571).
- commit edfadb0
* Mon Dec  2 2024 vbabka@suse.cz
- mm: always initialise folio->_deferred_list (CVE-2024-53079
  bsc#1233570 prerequisity).
- commit 3c832a9
* Mon Dec  2 2024 pjakobsson@suse.de
- Update patches.suse/0906-drm-xe-bmg-Drop-force_probe-requirement.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022 jsc#PED-10840).
- commit 5193443
* Mon Dec  2 2024 osalvador@suse.de
- mm/hugetlb: fix nodes huge page allocation when there are
  surplus pages (bsc#1234012).
- commit 9fde6f7
* Mon Dec  2 2024 oneukum@suse.com
- Input: xpad - add support for MSI Claw A1M (git-fixes).
- commit d37ec4c
* Mon Dec  2 2024 oneukum@suse.com
- Input: xpad - add support for 8BitDo Ultimate 2C Wireless
  Controller (git-fixes).
- commit 0d7bec2
* Mon Dec  2 2024 oneukum@suse.com
- Input: xpad - add support for Machenike G5 Pro Controller
  (git-fixes).
- commit f071586
* Mon Dec  2 2024 oneukum@suse.com
- Input: xpad - sort xpad_device by vendor and product ID
  (git-fixes).
- Refresh
  patches.suse/Input-xpad-add-support-for-Snakebyte-GAMEPADs.patch.
- commit 5f46bd9
* Mon Dec  2 2024 oneukum@suse.com
- Input: xpad - add GameSir T4 Kaleid Controller support
  (git-fixes).
- commit d80239f
* Mon Dec  2 2024 hare@suse.de
- Revert atomic queue_limit API change (bsc#1233290)
- Delete
  patches.suse/block-Drop-locking-annotation-for-limits_lock.patch.
- Delete
  patches.suse/block-add-an-API-to-atomically-update-queue-limits.patch.
- Delete patches.suse/block-add-back-disk_update_readahead.patch.
- Delete
  patches.suse/block-allow-device-to-have-both-virt_boundary_mask-and-max-segment-size.patch.
- Delete
  patches.suse/block-decouple-blk_set_stacking_limits-from-blk_set_.patch.
- Delete
  patches.suse/block-fix-virt_boundary-handling-in-blk_validate_limits.patch.
- Delete
  patches.suse/block-move-max_-open-active-_zones-to-struct-queue_limits.patch.
- Delete patches.suse/block-refactor-disk_update_readahead.patch.
- Delete patches.suse/block-remove-disk_update_readahead.patch.
- Delete
  patches.suse/block-set-default-max-segment-size-in-case-of-virt_boundary.patch.
- Delete
  patches.suse/megaraid_sas-don-t-set-QUEUE_FLAG_NOMERGES.patch.
- Delete
  patches.suse/mpt3sas_scsih-don-t-set-QUEUE_FLAG_NOMERGES.patch.
- Delete
  patches.suse/scsi-block-Add-a-helper-to-cancel-atomic-queue-limit-updates.patch.
- Delete
  patches.suse/scsi-bsg-Pass-queue_limits-to-bsg_setup_queue.patch.
- Delete
  patches.suse/scsi-core-Add-a-device_configure-method-to-the-host-template.patch.
- Delete
  patches.suse/scsi-core-Use-the-atomic-queue-limits-API-in-scsi_add_lun.patch.
- Delete
  patches.suse/scsi-libsas-Fix-the-failure-of-adding-phy-with-zero-address-to-port.patch.
- Delete
  patches.suse/scsi-megaraid_sas-Switch-to-using-device_configure.patch.
- Delete
  patches.suse/scsi-mpi3mr-Pass-queue_limits-to-bsg_setup_queue.patch.
- Delete
  patches.suse/scsi-mpi3mr-Switch-to-using-device_configure.patch.
- Delete
  patches.suse/scsi-mpt3sas-Switch-to-using-device_configure.patch.
- commit e9790ea
* Mon Dec  2 2024 oneukum@suse.com
- Input: xpad - add GameSir VID for Xbox One controllers
  (git-fixes).
- commit 993ca75
* Mon Dec  2 2024 oneukum@suse.com
- Input: xpad - fix support for some third-party controllers
  (git-fixes).
- commit 1d5b082
* Mon Dec  2 2024 oneukum@suse.com
- Input: xpad - spelling fixes for "Xbox" (git-fixes).
- Refresh
  patches.suse/Input-xpad-add-HyperX-Clutch-Gladiate-Support.patch.
- Refresh
  patches.suse/Input-xpad-add-Lenovo-Legion-Go-controllers.patch.
- Refresh patches.suse/Input-xpad-add-PXN-V900-support.patch.
- Refresh
  patches.suse/Input-xpad-add-additional-HyperX-Controller-Identifi.patch.
- Refresh
  patches.suse/Input-xpad-add-support-for-ASUS-ROG-RAIKIRI.patch.
- Refresh
  patches.suse/Input-xpad-add-support-for-Snakebyte-GAMEPADs.patch.
- commit 15a1c29
* Mon Dec  2 2024 vbabka@suse.cz
- mm: convert free_transhuge_folio() to
  folio_undo_large_rmappable() (CVE-2024-53079 bsc#1233570
  prerequisity).
- commit 4e7d9f6
* Mon Dec  2 2024 pjakobsson@suse.de
- i915: fix DRM_I915_GVT_KVMGT dependencies (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit d12a00e
* Mon Dec  2 2024 pjakobsson@suse.de
- drm/panic: Remove build time dependency with FRAMEBUFFER_CONSOLE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit a7f7d58
* Mon Dec  2 2024 tbogendoerfer@suse.de
- net: arc: fix the device for dma_map_single/dma_unmap_single
  (CVE-2024-50295 bsc#1233484).
- net: vertexcom: mse102x: Fix possible double free of TX skb
  (CVE-2024-50276 bsc#1233465).
- net: enetc: allocate vf_state during PF probes (CVE-2024-50298
  bsc#1233487).
- net: stmmac: TSO: Fix unbalanced DMA map/unmap for non-paged
  SKB data (CVE-2024-53058 bsc#1233552).
- commit ae38000
* Mon Dec  2 2024 pjakobsson@suse.de
- drm/panel: add BOE tv101wum-ll2 panel driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit fc683ef
* Mon Dec  2 2024 jroedel@suse.de
- x86/CPU/AMD: Clear virtualized VMLOAD/VMSAVE on Zen4 client
  (bsc#1233443).
- commit 5beba61
* Mon Dec  2 2024 jroedel@suse.de
- x86/sev: Dump SEV_STATUS (bsc#1234034).
- Refresh
  patches.suse/x86-CPU-AMD-Track-SNP-host-status-with-cc_platform_.
- commit a937731
* Mon Dec  2 2024 jroedel@suse.de
- x86/sev: Ensure that RMP table fixups are reserved
  (bsc#1234034).
- x86/sev: Add callback to apply RMP table fixups for kexec
  (bsc#1234034).
- x86/e820: Add a new e820 table update helper (bsc#1234034).
- commit 0ec52d7
* Mon Dec  2 2024 nik.borisov@suse.com
- x86: Increase brk randomness entropy for 64-bit systems (git-fixes).
- commit 7e88dd7
* Mon Dec  2 2024 nik.borisov@suse.com
- x86/resctrl: Remove hard-coded memory bandwidth limit (git-fixes).
- Refresh patches.suse/x86-resctrl-Annotate-get_mem_config-functions-as-__init.patch.
- commit 6888d66
* Mon Dec  2 2024 vkarasulli@suse.de
- Update
  patches.suse/ASoC-qcom-sc7280-Fix-missing-Soundwire-runtime-strea.patch
  (git-fixes CVE-2024-50105 bsc#1232879).
- Update
  patches.suse/ASoC-qcom-sdm845-add-missing-soundwire-runtime-strea.patch
  (git-fixes CVE-2024-50104 bsc#1232868).
- Update patches.suse/idpf-fix-idpf_vc_core_init-error-path.patch
  (jsc#PED-11153 CVE-2024-53064 bsc#1233558).
- Update
  patches.suse/net-hns3-fix-kernel-crash-when-uninstalling-driver.patch
  (jsc#PED-11472 CVE-2024-50296 bsc#1233485).
- Update
  patches.suse/wifi-iwlwifi-mvm-fix-6-GHz-scan-construction.patch
  (git-fixes CVE-2024-53055 bsc#1233550).
- commit 231cae2
* Mon Dec  2 2024 vkarasulli@suse.de
- Update
  patches.suse/ASoC-dapm-fix-bounds-checker-error-in-dapm_widget_li.patch
  (git-fixes CVE-2024-53045 bsc#1233524).
- Update
  patches.suse/ASoC-stm32-spdifrx-fix-dma-channel-release-in-stm32_.patch
  (git-fixes CVE-2024-50292 bsc#1233481).
- Update
  patches.suse/HID-core-zero-initialize-the-report-buffer.patch
  (git-fixes CVE-2024-50302 bsc#1233491).
- Update
  patches.suse/USB-serial-io_edgeport-fix-use-after-free-in-debug-p.patch
  (git-fixes CVE-2024-50267 bsc#1233456).
- Update patches.suse/can-bcm-Fix-UAF-in-bcm_proc_show.patch
  (bsc#1012628 CVE-2023-52922 bsc#1233977).
- Update
  patches.suse/drm-amdgpu-add-missing-size-check-in-amdgpu_debugfs_.patch
  (stable-fixes CVE-2024-50282 bsc#1233471).
- Update
  patches.suse/drm-amdgpu-fix-possible-UAF-in-amdgpu_cs_pass1.patch
  (jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070
  jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511
  jsc#PED-6041 jsc#PED-6069 jsc#PED-6071 CVE-2023-52921
  bsc#1233452).
- Update
  patches.suse/drm-amdgpu-prevent-NULL-pointer-dereference-if-ATIF-.patch
  (git-fixes CVE-2024-53060 bsc#1233554).
- Update
  patches.suse/firmware-arm_scmi-Fix-slab-use-after-free-in-scmi_bu.patch
  (git-fixes CVE-2024-53068 bsc#1233561).
- Update
  patches.suse/fs-Fix-uninitialized-value-issue-in-from_kuid-and-from_kgid.patch
  (git-fixes CVE-2024-53101 bsc#1233769).
- Update
  patches.suse/i40e-fix-race-condition-by-adding-filter-s-intermedi.patch
  (git-fixes CVE-2024-53088 bsc#1233580).
- Update
  patches.suse/iio-gts-helper-Fix-memory-leaks-for-the-error-path-o.patch
  (git-fixes CVE-2024-53076 bsc#1233567).
- Update
  patches.suse/io_uring-rw-fix-missing-NOWAIT-check-for-O_DIRECT-st.patch
  (git-fixes CVE-2024-53052 bsc#1233548).
- Update
  patches.suse/media-ar0521-don-t-overflow-when-checking-PLL-values.patch
  (git-fixes CVE-2024-53081 bsc#1233572).
- Update
  patches.suse/media-cx24116-prevent-overflows-on-SNR-calculus.patch
  (git-fixes CVE-2024-50290 bsc#1233479).
- Update
  patches.suse/media-dvbdev-prevent-the-risk-of-out-of-memory-acces.patch
  (git-fixes CVE-2024-53063 bsc#1233557).
- Update
  patches.suse/media-s5p-jpeg-prevent-buffer-overflows.patch
  (git-fixes CVE-2024-53061 bsc#1233555).
- Update
  patches.suse/media-v4l2-tpg-prevent-the-risk-of-a-division-by-zer.patch
  (git-fixes CVE-2024-50287 bsc#1233476).
- Update
  patches.suse/nfs-Fix-KMSAN-warning-in-decode_getfattr_attrs.patch
  (git-fixes CVE-2024-53066 bsc#1233560).
- Update
  patches.suse/ocfs2-remove-entry-once-instead-of-null-ptr-dereference-in-ocfs2_xa_remove.patch
  (git-fixes CVE-2024-50265 bsc#1233454).
- Update
  patches.suse/platform-x86-amd-pmc-Detect-when-STB-is-not-availabl.patch
  (git-fixes CVE-2024-53072 bsc#1233564).
- Update
  patches.suse/posix-clock-posix-clock-Fix-unbalanced-locking-in-pc.patch
  (CVE-2024-50195 bsc#1233103 CVE-2024-50210 bsc#1233097).
- Update
  patches.suse/scsi-wd33c93-Don-t-use-stale-scsi_pointer-value.patch
  (git-fixes CVE-2024-50026 bsc#1231952).
- Update
  patches.suse/security-keys-fix-slab-out-of-bounds-in-key_task_per.patch
  (git-fixes CVE-2024-50301 bsc#1233490).
- Update
  patches.suse/tpm-Lock-TPM-chip-in-tpm_pm_suspend-first.patch
  (bsc#1082555 git-fixes CVE-2024-53085 bsc#1233577).
- Update
  patches.suse/usb-musb-sunxi-Fix-accessing-an-released-usb-phy.patch
  (git-fixes CVE-2024-50269 bsc#1233458).
- Update
  patches.suse/usb-typec-fix-potential-out-of-bounds-in-ucsi_ccg_up.patch
  (git-fixes CVE-2024-50268 bsc#1233457).
- Update
  patches.suse/wifi-iwlwifi-mvm-Fix-response-handling-in-iwl_mvm_se.patch
  (git-fixes CVE-2024-53059 bsc#1233553).
- Update
  patches.suse/wifi-iwlwifi-mvm-don-t-leak-a-link-on-AP-removal.patch
  (git-fixes CVE-2024-53074 bsc#1233566).
- commit 5a024cd
* Mon Dec  2 2024 nik.borisov@suse.com
- x86/tdx: Enable CPU topology enumeration (git-fixes).
- commit cf1674b
* Mon Dec  2 2024 nik.borisov@suse.com
- x86/tdx: Dynamically disable SEPT violations from causing #VEs (git-fixes).
- commit 29f8884
* Mon Dec  2 2024 nik.borisov@suse.com
- x86/tdx: Rename tdx_parse_tdinfo() to tdx_setup() (git-fixes).
- commit a66f7df
* Mon Dec  2 2024 nik.borisov@suse.com
- x86/tdx: Introduce wrappers to read and write TD metadata (git-fixes).
- commit 182660e
* Mon Dec  2 2024 nik.borisov@suse.com
- x86/microcode/intel: Remove unnecessary cache writeback and invalidation (git-fixes).
- commit dc97c33
* Mon Dec  2 2024 nik.borisov@suse.com
- blacklist.conf: FRED is not supported on SLE15-SP6
- commit 0e4192c
* Mon Dec  2 2024 nik.borisov@suse.com
- x86/traps: move kmsan check after instrumentation_begin (git-fixes).
- commit 788cc4b
* Mon Dec  2 2024 nik.borisov@suse.com
- x86: fix off-by-one in access_ok() (git-fixes).
- commit ada1011
* Mon Dec  2 2024 nik.borisov@suse.com
- x86/syscall: Avoid memcpy() for ia32 syscall_get_arguments() (git-fixes).
- commit a421b7f
* Mon Dec  2 2024 nik.borisov@suse.com
- blacklist.conf: LAM is disabled
- commit 616d7eb
* Sun Dec  1 2024 tiwai@suse.de
- tools/power turbostat: Fix trailing '\n' parsing (git-fixes).
- modpost: remove incorrect code in do_eisa_entry() (git-fixes).
- rtc: ab-eoz9: don't fail temperature reads on undervoltage
  notification (git-fixes).
- rtc: rzn1: fix BCD to rtc_time conversion errors (git-fixes).
- rtc: check if __rtc_read_time was successful in
  rtc_timer_do_work() (git-fixes).
- rtc: abx80x: Fix WDT bit position of the status register
  (git-fixes).
- rtc: bbnsm: add remove hook (git-fixes).
- rtc: st-lpc: Use IRQF_NO_AUTOEN flag in request_irq()
  (git-fixes).
- tty: ldsic: fix tty_ldisc_autoload sysctl's proc_handler
  (git-fixes).
- serial: 8250: omap: Move pm_runtime_get_sync (git-fixes).
- commit 003de2e
* Sat Nov 30 2024 tiwai@suse.de
- ALSA: hda/tas2781: Add speaker id check for ASUS projects
  (stable-fixes).
- commit a62820c
* Sat Nov 30 2024 tiwai@suse.de
- ASoC: mediatek: Check num_codecs is not zero to avoid panic
  during probe (git-fixes).
- ASoC: imx-audmix: Add NULL check in imx_audmix_probe
  (git-fixes).
- ALSA: rawmidi: Fix kvfree() call in spinlock (git-fixes).
- commit aa98051
* Sat Nov 30 2024 tiwai@suse.de
- USB: chaoskey: Fix possible deadlock chaoskey_list_lock
  (git-fixes).
- commit bc5d0b3
* Sat Nov 30 2024 tiwai@suse.de
- ALSA: hda: Show the codec quirk info at probing (stable-fixes).
- ALSA: hda/realtek: Set PCBeep to default value for ALC274
  (stable-fixes).
- ALSA: usb-audio: Fix out of bounds reads when finding clock
  sources (stable-fixes).
- ALSA: pcm: Add sanity NULL check for the default mmap fault
  handler (stable-fixes).
- commit 0da3d44
* Sat Nov 30 2024 tiwai@suse.de
- drm/amd/display: Fix null check for pipe_ctx->plane_state in
  hwss_setup_dpp (git-fixes).
- drm/amd/display: Fix null check for pipe_ctx->plane_state in
  dcn20_program_pipe (git-fixes).
- drm/amd: Add some missing straps from NBIO 7.11.0 (git-fixes).
- ASoC: SOF: ipc3-topology: Convert the topology pin index to
  ALH dai index (git-fixes).
- ASoC: amd: yc: Fix for enabling DMIC on acp6x via _DSD entry
  (git-fixes).
- ALSA: ump: Fix evaluation of MIDI 1.0 FB info (git-fixes).
- ALSA: hda/realtek: Update ALC225 depop procedure (git-fixes).
- ALSA: usb-audio: Fix potential out-of-bound accesses for Extigy
  and Mbox devices (git-fixes).
- ALSA: hda/realtek: Update ALC256 depop procedure (git-fixes).
- ALSA: ac97: bus: Fix the mistake in the comment (git-fixes).
- =?UTF-8?q?iio:=20accel:=20kxcjk-1013:=20Remove=20redundan?=
  =?UTF-8?q?t=20I=C2=B2C=20ID?= (git-fixes).
- iio: Fix fwnode_handle in __fwnode_iio_channel_get_by_name()
  (git-fixes).
- iio: accel: kx022a: Fix raw read format (git-fixes).
- iio: gts: fix infinite loop for gain_to_scaletables()
  (git-fixes).
- iio: gts: Fix uninitialized symbol 'ret' (git-fixes).
- ad7780: fix division by zero in ad7780_write_raw() (git-fixes).
- iio: adc: ad7923: Fix buffer overflow for tx_buf and ring_xfer
  (git-fixes).
- comedi: Flush partial mappings in error case (git-fixes).
- goldfish: Fix unused const variable 'goldfish_pipe_acpi_match'
  (git-fixes).
- iio: adc: ad7606: Fix typo in the driver name (git-fixes).
- iio: light: al3010: Fix an error handling path in al3010_probe()
  (git-fixes).
- misc: apds990x: Fix missing pm_runtime_disable() (git-fixes).
- firmware_loader: Fix possible resource leak in
  fw_log_firmware_info() (git-fixes).
- usb: dwc3: gadget: Fix looping of queued SG entries (git-fixes).
- usb: dwc3: gadget: Fix checking for number of TRBs left
  (git-fixes).
- Revert "usb: gadget: composite: fix OS descriptors w_value
  logic" (git-fixes).
- usb: ehci-spear: fix call balance of sehci clk handling routines
  (git-fixes).
- USB: serial: ftdi_sio: Fix atomicity violation in
  get_serial_info() (git-fixes).
- usb: dwc3: gadget: Add missing check for single port RAM in
  TxFIFO resizing logic (git-fixes).
- usb: musb: Fix hardware lockup on first Rx endpoint request
  (git-fixes).
- usb: xhci: Fix TD invalidation under pending Set TR Dequeue
  (git-fixes).
- USB: chaoskey: fail open after removal (git-fixes).
- usb: yurex: make waiting on yurex_write interruptible
  (git-fixes).
- usb: using mutex lock and supporting O_NONBLOCK flag in
  iowarrior_read() (git-fixes).
- apparmor: fix 'Do simple duplicate message elimination'
  (git-fixes).
- apparmor: test: Fix memory leak for aa_unpack_strdup()
  (git-fixes).
- apparmor: use kvfree_sensitive to free data->data (git-fixes).
- commit 875afee
* Fri Nov 29 2024 trenn@suse.com
- powercap: intel_rapl_tpmi: Enable PMU support (jsc#PED-10410).
- commit c9bae94
* Fri Nov 29 2024 trenn@suse.com
- powercap: intel_rapl: Introduce APIs for PMU support
  (jsc#PED-10410).
- commit fabdbde
* Fri Nov 29 2024 trenn@suse.com
- powercap: intel_rapl: Sort header files (jsc#PED-10410).
- commit 018ac73
* Fri Nov 29 2024 trenn@suse.com
- powercap: intel_rapl: Fix locking in TPMI RAPL (jsc#PED-4897).
- commit ea1ecdd
* Fri Nov 29 2024 mgorman@suse.de
- blacklist.conf: SCX-specific and SCX is not backported
- commit 199461a
* Fri Nov 29 2024 mgorman@suse.de
- media: gpio-ir-tx: Remove redundant call to local_irq_disable()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- media: gpio-ir-tx: Driver does not behave with PREEMPT_RT
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- hrtimers: Add missing hrtimer_init() trace points (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- posix-timers: Replace call_rcu() by kfree_rcu() for simple
  kmem_cache_free() callback (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- softirq: Use a dedicated thread for timer wakeups on PREEMPT_RT
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers: Use __raise_softirq_irqoff() to raise the softirq
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- hrtimer: Use __raise_softirq_irqoff() to raise the softirq
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- sched: No PREEMPT_RT=y for all{yes,mod}config (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- locking/rtmutex: Fix misleading comment (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- locking/rt: Annotate unlock followed by lock for sparse
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- locking/rt: Add sparse annotation for RCU (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- locking/rt: Remove one __cond_lock() in RT's
  spin_trylock_irqsave() (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- locking/rt: Add sparse annotation PREEMPT_RT's sleeping locks
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- sched/timers: Explain why idle task schedules out on remote
  timer enqueue (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit b4cc41a
* Fri Nov 29 2024 mgorman@suse.de
- sched: Restructure sched_class order sanity checks in
  sched_init() (bsc#1233998 (Scheduler functional and performance
  backports)).
- sched/cpufreq: Use NSEC_PER_MSEC for deadline task (bsc#1233998
  (Scheduler functional and performance backports)).
- sched/core: Introduce SM_IDLE and an idle re-entry fast-path in
  __schedule() (bsc#1233998 (Scheduler functional and performance
  backports)).
- sched/deadline: Comment sched_dl_entity::dl_server variable
  (bsc#1233998 (Scheduler functional and performance backports)).
- sched/core: Add WARN_ON_ONCE() to check overflow for
  migrate_disable() (bsc#1233998 (Scheduler functional and
  performance backports)).
- cgroup/cpuset: Remove cpuset_slab_spread_rotor (bsc#1233998
  (Scheduler functional and performance backports)).
- sched: Remove vruntime from trace_sched_stat_runtime()
  (bsc#1233998 (Scheduler functional and performance backports)).
- sched: Unify runtime accounting across classes (bsc#1233998
  (Scheduler functional and performance backports)).
- sched/fair: Propagate enqueue flags into place_entity()
  (bsc#1233998 (Scheduler functional and performance backports)).
- commit 596a6e8
* Fri Nov 29 2024 dfaggioli@suse.com
- bpf, vsock: Drop static vsock_bpf_prot initialization (git-fixes).
- commit 939d649
* Fri Nov 29 2024 dfaggioli@suse.com
- vsock: Update msg_count on read_skb() (git-fixes).
- commit fce5f41
* Fri Nov 29 2024 dfaggioli@suse.com
- vsock: Update rx_bytes on read_skb() (git-fixes, bsc#1233320,
  CVE-2024-50169).
- commit acfc5df
* Fri Nov 29 2024 dfaggioli@suse.com
- bpf, sockmap: SK_DROP on attempted redirects of unsupported af_vsock (git-fixes).
- commit 8db08f8
* Fri Nov 29 2024 pjakobsson@suse.de
- blacklist.conf: Remove alt-commits from blacklist
- Refresh
  patches.suse/0008-drm-xe-Use-write-back-caching-mode-for-system-memory.patch.
- Refresh
  patches.suse/0009-drm-xe-display-xe_hdcp_gsc-Free-arbiter-on-driver-re.patch.
- Refresh
  patches.suse/2336-drm-xe-uapi-Rename-xe-perf-layer-as-xe-observation-l.patch.
- Refresh
  patches.suse/2337-drm-xe-Drop-trace_xe_hw_fence_free.patch.
- Refresh
  patches.suse/2407-drm-i915-dp-Reset-intel_dp-link_trained-before-retra.patch.
- Refresh
  patches.suse/2409-drm-xe-exec-Fix-minor-bug-related-to-xe_sync_entry_c.patch.
- Refresh
  patches.suse/2410-drm-xe-pf-Limit-fair-VF-LMEM-provisioning.patch.
- Refresh patches.suse/2411-drm-xe-Wedge-the-entire-device.patch.
- Refresh
  patches.suse/2412-drm-xe-Don-t-suspend-device-upon-wedge.patch.
- Refresh
  patches.suse/2432-drm-i915-Allow-NULL-memory-region.patch.
- Refresh patches.suse/2434-drm-amdgpu-Fix-atomics-on-GFX12.patch.
- Refresh
  patches.suse/2436-drm-amdgpu-Add-empty-HDP-flush-function-to-JPEG-v4.0.patch.
- Refresh
  patches.suse/2437-drm-amdgpu-Add-empty-HDP-flush-function-to-VCN-v4.0..patch.
- Refresh
  patches.suse/2438-drm-amdgpu-vcn-Use-offsets-local-to-VCN-JPEG-in-VF.patch.
- Refresh
  patches.suse/2440-drm-amd-display-Remove-ASSERT-if-significance-is-zer.patch.
- Refresh
  patches.suse/2441-drm-amdgpu-fix-ras-UE-error-injection-failure-issue.patch.
- Refresh
  patches.suse/2442-drm-amdgpu-Fix-eeprom-max-record-count.patch.
- Refresh
  patches.suse/2443-drm-amdgpu-add-missed-harvest-check-for-VCN-IP-v4-v5.patch.
- Refresh
  patches.suse/2448-drm-amdgpu-Fix-APU-handling-in-amdgpu_pm_load_smu_fi.patch.
- Refresh
  patches.suse/2456-drm-v3d-Fix-potential-memory-leak-in-the-timestamp-e.patch.
- Refresh
  patches.suse/2457-drm-v3d-Fix-potential-memory-leak-in-the-performance.patch.
- Refresh
  patches.suse/2458-drm-v3d-Validate-passed-in-drm-syncobj-handles-in-th.patch.
- Refresh
  patches.suse/2459-drm-v3d-Validate-passed-in-drm-syncobj-handles-in-th.patch.
- Refresh
  patches.suse/2478-drm-bridge-connector-Fix-double-free-in-error-handli.patch.
- Refresh
  patches.suse/2481-drm-amd-display-Add-missing-DET-segments-programming.patch.
- Refresh
  patches.suse/2482-drm-amd-display-Add-dcc-propagation-value.patch.
- Refresh
  patches.suse/2483-drm-amd-display-Add-missing-mcache-registers.patch.
- Refresh
  patches.suse/2484-drm-amd-pm-update-powerplay-structure-on-smu-v14.0.2.patch.
- Refresh
  patches.suse/2485-drm-amdgpu-force-to-use-legacy-inv-in-mmhub.patch.
- Refresh
  patches.suse/2486-drm-amd-display-Add-missing-DCN314-to-the-DML-Makefi.patch.
- Refresh
  patches.suse/2487-drm-amd-display-Add-missing-program-DET-segment-call.patch.
- Refresh
  patches.suse/2488-drm-buddy-Add-start-address-support-to-trim-function.patch.
- Refresh
  patches.suse/2489-drm-amdgpu-add-golden-setting-for-gc-v12.patch.
- Refresh
  patches.suse/2491-drm-amdgpu-change-non-dcc-buffer-copy-configuration.patch.
- Refresh
  patches.suse/2493-drm-amdgpu-Add-address-alignment-support-to-DCC-buff.patch.
- Refresh patches.suse/2494-drm-amdgpu-correct-sdma7-max-dw.patch.
- Refresh
  patches.suse/2495-drm-amdgpu-Add-DCC-GFX12-flag-to-enable-address-alig.patch.
- Refresh
  patches.suse/2496-drm-xe-rtp-Fix-off-by-one-when-processing-rules.patch.
- Refresh
  patches.suse/2497-drm-xe-Use-dma_fence_chain_free-in-chain-fence-unuse.patch.
- Refresh
  patches.suse/2498-drm-xe-hwmon-Fix-PL1-disable-flow-in-xe_hwmon_power_.patch.
- Refresh
  patches.suse/2499-drm-xe-Take-ref-to-VM-in-delayed-snapshot.patch.
- Refresh
  patches.suse/2500-drm-i915-display-correct-dual-pps-handling-for-MTL_P.patch.
- Refresh
  patches.suse/2503-drm-i915-Allow-evicting-to-use-the-requested-placeme.patch.
- Refresh
  patches.suse/2504-drm-i915-Attempt-to-get-pages-without-eviction-first.patch.
- Refresh
  patches.suse/2505-drm-amdgpu-mes-fix-mes-ring-buffer-overflow.patch.
- Refresh
  patches.suse/2507-drm-amd-display-Enable-otg-synchronization-logic-for.patch.
- Refresh
  patches.suse/2508-drm-amd-display-Fix-MST-BW-calculation-Regression.patch.
- Refresh
  patches.suse/2514-drm-amdgpu-mes12-update-mes_v12_api_def.h.patch.
- Refresh
  patches.suse/2515-drm-amdgpu-mes-add-multiple-mes-ring-instances-suppo.patch.
- Refresh
  patches.suse/2516-drm-amdgpu-mes12-load-unified-mes-fw-on-pipe0-and-pi.patch.
- Refresh
  patches.suse/2517-drm-amdgpu-mes12-add-mes-pipe-switch-support.patch.
- Refresh
  patches.suse/2519-drm-amdgpu-mes12-configure-two-pipes-hardware-resour.patch.
- Refresh
  patches.suse/2520-drm-amdgpu-mes12-sw-hw-fini-for-unified-mes.patch.
- Refresh
  patches.suse/2521-drm-amdgpu-mes12-fix-suspend-issue.patch.
- Refresh
  patches.suse/2522-drm-amd-amdgpu-command-submission-parser-for-JPEG.patch.
- Refresh
  patches.suse/2523-drm-amdgpu-Update-kmd_fw_shared-for-VCN5.patch.
- Refresh
  patches.suse/2524-drm-amd-amdgpu-add-HDP_SD-support-on-gc-12.0.0-1.patch.
- Refresh
  patches.suse/2529-drm-xe-Validate-user-fence-during-creation.patch.
- Refresh
  patches.suse/2530-drm-xe-Move-part-of-xe_file-cleanup-to-a-helper.patch.
- Refresh
  patches.suse/2531-drm-xe-Add-ref-counting-for-xe_file.patch.
- Refresh
  patches.suse/2532-drm-xe-Take-a-ref-to-xe-file-when-user-creates-a-VM.patch.
- Refresh
  patches.suse/2533-drm-xe-Fix-use-after-free-when-client-stats-are-capt.patch.
- Refresh
  patches.suse/2534-drm-xe-vf-Fix-register-value-lookup.patch.
- Refresh
  patches.suse/2535-drm-xe-Build-PM-into-GuC-CT-layer.patch.
- Refresh
  patches.suse/2536-drm-xe-pf-Fix-VF-config-validation-on-multi-GT-platf.patch.
- Refresh
  patches.suse/2537-drm-xe-Add-xe_gt_tlb_invalidation_fence_init-helper.patch.
- Refresh
  patches.suse/2538-drm-xe-Drop-xe_gt_tlb_invalidation_wait.patch.
- Refresh
  patches.suse/2539-drm-xe-Hold-a-PM-ref-when-GT-TLB-invalidations-are-i.patch.
- Refresh
  patches.suse/2551-drm-amdgpu-fixing-rlc-firmware-loading-failure-issue.patch.
- Refresh
  patches.suse/2554-drm-amdgpu-fix-eGPU-hotplug-regression.patch.
- Refresh
  patches.suse/2555-drm-i915-hdcp-Use-correct-cp_irq_count.patch.
- Refresh patches.suse/2557-drm-xe-Fix-opregion-leak.patch.
- Refresh
  patches.suse/2558-drm-xe-observation-Drop-empty-sysctl-table-entry.patch.
- Refresh
  patches.suse/2559-drm-xe-Move-VM-dma-resv-lock-from-xe_exec_queue_crea.patch.
- Refresh patches.suse/2560-drm-xe-Fix-tile-fini-sequence.patch.
- Refresh
  patches.suse/2561-drm-xe-prevent-UAF-around-preempt-fence.patch.
- Refresh
  patches.suse/2562-drm-xe-display-Make-display-suspend-resume-work-on-d.patch.
- Refresh
  patches.suse/2563-drm-xe-oa-uapi-Make-bit-masks-unsigned.patch.
- Refresh
  patches.suse/2564-drm-xe-bmg-implement-Wa_16023588340.patch.
- Refresh
  patches.suse/2566-drm-xe-xe2lpg-Extend-workaround-14021402888.patch.
- Refresh
  patches.suse/2567-drm-xe-xe2-Make-subsequent-L2-flush-sequential.patch.
- Refresh patches.suse/2568-drm-xe-xe2-Add-Wa_15015404425.patch.
- Refresh patches.suse/2569-drm-xe-fix-WA-14018094691.patch.
- Refresh
  patches.suse/2570-drm-xe-xe2hpg-Add-Wa_14021821874.patch.
- Refresh
  patches.suse/2571-drm-xe-use-devm-instead-of-drmm-for-managed-bo.patch.
- Refresh
  patches.suse/2572-drm-xe-uc-Use-devm-to-register-cleanup-that-includes.patch.
- Refresh
  patches.suse/2573-drm-xe-Fix-missing-workqueue-destroy-in-xe_gt_pagefa.patch.
- Refresh
  patches.suse/2574-drm-xe-Drop-HW-fence-pointer-to-HW-fence-ctx.patch.
- Refresh
  patches.suse/2575-drm-xe-Free-job-before-xe_exec_queue_put.patch.
- Refresh
  patches.suse/2577-drm-amdgpu-smu13.0.7-print-index-for-profiles.patch.
- Refresh
  patches.suse/2579-drm-amd-pm-update-message-interface-for-smu-v14.0.2-.patch.
- Refresh
  patches.suse/2580-drm-amdgpu-gfx12-set-UNORD_DISPATCH-in-compute-MQDs.patch.
- Refresh
  patches.suse/2582-drm-amdgpu-support-for-gc_info-table-v1.3.patch.
- Refresh
  patches.suse/2583-drm-amd-pm-Add-support-for-new-P2S-table-revision.patch.
- Refresh
  patches.suse/2584-drm-amd-pm-Drop-unsupported-features-on-smu-v14_0_2.patch.
- Refresh
  patches.suse/2586-drm-i915-ARL-requires-a-newer-GSC-firmware.patch.
- Refresh patches.suse/2588-drm-xe-Invalidate-media_gt-TLBs.patch.
- Refresh
  patches.suse/2589-drm-xe-hwmon-Fix-WRITE_I1-param-from-u32-to-u16.patch.
- Refresh
  patches.suse/2596-drm-i915-Fix-readout-degamma_lut-mismatch-on-ilk-snb.patch.
- Refresh
  patches.suse/2599-drm-i915-display-Add-mechanism-to-use-sink-model-whe.patch.
- Refresh
  patches.suse/2600-drm-i915-display-Increase-Fast-Wake-Sync-length-as-a.patch.
- Refresh
  patches.suse/2601-drm-xe-gsc-Do-not-attempt-to-load-the-GSC-multiple-t.patch.
- Refresh
  patches.suse/2602-drm-xe-pcode-Treat-pcode-as-per-tile-rather-than-per.patch.
- Refresh
  patches.suse/2603-drm-xe-Add-missing-runtime-reference-to-wedged-upon-.patch.
- Refresh
  patches.suse/2604-drm-xe-display-Match-i915-driver-suspend-resume-sequ.patch.
- Refresh
  patches.suse/2605-drm-xe-Suspend-resume-user-access-only-during-system.patch.
- Refresh
  patches.suse/2606-drm-xe-display-Avoid-encoder_suspend-at-runtime-susp.patch.
- Refresh
  patches.suse/2617-drm-amd-display-Determine-IPS-mode-by-ASIC-and-PMFW-.patch.
- Refresh
  patches.suse/2618-drm-amdgpu-mes-add-mes-mapping-legacy-queue-switch.patch.
- Refresh
  patches.suse/2619-drm-amdgpu-always-allocate-cleared-VRAM-for-GEM-allo.patch.
- Refresh
  patches.suse/2620-drm-amd-display-Lock-DC-and-exit-IPS-when-changing-b.patch.
- Refresh
  patches.suse/2621-drm-amd-display-Block-timing-sync-for-different-sign.patch.
- Refresh
  patches.suse/2623-drm-amdkfd-Add-cache-line-size-info.patch.
- Refresh
  patches.suse/2625-drm-amd-display-Avoid-race-between-dcn35_set_drr-and.patch.
- Refresh
  patches.suse/2626-drm-amd-display-Do-not-reset-planes-based-on-crtc-zp.patch.
- Refresh
  patches.suse/2627-drm-amd-pm-update-the-features-set-on-smu-v14.0.2-3.patch.
- Refresh
  patches.suse/2628-drm-amd-pm-fix-the-pp_dpm_pcie-issue-on-smu-v14.0.2-.patch.
- Refresh
  patches.suse/2629-drm-amd-amdgpu-apply-command-submission-parser-for-J.patch.
- Refresh
  patches.suse/2630-drm-amd-amdgpu-apply-command-submission-parser-for-J.patch.
- Refresh
  patches.suse/2632-drm-amd-display-Add-all-planes-on-CRTC-to-state-for-.patch.
- Refresh
  patches.suse/2636-drm-stm-add-COMMON_CLK-dependency.patch.
- Refresh patches.suse/2638-drm-xe-gt-Remove-double-include.patch.
- Refresh
  patches.suse/2639-drm-xe-Remove-fence-check-from-send_tlb_invalidation.patch.
- Refresh
  patches.suse/2640-drm-xe-Fix-possible-UAF-in-guc_exec_queue_process_ms.patch.
- Refresh
  patches.suse/2641-drm-xe-Fix-access_ok-check-in-user_fence_create.patch.
- Refresh
  patches.suse/2642-drm-xe-display-fix-compat-IS_DISPLAY_STEP-range-end.patch.
- Refresh
  patches.suse/2644-drm-xe-client-fix-deadlock-in-show_meminfo.patch.
- Refresh
  patches.suse/2645-drm-xe-client-add-missing-bo-locking-in-show_meminfo.patch.
- Refresh
  patches.suse/drm-amd-amdgpu-Fix-uninitialized-variable-warnings.patch.
- Refresh
  patches.suse/drm-amd-display-Avoid-race-between-dcn10_set_drr-and.patch.
- Refresh
  patches.suse/drm-amd-display-Check-for-NULL-pointer.patch.
- Refresh
  patches.suse/drm-amd-display-Replace-dm_execute_dmub_cmd-with-dc_.patch.
- Refresh
  patches.suse/drm-amd-display-Skip-Recompute-DSC-Params-if-no-Stre.patch.
- Refresh
  patches.suse/drm-amd-display-fix-s2idle-entry-for-DCN3.5.patch.
- Refresh
  patches.suse/drm-amdgpu-Actually-check-flags-for-all-context-ops.patch.
- Refresh
  patches.suse/drm-amdgpu-Forward-soft-recovery-errors-to-userspace.patch.
- Refresh
  patches.suse/drm-amdgpu-atomfirmware-Silence-UBSAN-warning.patch.
- Refresh
  patches.suse/drm-amdgpu-fix-contiguous-handling-for-IB-parsing-v2.patch.
- Refresh
  patches.suse/drm-amdgpu-jpeg2-properly-set-atomics-vmid-field.patch.
- Refresh
  patches.suse/drm-amdgpu-jpeg4-properly-set-atomics-vmid-field.patch.
- Refresh
  patches.suse/drm-amdgpu-reset-vm-state-machine-after-gpu-reset-vr.patch.
- Refresh
  patches.suse/drm-amdgpu-sdma5.2-Update-wptr-registers-as-well-as-.patch.
- Refresh
  patches.suse/drm-amdgpu-sdma5.2-limit-wptr-workaround-to-sdma-5.2.patch.
- Refresh
  patches.suse/drm-amdgpu-swsmu-always-force-a-state-reprogram-on-i.patch.
- Refresh
  patches.suse/drm-i915-Do-not-attempt-to-load-the-GSC-multiple-tim.patch.
- Refresh
  patches.suse/drm-i915-Fix-possible-int-overflow-in-skl_ddi_calcul.patch.
- Refresh
  patches.suse/drm-i915-dp-Don-t-switch-the-LTTPR-mode-on-an-active.patch.
- Refresh
  patches.suse/drm-i915-dsi-Make-Lenovo-Yoga-Tab-3-X90F-DMI-match-l.patch.
- Refresh
  patches.suse/drm-i915-fence-Mark-debug_fence_free-with-__maybe_un.patch.
- Refresh
  patches.suse/drm-i915-fence-Mark-debug_fence_init_onstack-with-__.patch.
- Refresh
  patches.suse/drm-i915-gem-Adjust-vma-offset-for-framebuffer-mmap-.patch.
- Refresh
  patches.suse/drm-i915-gem-Fix-Virtual-Memory-mapping-boundaries-c.patch.
- Refresh
  patches.suse/drm-i915-gt-Do-not-consider-preemption-during-execli.patch.
- Refresh
  patches.suse/drm-i915-hdcp-Fix-HDCP2_STREAM_STATUS-macro.patch.
- Refresh
  patches.suse/drm-nouveau-prime-fix-refcount-underflow.patch.
- Refresh
  patches.suse/i915-perf-Remove-code-to-update-PWR_CLK_STATE-for-ge.patch.
- commit f704b1e
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/915/lspcon: Reduce dmesg errors during lspcon_init failure (bsc#1193599).
- commit 30ee9a5
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/lspcon: Separate out function to set pcon mode (bsc#1193599).
- commit 88e5572
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/lspcon: Separate out function to get expected mode (bsc#1193599).
- commit 02d318e
* Fri Nov 29 2024 trenn@suse.com
- platform/x86: ISST: Fix return value on last invalid resource
  (jsc#PED-10408).
- commit 9eab587
* Fri Nov 29 2024 trenn@suse.com
- platform/x86: ISST: fix use-after-free in tpmi_sst_dev_remove()
  (jsc#PED-10408).
- commit 93a89b6
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/v3d: Size the kperfmon_ids array at runtime (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2455-drm-v3d-Prevent-out-of-bounds-access-in-performance-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022 CVE-2024-42264 bsc#1229333 CVE-2024-49984 bsc#1232095).
- Delete patches.suse/drm-v3d-Prevent-out-of-bounds-access-in-performance-.patch.
- commit 1c4f8c8
* Fri Nov 29 2024 mgorman@suse.de
- mm: revert "mm: shmem: fix data-race in shmem_getattr()"
  (CVE-2024-50228, bsc#1233204, git fixes (mm/shmem)).
  CVE is likely a non-issue while the fix introduces real bugs.
- commit b77756a
* Fri Nov 29 2024 pjakobsson@suse.de
- video/aperture: optionally match the device in sysfb_disable() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/0001-bsc-1204315-Disable-sysfb-before-creating-simple-fra.patch.
- commit 3faae8b
* Fri Nov 29 2024 trenn@suse.com
- platform/x86: ISST: Use in_range() to check package ID validity
  (jsc#PED-10408).
- commit e824409
* Fri Nov 29 2024 trenn@suse.com
- platform/x86: ISST: Support partitioned systems (jsc#PED-10408).
- commit 1aa2f04
* Fri Nov 29 2024 trenn@suse.com
- platform/x86: ISST: Shorten the assignments for
  power_domain_info (jsc#PED-10408).
- commit 1abcfa6
* Fri Nov 29 2024 trenn@suse.com
- platform/x86: ISST: Use local variable for auxdev->dev
  (jsc#PED-10408).
- commit e230c56
* Fri Nov 29 2024 pjakobsson@suse.de
- Revert "drm/amd/pm: correct the workload setting" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d0c422
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/oa: Fix "Missing outer runtime PM protection" warning (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6485c3d
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: handle flat ccs during hibernation on igpu (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ebc9198
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: improve hibernation on igpu (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d5d847f
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Restore system memory GGTT mappings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5236c3b
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Ensure all locks released in exec IOCTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 00fb31f
* Fri Nov 29 2024 pjakobsson@suse.de
- Revert "drm/amd/display: parse umc_info or vram_info based on ASIC" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5d480a0
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Fix failure to read vram info due to static (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d84932a
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: enable GTT fallback handling for dGPUs only (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4e1696f
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: correct kiq unmap latency (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ae46e0
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/pm: print pp_dpm_mclk in ascending order on SMU v14.0.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 584ea9f
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: Fix video caps for H264 and HEVC encode maximum size (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1dbf7f8
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Require minimum VBlank size for stutter optimization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0039135
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Handle dml allocation failure to avoid crash (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7c26c8b
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Fix Panel Replay not update screen correctly (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f6d5198
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Change some variable name of psr (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f9a90a2
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/vmwgfx: avoid null_ptr_deref in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a80cc5b
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/panthor: Fix handling of partial GPU mapping of BOs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cac8ac0
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915: Grab intel_display from the encoder to avoid potential (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 641168d
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/gsc: ARL-H and ARL-U need a newer GSC FW. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 225a19d
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Stop accumulating LRC timestamp on job_free (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9a41276
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/pf: Fix potential GGTT allocation leak (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 80d2db6
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Drop VM dma-resv lock on xe_sync_in_fence_get failure in exec (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 294dc7e
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Fix possible exec queue leak in exec IOCTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8bc8b42
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/guc/tlb: Flush g2h worker in case of tlb timeout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit db21bab
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/ufence: Flush xe ordered_wq in case of ufence timeout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d7b7970
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Move LNL scheduling WA to xe_device.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2de3d0b
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Use the filelist from drm for ccs_mode change (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ab605fa
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Set mask bits for CCS_MODE register (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6296d61
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/panthor: Be stricter about IO mapping flags (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 04f0b8f
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/panthor: Lock XArray when getting entries for the VM (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9e36da3
* Fri Nov 29 2024 pjakobsson@suse.de
- drm: panel-orientation-quirks: Make Lenovo Yoga Tab 3 X90F DMI match (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 74bdce0
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/imagination: Break an object reference loop (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 69d852c
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/imagination: Add a per-file PVR context list (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d62da15
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/pm: correct the workload setting (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 62fe862
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/pm: always pick the pptable from IFWI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 56f4ffe
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: parse umc_info or vram_info based on ASIC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit abbe215
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Fix brightness level not retained over reboot (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-amd-display-Fix-brightness-level-not-retained-ov.patch.
- commit ca2e05c
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Don't short circuit TDR on jobs not started (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 77bfceb
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Add mmio read before GGTT invalidate (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit df396b1
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/display: Add missing HPD interrupt enabling during non-d3cold (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b72ba34
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/display: Separate the d3cold and non-d3cold runtime PM (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 904117a
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Remove runtime argument from display s/r functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 71b2d16
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/mediatek: Fix potential NULL dereference in mtk_crtc_destroy() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa35d11
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/mediatek: Fix color format MACROs in OVL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4754217
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/mediatek: Add blend_modes to mtk_plane_init() for different SoCs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ce1e443
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/mediatek: ovl: Add blend_modes to driver data (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d6fdc6
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/mediatek: ovl: Remove the color format comment for (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f7d361e
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/mediatek: ovl: Refine ignore_pixel_alpha comment and placement (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d71012
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/mediatek: ovl: Fix XRGB format breakage for blend_modes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e34ff31
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/smu13: fix profile reporting (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ff0e08a
* Fri Nov 29 2024 pjakobsson@suse.de
- Revert "drm/amd/display: update DML2 policy (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9757f1d
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/tests: hdmi: Fix memory leaks in drm_display_mode_from_cea_vic() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 61ec93d
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/connector: hdmi: Fix memory leak in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c07fa74
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/tests: helpers: Add helper for drm_display_mode_from_cea_vic() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 748ffac
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/panthor: Report group as timedout when we fail to properly (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 79da3ee
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/panthor: Fail job creation when the group is dead (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8e77d2f
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/panthor: Fix firmware initialization on systems with a page size (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 30627cc
* Fri Nov 29 2024 pjakobsson@suse.de
- accel/ivpu: Fix NOC firewall interrupt handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4d03f62
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/sched: Mark scheduler work queues with WQ_MEM_RECLAIM (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 37097e7
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/tegra: Fix NULL vs IS_ERR() check in probe() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 59c1264
* Fri Nov 29 2024 pjakobsson@suse.de
- fbdev: wm8505fb: select CONFIG_FB_IOMEM_FOPS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aa76220
* Fri Nov 29 2024 pjakobsson@suse.de
- fbdev: da8xx: remove the driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9527d4a
* Fri Nov 29 2024 pjakobsson@suse.de
- fbdev: Constify struct sbus_mmap_map (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 90d8ace
* Fri Nov 29 2024 pjakobsson@suse.de
- fbdev: nvidiafb: fix inconsistent indentation warning (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a768b9b
* Fri Nov 29 2024 pjakobsson@suse.de
- fbdev: sstfb: Make CONFIG_FB_DEVICE optional (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a1a8e92
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Don't restart parallel queues multiple times on GT reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d21e14f
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/ufence: Prefetch ufence addr to catch bogus address (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fad9b37
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Handle unreliable MMIO reads during forcewake (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7f22461
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/guc/ct: Flush g2h worker in case of g2h response timeout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f253d05
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Enlarge the invalidation timeout from 150 to 500 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f28ee72
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/bridge: tc358767: fix missing of_node_put() in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1c1b045
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/bridge: Fix assignment of the of_node of the parent to aux bridge (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c0f2bcd
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: handle default profile on on devices without fullscreen (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9852438
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: fix random data corruption for sdma 7 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b48dee
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: temp w/a for DP Link Layer compliance (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 04041a5
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: temp w/a for dGPU to enter idle optimizations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3f6d44b
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/pm: update deep sleep status on smu v14.0.2/3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f3805bb
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/pm: update overdrive function on smu v14.0.2/3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7113e6b
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/pm: update the driver-fw interface file for smu v14.0.2/3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 91a6369
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/display: Don't allow tile4 framebuffer to do hflip on (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d4c6b1c
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/bmg: improve cache flushing behaviour (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e115193
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/ufence: ufence can be signaled right after wait_woken (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0141d6a
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Use bookkeep slots for external BO's in exec IOCTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e08560f
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/query: Increase timestamp width (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 50b6ebd
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Don't free job in TDR (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a9f004c
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Take job list lock in xe_sched_add_pending_job (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d7c1fb4
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: fix unbalanced rpm put() with declare_wedged() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d05d91
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: fix unbalanced rpm put() with fence_fini() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c6b6084
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/xe2lpg: Extend Wa_15016589081 for xe2lpg (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5209f87
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/ast: vga: Clear EDID if no display is connected (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ea6089b
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/ast: sil164: Clear EDID if no display is connected (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5fbf641
* Fri Nov 29 2024 pjakobsson@suse.de
- Revert "drm/mgag200: Add vblank support" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c7c8bbc
* Fri Nov 29 2024 pjakobsson@suse.de
- gpu: host1x: Set up device DMA parameters (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4ff7d7a
* Fri Nov 29 2024 pjakobsson@suse.de
- gpu: host1x: Fix boot regression for Tegra (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3d51eb4
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/panel: himax-hx83102: Adjust power and gamma to optimize (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 488dc0c
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/vmwgfx: Remove unnecessary NULL checks before kvfree() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fb3e0cb
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/vmwgfx: Cleanup kms setup without 3d (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a4a0207
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/vmwgfx: Handle possible ENOMEM in vmw_stdu_connector_atomic_check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ec06622
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Don't require DSC hblank quirk for a non-DSC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b96bd7c
* Fri Nov 29 2024 tiwai@suse.de
- Bluetooth: MGMT: Fix slab-use-after-free Read in
  set_powered_sync (git-fixes).
- net: mdio-ipq4019: add missing error check (git-fixes).
- net: usb: lan78xx: Fix refcounting and autosuspend on invalid
  WoL configuration (git-fixes).
- net: usb: lan78xx: Fix memory leak on device unplug by freeing
  PHY device (git-fixes).
- net: usb: lan78xx: Fix double free issue with interrupt buffer
  allocation (git-fixes).
- spi: Fix acpi deferred irq probe (git-fixes).
- spi: atmel-quadspi: Fix register name in verbose logging
  function (git-fixes).
- power: supply: rt9471: Use IC status regfield to report real
  charger status (git-fixes).
- power: supply: rt9471: Fix wrong WDT function regfield
  declaration (git-fixes).
- power: supply: bq27xxx: Fix registers of bq27426 (git-fixes).
- power: supply: core: Remove might_sleep() from
  power_supply_put() (git-fixes).
- commit 0e6f9cb
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Handle error during DSC BW overhead/slice (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0d31028
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/swsmu: default to fullscreen 3D profile for dGPUs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6885032
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/smu13: always apply the powersave optimization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f20a4ed
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/mes: fix issue of writing to the same log buffer from 2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3783c5
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: prevent BO_HANDLES error from being overwritten (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ce9c55a
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: enable enforce_isolation sysfs node on VFs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 35fa20b
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm/a6xx+: Insert a fence wait before SMMU table update (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b6a1c2f
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm/dpu: Don't always set merge_3d pending flush (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bcde5b1
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm/hdmi: drop pll_cmp_to_fdata from hdmi_phy_8998 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e04c3ec
* Fri Nov 29 2024 pjakobsson@suse.de
- Revert "drm/tegra: gr3d: Convert into (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9e3f75a
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Make wedged_mode debugfs writable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1be8b88
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Restore GT freq on GSC load error (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit efca423
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/guc_submit: fix xa_store() error checking (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8a7f034
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/ct: fix xa_store() error checking (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3fb4376
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/ct: prevent UAF in send_recv() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 196d2db
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/fbdev-dma: Only cleanup deferred I/O if necessary (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 70bbb54
* Fri Nov 29 2024 pjakobsson@suse.de
- nouveau/dmem: Fix privileged error in copy engine channel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9892e2a
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/nouveau/gsp: remove extraneous ; after mutex (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit da833a7
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Drop GuC submit_wq pool (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a18d11d
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/sched: Use drm sched lockdep map for submit_wq (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ca058ed
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/radeon: always set GEM function pointer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bc83a46
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: fix hibernate entry for DCN35+ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 14267d5
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Clear update flags after update has been applied (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b6024d9
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: partially revert powerplay `__counted_by` changes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 497a22d
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/radeon: add late_register for connector (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7db39d3
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdkfd: Fix an eviction fence leak (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit adc2343
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Fix memory leak when aborting binds (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5552222
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Prevent null pointer access in xe_migrate_copy (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 025a562
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/oa: Don't reset OAC_CONTEXT_ENABLE on OA stream close (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1a369f4
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/queue: move xa_alloc to prevent UAF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1cbdf34
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/vm: move xa_alloc to prevent UAF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e206c65
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Clean up VM / exec queue file lock usage. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c346816
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Resume TDR after GT reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7b8a70c
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/xe2: Add performance tuning for L3 cache flushing (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bab1afe
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/xe2: Extend performance tuning to media GT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a64cee7
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/mcr: Use Xe2_LPM steering tables for Xe2_HPM (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 133174c
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Use helper for ASID -> VM in GPU faults and access counters (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6ea67c4
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Convert to USM lock to rwsem (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c7d49a3
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: use devm_add_action_or_reset() helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 722aa78
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: fix UAF around queue destruction (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3a1ee8f
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/guc_submit: add missing locking in wedged_fini (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eca1a6f
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Restore pci state upon resume (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ae3f4d0
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/panthor: Don't add write fences to the shared BOs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ec5df6b
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/panthor: Don't declare a queue blocked if deferred operations are (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4e303ce
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/panthor: Fix access to uninitialized variable in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 79337e0
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/panthor: Lock the VM resv before calling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5cdc1d6
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/sched: revert "Always increment correct scheduler score" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit af44738
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/sched: Always increment correct scheduler score (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f263c3f
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/sched: Always wake up correct scheduler in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 249ede3
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Enable idle workqueue for more IPS modes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 21b0dff
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Add HDR workaround for specific eDP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 67d7225
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: avoid set dispclk to 0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8a0f32e
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Restore Optimized pbn Value if Failed to Disable DSC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aa7582a
* Fri Nov 29 2024 pjakobsson@suse.de
- firmware/sysfb: Disable sysfb for firmware buffers with unknown (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c49c6e2
* Fri Nov 29 2024 pjakobsson@suse.de
- of/platform: Disable sysfb if a simple-framebuffer node is found (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/0001-bsc-1204315-Disable-sysfb-before-creating-simple-fra.patch.
- commit 638d99b
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/connector: hdmi: Fix writing Dynamic Range Mastering infoframes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7f8fb2f
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/sched: Fix dynamic job-flow control race (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e6340a5
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/panthor: Fix race when converting group handle to group object (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9621268
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/display: fix kerneldocs references (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe96702
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/dp_mst: Fix DSC decompression detection in Synaptics branch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa192eb
* Fri Nov 29 2024 pjakobsson@suse.de
- fbcon: break earlier in search_fb_in_map and search_for_mapped_con (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eee4da1
* Fri Nov 29 2024 pjakobsson@suse.de
- fbdev: omapfb: Call of_node_put(ep) only once in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 86c9903
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/pm: update workload mask after the setting (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 275e973
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: bump driver version for cleared VRAM (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e3fc6df
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: fix vbios fetching for SR-IOV (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bbba003
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: fix PTE copy corruption for sdma 7 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4621262
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdkfd: Add SDMA queue quantum support for GFX12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e02c74a
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdkfd: Fix CU occupancy for GFX 9.4.3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 83545bf
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdkfd: Update logic for CU occupancy calculations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6461841
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: skip coredump after job timeout in SRIOV (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3027efc
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: sync to KFD fences before clearing PTEs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 81ca4b1
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: set enable_level_process_quantum_check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6a84cc4
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: reduce timeout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c154dd3
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/mes11: reduce timeout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7f3c98e
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: use GEM references instead of TTMs v2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 85c1bff
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Allow backlight to go below (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0aaacac
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Fix kdoc entry for 'tps' in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 05aa7ef
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: update golden regs for gfx12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d115ca
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: clean up vbios fetching code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 85f2e7c
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/bios: split vbios fetching between APU and dGPU (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a4f3978
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: remove amdgpu_pin_restricted() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb536d0
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: explicitely set the AMDGPU_GEM_CREATE_VRAM_CONTIGUOUS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1fdf009
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: Fix XCP instance mask calculation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0836937
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.301 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 30d3ea4
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Clear cached watermark after resume (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6784569
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Update IPS default mode for DCN35/DCN351 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4a2be7a
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Use full update for swizzle mode change (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 50d45c6
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Fix underflow when setting underscan on DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d3363ec
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Remove always-false branches (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 73fabe6
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.300 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6fbdf80
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Add fullscreen only sharpening policy (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7cac5ea
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Restructure dpia link training (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 31e307f
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Disable SYMCLK32_LE root clock gating (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 56c8c47
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Clean up dsc blocks in accelerated mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c5dd525
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Block dynamic IPS2 on DCN35 for incompatible FW (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ec9ef72
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Add debug options to change sharpen policies (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c8a91d8
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Block timing sync for different output formats in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7fbca99
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Enable DML2 override_det_buffer_size_kbytes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5237729
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Add dmub hpd sense callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1294035
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Emulate Display Hotplug Hang (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0423eca
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Implement new DPCD register handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 552b595
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Use SDR white level to calculate matrix coefficients (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6be994e
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: load sos binary properly on the basis of pmfw version (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 097f393
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: add psp funcs callback to check if aux fw is needed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9371bf5
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/pm: Update SMUv13.0.6 PMFW headers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ae3e16f
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: nuke the VM PD/PT shadow handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3360c02
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9.4.3: Explicitly halt MEC before init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 41fefc9
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9.4.3: set additional bits on MEC halt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5a076ed
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: Fix selfring initialization sequence on soc24 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 38a8ad5
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: switch SET_SHADER_DEBUGGER pkt to mes schq pipe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 48e6ff0
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: Retry i2c transfer once if it fails on SMU13.0.6 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 316de04
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: fix typo in the comment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bca023e
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: Fix a typo (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1b0ab56
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: fix typo in the comment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1e49e11
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: fix spelling in amd_shared.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a740871
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9.4.3: drop extra wrapper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 01b9285
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: Fix missing check pcie_p2p module param (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dddf2b0
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: disable GPU RAS bad page feature for specific ASIC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 20e23dd
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: ensure the connector is not null before using it (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 05ec815
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdkfd: clean up code for interrupt v10 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5b5c422
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdkfd: Move queue fs deletion after destroy check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f4b7ba9
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/dp: Fix colorimetry detection (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit af3b04e
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/oa: Fix overflow in oa batch buffer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 634f7d5
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Do not run GPU page fault handler on a closed VM (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1ad70d2
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/bo: add some annotations in bo_put() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c127daf
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/client: use mem_type from the current resource (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0a3205d
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/vram: fix ccs offset calculation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1be586c
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/guc: Fix GUC_{SUBMIT,FIRMWARE}_VER helper macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5cc62ff
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/dp: Fix AUX IO power enabling for eDP PSR (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b04cc45
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/display: BMG supports UHBR13.5 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d76b778
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/psr: Do not wait for PSR being idle on on Panel Replay (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ba61e9d
* Fri Nov 29 2024 pjakobsson@suse.de
- backlight: l4f00242t03: Add check for spi_setup (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 68b1685
* Fri Nov 29 2024 pjakobsson@suse.de
- treewide: correct the typo 'retun' (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8903dbd
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: clean up fault injection usage (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 09cc5d7
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm: clean up fault injection usage (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 11f9535
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Fix missing conversion to xe_display_pm_runtime_resume (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 49211b7
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/xe2hpg: Add Wa_15016589081 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 07abe89
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Don't keep stale pointer to bo->ggtt_node (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bfa68e6
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: fix missing 'xe_vm_put' (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d48a6ba
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: fix build warning with CONFIG_PM=n (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d57b6cd
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Suppress missing outer rpm protection warning (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4e9dd4c
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: prevent potential UAF in pf_provision_vf_ggtt() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 98d5060
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: get rid of bogus includes of fdtable.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f1518bb
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdkfd: CRIU fixes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ea5cc24
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: fix a race in kfd_mem_export_dmabuf() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cb24dee
* Fri Nov 29 2024 pjakobsson@suse.de
- drm: new helper: drm_gem_prime_handle_to_dmabuf() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a6093a8
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: Fix kdoc entry in 'amdgpu_vm_cpu_prepare' (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7f760da
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdkfd: Fix resource leak in criu restore queue (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 405bcca
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: drop redundant W=1 warnings from Makefile (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a2323a4
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: revert "use CPU for page table update if SDMA is (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8857716
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/mes11: Indent an if statment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c7fed1f
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdkfd: Document and define SVM events message macro (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a7389ff
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdkfd: Select reset method for poison handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e0c4944
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdkfd: fix missed queue reset on queue destroy (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d92223e
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: Surface svm_default_granularity, a RW module parameter (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 07bbbc2
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: fix queue reset issue by mmio (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 53de602
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Add kdoc entry for 'program_isharp_1dlut' in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6decd2c
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: Replace 'amdgpu_job_submit_direct' with (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4a00dea
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/: Add missing kdoc entry in amdgpu_vm_handle_fault (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit be18917
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: fix dccg root clock optimization related hang (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4e94ea6
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Refactor dccg35_get_other_enabled_symclk_fe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 092667f
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: Normalize reg offsets on JPEG v4.0.3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 426c8db
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: use clamp() in amdgpu_vm_adjust_size() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b03cc08
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd: use clamp() in amdgpu_pll_get_fb_ref_div() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 38e66ef
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: enable gfxoff quirk on HP 705G4 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7b211fb
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: add raven1 gfxoff quirk (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5840d4a
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Fix spelling mistake "recompte" -> "recompute" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c3846c5
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Add missing kdoc entry for 'bs_coeffs_updated' in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9872aec
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: fix invalid fence handling in amdgpu_vm_tlb_flush (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3a7003
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: re-work VM syncing (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dc5d2cb
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/bios: fix printk format width (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4d33bdb
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/display: Fix BMG CCS modifiers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1ac1e58
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/tegra: fix potential uninitialized variable use (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d9faf43
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/exynos: Remove unnecessary code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 509f3fc
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/exynos: Constify struct exynos_drm_ipp_funcs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 98383a5
* Fri Nov 29 2024 pjakobsson@suse.de
- Revert "drm/amdgpu: align pp_power_profile_mode with kernel docs" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2c7c5dc
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx10: use rlc safe mode for soft recovery (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 855298b
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx11: use rlc safe mode for soft recovery (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 146bfb1
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx12: use rlc safe mode for soft recovery (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3d04af9
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx12: use proper rlc safe mode helpers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cba7c73
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx11: use proper rlc safe mode helpers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8129fd7
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx10: use proper rlc safe mode helpers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e01865f
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx12: per queue reset only on bare metal (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 15a8617
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx11: per queue reset only on bare metal (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1c74078
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx10: per queue reset only on bare metal (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f078fb0
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/mes11: implement mmio queue reset for gfx11 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a26171b
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/mes: implement amdgpu_mes_reset_hw_queue_mmio (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b4952db
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/mes: modify mes api for mmio queue reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bc542c4
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx12: fallback to driver reset compute queue directly (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7238cc6
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx12: add ring reset callbacks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dc62087
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx10: rework reset sequence (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3dfc51e
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx10: wait for reset done before remap (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 86728ce
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx10: remap queue after reset successfully (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6e2a75a
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx10: add ring reset callbacks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9508938
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx11: wait for reset done before remap (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3fe5c0a
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx11: rename gfx_v11_0_gfx_init_queue() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e43aedf
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx11: fallback to driver reset compute queue directly (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7a5bba6
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.299 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6b2bacf
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Fix flickering caused by dccg (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 170b88b
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: fix graphics hang in multi-display mst case (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 821b5c4
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Add sharpness control interface (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5ff486a
* Fri Nov 29 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Wait for all pending cleared before full (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 82cb90c
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: disable sharpness if HDR Multiplier is too large (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b3447db
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Add dpia debug option to control power management (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 25bc658
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx11: add ring reset callbacks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit db142a8
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: re-enable Dynamic ODM policy (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9d540b8
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: only trigger BIOS related assert for older ASICs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8827dbb
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Fix DCN35 set min dispclk logic (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 49dbdf3
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9.4.3: Implement compute pipe reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 43bebab
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdkfd: Don't drain ih1 for APU (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c5ea456
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx12: return early in preempt_ib() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 37a3717
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx11: return early in preempt_ib() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f15546
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: Move the dumping log out of for loop (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5797750
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/amdgpu: move drain_workqueue before shutdown is set (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit abb6c2e
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: Do core dump immediately when job tmo (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9c91917
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: skip printing vram_lost if needed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a0027c9
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9: put queue resets behind a debug option (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dbcad95
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: add experimental resets debug flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9d12fd7
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/display: Fix a mistake in revert commit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c29e7c8
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/display: remove unnecessary TODO spl_os_types.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 30d2b12
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/display: SPDX copyright for spl_os_types.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4baae7b
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Add DSC Debug Log (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 75d1c1d
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.298 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ec5d7b7
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: add sharpness support for windowed YUV420 video (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b2e21a3
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: add improvements for text display and HDR DWM and (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fbf9256
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Add Replay Low Refresh Rate parameters in dc type. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4adad3d
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: add back quality EASF and ISHARP and dc dependency (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dfc3a75
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Notify DMCUB of D0/D3 state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 59466dc
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Fix Synaptics Cascaded Panamera DSC Determination (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d4811a3
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Retry Replay residency (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dfb31b3
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Allocate DCN35 clock table transfer buffers in GART (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit baac899
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: do not set traslate_by_source for DCN401 cursor (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2cc7360
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Resolve Coverity Issues (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2026893
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Fix MS/MP mismatches in dml21 for dcn401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b12d4d6
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Wait for all pending cleared before full update (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 71f07b3
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: guard write a 0 post_divider value to HW (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7a64cfe
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd/display: Don't skip clock updates in overclocking (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8808d96
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amd: Introduce additional IPS debug flags (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa48175
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu/swsmu: fix ordering for setting workload_mask (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5ae532a
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/amdgpu: align pp_power_profile_mode with kernel docs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c599cde
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915: Remove extra unlikely helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8eb9f40
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/hwmon: expose fan speed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 612bc65
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/guc: Fix missing enable of Wa_14019159160 on ARL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 96a77ce
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/gt: Whitelist COMMON_SLICE_CHICKEN1 for UMD access. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d79930d
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/gt: Continue creating engine sysfs files even after a (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c429e4c
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Use xe_pm_runtime_get in xe_bo_move() if reclaim-safe. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 40fd41e
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Remove redundant [drm] tag from xe_assert() message (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 63b9df0
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/pf: Reset thresholds when releasing a VF config (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7deadcc
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/pf: Add thresholds to the VF KLV config (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e2b1669
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Invalidate media_gt TLBs in PT code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ef8450c
* Fri Nov 29 2024 pjakobsson@suse.de
- dma-buf: Split out dma fence array create into alloc and arm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 07f8b70
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/hwmon: Treat hwmon as a per-device concept (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3984170
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/display: Drop unnecessary xe_gt.h includes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f9f010
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Fix memory leak on xe_alloc_pf_queue failure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 346d874
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/pf: Improve VF control (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0c93ee1
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/pf: Drop GuC notifications for non-existing VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3f5c630
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/pf: Fix documentation formatting (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6c67e73
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/pf: Add function to sanitize VF resources (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b5a6860
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/gsc: Wedge the device if the GSCCS reset fails (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b990994
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/gsc: Add debugfs to print GSC info (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b3311ea
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/gsc: Track the platform in the compatibility version (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3c55a5c
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/gsc: Fix FW status if the firmware is already loaded (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4b605dd
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: replace #include <drm/xe_drm.h> with <uapi/drm/xe_drm.h> (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b7e1762
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: move the kernel lrc from hwe to execlist port (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 415a32f
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm/dpu: enable writeback on SM6350 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2cec259
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm/dpu: enable writeback on SM6125 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d69c938
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm/dpu: enable writeback on SC8108X (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e470036
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm/dpu: enable writeback on SM8150 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9d0f3d1
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm/dp: enable widebus on all relevant chipsets (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 59030eb
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm: add msm8998 hdmi phy/pll support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e64516c
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm/hdmi: add "qcom,hdmi-tx-8998" compatible (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0604272
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm/dpu: Configure DP INTF/PHY selector (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 05f18ac
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm/adreno: Add A306A support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c42c2be
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm/a6xx: Add A621 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ecdcaf6
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm/a6xx: Set GMU CGC properties on a6xx too (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cc55342
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm/a6xx: Use the per-GPU value for gmu_cgc_mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2c4dcc5
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm/a6xx: Store correct gmu_cgc_mode in struct a6xx_info (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 393025c
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm/a6xx: Store primFifoThreshold in struct a6xx_info (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1287c38
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm/a6xx: Evaluate adreno_is_a650_family in pdc_in_aop check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cc133d3
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm: Fix UBWC macrotile_mode for a680 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b9c1588
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm: Expose expanded UBWC config uapi (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5bbf673
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm: Expand UBWC config setting (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d54dd3c
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm: Update a6xx register XML (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f24969b
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm: Fix CP_BV_DRAW_STATE_ADDR name (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e245a58
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm: Dump correct dbgahb clusters on a750 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 226001d
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm: Use a7xx family directly in gpu_state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cb4f558
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm/adreno: add a615 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e14981c
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm/a6xx: Add A642L speedbin (0x81) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ab364fe
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm: Remove unused pm_state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c0ecf03
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm: Remove prototypes for non-existing functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f215a66
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/msm/adreno: Use kvmemdup to simplify the code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5836177
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/mediatek: Use spin_lock_irqsave() for CRTC event lock (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9e23dd5
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/mediatek: Fix missing configuration flags in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d745717
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/mediatek: dsi: Add dsi per-frame lp code for mt8188 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 384e44e
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/mediatek: Drop unnecessary check for property presence (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 423ab29
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/mediatek: Declare Z Position for all planes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6e554f2
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/mediatek: ovl_adaptor: Use scoped variant of (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b888ad
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/mediatek: ovl_adaptor: Drop unused mtk_crtc.h header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd5e536
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/mediatek: Use cmdq_pkt_create() and cmdq_pkt_destroy() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e0d39a3
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/mediatek: Use cmdq_pkt_eoc() instead of cmdq_pkt_finalize() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7681df8
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/mediatek: Support alpha blending in display driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 51c7461
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/mediatek: Support "Pre-multiplied" blending in Mixer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dfc989b
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/mediatek: Support "Pre-multiplied" blending in OVL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ce8edb7
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/mediatek: Support "None" blending in Mixer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1dfbc03
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/mediatek: Support "None" blending in OVL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a6a7ec5
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/dp: hide dp_to_i915() inside intel_dp.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f111a0a
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/ddi: stop using dp_to_i915() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 970bd6b
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/psr: convert intel_psr.[ch] to struct intel_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1a58b5d
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/pps: convert intel_pps.[ch] to struct intel_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3504edf
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/pps: pass intel_dp to pps_name() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d44e035
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/dp: convert intel_dp_link_training.[ch] to struct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8e4d882
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/dp: convert intel_dp_aux.[ch] to struct intel_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7dc8876
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/dp: convert intel_dp_tunnel.[ch] to struct intel_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4c137b1
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/dp: convert g4x_dp.[ch] to struct intel_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5c08cc5
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/hdmi: convert to struct intel_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3a84fda
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/display: use xe && 0 to avoid warnings about unused variables (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 61d1980
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/display: remove unused compat kdev_to_i915() and (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3fd33b2
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/hdcp: migrate away from kdev_to_i915() in GSC messaging (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 90c68dc
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/hdcp: migrate away from kdev_to_i915() in bind/unbind (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2166d37
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/audio: migrate away from kdev_to_i915() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4da3320
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915: support struct device and pci_dev in to_intel_display() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f589b0f
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915 & drm/xe: save struct drm_device to drvdata (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 85c6998
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/bios: Update new entries in VBT BDB block definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2f44343
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915: deprecate the i915.modeset module parameter (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9d39f89
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915: fail module probe on nomodeset and i915.modeset=0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a17dbc3
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/dsb: Use chained DSBs for LUT programming (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5836bda
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/dsb: s/dsb/dsb_color_vblank/ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f63f697
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/dsb: Clear DSB_ENABLE_DEWAKE once the DSB is done (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c0ee931
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/dsb: Allow intel_dsb_chain() to use DSB_WAIT_FOR_VBLANK (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f85bbf8
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/dsb: Introduce intel_dsb_chain() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ef85329
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/dsb: Introduce intel_dsb_wait_scanline_{in,out}() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6cf9bf5
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/dsb: Precompute DSB_CHICKEN (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5bd72a0
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/dsb: Account for VRR properly in DSB scanline stuff (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 559998b
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/dsb: Fix dewake scanline (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ef011b2
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/dsb: Shuffle code around (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f9dd840
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/dsb: Convert dewake_scanline to a hw scanline number earlier (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 31f82cd
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/dsb: Hook up DSB error interrupts (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 78d88f4
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: Align all VRAM scanout buffers to 64k physical pages when (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 943134e
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/display: Plane capability for 64k phys alignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4530e9a
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915: remove unused leftover basedie step code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d16eacb
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915: remove unnecessary display includes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fdddb56
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/display: convert params to struct intel_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2f18f7a
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/sprite: convert to struct intel_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fb866aa
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/tv: convert to struct intel_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6bbc0e0
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/vrr: convert to struct intel_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 934583f
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/vblank: convert to struct intel_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d3f760f
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/vblank: fix context imbalance warnings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 72bd6e5
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/vblank: use drm_crtc_vblank_crtc() instead of open-coding (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2c7ef85
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe: remove display stepping handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 514bfa4
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915: remove display stepping handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e279b46
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/display: switch to display detected steppings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 300a7ed
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/display: identify display steppings in display probe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f3a2c1e
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/display: rename IS_DISPLAY_IP_STEP() to (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 02d82fe
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/display: rename IS_DISPLAY_IP_RANGE() to (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ec3fa7b
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/step: define more steppings E-J (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5076521
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/display: remove the unused compat HAS_GMD_ID() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 615890b
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/display: remove intel_display_step_name() to simplify (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 264eeb6
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/display: allow creation of Xe2 ccs framebuffers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f337d3a
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/fourcc: define Intel Xe2 related tile4 ccs modifiers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 831ec4a
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/display: Don't enable decompression on Xe2 with Tile4 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bd3f31d
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/psr: Prevent Panel Replay if CRC calculation is enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0feef66
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/xe/display: drop unused rawclk_freq and RUNTIME_INFO() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ff3a024
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915: move rawclk from runtime to display runtime info (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ab08bc5
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915: make intel_display_power_domain_str() static (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cee0daf
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/hti: convert to struct intel_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a284b13
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/display: convert dp aux backlight to struct intel_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d103285
* Fri Nov 29 2024 pjakobsson@suse.de
- drm/i915/lspcon: convert to struct intel_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Delete patches.suse/drm-i915-lspcon-Separate-function-to-set-expected-mo.patch.
- Delete patches.suse/drm-i915-lspcon-Separate-lspcon-probe-and-lspcon-ini.patch.
- commit bd47a6d
* Fri Nov 29 2024 trenn@suse.com
- platform/x86: ISST: Support SST-BF and SST-TF per level
  (jsc#PED-10347).
- commit fec7b3b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/alpm: convert to struct intel_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 876cfdb
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/display: convert intel_load_detect.c to struct intel_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit baa53d2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/display: convert intel_link_bw.c to struct intel_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 391d24a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/display: support struct intel_atomic_state in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 234b5dc
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/pps: Disable DPLS_GATING around pps sequence (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a33b405
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: make __intel_display_power_is_enabled() static (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1ce0c3b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/bmg: Drop force_probe requirement (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 28cd1dd
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Fix NPD in ggtt_node_remove() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 89ebe31
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Use separate rpm lockdep map for non-d3cold-capable devices (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b4c1fe4
* Thu Nov 28 2024 pjakobsson@suse.de
- Revert "drm/ttm: Add a flag to allow drivers to skip clear-on-free" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ed2ab7a
* Thu Nov 28 2024 pjakobsson@suse.de
- Revert "drm/xe/lnl: Offload system clear page activity to GPU" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5b65b58
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Support 'nomodeset' kernel command-line option (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8229e83
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Remove unrequired NULL check in xe_sched_job_free_fences (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 43338d9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Remove unrequired NULL checks in xe_sync_entry_cleanup (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd822f7
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Remove extra dma_fence_put on xe_sync_entry_add_deps failure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b4a7dd5
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/lnl: Drop force_probe requirement (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bc1d3a9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Remove NULL check of lrc->bo in xe_lrc_snapshot_capture() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4180b72
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Fix total initialization in xe_ggtt_print_holes() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a976ecb
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/display: handle HPD polling in display runtime suspend/resume (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit de96857
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Handle polling only for system s/r in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 62c72a4
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Update xe_sa to use xe_managed_bo_create_pin_map (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8998a4f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Move hw_engine_fini to devm managed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 86366a9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Drop warn on xe_guc_pc_gucrc_disable in guc pc fini (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 341f7a5
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Set firmware state to loadable before registering guc_fini_hw (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7414edc
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Move ggtt_fini to devm managed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a709ff4
* Thu Nov 28 2024 pjakobsson@suse.de
- Revert "drm/xe: Invalidate media_gt TLBs in PT code" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9184320
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Fix missing runtime outer protection for ggtt_remove_node (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2d0ae98
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Make xe_ggtt_node struct independent (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d2e33b2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Refactor xe_ggtt balloon functions to make the node clear (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd2d5e4
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Introduce xe_ggtt_print_holes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a90c58b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Introduce xe_ggtt_largest_hole (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 841beb7
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Limit drm_mm_node_allocated access to xe_ggtt_node (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 91a4014
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Rename xe_ggtt_node related functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 30d6665
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Encapsulate drm_mm_node inside xe_ggtt_node (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6ad0258
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/{i915, xe}: Avoid direct inspection of dpt_vma from outside dpt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1e0db31
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Remove unnecessary drm_mm.h includes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 371ea49
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Introduce GGTT documentation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 70df8a6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Removed unused xe_ggtt_printk (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e49c7f5
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: fixup xe_alloc_pf_queue (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 93b79c3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Invalidate media_gt TLBs in PT code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 356f089
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/guc: Bump the G2H queue size to account for page faults (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1458cee
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Use topology to determine page fault queue size (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0b72a86
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/lnl: Offload system clear page activity to GPU (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 045fd9a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ttm: Add a flag to allow drivers to skip clear-on-free (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6c3fd6f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/oa: Use vma_pages() helper function in xe_oa_mmap() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe46138
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Remove redundant param from xe_bo_create_user (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a6afb2d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/device: Remove unused xe_device::usm::num_vm_in_* (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c3c7bb1
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/vm: Remove restriction that all VMs must be faulting if one is (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7667bc0
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/exec: Switch hw engine group execution mode upon job (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 29a3e87
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/hw_engine_group: Ensure safe transition between execution (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cd32fa2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/hw_engine_group: Add helper to wait for dma fence jobs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ebcacfc
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/exec_queue: Prepare last fence for hw engine group resume (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a9e599e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/exec_queue: Remove duplicated code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit de708f6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/hw_engine_group: Add helper to suspend faulting LR jobs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 66084dc
* Thu Nov 28 2024 pjakobsson@suse.de
- 'drm/xe/hw_engine_group: Register hw engine group's exec queues (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5fbbe4b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/guc_submit: Make suspend_wait interruptible (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d088e5c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/hw_engine_group: Introduce xe_hw_engine_group (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3189052
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Use reserved copy engine for user binds on faulting devices (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 41f53fe
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/mcr: Try to derive dss_per_grp from hwconfig attributes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e78f8e0
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Add debugfs to dump GuC's hwconfig (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d95f3fc
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Use for_each_remote_tile rather than manual check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 944f621
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/uc: Use managed bo for HuC and GSC objects (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9743a94
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Make exec_queue_kill safe to call twice (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f9a5455
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: fix engine_class bounds check again (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 11466d7
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Define STATELESS_COMPRESSION_CTRL as mcr register (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3f1c332
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Write all slices if its mcr register (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ae3399c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Move enable host l2 VRAM post MCR init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2d9a989
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Rename enable_display module param (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit af65519
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Remove unused xe parameter (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f931623
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Name and document Wa_14019789679 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 52e8237
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: add kdev_to_xe_device() helper and use it (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f64fe13
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: use pdev_to_xe_device() instead of pci_get_drvdata() directly (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7938ea7
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/tests: remove unused leftover xe_call_for_each_device() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2394d8b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/migrate: Parameterize ccs and bo data clear in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit acf88fa
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Add stats for tlb invalidation count (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b44e4cd
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/gt: Add APIs for printing stats over debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 15757c1
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Allow to compile out debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 46462b9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Allow suspend / resume to be safely called multiple times (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 372735f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Only enable scheduling upon resume if needed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a0ba14c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Add xe_sched_add_msg_locked helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1f74156
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Reinit msg link when processing a message (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7cba1f3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Add xe_sched_msg_lock/unlock helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 47a1d4d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/guc: Enable w/a 14022293748 and 22019794406 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 50d91ee
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Add kernel doc for xe_hw_engine_lookup (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 05a520b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Export xe_hw_engine's mmio accessors (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b4d61d3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/guc: Define GuC version v70.29.2 for BMG (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 775a78b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/guc: Bump minimum required GuC version to v70.29.2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2942add
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/xe2: Add performance turning changes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a0411bc
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Only check last fence on user binds (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 84059bf
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/xe2: Introduce performance changes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8eb4284
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Faster devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d714ea3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/printer: Allow NULL data in devcoredump printer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ec92414
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/xe2: Enable Priority Mem Read (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 00cd76c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Move and export xe_hw_engine lookup. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f3c2302
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/tiny/gm12u320: convert to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8a2bbab
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ipuv3/parallel: convert to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 847583f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/tegra: convert to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 49e63d8
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/sti/sti_hdmi: convert to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9c683bf
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: nv3051d: Transition to mipi_dsi_dcs_write_seq_multi (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 548740e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: novatek-nt35950: transition to mipi_dsi wrapped functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d723299
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: visionox-vtdr6130: switch to devm_regulator_bulk_get_const (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c7f63e1
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: visionox-vtdr6130: switch to mipi_dsi wrapped functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 727f1ed
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: switch to guid_gen() to generate valid GUIDs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6ec1f8f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/mst: switch to guid_gen() to generate valid GUIDs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ae93aa2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/mst: switch to guid_t type for GUID (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2041a29
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/tegra: hub: Use fn parameter directly to fix Coccinelle warning (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3d6cc6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/tegra: gr3d: Convert into dev_pm_domain_attach|detach_list() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5946bfc
* Thu Nov 28 2024 pjakobsson@suse.de
- gpu: host1x: Request syncpoint IRQs only during probe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe58469
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ci: increase timeout for all jobs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5898a15
* Thu Nov 28 2024 pjakobsson@suse.de
- Revert "drm/panel-edp: Add SDC ATNA45AF01" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 88bc630
* Thu Nov 28 2024 pjakobsson@suse.de
- drm: Expand max DRM device number to full MINORBITS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a59aa82
* Thu Nov 28 2024 pjakobsson@suse.de
- accel: Use XArray instead of IDR for minors (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 90d9371
* Thu Nov 28 2024 pjakobsson@suse.de
- drm: Use XArray instead of IDR for minors (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fbb3683
* Thu Nov 28 2024 pjakobsson@suse.de
- drm: Fix kerneldoc for "Returns" section (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 512ed0d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/atomic: fix kerneldoc for fake_commit field (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0285d85
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel-edp: add BOE NE140WUM-N6G panel entry (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8e9608c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm: renesas: rz-du: Add RZ/G2UL DU Support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 19ad2a5
* Thu Nov 28 2024 pjakobsson@suse.de
- drm: renesas: Move RZ/G2L MIPI DSI driver to rz-du (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6d19c0e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ttm: fix kernel-doc typo for @trylock_only (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5af5a44
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: use a more lax vblank enable policy for older ASICs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 71b5f8a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: use a more lax vblank enable policy for DCN35+ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d6fb394
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: use new vblank enable policy for DCN35+ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f8657a4
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panic: Add a QR code panic screen (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b2bf392
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panic: Simplify logo handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5d6563e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/rect: Add drm_rect_overlap() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ffbfb12
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panic: Add integer scaling to blit() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5fa620f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: Change kfd/svm page fault drain handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 185f47f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add list empty check to avoid null pointer issue (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0fcc9dc
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Make dcn401_dsc_funcs static (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ba43d38
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Make dcn35_hubp_funcs static (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 362a8d5
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Make core_dcn4_ip_caps_base static (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d7afb51
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Make core_dcn4_g6_temp_read_blackout_table static (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb4919b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Retire query_utcl2_poison_status callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a489c4e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Take IOMMU remapping into account for p2p checks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fdff1c2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: Drop poison hanlding from gfx v10 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f3bda7e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: Check int source id for utcl2 poison event (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8cca7ee
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/gfx11: move the gfx mutex into the caller (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f689c20
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/amdgpu: allow use kiq to do hdp flush under sriov (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d3592d7
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Promote DC to 3.2.297 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5295dfd
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: DML2.1 Reintegration for Various Fixes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6781849
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: DCN35 set min dispclk to 50Mhz (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 17b02e7
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Fix construct_phy with MXM connector (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 62f0990
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Support UHBR10 link rate on eDP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9e5e2da
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Hardware cursor changes color when switched to (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0f2c2f3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Allow UHBR Interop With eDP Supported Link Rates (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f73ba24
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Remove redundant check in DCN35 hwseq (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6ff9ba4
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: remove an extraneous call for checking dchub clock (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7bd0358
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Update HPO I/O When Handling Link Retrain Automation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 49621fe
* Thu Nov 28 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Update to using new dccg callbacks" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 77f7774
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: Update BadOpcode Interrupt handling with MES (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9f333a2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: Update queue unmap after VM fault with MES (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d39544c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Implement MES Suspend and Resume APIs for GFX11 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ce41aa7
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: Enable processes isolation on gfx9 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 865a0c1
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx_v9_4_3: Apply Isolation Enforcement to GFX & Compute (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7912829
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9: Apply Isolation Enforcement to GFX & Compute rings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ba108dd
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Implement Enforce Isolation Handler for KGD/KFD (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d58a775
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: APIs to stop/start KFD scheduling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2863fcf
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9: Add cleaner shader support for GFX9.4.4 hardware (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ef185ef
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9: Add cleaner shader for GFX9.4.3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5897c56
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9: Implement cleaner shader support for GFX9.4.3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 73fe0a0
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9: Implement cleaner shader support for GFX9 hardware (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6548f35
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Add PACKET3_RUN_CLEANER_SHADER for cleaner shader (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a1aee5a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Add sysfs interface for running cleaner shader (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 85f98ab
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Add enforce_isolation sysfs attribute (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c32f820
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Enforce isolation as part of the job (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 94590e1
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: abort KIQ waits when there is a pending reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 026828d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Make enforce_isolation setting per GPU (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8616e20
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Emit cleaner shader at end of IB submission (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e065f2d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Add infrastructure for Cleaner Shader feature (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 38e0e8c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: handle enforce isolation on non-0 gfxhub (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 291f439
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add vcn ip dump support for vcn_v2_6 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c9fcd1a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add print support for vcn_v2_5 ip dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 36d989b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add vcn_v2_5 ip dump support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7130277
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add print support for vcn_v2_0 ip dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b34c1f9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add vcn_v2_0 ip dump support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f8188c6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add print support for vcn_v1_0 ip dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d6b2352
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add vcn_v1_0 ip dump support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b6e33d5
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add print support for vcn_v4_0_5 ip dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 176c3fe
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add print support for vcn_v4_0 ip dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6173d88
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add print support for vcn_v4_0_3 ip dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c72113b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add vcn_v4_0_5 ip dump support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 123fa05
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add vcn_v4_0 ip dump support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 949e0aa
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add vcn_v4_0_3 ip dump support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 37d4791
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add print support for vcn_v5_0 ip dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9557c1a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: add API for user queue reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 099ab57
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/mes11: add API for user queue reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c949927
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/mes: add API for user queue reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2deb9c5
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx11: export gfx_v11_0_request_gfx_index_mutex() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0d12fb8
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx11: add a mutex for the gfx semaphore (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2c9ca47
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx11: enter safe mode before touching CP_INT_CNTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 01283b6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx7: add ring reset callback for gfx (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3c5ccca
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx8: add ring reset callback for gfx (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fc3f26e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add vcn_v5_0 ip dump support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4b56c50
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add print support for vcn_v3_0 ip dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ad953de
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add vcn_v3_0 ip dump support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 89fb956
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add vcn ip dump ptr in vcn global struct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6850779
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd: Remove unused declarations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8f135f4
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: remove ME0 registers from mi300 dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa5c428
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9: use rlc safe mode for soft recovery (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 36ab9d3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9.4.3: use rlc safe mode for soft recovery (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 652798d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9.4.3: use proper rlc safe mode helpers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 858d22d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9: use proper rlc safe mode helpers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1a85ca8
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9: add ring reset callback for gfx (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit df0cb2e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9: per queue reset only on bare metal (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 834d5c0
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9.4.3: implement reset_hw_queue for gfx9.4.3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6ae3bd9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9: implement reset_hw_queue for gfx9 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c405e51
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx: add a new kiq_pm4_funcs callback for reset_hw_queue (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 44f5930
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx_9.4.3: wait for reset done before remap (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1f3fe8b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9.4.3: remap queue after reset successfully (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dcece4d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9.4.3: add ring reset callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c635d7d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9: wait for reset done before remap (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eff4b84
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9: remap queue after reset successfully (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c17683c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9: add ring reset callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 910dc3b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: increase the reset counter for the queue reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 77308b1
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add per ring reset support (v5) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fb3bbd6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add new ring reset callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0a4f6bd
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Return earlier in amdgpu_sw_ring_ib_end if mcbp is off (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 73384d8
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add cp queue registers print for gfx9_4_3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 31edf69
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add cp queue registers for gfx9_4_3 ipdump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ed1144f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Align hwss_wait_for_all_blank_complete descriptor (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9d8e8bf
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add print support for gfx9_4_3 ipdump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d8eb9f8
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add gfx9_4_3 register support in ipdump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9e3368a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/amdgpu: cleanup parse_cs callbacks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9a60c12
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: adjust mes12 sw/hw init for multiple pipes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 36ef534
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Block MMR_READ IOCTL in reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b243567
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: fallback to pipe reset on queue reset fail for gfx9 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f327d0
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Reorder to read EFI exported ROM first (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1c73334
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Disable dpm_enabled flag while VF is in reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6ebc03e
* Thu Nov 28 2024 pjakobsson@suse.de
- Revert "drm/amdgpu: Extend KIQ reg polling wait for VF" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 375aaf6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: Add node_id to location_id generically (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9f6b05c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/sriov: extend NV_MAILBOX_POLL_MSG_TIMEDOUT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8e16b4e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Promote DAL to 3.2.296 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6e7a6e3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Remove unnecessary call to REG_SEQ_SUBMIT|WAIT_DONE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9a78b23
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Improve FAM control for DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c2ffdc9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Remove unused field (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f2c6f53
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: remove redundant msg to pmfw at boot/resume (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 241cfce
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Set max VTotal cap for dcn401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2bd495a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Perform outstanding programming on full updates (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e44721e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Disable DCN401 UCLK P-State support on full updates (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 77f0503
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Reduce redundant minimal transitions due to SubVP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b65c35d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Optimize vstartup position for AS-SDP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ce70828
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Fix print format specifiers in DC_LOG_IPS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4f9444c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: Handle queue destroy buffer access race (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cf14977
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: fix partition query when setting up recommended sdma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 36bbf4e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: fix ptr check warning in gfx12 ip_dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 934164a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: fix ptr check warning in gfx11 ip_dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a6231d8
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: fix ptr check warning in gfx10 ip_dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a5c68d0
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: fix ptr check warning in gfx9 ip_dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8532948
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: guard otg disable w/a for test (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9b581c4
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add more logging for MALL static screen (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 44bdc11
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Update to using new dccg callbacks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 15c0838
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Unlock Pipes Based On DET Allocation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 80de1ca
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: 3DLUT non-DMA refactor (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f848986
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: apply vmin optimization even if it doesn't reach (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e87e013
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: fix minor coding errors where dml21 phase 5 uses (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit afb7276
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add null check for 'afb' in amdgpu_dm_update_cursor (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3d21ca
* Thu Nov 28 2024 pjakobsson@suse.de
- Revert "drm/amdgpu: add vcn ip dump ptr in vcn global struct" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9128c1b
* Thu Nov 28 2024 pjakobsson@suse.de
- Revert "drm/amdgpu: add vcn_v3_0 ip dump support" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit abdcec4
* Thu Nov 28 2024 pjakobsson@suse.de
- Revert "drm/amdgpu: add print support for vcn_v3_0 ip dump" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f4a74fc
* Thu Nov 28 2024 pjakobsson@suse.de
- Revert "drm/amdgpu: add vcn_v5_0 ip dump support" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 646fba5
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add vcn_v5_0 ip dump support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e8ebe91
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: add API for legacy queue reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 61add0f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/mes11: add API for legacy queue reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9425414
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/mes: add API for legacy queue reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d67c2fe
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/radeon/r100: Handle unknown family in r100_cp_init_microcode() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 77bc398
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd: Use a constant format string for amdgpu_ucode_request (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 588366b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/swsmu: fix SMU11 typos (memlk -> memclk) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 79167d1
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd: Make amd_ip_funcs static for SDMA v5.2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 47c9365
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd: Make amd_ip_funcs static for SDMA v5.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 51cd55a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/uvd4: fix mask and shift definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a83f04c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: remove extraneous ; after statements (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ebf12c3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: fix unchecked return value warning for amdgpu_atombios (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ab34bf3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: fix unchecked return value warning for amdgpu_gfx (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6089a66
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/pm: fix unchecked return value warning for vega10_hwmgr (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2b60468
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.295 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6bc4e91
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add DML2.1 option to disable DRR clamped P-State (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f7f1aab
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Revert Avoid overflow assignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f97678
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add clock control callbacks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2923261
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Address coverity change (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d28a226
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: skip crtc power down when ips switch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f6f72f0
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add clock control callbacks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e871df6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Re-enable panel replay feature (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit de7d8e0
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Force enable 3DLUT DMA check for dcn401 in DML (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 48686ca
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Assume 32 bpp cursor in DML21 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e9978e2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Disable SubVP if Hardware Rotation is Used (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ba06349
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: report bad status in GPU recovery (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f0d865b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: update bad state check in GPU recovery (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 24296b3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Print Pcon FRL Link BW in Debug Message (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f6bd1ce
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: remove RAS unused paramter 'err_addr' (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1ddae19
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: fix a UBSAN warning in DML2.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 02e109f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: create function to check RAS RMA status (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1ab0c50
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add stream and char control callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa3bfa1
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Fix overlay with pre-blend color processing (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 99ae451
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Remove unused fields from dc_caps (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5d0c9db
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Remove unused fields from (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6cbb0eb
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Remove useless defines (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 97b8ee4
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Cleanup dml2 and dc/resource Makefile (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4340442
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: optimize the padding for gfx_v9_4_3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2a09eb3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/radeon: use GEM references instead of TTMs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a9b8146
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: optimize the padding for gfx9 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 733dcea
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdpgu: Micro-optimise amdgpu_ring_commit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9fa7371
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Add more types for boot time error reporting (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 209f0d1
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: optimize the padding for gfx12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 41b4908
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add NULL check for function pointer in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e601323
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: use CPU for page table update if SDMA is unavailable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2834d35
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: optimize the padding for gfx11 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 665d642
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: fix debug watchpoints for logical devices (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 691bfd1
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: do not call insert_nop fn for zero count (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ec425c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: support per-queue reset on gfx9 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 701bdf6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: optimize the padding for gfx10 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 35fa3ac
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Align 'dpp401_dscl_program_isharp' with actual (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6b1c484
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Clean up the register dump via debugfs list (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ab0de45
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Remove debugfs amdgpu_reset_dump_register_list (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 216037a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/pm: add overdrive support on smu v14.0.2/3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 83a1297
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: Fix compile error if HMM support not enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 932f688
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.294 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d1dadd3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Remove unused code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7980bdb
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add missing registers for dcn32 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 425fcb5
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Remove duplicated code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f76e813
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: For FAMS2 don't program P-State force from driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 037a16b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Fix Cursor Offset in Scaled Scenarios (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b596020
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Setup two pixel per container (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2d8d9e4
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Re-order enum in a header file (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0afb26b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Get link index for AUX reply notification (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f916f9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Check UnboundedRequestEnabled's value (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb6ab8e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Underflow Seen on DCN401 eGPU (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 37c3f18
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Enable aux transfer path via dmub for dp tunneling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ca2643b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add new enable and disable functions for DCN35 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b4d53f1
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Use gpuvm_min_page_size_kbytes for DML2 surfaces (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a5bcdb1
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Check null values from functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6b3b0c8
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add logs for debugging outbox (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cc627bd
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add new enable and disable functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 39b39ea
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/radeon: convert bios_hardcoded_edid to drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 73dd072
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: convert bios_hardcoded_edid to drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 929417d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: trigger ip dump before suspend of IP's (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0d04c85
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Avoid overflow assignment in link_dp_cts (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6078001
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Use correct cm_helper function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7df8b62
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add seamless boot support for more DIG operation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 358bf87
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Reset VRR config during resume (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2e339d2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add a missing PSR state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 12e4257
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: sync dmub output event type. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8cfbc8d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: restore immediate_disable_crtc for w/a (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dcea0f7
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: increase mes log buffer size for gfx12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6476cfa
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Check stream_status before it is used (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b2acbe7
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Check null pointers before using them (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe4ad2d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Fix possible overflow in integer multiplication (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b2ac4c9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add option to disable unbounded req in DML21 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 39bc0c1
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Refactor for dio (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 831599a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Request 0MHz dispclk for zero display case (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6e1c7e2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: print VCN instance dump for valid instance (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9fe51ec
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add two dmmuy I2C entry for GPIO port mapping issue (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 957e4aa
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Run idle optimizations at end of vblank handler (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2830fb8
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Let drm_crtc_vblank_on/off manage interrupts (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3241e24
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: roll back quality EASF and ISHARP and dc dependency changes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit 41126d0
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: Fix missing error code in kfd_queue_acquire_buffers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bd9d999
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Add MFD support for ISP I2C bus (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d26895b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add print support for vcn_v3_0 ip dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b7850cf
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add vcn_v3_0 ip dump support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f5932fe
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add macro to calculate offset with instance (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2abd2a5
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add vcn ip dump ptr in vcn global struct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd798cd
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: remove unneeded semicolon (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c09704c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: allow users to target recommended SDMA engines (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ac6d18
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: use swap() in sort() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bfa7c19
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Reapply 2fde4fdddc1f (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a038c49
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Fix spelling mistake "tolarance" -> "tolerance" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 577aeeb
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: Validate queue cwsr area and eop buffer size (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0161a9c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: Store queue cwsr area size to node properties (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 065f16b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: skip kfd init if GFX is not ready. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1e0f137
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: Validate user queue update (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2a4a70f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: Validate user queue svm memory residency (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 45e7321
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9.4.3: Enable bad opcode interrupt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6aff915
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9: Enable bad opcode interrupt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2ebf454
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx12: Enable bad opcode interrupt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 701d7a6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx10: Enable bad opcode interrupt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ef2ae7d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx11: Enable bad opcode interrupt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 470fdd8
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx: add bad opcode interrupt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 42bb76b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9: properly handle error ints on all pipes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 43130eb
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx12: properly handle error ints on all pipes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 64b80b8
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx11: properly handle error ints on all pipes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6bf32a1
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx10: properly handle error ints on all pipes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0671082
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx12: enable wave kill for compute queues (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c9609dc
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx11: enable wave kill for compute queues (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7257c66
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx10: enable wave kill for compute queues (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 31cc343
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add NULL check for clk_mgr in dcn32_init_hw (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0d2b248
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: Ensure user queue buffers residency (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f323ca
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9.4.3: implement wave kill for compute queues (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4c2b517
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add print support for sdma_v_4_4_2 ip_dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5355d2d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add NULL check for clk_mgr and clk_mgr->funcs in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2e493c9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: Validate user queue buffers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 96b1d58
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx9: enable wave kill for compute queues (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1131c44
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx8: enable wave kill for compute queues (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5318f6e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu/gfx7: enable wave kill for compute queues (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 19bd32b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Implement bounds check for stream encoder creation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a740d3e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add kdoc entry for 'bs_coeffs_updated' in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0813604
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.293 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit faa2182
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: remove unused folder (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7812a38
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Remove duplicate HWSS interfaces (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2b07802
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Various DML2 fixes for FAMS2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ea3997
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Remove old comments (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fbdc4ea
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add MST debug message when link detection fails (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb01a85
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Check top sink only when multiple streams for DP2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 808bd0e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Fix Potential Null Dereference (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6562c51
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add helper function to check for non-address fast (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit add02fc
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: rename dcn401_soc to dcn4_variant_a_soc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 774f6c9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: rename dcn3/dcn4 to more sound terms (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe5c574
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add source select helper functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0a5f42f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Check if Mode is Supported Before Returning Result (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7879e41
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: ensure EASF and ISHARP coefficients are programmed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit da1bf2c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Fix visual confirm bug for SubVP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f463a6f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add RCG helper functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d098219
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Refactoring HPO (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 623780f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add private data type for RCG (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 380611e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Remove hardmax usage for dcn401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8c45de5
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: Refactor queue wptr_bo GART mapping (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5694da0
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Add sdma_v4_4_2 ip dump for devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e61fe15
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add print support for sdma_v_4_0 ip_dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7b1923a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdkfd: kfd_bo_mapped_dev support partition (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f732a9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: disallow multiple BO_HANDLES chunks in one submit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 69ac955
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Add sdma_v4_0 ip dump for devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8e56b7b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add print support for sdma_v_7_0 ip_dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 349c3c7
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Add sdma_v7_0 ip dump for devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cc72054
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add 'pstate_keepout' kdoc entry in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit adb463e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Remove unused code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9070e92
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: optimize logging deferred error info (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6507dcb
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: optimize umc v12 address conversion function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0393f72
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/radeon: change drm_dev_alloc to devm_drm_dev_alloc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6a37951
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/radeon: change rdev->ddev to rdev_to_drm(rdev) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3ba7e60
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/radeon: add helper rdev_to_drm(rdev) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 97484e6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/radeon: use variable flags as parameter (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5e66bfe
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/radeon: remove load callback from kms_driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e1c60ac
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/radeon: change variable name "dev" to "ddev" for consistency (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f230f5f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.292 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 29c94bc
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Remove unused dml2_core_ip_params struct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 76694ac
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Remove unnecessary DSC power gating for DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 77c6bd9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: free bo used for dmub bounding box (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c2ccfb6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add visual confirm for Idle State (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6bca2dd
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Set Cursor Matrix to bypass instead of Input Plane (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a40852f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Check stream pointer is initialized before accessing (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 945d7e5
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Export additional FAMS2 global configuration options (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3e7c6c5
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Refactoring DWB related files from dcn30 Files (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1824df9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: add dmcub support check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c9b6420
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Increase array size of dummy_boolean (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 74daefe
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add P-State Keepout to dcn401 Global Sync (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2e437e1
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: remove dc dependencies from SPL library (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit 41677ff
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Issue with 3 or more mcaches per surface (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1fa8f80
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Calculate ODM width using odm slice rect, not recout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 810fee9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add blanked streams override to DML2.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1896a07
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Fix VRR cannot enable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8dd55a8
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Refactoring MPC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0895aaa
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: DML2.1 resynchronization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9de778d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Do 1-to-1 mapping between OPP and DSC in DML2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a31d640
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Refactoring MMHUBBUB (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9f3c07c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Refactoring OPP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 625f8aa
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Fix DP-DVI dongle hotplug (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d5b50bd
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Disable subvp based on HW cursor requirement (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bd420b3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: When resync fifo ensure to use correct pipe ctx (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ddd680c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Add option to allow transition when odm is forced (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f4a22f6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: avoid disable otg when dig was disabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4460c99
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Implement bias and scale pre scl (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9ff81f6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: apply vmin optimization even if it doesn't reach (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 54af8f1
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: fix dscclk programming sequence on DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6a2c4c1
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Replace assert with error message in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9297efb
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Added logging for automated DPM testing (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f77918e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Don't consider cursor for no plane case in DML1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 252c595
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: quality improvements for EASF and ISHARP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b63468c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Disable HBR audio for DP2 for certain ASICs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6afb984
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd/display: Disable replay if VRR capability is false (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cf439af
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add print support for sdma_v_5_0 ip_dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1989b33
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Add sdma_v5_0 ip dump for devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5b02bc1
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add print support for sdma_v_6_0 ip_dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 378e297
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Add sdma_v6_0 ip dump for devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cd3776c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: fix the print message in devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c9a11d9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: fix the extra space between two functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1bb62ee
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: add print support for sdma_v_5_2 ip_dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b830d7b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Add sdma_v5_2 ip dump for devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7a641a5
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/gem: Calculate object page offset for partial memory mapping (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 754f903
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/gem: Do not look for the exact address in node (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 85144ec
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/gt: remove stray declaration of intel_gt_release_all() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bf80064
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/guc: Change GEM_WARN_ON to guc_err to prevent taints in CI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 12e0e54
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/gt: Mark the GT as dead when mmio is unreliable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 43336ed
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: Replace double blank with single blank after comma in gem/ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 383cc0b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/gem: Improve pfn calculation readability in vm_fault_gtt() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f01a8d2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: 2 GiB of relocations ought to be enough for anybody* (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c75b596
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/gt: Empty uabi engines list during intel_engines_release() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 03ba06b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/gt: Add Wa_14019789679 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4242473
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/guc: Extend w/a 14019159160 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 54391c6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/arl: Enable Wa_14019159160 for ARL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a668fab
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/vc4: v3d: simplify clock retrieval (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 15418a8
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/vc4: Get the rid of DRM_ERROR() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cacc87a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ast: Remove BMC output (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c3163aa
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ast: vga: Transparently handle BMC support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 968e5a1
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ast: sil164: Transparently handle BMC support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1cb9efc
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ast: dp501: Transparently handle BMC support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1e3db25
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ast: dp501: Use struct drm_edid and helpers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 51ee394
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ast: astdp: Transparently handle BMC support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d6d0858
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ast: astdp: Simplify power management when detecting display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 11bb3aa
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ast: astdp: Use struct drm_edid and helpers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5592afb
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ast: astdp: Move locking into EDID helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f2f18d0
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ast: Add struct ast_connector (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 102c60b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ast: Move code for physical outputs into separate files (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4cc7815
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: jdi-fhd-r63452: transition to mipi_dsi wrapped functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aa19290
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/mipi-dsi: Add mipi_dsi_dcs_set_tear_scanline_multi (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ed0118c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: ili9341: Add comments for registers in ili9341_config() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 08b4441
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: mantix-mlaf057we51: write hex in lowercase (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b891071
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: mantix-mlaf057we51: transition to mipi_dsi wrapped (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2255a2c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: jd9365da: Modify the init code of Melfas (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4bede2f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: jd9365da: Move "exit sleep mode" and "set display on" cmds (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 24411fa
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: simple: Add ON Tat Industrial Company KD50G21-40NT-A1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7b950be
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: st7701: Add Anbernic RG28XX panel support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 86d3ff9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: st7701: Add support for SPI for configuration (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 06b8797
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: st7701: Decouple DSI and DRM parts (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2edf1fd
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: st7701: Rename macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c765e64
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: simple: add Innolux G070ACE-LH3 LVDS display support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 23c1404
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/bridge: nwl-dsi: Use vsync/hsync polarity from display mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d4d69fc
* Thu Nov 28 2024 pjakobsson@suse.de
- drm: bridge: anx7625: Use of_property_read_variable_u8_array() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 064568f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/bridge: dw-hdmi: Simplify clock handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c1b122e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm: use mem_is_zero() instead of !memchr_inv(s, 0, n) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 187473f
* Thu Nov 28 2024 pjakobsson@suse.de
- string: add mem_is_zero() helper to check if memory area is all zeros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit cf8e669
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/tilcdc: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f797e4f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/radeon: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 518da67
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: panel-sony-acx565akm: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 408e44b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: panel-samsung-s6e3ha2: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7f38f19
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: panel-samsung-s6e63j0x03: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit abcacec
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: panel-orisetech-otm8009a: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d3ae585
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: panel-novatak-nt35510: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit db0c296
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit df758e7
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/rockchip: dw_hdmi: Add max_tmds_clock validation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2551034
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/rockchip: dw_hdmi: Allow High TMDS Bit Rates (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bf0e92a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/vkms: Formatting and typo fix (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b0e314c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/rockchip: dw_hdmi: Drop superfluous assignments of mpll_cfg, (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit daf655c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/rockchip: dw_hdmi: Use devm_regulator_get_enable() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9482679
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/rockchip: dw_hdmi: Simplify clock handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d2574a2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/rockchip: dw_hdmi: Use modern drm_device based logging (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 736a019
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/rockchip: Explicitly include bits header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8d88b78
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/rockchip: Constify struct drm_encoder_helper_funcs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4c1ec51
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/rockchip: cdn-dp: Clean up a few logged messages (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 13c11c0
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/edid: make drm_edid_block_valid() static (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0fb2539
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/gvt: stop using drm_edid_block_valid() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9378661
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/rockchip: cdn-dp: get rid of drm_edid_raw() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d9d4699
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/edid: reduce DisplayID log spamming (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4d46c38
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ci: uprev mesa (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 530afe6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ci: Upgrade setuptools requirement to 70.0.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b62cc87
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: startek-kd070fhfid015: transition to mipi_dsi wrapped (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ee41de4
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/mipi-dsi: add more multi functions for better error handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4f5ffb9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ast: astdp: fix loop timeout check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0b8b6a5
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/hisilicon: Remove unused delarations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 016448a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm: Remove struct drm_mode_config_funcs.output_poll_changed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0ec74b2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm: Remove struct drm_driver.lastclose (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 482db90
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/fbdev-helper: Remove drm_fb_helper_output_poll_changed() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 443cd0b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/fbdev-helper: Update documentation on obsolete callbacks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b746ce8
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: Implement switcheroo reprobe with (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 37ac91f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: Do not set struct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 56baaf2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: Do not set struct drm_driver.lastclose (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa9338f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amdgpu: Do not set struct drm_driver.lastclose (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4c3ad89
* Thu Nov 28 2024 pjakobsson@suse.de
- drm: Do delayed switcheroo in drm_lastclose() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7439458
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/connector: kerneldoc: Fix two missing newlines in drm_connector.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b17a5a8
* Thu Nov 28 2024 pjakobsson@suse.de
- drm: Add missing documentation for struct drm_plane_size_hint (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4f1f85a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panic: Add panic description (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a1db8bc
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panic: Move copyright notice to the top (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 839dc1d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panic: Move drm_panic_register prototype to drm_crtc_internal.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f84a780
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panic: Remove useless export symbols (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5613e32
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panic: Remove space before "!" in panic message (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 709f6a6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: use pdev_to_i915() instead of pci_get_drvdata() directly (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d71a2ef
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/bios: convert to struct intel_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dfc0410
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/opregion: convert to struct intel_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2286038
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/opregion: unify intel_encoder/intel_connector naming (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e304996
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/acpi: convert to struct intel_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 474eaf5
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/bmg: Read display register timeout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a84bcc6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: remove __i915_printk() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 429ed98
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: remove i915_report_error() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ac63343
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: remove a few __i915_printk() uses (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fff8c97
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: Replace double blank with single blank after comma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8fcc631
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: Remove DSC register dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1b91351
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: Dump DSC state to dmesg and debugfs/i915_display_info (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 09db6ff
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: Replace BPP_X16_FMT()/ARGS() with FXP_Q4_FMT()/ARGS() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 671b365
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: Replace to_bpp_frac() with fxp_q4_to_frac() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 705a9d2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: Replace to_bpp_int_roundup() with fxp_q4_to_int_roundup() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e0a993d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: Replace to_bpp_int() with fxp_q4_to_int() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 07ec670
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: Replace to_bpp_x16() with fxp_q4_from_int() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e20907b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d7c93de
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: remove unused HAS_BROKEN_CS_TLB() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dcdf76b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/dpkgc: Add VRR condition for DPKGC Enablement (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f1dbdfe
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Enable LT fallback between UHBR/non-UHBR link rates (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c977cda
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Ensure link parameters are up-to-date for a disabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 27f1461
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Reprobe the MST topology after a link parameter (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 99e6d69
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Queue modeset-retry after a failed payload BW (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5c23da0
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Configure MST after the link parameters are reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e652bc6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Reduce the link parameters in BW order after LT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2f32e10
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/dp: Add helpers to set link training mode, BW parameters (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bebed2e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/dp: Add a separate function to reduce the link parameters (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c6731f9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/dp: Send only a single modeset-retry uevent for a commit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5eb039d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/dp: Initialize the link parameters during HW readout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f3ab46e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/ddi: For an active output call the DP encoder sync_state() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 70c78f3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/dp_mst: Simplify the condition when to enumerate path resources (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d277102
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/dp_mst: Add a helper to queue a topology probe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 877357a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/dp_mst: Factor out function to queue a topology probe work (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5e186b9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/bios: remove stale and useless comments (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dfa6ae6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/display/dp: Compute AS SDP when vrr is also enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d3c1c13
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/dp: Clear VSC SDP during post ddi disable routine (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 98198b0
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/hdcp: Check GSC structure validity (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1211c97
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/hdcp: Add encoder check in hdcp2_get_capability (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 756f9e7
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/hdcp: Add encoder check in intel_hdcp_get_capability (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 095a6df
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/dp: Make read-only array bw_gbps static const (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fc8d131
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: Make I2C terminology more inclusive (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f7baa26
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/dp: Don't WARN on failed link-retrain modeset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 439c052
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/dp: Require a valid atomic state for SST link training (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d092545
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/dp: Retrain SST links via a modeset commit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5eaf46d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/fbc: Extract intel_fbc_cfb_cpp() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 011b1b6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/fbc: Extract _intel_fbc_cfb_size() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 09b6288
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/fbc: Extract intel_fbc_max_cfb_height() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c1ddd7c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/fbc: Reoder CFB max height platform checks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cc461c1
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/fbc: s/lines/height/ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2356ed3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/fbc: Extract _intel_fbc_cfb_stride() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 974ba09
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/fbc: Adjust g4x+ platform checks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8b2ff91
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/fbc: (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b4c5394
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/fbc: Extract intel_fbc_max_surface_size() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6539596
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/fbc: Extract intel_fbc_max_plane_size() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1ae6845
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/fbc: s/_intel_fbc_cfb_stride()/intel_fbc_plane_cfb_stride()/ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d5b0bdb
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/fbc: Convert to intel_display, mostly (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6d61fb9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/fbc: Extract intel_fbc_has_fences() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aabf6c2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: Make vrr_{enabling,disabling}() usable outside (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1014ee7
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: Calculate vblank delay more accurately (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c05144f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/dp: Keep cached LTTPR mode up-to-date (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0a0a8b6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/dp: Reset cached LTTPR count if number of LTTPRs is (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d7ddf2f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/display: WA for Re-initialize dispcnlunitt1 xosc clock (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8088208
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915/display: Cache adpative sync caps to use it later (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f3a29c4
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: Skip programming FIA link enable bits for MTL+ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4a52a63
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/mgag200: Remove BMC output (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 525446b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/mgag200: vga-bmc: Control BMC scanout from encoder (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 90fff53
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/mgag200: vga-bmc: Control CRTC VIDRST flag from encoder (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 76860d9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/mgag200: vga-bmc: Transparently handle BMC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2d637ba
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/mgag200: Add VGA-BMC output (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 84a3721
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/vkms: Fix cpu_to_le16()/le16_to_cpu() warnings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 22a6b38
* Thu Nov 28 2024 pjakobsson@suse.de
- gpu: drm: use for_each_endpoint_of_node() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1f10655
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ci: rockchip: add tests for rockchip display driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4fd7c7e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ci: meson: add tests for meson display driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 770e81d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ci: mediatek: add tests for powervr gpu driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2671e76
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ci: mediatek: add tests for mediatek display driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9fb1232
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ci: skip tools_test on non-intel platforms (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe95958
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ci: arm64.config: Enable CONFIG_DRM_ANALOGIX_ANX7625 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a48e044
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/bridge: lt9611uxc: drop support for (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ab6cb6b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/bridge: lt9611uxc: properly attach to a next bridge (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1f156f6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/connector: Document destroy hook in drmm init functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aeb4a3a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel-edp: Fix HKC MB116AN01 name (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 35b822e
* Thu Nov 28 2024 pjakobsson@suse.de
- Revert "drm/amd: Add power_saving_policy drm property to eDP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fc87af2
* Thu Nov 28 2024 pjakobsson@suse.de
- Revert "drm: Introduce 'power saving policy' drm property" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 573bb3b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/bridge: synopsys: dw-mipi-dsi: enable EoTp by default (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 069df14
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/loongson: use GEM references instead of TTMs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b473ffb
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/mgag200: Fix VBLANK interrupt handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3207dda
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/dp: Describe target_rr_divider in struct drm_dp_as_sdp (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e77720a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ast: astdp: Clean up EDID reading (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1440587
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ast: astdp: Perform link training during atomic_enable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8dd44a2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ast: astdp: Only test HDP state in ast_astdp_is_connected() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 90fc6f0
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ast: astdp: Test firmware status once during probing (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fd640f2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm: Add the missing symbol '.' (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f165f2e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: remove unused variable ret (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1f1af64
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/gma500: Make I2C terminology more inclusive (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 73d6df2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau/kms: remove push pointer from nv50_dmac (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 56b8d62
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau/kms: remove a few unused struct members and fn decls (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e1bc277
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: remove push pointer from nouveau_channel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6e9e8a2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: remove master (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5ce1536
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: remove chan->drm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ef41d8
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: remove nouveau_chan.device (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b12a09
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: pass cli to nouveau_channel_new() instead of drm+device (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a79e9c4
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: pass drm to nv50_dmac_create(), rather than device+disp (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 06f9ffa
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: pass drm to nouveau_mem_new(), instead of cli (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 72ba5d2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: add nvif_mmu to nouveau_drm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7ddc7c3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: move nvxx_* definitions to nouveau_drv.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 61ac490
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau/nvif: remove disp chan rd/wr (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 76716ac
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau/nvif: remove device rd/wr (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7040b97
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: always map device (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e5f2a7a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau/nvif: remove device args (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5679c8e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau/nvif: remove client fini (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1db037b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau/nvif: remove client devlist (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 10ea819
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau/nvif: remove client version (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b08648e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau/nvif: remove client device arg (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 06f4ec4
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau/nvif: remove driver keep/fini (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a808558
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau/nvif: remove nvxx_client() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a018cf4
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau/nvif: remove nvxx_object() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 59cb326
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau/nvif: remove route/token (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3b7df9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau/nvif: remove support for userspace backends (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 92f13ca
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau/nvkm: remove nvkm_client_search() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit caa8b58
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau/nvkm: remove perfmon (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5c5acd8
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau/nvkm: remove detect/mmio/subdev_mask from device args (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 74c988a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: remove abi16->handles (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 80024e4
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: remove abi16->device (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 55b2636
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: handle limited nvif ioctl in abi16 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1445ae5
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: add nouveau_cli to nouveau_abi16 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 315fdd4
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: move allocation of root client out of nouveau_cli_init() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7834af8
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: store nvkm_device pointer in nouveau_drm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d79ff87
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: create pci device once (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f9cc6dc
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: replace drm_device* with nouveau_drm* as dev drvdata (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c74b701
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: handle pci/tegra drm_dev_{alloc, register} from common code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-nouveau-blacklist-Turing-and-Ampere-models-as-default.patch.
- commit b78cacd
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: move nouveau_drm_device_fini() above init() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 181bb7e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/vblank: add dynamic per-crtc vblank configuration support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6ffdad2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel-edp: Add CSW MNB601LS1-4 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9646f0e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ci: update link to Gitlab server (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f1cddab
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: nt36672e: Break some CMDS into helper functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cca5215
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: nt35521: Break some CMDS into helper functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd6d2c4
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: boe-tv101wum-nl6: Break some CMDS into helper functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 75759cc
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/test: use kunit action wrapper macro in the gem shmem test suite (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7a1dba5
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/scheduler: remove full_recover from drm_sched_start (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 644e5de
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/bridge: it6505: Disable IRQ when powered off (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 059d393
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel/panel-ilitek-ili9806e: Add Densitron DMT028VGHMCMI-1D TFT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit af278fc
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: boe-th101mb31ig002 : using (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c4799f3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: boe-th101mb31ig002 : Fix the way to get porch parameters (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4143601
* Thu Nov 28 2024 pjakobsson@suse.de
- drm: panel: boe-bf060y8m-aj0: Enable prepare_prev_first (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 914b71b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/dp_mst: Simplify character output in drm_dp_mst_dump_topology() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7fc7400
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/bridge: tc358767: Add configurable default preemphasis (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 32723c8
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ttm: Allow direct reclaim to allocate local memory v2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e9f21a8
* Thu Nov 28 2024 pjakobsson@suse.de
- dma-buf: heaps: Deduplicate docs and adopt common format (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 921710a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: use GEM references instead of TTMs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8cd0679
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: bo: remove unused functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4855f92
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel-edp: Add 6 panels used by MT8186 Chromebooks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2122550
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: Avoid warnings w/ panel-simple/panel-edp at shutdown (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit be12644
* Thu Nov 28 2024 pjakobsson@suse.de
- fbcon: Use oops_in_progress instead of panic_cpu (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5c3c058
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panic: Add missing static inline to drm_panic_is_enabled() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5ec44a7
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/fb-helper: Set skip_panic if the drm driver supports drm panic (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 47a409c
* Thu Nov 28 2024 pjakobsson@suse.de
- fbcon: Add an option to disable fbcon in panic (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3bf8f1f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panic: Add drm_panic_is_enabled() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7c4431b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/stm: ltdc: remove reload interrupt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4487ad5
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/stm: ltdc: add mask for lxcr register (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 05aa5ac
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/stm: ltdc: reset plane transparency after plane disable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 47d2fab
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/mgag200: Implement struct drm_crtc_funcs.get_vblank_timestamp (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d80536a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/mgag200: Add vblank support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb685a7
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/mgag200: Add dedicted variable for <linecomp> field (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dfd17e6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/mgag200: Add dedicated variables for blanking fields (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0cb8f12
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/mgag200: Use adjusted mode values for CRTCs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 73ae955
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/mgag200: Align register field names with documentation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f3b63e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/mgag200: Use hexadecimal register indeces (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9cd31d5
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/bridge: analogix: remove unused struct 'bridge_init' (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9871310
* Thu Nov 28 2024 pjakobsson@suse.de
- drm: Add might_fault to drm_modeset_lock priming (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit f65d748
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/bridge: Silence error messages upon probe deferral (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4d6c98a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel-edp: Add entry for BOE NV133WUM-N63 panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a7870fb
* Thu Nov 28 2024 pjakobsson@suse.de
- drm: lcdif: Use adjusted_mode .clock instead of .crtc_clock (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f44bf66
* Thu Nov 28 2024 pjakobsson@suse.de
- accel/ivpu: Add missing MODULE_FIRMWARE metadata (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3069b60
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/stm: ltdc: Remove unused function plane_to_ltdc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f360524
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/stm: Avoid use-after-free issues with crtc and plane (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4936483
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/mgag200: Rename BMC vidrst names (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b803b1f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/mgag200: Remove vidrst callbacks from struct mgag200_device_funcs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 96743ac
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/mgag200: Only set VIDRST bits in CRTC modesetting (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d04d0e1
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/v3d: Expose memory stats through fdinfo (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f440ecd
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/v3d: Add some local variables in queries/extensions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4832095
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/v3d: Prefer get_user for scalar types (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 484b1a8
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/v3d: Move perfmon init completely into own unit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit ad76dc4
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/v3d: Do not use intermediate storage when copying performance (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 41d0e2c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/v3d: Move part of copying of reset/copy performance extension to (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b731443
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/nouveau: Improve variable name in nouveau_sched_init() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4ecdd76
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/dp: Add helper to dump an LTTPR PHY descriptor (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6606333
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel-edp: Add BOE NV140WUM-N41 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 617e575
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/amd: Add power_saving_policy drm property to eDP connectors (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b723d0
* Thu Nov 28 2024 pjakobsson@suse.de
- drm: Introduce 'power saving policy' drm property (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 94ffb4c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ci: uprev IGT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 995c48d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: boe-th101mb31ig002: Support for starry-er88577 MIPI-DSI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 47f369a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: boe-th101mb31ig002: use wrapped MIPI DCS functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 65565f7
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: boe-th101mb31ig002: switch to devm_gpiod_get_optional() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5db419c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: boe-th101mb31ig002 : Make it compatible with other panel. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d43ad3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: jd9365da: Break some CMDS into helper functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9f84a84
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: jd9365da: Support for Melfas lmfbx101117480 MIPI-DSI panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9c3d3b4
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: himax-hx8394: Add Support for Microchip AC40T08A MIPI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3f80b12
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/panel: himax-hx8394: switch to devm_gpiod_get_optional() for (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c8600fc
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ttm: Use the LRU walker for eviction (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f396990
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ttm: Use the LRU walker helper for swapping (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 150a0ee
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ttm: Provide a generic LRU walker helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1950d14
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ttm, drm/amdgpu, drm/xe: Consider hitch moves within bulk sublist (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a53b5a3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ttm: Use LRU hitches (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 868be5f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ttm: Slightly clean up LRU list iteration (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 36df094
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/ttm: Allow TTM LRU list nodes of different types (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 60a00c0
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/drm_connector: Document Colorspace property variants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 79e9f3d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/tegra: Call drm_atomic_helper_shutdown() at shutdown time (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 57739a8
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/stm: Remove unnecessary .owner for lvds_platform_driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3615c20
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/vkms: Remove event from vkms_output (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5ab5a0d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/sti: hqvdp: drop driver owner assignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0faf3fd
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/sti: hdmi: drop driver owner assignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d74af96
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/sti: vtg: drop driver owner assignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bdf460a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/sti: tvout: drop driver owner assignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5309030
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/sti: hda: drop driver owner assignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a5da8f4
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/sti: dvo: drop driver owner assignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 412599f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/xe2hpg: Introduce performance tuning changes for Xe2_HPG (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2387b34
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Migrate OOB WAs to OR rules (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f2a2436
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/rtp: Expand max rules/actions per entry again (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b533493
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/rtp: Simplify marking active workarounds (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1468f51
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/kunit: Test rtp with no actions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0bee518
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/kunit: Rename rtp test cases (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2fdf13c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/kunit: Test active rtp entries (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8082c6b
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/kunit: Rename count to count_sr_entries (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e6b1007
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/kunit: Test WAs for BMG (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6fbdbf3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/migrate: Future-proof compressed PAT check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 95174de
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Assert G2H outstanding when releasing G2H (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6c9281a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/mmio: Use single logic for waiting functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d750f77
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Remove stale declaration of xe_mmio_probe_vram() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4cdb923
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/huc: Define HuC binary for BMG (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 38d0b1e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/gsc: Define GSC binary for LNL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 319ecd9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/huc: Define HuC binary for LNL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c68cfbe
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Delete unused register from xe_regs.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e5144a4
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Add assert for XE_WA() usage (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 629ded4
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Refactor mmio setup for multi-tile (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a5444a7
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Store process name and pid in xe file (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9ec88c7
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Return -ENOBUFS if a kmalloc fails which is tied to an array (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 07762e3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Fix xe_pt_abort_unbind (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cafc8c6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Fix warning on unreachable statement (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb8cdc6
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Add NEEDS_2M BO flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8181003
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Normalize NEEDS_64K BO flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 88104ee
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/tests: Skip xe_mocs live tests on VF device (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 41e2c96
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/tests: Convert xe_mocs live tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4216158
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/tests: Convert xe_migrate live tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa09d80
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/tests: Convert xe_dma_buf live tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f1a7c16
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/tests: Convert xe_bo live tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3f6bb19
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/tests: Add helpers for use in live tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c9061b9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Introduce const cast helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8c6db73
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/oa: Don't use hardcoded values (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f01fd5d
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/uapi: Expose SIMD16 EU mask in topology query (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 044abfa
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Remove unused xe_sync_entry_wait (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c48cd6c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/pm: Add trace for pm functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c345ef5
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/fbdev: Limit the usage of stolen for LNL+ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 98ec62c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/xe2: Do not run xe_bo_test for xe2+ dgfx (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3fd8ca0
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/migrate: Add kunit to test migration functionality for BMG (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f621d98
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/xe_migrate: Handle migration logic for xe2+ dgfx (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 100d231
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/xe2: Introduce identity map for compressed pat for vram (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 216280a
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/migrate: Add helper function to program identity map (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c5237c8
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/migrate: Add kunit to test clear functionality (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa30af0
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/migrate: Handle clear ccs logic for xe2 dgfx (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6305acf
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/gsc: add Battlemage support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0dd9916
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/vf: Track writes to inaccessible registers from VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 03b028e
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/kunit: Simplify xe_mocs live tests code layout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8fef32c
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/kunit: Simplify xe_migrate live tests code layout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1377579
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/kunit: Simplify xe_dma_buf live tests code layout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 379c9aa
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/kunit: Simplify xe_bo live tests code layout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f2a0691
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/kunit: Drop XE_TEST_EXPORT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bab4178
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/kunit: Kill xe_cur_kunit() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d211763
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Add process name and PID to job timedout message (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cc2b155
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Generate oob before compiling anything (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 47535cc
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/i915: disable fbc due to Wa_16023588340 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2a898a3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Use VF_CAP_REG for device wmb (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7ac98cb
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Kill regs/xe_sriov_regs.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ec4034
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Fix register definition order in xe_regs.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bc5b631
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Add VM bind IOCTL error injection (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d4c5c7f
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Update PT layer with better error handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8948835
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Update VM trace events (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d2e734a
* Thu Nov 28 2024 dsterba@suse.com
- posix-clock: posix-clock: Fix unbalanced locking in pc_clock_settime() (CVE-2024-50195 bsc#1233103)
- commit 6192694
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Convert multiple bind ops into single job (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit 9c874c3
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Add xe_exec_queue_last_fence_test_dep (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8b416d2
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Add xe_vm_pgtable_update_op to xe_vma_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 409f1d9
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: s/xe_tile_migrate_engine/xe_tile_migrate_exec_queue (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f34854
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe: Add timeout to preempt fences (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2d29532
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/xe/guc: Demote GuC IDs usage message to debug (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 32e5d9d
* Thu Nov 28 2024 pjakobsson@suse.de
- fbdev: omapfb: Fix typo in comment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0417b43
* Thu Nov 28 2024 pjakobsson@suse.de
- fbdev: pxafb: Fix possible use after free in pxafb_task() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6ec0af9
* Thu Nov 28 2024 pjakobsson@suse.de
- fbdev: xen-fbfront: Assign fb_info->device (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 30f1602
* Thu Nov 28 2024 pjakobsson@suse.de
- fbdev: hyperv_fb: Convert comma to semicolon (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1b30126
* Thu Nov 28 2024 pjakobsson@suse.de
- fbdev: imsttfb: convert comma to semicolon (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d15e907
* Thu Nov 28 2024 pjakobsson@suse.de
- fbdev: pxa3xx-gcu: Convert comma to semicolon (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0c6ff43
* Thu Nov 28 2024 pjakobsson@suse.de
- fbdev: efifb: Use driver-private screen_info for sysfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d4fbdf6
* Thu Nov 28 2024 pjakobsson@suse.de
- fbdev: efifb: Use devm_register_framebuffer() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a178196
* Thu Nov 28 2024 pjakobsson@suse.de
- fbdev: Introduce devm_register_framebuffer() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f91a885
* Thu Nov 28 2024 pjakobsson@suse.de
- fbdev: omapfb: Use sysfs_emit_at() to simplify code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d2fd243
* Thu Nov 28 2024 pjakobsson@suse.de
- fbdev: omapfb: panel-sony-acx565akm: Simplify (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f5779c8
* Thu Nov 28 2024 pjakobsson@suse.de
- fbdev: mmp: Use devm_clk_get_enabled() helpers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b2608b
* Thu Nov 28 2024 pjakobsson@suse.de
- video: Handle HAS_IOPORT dependencies (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7308111
* Thu Nov 28 2024 pjakobsson@suse.de
- drm/bridge: dw-hdmi: Move vmalloc PCM buffer management into the (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b7bf69d
* Thu Nov 28 2024 pjakobsson@suse.de
- Documentation/gpu: Fix typo in Documentation/gpu/komeda-kms.rst (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f34b9a2
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Fix-initialization-mistake-for-NBIO-7.7.0.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4e8c2e2
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-check-in-gmc_v9_0_get_vm_pte.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 44731ce
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Adjust-VSDB-parser-for-replay-featur.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bcc1f19
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-Fix-DSI-command-tx.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cedf623
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-dp-handle-retries-for-AUX-CH-transfers-with-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 171e2d9
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-handle-EBUSY-and-EAGAIN-for-GSP-aux-errors.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 18661e3
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-fw-sync-dma-after-setup-is-called.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 314c478
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-vop-Fix-a-dereferenced-before-check-war.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 852e7b5
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-add-missing-size-check-in-amdgpu_debugfs_.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ecdf10c
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Adjust-debugfs-eviction-and-IB-access-per.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d071ce6
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Adjust-debugfs-register-access-permission.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 12b9899
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-DPX-valid-mode-check-on-GC-9.4.3.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 87c4a9c
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-prevent-NULL-pointer-dereference-if-ATIF-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7bb2c2d
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/mei-use-kvmalloc-for-read-buffer.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3d1bd1a
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-get-efuse-issue-for-MT8188-DPTX.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 775c2ab
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-Vangogh-Fix-kernel-memory-out-of-bounds-w.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5d03f62
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Disable-PSR-SU-on-Parade-08-01-TCON-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6048dda
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-xe-xe_sync-initialise-ufence.signalled.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fec7b15
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/accel-qaic-Fix-the-for-loop-used-to-walk-SG-table.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd5d62a
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-vmwgfx-Handle-surface-check-failure-correctly.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 93f5853
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-vmwgfx-Limit-display-layout-ioctl-array-size-to-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0227812
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-swsmu-Only-force-workload-setup-on-init.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e51cc2f
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-Fix-encoder-possible_clones.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d54acb2
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Accounting-pdd-vram_usage-for-svm.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 467123f
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-amdgpu-Fix-double-unlock-in-amdgpu_mes_add_r.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a455daa
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-don-t-always-program-merge_3d-block.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 23c0046
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-Allocate-memory-for-disp-snapshot-with-kvzal.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 44e2cd2
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dsi-fix-32-bit-signed-integer-extension-in-p.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit feecf63
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dsi-improve-fix-dsc-pclk-calculation.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7107ada
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-check-for-overflow-in-_dpu_crtc_setup_lm.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit acbbd88
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-move-CRTC-resource-assignment-to-dpu_enc.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a42f5f7
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-make-sure-phys-resources-are-properly-in.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ee96e25
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-dmem-Fix-vulnerability-in-migrate_to_ram-upo.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 95d8f46
* Thu Nov 28 2024 pjakobsson@suse.de
- Delete patches.suse/nouveau-dmem-Fix-privileged-error-in-copy-engine-cha.patch.
- commit fd87ff0
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-vc4-Stop-the-active-perfmon-before-being-destroy.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 691d33e
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-v3d-Stop-the-active-perfmon-before-being-destroy.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c60f7dc
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-hdcp-fix-connector-refcounting.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8db0baf
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gem-fix-bitwise-and-logical-AND-mixup.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 38142bb
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-sched-Add-locking-to-drm_sched_entity_modify_sch.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 511f1c8
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-system-hang-while-resume-with-TB.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 379e068
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-update-DML2-policy-EnhancedPrefetchS.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3fcc6d4
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-Consistently-use-struct-drm_mode_rect-for-FB_DAM.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1748e3e
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/fbcon-Fix-a-NULL-pointer-dereference-issue-in-fbcon_.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 107758a
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-vcn-enable-AV1-on-both-instances.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 47a715f
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-handle-nulled-pipe-context-in-DCE110.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4db592d
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-get-each-xcp-macro.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e443973
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Validate-backlight-caps-are-sane.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c32bba5
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Skip-to-enable-dsc-if-it-has-been-of.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f0f206c
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Check-null-pointer-before-dereferenc.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 15bb89b
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-HDMI-DSC-native-YCbCr422-support.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cad2bcd
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Round-calculated-vtotal.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 12fcd09
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drivers-drm-exynos_drm_gsc-Fix-wrong-assignment-in-g.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d73d836
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-fix-s-null-argument-error.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 12a5d96
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dsi-correct-programming-sequence-for-SM8350-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 66d0871
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-a5xx-workaround-early-ring-buffer-emptiness-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 41e558a
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-a5xx-fix-races-in-preemption-evaluation-stag.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe5f5cd
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-a5xx-properly-clear-preemption-records-on-re.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c507aee
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-a5xx-disable-preemption-in-submits-by-defaul.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e07baca
* Thu Nov 28 2024 tiwai@suse.de
- media: av7110: fix a spectre vulnerability (CVE-2024-50289
  bsc#1233478).
- commit 2969047
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-adreno-Assign-msm_gpu-pdev-earlier-to-avoid-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1466285
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-Fix-incorrect-file-name-output-in-adreno_req.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 19da340
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-ovl_adaptor-Add-missing-of_node_put.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb39dc8
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-ensure-the-fw_info-is-not-null-before-usi.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bbb134c
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-double-free-issue-during-amdgpu-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 363ae09
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-evergreen_cs-fix-int-overflow-errors-in-c.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 83f83cc
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/0001-drm-amd-display-Check-null-pointer-before-try-to-acc.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f80772e
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/0001-drm-amd-display-Check-null-pointers-before-using-dc-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4095778
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/0001-drm-amd-display-Add-null-check-for-afb-in-amdgpu_dm_.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b5637c5
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-amdgpu-Properly-tune-the-size-of-struct.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5379070
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-NULL-check-for-function-pointer-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bed2b83
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-NULL-check-for-function-pointer-2.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d61d1ed
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Handle-null-stream_status-in-planes_.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ab18822
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Initialize-get_bytes_per_element-s-d.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit db80054
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-null-check-for-top_pipe_to_progr.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b0c4073
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/0001-drm-amd-display-Add-null-check-for-pipe_ctx-plane_st.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 976af51
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-properly-handle-vbios-fake-edid-sizing.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8790f48
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-properly-handle-vbios-fake-edid-sizing.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 21de38e
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-null-check-for-set_output_gamma-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e2f5494
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/0001-drm-amd-display-Add-null-check-for-head_pipe-in-dcn3.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 33614f8
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/0001-drm-amd-display-Add-null-check-for-head_pipe-in-dcn2.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ebcc52d
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-index-out-of-bounds-in-DCN30-col.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 098636a
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-index-out-of-bounds-in-degamma-h.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 09935ea
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-index-out-of-bounds-in-DCN30-deg.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 283ab6a
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-amdkfd_free_gtt_mem-clear-the-correct-poi.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb5563e
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-a-possible-null-pointer-dereference.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a442e0f
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-fix-null-pointer-dereference-in-radeon_ad.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eea6780
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/0001-drm-amd-display-Check-null-pointers-before-multiple-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4b065a1
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/0001-drm-amd-display-Check-link_res-hpo_dp_link_enc-befor.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit baa9c05
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Deallocate-DML-memory-if-allocation-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0595ab7
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Check-stream-before-comparing-them.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 37a81df
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Check-null-pointers-before-using-the.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 09b07ff
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Pass-non-null-to-dcn20_validate_appl.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7f42522
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Check-phantom_stream-before-it-is-us.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2dc16b0
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/0001-drm-amd-display-Check-null-initialized-variables.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 12e7147
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Initialize-denominators-default-to-1.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e972299
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Revert-Check-HDCP-returned-status.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6d61d15
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-vc4-hdmi-Handle-error-case-of-pm_runtime_resume_.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fff9356
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-lontium-lt8912b-Validate-mode-in-drm_brid.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 007a891
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-dw_hdmi-Fix-reading-EDID-when-using-a-f.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eaff4e8
* Thu Nov 28 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-efifb-Register-sysfs-groups-through-driver-cor.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e546959
* Thu Nov 28 2024 pjakobsson@suse.de
- blacklist.conf: Unblacklist patches for DRM v6.12 backport
- commit bf691f0
* Thu Nov 28 2024 pjakobsson@suse.de
- Revert "drm/v3d: Fix Indirect Dispatch configuration for V3D 7.1.6 and later (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)"
  This reverts commit ba09c12a16c62ae24a7a07465cd6434d37a7bca6.
  SUSE: The contents of this patch got removed in a merge commit
  (ba09c12a16c62ae24a7a07465cd6434d37a7bca6)
- commit 93b92b9
* Thu Nov 28 2024 tiwai@suse.de
- Drop OCFS2 patch causing a regression (bsc#1233255)
  Deleted:
  patches.suse/ocfs2-fix-the-la-space-leak-when-unmounting-an-ocfs2-volume.patch
- commit 2a24fc4
* Thu Nov 28 2024 sjaeckel@suse.de
- net: fix out-of-bounds access in ops_init (CVE-2024-36883
  bsc#1225725).
- commit f1b40e8
* Thu Nov 28 2024 tiwai@suse.de
- efi/memattr: Ignore table if the size is clearly bogus
  (bsc#1231465).
- commit c92a68e
* Thu Nov 28 2024 tiwai@suse.de
- thermal: int3400: Fix reading of current_uuid for active policy
  (git-fixes).
- gpio: exar: set value when external pull-up or pull-down is
  present (git-fixes).
- gpio: zevio: Add missed label initialisation (git-fixes).
- commit a62e144
* Thu Nov 28 2024 tiwai@suse.de
- ALSA: hda/realtek: Apply quirk for Medion E15433 (bsc#1233298).
- commit 9a99613
* Thu Nov 28 2024 jlee@suse.com
- x86/efistub: Revert to heap allocated boot_params for PE
  entrypoint (jsc#PED-11167).
- efi: Replace efi_memory_attributes_table_t 0-sized array with
  flexible array (jsc#PED-11167).
- efi: Rename efi_early_memdesc_ptr() to efi_memdesc_ptr()
  (jsc#PED-11167).
- arm64/efistub: Clean up KASLR logic (jsc#PED-11167).
- x86/efistub: Avoid returning EFI_SUCCESS on error
  (jsc#PED-11167).
- x86/efistub: Call Apple set_os protocol on dual GPU Intel Macs
  (jsc#PED-11167).
- x86/efistub: Enable SMBIOS protocol handling for x86
  (jsc#PED-11167).
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch.
- efistub/smbios: Simplify SMBIOS enumeration API (jsc#PED-11167).
- x86/efi: Drop support for fake EFI memory maps (jsc#PED-11167).
- commit a848f4b
* Thu Nov 28 2024 trenn@suse.com
- platform/x86: ISST: Allow reading core-power state on HWP
  disabled systems (jsc#PED-10107).
- commit 6fa895b
* Thu Nov 28 2024 trenn@suse.com
- platform/x86: ISST: Process read/write blocked feature status
  (jsc#PED-10107).
- commit 352edf0
* Thu Nov 28 2024 trenn@suse.com
- platform/x86: ISST: Ignore minor version change (jsc#PED-10107).
- commit 64ad15a
* Thu Nov 28 2024 trenn@suse.com
- platform/x86: ISST: Allow level 0 to be not present
  (jsc#PED-10107).
- commit b6fadf3
* Thu Nov 28 2024 trenn@suse.com
- platform/x86: ISST: Use fuse enabled mask instead of allowed
  levels (jsc#PED-10107).
- commit fe90254
* Wed Nov 27 2024 tbogendoerfer@suse.de
- ice: fix crash on probe for DPLL enabled E810 LOM
  (CVE-2024-53048 bsc#1233721).
- commit 5f7ca77
* Wed Nov 27 2024 nmorey@suse.com
- Update references for patches.suse/RDMA-siw-Add-sendpage_ok-check-to-disable-MSG_SPLICE.patch (bsc#1233641 CVE-2024-53094)
- commit 1f528cf
* Wed Nov 27 2024 jlee@suse.com
- ACPI: video: Add backlight=native quirk for Dell OptiPlex 5480
  AIO (jsc#PED-11164).
- ACPI: video: Add backlight=native quirk for Dell OptiPlex 7760
  AIO (jsc#PED-11164).
- ACPI: video: Add Dell UART backlight controller detection
  (jsc#PED-11164).
- x86/aperfmperf: Fix deadlock on cpu_hotplug_lock
  (jsc#PED-11164).
- ACPI: NFIT: add missing MODULE_DESCRIPTION() macro
  (jsc#PED-11164).
- ACPI: PCI: Remove unused struct 'acpi_handle_node'
  (jsc#PED-11164).
- ACPI: utils: introduce acpi_get_local_u64_address()
  (jsc#PED-11164).
- ACPI: add missing MODULE_DESCRIPTION() macros (jsc#PED-11164).
- ACPI: video: force native for some T2 macbooks (jsc#PED-11164).
- ACPI: video: Use strscpy() instead of strcpy() (jsc#PED-11164).
- ACPI: resource: Skip IRQ override on Asus Vivobook Pro N6506MJ
  (jsc#PED-11164).
- ACPI: resource: Skip IRQ override on Asus Vivobook Pro N6506MU
  (jsc#PED-11164).
- ACPI: acpi_pad: Still evaluate _OST when _PUR evaluation fails
  (jsc#PED-11164).
- ACPI: processor: Downgrade Intel _OSC and _PDC messages to debug
  (jsc#PED-11164).
- ACPI: HMAT: Use ACCESS_COORDINATE_CPU when appropriate
  (jsc#PED-11164).
- ACPI: bus: Indicate support for battery charge limiting thru
  _OSC (jsc#PED-11164).
- ACPI: battery: Add support for charge limiting state
  (jsc#PED-11164).
- ACPI: battery: use sysfs_emit over sprintf (jsc#PED-11164).
- ACPI: battery: constify powersupply properties (jsc#PED-11164).
- ACPI: SBS: constify powersupply properties (jsc#PED-11164).
- ACPI: AC: constify powersupply properties (jsc#PED-11164).
- ACPI: PMIC: Constify struct pmic_table (jsc#PED-11164).
- ACPI: PMIC: Replace open coded be16_to_cpu() (jsc#PED-11164).
- ACPI: PMIC: Convert pr_*() to dev_*() printing macros
  (jsc#PED-11164).
- ACPI: PMIC: Use sizeof() instead of hard coded value
  (jsc#PED-11164).
- ACPI: CPPC: Replace ternary operator with umax()
  (jsc#PED-11164).
- ACPI: CPPC: add sysfs entry for guaranteed performance
  (jsc#PED-11164).
- ACPI: fan: Add hwmon support (jsc#PED-11164).
- ACPI: battery: add devm_battery_hook_register() (jsc#PED-11164).
- ACPI: Add post_eject to struct acpi_scan_handler for cpu hotplug
  (jsc#PED-11164).
- ACPI: scan: switch to flags for acpi_scan_check_and_detach()
  (jsc#PED-11164).
- ACPI: processor: Register deferred CPUs from
  acpi_processor_get_info() (jsc#PED-11164).
- ACPI: processor: Add acpi_get_processor_handle() helper
  (jsc#PED-11164).
- ACPI: processor: Move checks and availability of acpi_processor
  earlier (jsc#PED-11164).
- ACPI: processor: Drop duplicated check on _STA (enabled +
  present) (jsc#PED-11164).
- ACPI: processor: Simplify initial onlining to use same path
  for cold and hotplug (jsc#PED-11164).
- ACPI / amba: Drop unnecessary check for registered
  amba_dummy_clk (jsc#PED-11164).
- arm64: FFH: Move ACPI specific code into drivers/acpi/arm64/
  (jsc#PED-11164).
- arm64: cpuidle: Move ACPI specific code into drivers/acpi/arm64/
  (jsc#PED-11164).
- ACPI: arm64: Sort entries alphabetically (jsc#PED-11164).
- arm64: cpuidle: fix #ifdef for acpi functions (jsc#PED-11164).
- commit 7fc5a0f
* Wed Nov 27 2024 trenn@suse.com
- platform/x86/intel-uncore-freq: Increase minor number support
  (jsc#PED-10242).
- commit 36cdbbc
* Wed Nov 27 2024 trenn@suse.com
- platform/x86: intel-uncore-freq: Add additional client
  processors (jsc#PED-10242).
- Refresh
  patches.suse/platform-x86-intel-uncore-freq-Switch-to-new-Intel-CPU-mod.patch.
- commit d06dd2c
* Wed Nov 27 2024 trenn@suse.com
- platform/x86/intel-uncore-freq: Process read/write blocked
  feature status (jsc#PED-10242).
- Refresh
  patches.suse/platform-x86-intel-uncore-freq-Don-t-present-root-do.patch.
- commit fb5c13b
* Wed Nov 27 2024 trenn@suse.com
- platform/x86/intel-uncore-freq: Ignore minor version change
  (jsc#PED-10242).
- commit 2dab2bc
* Wed Nov 27 2024 osalvador@suse.de
- mm/hugetlb: fix missing hugetlb_lock for resv uncharge
  (bsc#1224548 CVE-2024-36000).
- commit 92c1bc7
* Wed Nov 27 2024 osalvador@suse.de
- mm/huge_memory: don't unpoison huge_zero_folio (bsc#1227842
  CVE-2024-40914).
- commit 14bb799
* Wed Nov 27 2024 tbogendoerfer@suse.de
- net: xfrm: preserve kabi for xfrm_state (bsc#1233754).
- idpf: avoid vport access in idpf_get_link_ksettings
  (CVE-2024-50274 bsc#1233463).
- xfrm: Export symbol xfrm_dev_state_delete (bsc#1233754).
- xfrm: Fix unregister netdevice hang on hardware offload
  (bsc#1233754).
- commit 8c4cfeb
* Wed Nov 27 2024 pjakobsson@suse.de
- Update patches.suse/mei-me-add-lunar-lake-point-M-DID.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022 stable-fixes jsc#PED-11584).
- commit 97a4c53
* Wed Nov 27 2024 tiwai@suse.de
- hwmon: (tps23861) Fix reporting of negative temperatures
  (git-fixes).
- i3c: master: svc: Fix pm_runtime_set_suspended() with runtime
  pm enabled (git-fixes).
- i3c: master: Fix miss free init_dyn_addr at
  i3c_master_put_i3c_addrs() (git-fixes).
- PCI: Fix reset_method_store() memory leak (git-fixes).
- PCI: rockchip-ep: Fix address translation unit programming
  (git-fixes).
- PCI: keystone: Add link up check to ks_pcie_other_map_bus()
  (git-fixes).
- PCI: keystone: Set mode as Root Complex for "ti,keystone-pcie"
  compatible (git-fixes).
- PCI: endpoint: Clear secondary (not primary) EPC in
  pci_epc_remove_epf() (git-fixes).
- commit 29a3aa9
* Tue Nov 26 2024 tiwai@suse.de
- Move kabi netfilter fix into patches.kabi
- commit 6c82cf8
* Tue Nov 26 2024 farosas@suse.de
- virtio_net: Add hash_key_length check (CVE-2024-53082
  bsc#1233573).
- commit 1273e47
* Tue Nov 26 2024 tbogendoerfer@suse.de
- xfrm: Export symbol xfrm_dev_state_delete (bsc#1233754).
- commit 9f18fd1
* Tue Nov 26 2024 sjaeckel@suse.de
- net: relax socket state check at accept time (git-fixes).
- netfilter: nf_tables: missing iterator type in lookup walk
  (git-fixes).
- commit 180e959
* Tue Nov 26 2024 tbogendoerfer@suse.de
- net: hns3: fix a deadlock problem when config TC during
  resetting (CVE-2024-44995 bsc#1230231).
- commit e1fa968
* Tue Nov 26 2024 tbogendoerfer@suse.de
- xfrm: Fix unregister netdevice hang on hardware offload
  (bsc#1233754).
- commit 84bc961
* Tue Nov 26 2024 msuchanek@suse.de
- KVM: PPC: Book3S HV: Avoid returning to nested hypervisor on
  pending doorbells (bsc#1215199).
- KVM: PPC: Book3S HV: Stop using vc->dpdes for nested KVM guests
  (bsc#1215199).
- Revert "KVM: PPC: Book3S HV Nested: Stop forwarding all HFUs
  to L1" (bsc#1215199).
- commit d27c0c3
* Tue Nov 26 2024 msuchanek@suse.de
- KVM: PPC: Book3S HV: Add Power11 capability support for Nested
  PAPR guests (jsc#PED-7970 jsc#PED-11016).
- commit 0a4be1e
* Tue Nov 26 2024 tiwai@suse.de
- mailbox: arm_mhuv2: clean up loop in get_irq_chan_comb()
  (git-fixes).
- pinctrl: k210: Undef K210_PC_DEFAULT (git-fixes).
- pinctrl: qcom: spmi: fix debugfs drive strength (git-fixes).
- pinctrl: zynqmp: drop excess struct member description
  (git-fixes).
- lib: string_helpers: silence snprintf() output truncation
  warning (git-fixes).
- fbdev: sh7760fb: Fix a possible memory leak in
  sh7760fb_alloc_mem() (git-fixes).
- Input: hycon-hy46xx - add missing dependency on REGMAP_I2C
  (git-fixes).
- Input: hideep - add missing dependency on REGMAP_I2C
  (git-fixes).
- commit 17f846a
* Tue Nov 26 2024 msuchanek@suse.de
- KVM: PPC: Book3S HV: remove unused varible (bsc#1194869).
- commit 932ea3b
* Tue Nov 26 2024 sjaeckel@suse.de
- netrom: fix possible dead-lock in nr_rt_ioctl() (CVE-2024-38589
  bsc#1226748).
- commit 0e7a285
* Tue Nov 26 2024 msuchanek@suse.de
- KVM: PPC: Book3S HV: Fix kmv -> kvm typo (jsc#PED-11016
  git-fixes).
- commit b4d06eb
* Tue Nov 26 2024 msuchanek@suse.de
- tpm: Lock TPM chip in tpm_pm_suspend() first (bsc#1082555
  git-fixes).
- commit 4594f81
* Tue Nov 26 2024 sjaeckel@suse.de
- kABI fix for netfilter: nft_set_pipapo: walk over current view
  on netlink dump (CVE-2024-27017 bsc#1223733).
- commit 2be46c1
* Tue Nov 26 2024 nik.borisov@suse.com
- platform/x86/amd: amd_3d_vcache: Add sysfs ABI documentation (jsc#PED-11563).
- commit 7cdab68
* Tue Nov 26 2024 nik.borisov@suse.com
- platform/x86/amd: amd_3d_vcache: Add AMD 3D V-Cache optimizer driver (jsc#PED-11563).
- Update config files.
- commit d55d563
* Tue Nov 26 2024 vbabka@suse.cz
- Update references for
  patches.suse/mm-resolve-faulty-mmap_region-error-path-behaviour.patch
  (git-fixes CVE-2024-53096 bsc#1233756).
- commit 6c0d091
* Tue Nov 26 2024 tiwai@suse.de
- ALSA: hda/realtek: Enable speaker pins for Medion E15443
  platform (bsc#1233298).
- ALSA: hda/realtek: Fix Internal Speaker and Mic boost of
  Infinix Y4 Max (bsc#1233298).
- commit dd8caae
* Tue Nov 26 2024 tiwai@suse.de
- Move upstreamed patches into sorted section
- commit b72de8f
* Tue Nov 26 2024 vbabka@suse.cz
- kabi, mm: refactor arch_calc_vm_flag_bits() and arm64 MTE
  handling (git-fixes kabi).
- mm: refactor arch_calc_vm_flag_bits() and arm64 MTE handling
  (git-fixes).
- commit f31b0e3
* Mon Nov 25 2024 vbabka@suse.cz
- mm: resolve faulty mmap_region() error path behaviour
  (git-fixes).
- commit 84c4dfc
* Mon Nov 25 2024 vbabka@suse.cz
- mm: refactor map_deny_write_exec() (git-fixes).
- commit 8c66a90
* Mon Nov 25 2024 vbabka@suse.cz
- mm: unconditionally close VMAs on error (git-fixes).
- commit f81f7df
* Mon Nov 25 2024 vbabka@suse.cz
- mm: move dummy_vm_ops out of a header (git-fixes prerequisity).
- commit e1045c0
* Mon Nov 25 2024 vbabka@suse.cz
- mm: avoid unsafe VMA hook invocation when error arises on mmap
  hook (git-fixes).
- commit 2b96063
* Mon Nov 25 2024 tbogendoerfer@suse.de
- fsl/fman: Fix refcount handling of fman-related devices
  (CVE-2024-50166 bsc#1233050).
- fsl/fman: Save device references taken in mac_probe()
  (CVE-2024-50166 bsc#1233050).
- commit cff0dea
* Mon Nov 25 2024 sjaeckel@suse.de
- tcp: Fix refcnt handling in __inet_hash_connect() (git-fixes).
- commit 2b4c1a0
* Mon Nov 25 2024 mhocko@suse.com
- blacklist.conf: blacklist CVEs that are not relevant for this branch
- commit ad42b8c
* Mon Nov 25 2024 sjaeckel@suse.de
- tipc: fix UAF in error path (CVE-2024-36886 bsc#1225730).
- commit be7d8d3
* Mon Nov 25 2024 sjaeckel@suse.de
- ipv4: Fix uninit-value access in __ip_make_skb() (CVE-2024-36927
  bsc#1225813).
- commit 5457624
* Mon Nov 25 2024 mfranc@suse.cz
- vsock/virtio: Initialization of the dangling pointer occurring
  in vsk->trans (CVE-2024-50264 bsc#1233453).
- arm64/sve: Discard stale CPU state when handling SVE traps
  (CVE-2024-50275 bsc#1233464).
- commit 2855c61
* Mon Nov 25 2024 sjaeckel@suse.de
- tcp: defer shutdown(SEND_SHUTDOWN) for TCP_SYN_RECV sockets
  (CVE-2024-36905 bsc#1225742).
- commit 84c8bd7
* Mon Nov 25 2024 andrea.porta@suse.com
- coresight: etm4x: Match all ETM4 instances based on DEVARCH
  and DEVTYPE (jsc#PED-11536).
- commit e0bb831
* Mon Nov 25 2024 nik.borisov@suse.com
- kasan: move checks to do_strncpy_from_user (git-fixes).
- commit ca3142b
* Mon Nov 25 2024 sjaeckel@suse.de
- tipc: fix a possible memleak in tipc_buf_append (CVE-2024-36954
  bsc#1225764).
- commit b7093a9
* Mon Nov 25 2024 sjaeckel@suse.de
- erspan: make sure erspan_base_hdr is present in skb->head
  (CVE-2024-35888 bsc#1224518).
- commit aaa779d
* Mon Nov 25 2024 sjaeckel@suse.de
- net: esp: fix bad handling of pages from page_pool
  (CVE-2024-26953 bsc#1223656).
- commit b0a65f5
* Mon Nov 25 2024 sjaeckel@suse.de
- netfilter: nft_set_pipapo: walk over current view on netlink
  dump (CVE-2024-27017 bsc#1223733).
- commit d1885c4
* Mon Nov 25 2024 sjaeckel@suse.de
- dccp/tcp: Unhash sk from ehash for tb2 alloc failure after
  check_estalblished() (CVE-2024-26741 bsc#1222587).
- commit 9a5ac8a
* Mon Nov 25 2024 nmorey@suse.com
- bnxt_en: Add support for RoCE sriov configuration (jsc#PED-11232)
- commit 956d94b
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/nldev: Add IB device and net device rename events (jsc#PED-11236)
- commit 555b63e
* Mon Nov 25 2024 nmorey@suse.com
- IB/cm: Rework sending DREQ when destroying a cm_id (jsc#PED-11236)
- commit 976649d
* Mon Nov 25 2024 nmorey@suse.com
- IB/cm: Do not hold reference on cm_id unless needed (jsc#PED-11236)
- commit 3c7497b
* Mon Nov 25 2024 nmorey@suse.com
- IB/cm: Explicitly mark if a response MAD is a retransmission (jsc#PED-11236)
- commit 55ab73c
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/core: Move ib_uverbs_file struct to uverbs_types.h (jsc#PED-11236)
- commit 1cfd3d7
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/core: Add device ufile cleanup operation (jsc#PED-11236)
- commit ece0815
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/core: Implement RoCE GID port rescan and export delete function (jsc#PED-11236)
- commit 1a0d2d8
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/efa: Report link speed according to device attributes (jsc#PED-11236)
- commit a59cf4c
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/hns: Modify debugfs name (jsc#PED-11473)
- commit 8e87c09
* Mon Nov 25 2024 nmorey@suse.com
- RDMA: Use ethtool string helpers (jsc#PED-11236)
- commit da457e4
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/ipoib: Use the networking stack default for txqueuelen (jsc#PED-11236)
- commit 22e2e2c
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/bnxt_re: Correct the sequence of device suspend (jsc#PED-11232)
- commit 529c1ca
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/bnxt_re: Use the default mode of congestion control (jsc#PED-11232)
- commit b3bdfd2
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/bnxt_re: Support different traffic class (jsc#PED-11232)
- commit bd85116
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/bnxt_re: Cache MSIx info to a local structure (jsc#PED-11232)
- commit fb403de
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/bnxt_re: Refurbish CQ to NQ hash calculation (jsc#PED-11232)
- commit 772047b
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/bnxt_re: Refactor NQ allocation (jsc#PED-11232)
- commit e6aaaba
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/bnxt_re: Fail probe early when not enough MSI-x vectors are reserved (jsc#PED-11232)
- commit 48fa9b6
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/bnxt_re: Add set_func_resources support for P5/P7 adapters (jsc#PED-11232)
- commit 774d76f
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/bnxt_re: Enhance RoCE SRIOV resource configuration design (jsc#PED-11232)
- commit 7a41bcc
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/bnxt_re: Add debugfs hook in the driver (jsc#PED-11232)
- commit 74ebf88
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/bnxt_re: Support raw data query for each resources (jsc#PED-11232)
- commit 2c01ba1
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/bnxt_re: Add support for querying HW contexts (jsc#PED-11232)
- commit 4a6e8e9
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/bnxt_re: Support driver specific data collection using rdma tool (jsc#PED-11232)
- commit e2da798
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix access flags for MR and QP modify (jsc#PED-11232)
- commit 58a91c4
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/bnxt_re: Add support for modify_device hook (jsc#PED-11232)
- commit 1720799
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/bnxt_re: Add support for CQ rx coalescing (jsc#PED-11232)
- commit c7b007e
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/bnxt_re: Add support for optimized modify QP (jsc#PED-11232)
- commit 8481ee7
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/efa: Add option to set QP service level on create (jsc#PED-11232)
- commit f58b54e
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/efa: Update device interface (jsc#PED-11232)
- commit 46124c0
* Mon Nov 25 2024 nmorey@suse.com
- IB/hfi1: make clear_all_interrupts static (jsc#PED-9948)
- commit f285bd9
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/hns: Disassociate mmap pages for all uctx when HW is being reset (jsc#PED-11473)
- commit d4e1693
* Mon Nov 25 2024 nmorey@suse.com
- RDMA/core: Provide rdma_user_mmap_disassociate() to disassociate mmap pages (jsc#PED-11473)
- commit 993eab9
* Sun Nov 24 2024 lduncan@suse.com
- minmax: scsi: fix mis-use of 'clamp()' in sr.c (git-fixes).
- commit 46d200b
* Sun Nov 24 2024 nmorey@suse.com
- Fix warning in patches.suse/RDMA-mlx5-Move-events-notifier-registration-to-be-af.patch
  Fixes: ff613dcf3cc9c8aa5b4cc959d0bdfac2dec81854
- commit 56a258b
* Sun Nov 24 2024 tiwai@suse.de
- Move upstreamed crypto patches into sorted section
- commit 7706550
* Sun Nov 24 2024 tiwai@suse.de
- maple_tree: refine mas_store_root() on storing NULL (git-fixes).
- maple_tree: fix alloc node fail issue (git-fixes).
- unicode: Fix utf8_load() error path (git-fixes).
- commit 7f4b1c4
* Sat Nov 23 2024 nmorey@suse.com
- RDMA/mlx5: Move events notifier registration to be after device registration (git-fixes)
- commit ff613dc
* Sat Nov 23 2024 nmorey@suse.com
- RDMA/hns: Fix different dgids mapping to the same dip_idx (git-fixes)
- commit 482b364
* Sat Nov 23 2024 nmorey@suse.com
- RDMA/hns: Use macro instead of magic number (git-fixes)
- commit d6d944a
* Sat Nov 23 2024 nmorey@suse.com
- RDMA/hns: Add mutex_destroy() (git-fixes)
- commit 096658f
* Sat Nov 23 2024 nmorey@suse.com
- RDMA/hns: Fix NULL pointer derefernce in hns_roce_map_mr_sg() (git-fixes)
- commit abdac11
* Sat Nov 23 2024 nmorey@suse.com
- RDMA/hns: Fix out-of-order issue of requester when setting FENCE (git-fixes)
- commit a53ecd7
* Sat Nov 23 2024 nmorey@suse.com
- RDMA/rxe: Set queue pair cur_qp_state when being queried (git-fixes)
- commit 74c369b
* Sat Nov 23 2024 nmorey@suse.com
- RDMA/bnxt_re: Check cqe flags to know imm_data vs inv_irkey (git-fixes)
- commit 7a90d31
* Sat Nov 23 2024 nmorey@suse.com
- RDMA/rxe: Fix the qp flush warnings in req (git-fixes)
- commit 678f36e
* Sat Nov 23 2024 nmorey@suse.com
- RDMA/hns: Fix cpu stuck caused by printings during reset (git-fixes)
- commit 0c19d33
* Sat Nov 23 2024 nmorey@suse.com
- RDMA/hns: Use dev_* printings in hem code instead of ibdev_* (git-fixes)
- commit 21d3575
* Sat Nov 23 2024 nmorey@suse.com
- RDMA/hns: Fix flush cqe error when racing with destroy qp (git-fixes)
- commit 4c3bddb
* Sat Nov 23 2024 nmorey@suse.com
- RDMA/hns: Fix an AEQE overflow error caused by untimely update of eq_db_ci (git-fixes)
- commit c0d9dba
* Sat Nov 23 2024 tiwai@suse.de
- cpufreq: CPPC: Fix wrong return value in cppc_get_cpu_power()
  (git-fixes).
- cpufreq: CPPC: Fix wrong return value in cppc_get_cpu_cost()
  (git-fixes).
- commit b53ff09
* Sat Nov 23 2024 tiwai@suse.de
- cpufreq: mediatek-hw: Fix wrong return value in
  mtk_cpufreq_get_cpu_power() (git-fixes).
- cpufreq: CPPC: Fix possible null-ptr-deref for
  cppc_get_cpu_cost() (git-fixes).
- cpufreq: CPPC: Fix possible null-ptr-deref for
  cpufreq_cpu_get_raw() (git-fixes).
- Revert "cpufreq: brcmstb-avs-cpufreq: Fix initial command check"
  (stable-fixes).
- cpufreq: loongson2: Unregister platform_driver on failure
  (git-fixes).
- mtd: rawnand: atmel: Fix possible memory leak (git-fixes).
- mtd: spi-nor: core: replace dummy buswidth from addr to data
  (git-fixes).
- clk: qcom: clk-alpha-pll: fix lucid 5lpe pll enabled check
  (git-fixes).
- clk: qcom: clk-alpha-pll: drop lucid-evo pll enabled warning
  (git-fixes).
- clk: qcom: gcc-qcs404: fix initial rate of GPLL3 (git-fixes).
- clk: clk-axi-clkgen: make sure to enable the AXI bus clock
  (git-fixes).
- clk: sunxi-ng: d1: Fix PLL_AUDIO0 preset (git-fixes).
- clk: imx: clk-scu: fix clk enable state save and restore
  (git-fixes).
- clk: imx: fracn-gppll: fix pll power up (git-fixes).
- clk: imx: fracn-gppll: correct PLL initialization flow
  (git-fixes).
- clk: imx: lpcg-scu: SW workaround for errata (e10858)
  (git-fixes).
- clk: renesas: rzg2l: Fix FOUTPOSTDIV clk (git-fixes).
- clk: clk-apple-nco: Add NULL check in applnco_probe (git-fixes).
- leds: lp55xx: Remove redundant test for invalid channel number
  (git-fixes).
- mfd: rt5033: Fix missing regmap_del_irq_chip() (git-fixes).
- mfd: tps65010: Use IRQF_NO_AUTOEN flag in request_irq() to
  fix race (git-fixes).
- drm/amd: Fix initialization mistake for NBIO 7.7.0
  (stable-fixes).
- drm/amd/display: Adjust VSDB parser for replay feature
  (stable-fixes).
- media: dvbdev: fix the logic when DVB_DYNAMIC_MINORS is not set
  (stable-fixes).
- commit 15015b2
* Sat Nov 23 2024 lduncan@suse.com
- scsi: cdrom: kABI: fix cdrom_dev_ops change (git-fixes).
- commit ab3e426
* Fri Nov 22 2024 tonyj@suse.de
- perf/x86/amd/core: Define a proper ref-cycles event for Zen
  4 and later (jsc#PED-11561).
- commit 54196e8
* Fri Nov 22 2024 davide.benini@suse.com
- netfilter: Fix use-after-free in get_info() (CVE-2024-50257
  bsc#1233244).
- commit 1f00653
* Fri Nov 22 2024 tiwai@suse.de
- ASoC: da7213: Populate max_register to regmap_config
  (git-fixes).
- ASoC: fsl-asoc-card: Add missing handling of {hp,mic}-dt-gpios
  (git-fixes).
- Bluetooth: btbcm: fix missing of_node_put() in
  btbcm_get_board_name() (git-fixes).
- Bluetooth: btmtk: adjust the position to init iso data anchor
  (git-fixes).
- wifi: cfg80211: Remove the Medium Synchronization Delay validity
  check (git-fixes).
- commit 7398528
* Fri Nov 22 2024 tiwai@suse.de
- ALSA: usb-audio: Make mic volume workarounds globally applicable
  (stable-fixes).
- Refresh
  patches.suse/ALSA-usb-audio-Add-quirk-for-HP-320-FHD-Webcam.patch.
- commit 777a5df
* Fri Nov 22 2024 tiwai@suse.de
- drm/vc4: Match drm_dev_enter and exit calls in vc4_hvs_lut_load
  (git-fixes).
- ALSA: hda: Poll jack events for LS7A HD-Audio (stable-fixes).
- ALSA: usb-audio: Add Pioneer DJ/AlphaTheta DJM-A9 Mixer
  (stable-fixes).
- ALSA: usb-audio: Use snprintf instead of sprintf in
  build_mixer_unit_ctl (stable-fixes).
- ALSA: ice1712: Remove redundant code in stac9460_dac_vol_put
  (stable-fixes).
- commit e772374
* Fri Nov 22 2024 tiwai@suse.de
- drm/amdkfd: Fix wrong usage of INIT_WORK() (git-fixes).
- drm/panfrost: Add missing OPP table refcnt decremental
  (git-fixes).
- drm: use ATOMIC64_INIT() for atomic64_t (git-fixes).
- drm/vkms: Drop unnecessary call to drm_crtc_cleanup()
  (git-fixes).
- drm/etnaviv: hold GPU lock across perfmon sampling (git-fixes).
- drm/etnaviv: Request pages from DMA32 zone on addressing_limited
  (git-fixes).
- drm/amd/display: Fix brightness level not retained over reboot
  (git-fixes).
- drm/msm/dpu: cast crtc_clk calculation to u64 in
  _dpu_core_perf_calc_clk() (git-fixes).
- drm/mediatek: Fix child node refcount handling in early exit
  (git-fixes).
- drm/msm/gpu: Check the status of registration to PM QoS
  (git-fixes).
- drm/msm/adreno: Use IRQF_NO_AUTOEN flag in request_irq()
  (git-fixes).
- drm/msm: Fix some typos in comment (git-fixes).
- drm/msm/dpu: drop LM_3 / LM_4 on MSM8998 (git-fixes).
- drm/msm/dpu: drop LM_3 / LM_4 on SDM845 (git-fixes).
- drm/msm/dpu: on SDM845 move DSPP_3 to LM_5 block (git-fixes).
- drm: xlnx: zynqmp_dpsub: fix hotplug detection (git-fixes).
- drm: zynqmp_kms: Unplug DRM device before removal (git-fixes).
- drm/nouveau/gr/gf100: Fix missing unlock in gf100_gr_chan_new()
  (git-fixes).
- drm/panfrost: Remove unused id_mask from struct panfrost_model
  (git-fixes).
- drm/amdgpu: Fix JPEG v4.0.3 register write (git-fixes).
- drm/bridge: tc358767: Fix link properties discovery (git-fixes).
- drm/vc4: Match drm_dev_enter and exit calls in
  vc4_hvs_atomic_flush (git-fixes).
- drm/bridge: it6505: Drop EDID cache on bridge power off
  (git-fixes).
- drm/bridge: anx7625: Drop EDID cache on bridge power off
  (git-fixes).
- drm/v3d: Address race-condition in MMU flush (git-fixes).
- drm/sti: avoid potential dereference of error pointers
  (git-fixes).
- drm/sti: avoid potential dereference of error pointers in
  sti_gdp_atomic_check (git-fixes).
- drm/sti: avoid potential dereference of error pointers in
  sti_hqvdp_atomic_check (git-fixes).
- drm/imx/ipuv3: Use IRQF_NO_AUTOEN flag in request_irq()
  (git-fixes).
- drm/imx/dcss: Use IRQF_NO_AUTOEN flag in request_irq()
  (git-fixes).
- drm/omap: Fix locking in omap_gem_new_dmabuf() (git-fixes).
- drm/omap: Fix possible NULL dereference (git-fixes).
- drm/vc4: hvs: Correct logic on stopping an HVS channel
  (git-fixes).
- drm/vc4: hvs: Remove incorrect limit from hvs_dlist debugfs
  function (git-fixes).
- drm/vc4: hvs: Fix dlist debug not resetting the next entry
  pointer (git-fixes).
- drm/vc4: hdmi: Avoid hang with debug registers when suspended
  (git-fixes).
- drm/vc4: hvs: Don't write gamma luts on 2711 (git-fixes).
- drm/mm: Mark drm_mm_interval_tree*() functions with
  __maybe_unused (git-fixes).
- ASoC: codecs: Fix atomicity violation in
  snd_soc_component_get_drvdata() (git-fixes).
- ASoC: rt722-sdca: Remove logically deadcode in rt722-sdca.c
  (git-fixes).
- ASoC: fsl_micfil: fix regmap_write_bits usage (git-fixes).
- ALSA: 6fire: Release resources at card release (git-fixes).
- ALSA: caiaq: Use snd_card_free_when_closed() at disconnection
  (git-fixes).
- ALSA: us122l: Use snd_card_free_when_closed() at disconnection
  (git-fixes).
- ALSA: usx2y: Use snd_card_free_when_closed() at disconnection
  (git-fixes).
- Bluetooth: fix use-after-free in device_for_each_child()
  (git-fixes).
- wifi: brcmfmac: release 'root' node in all execution paths
  (git-fixes).
- wifi: cw1200: Fix potential NULL dereference (git-fixes).
- wifi: wfx: Fix error handling in wfx_core_init() (git-fixes).
- wifi: ath12k: fix warning when unbinding (git-fixes).
- wifi: ath12k: fix crash when unbinding (git-fixes).
- wifi: ath12k: remove msdu_end structure for WCN7850 (git-fixes).
- wifi: ath11k: Fix CE offset address calculation for WCN6750
  in SSR (git-fixes).
- wifi: ath12k: Skip Rx TID cleanup for self peer (git-fixes).
- wifi: ath10k: fix invalid VHT parameters in
  supported_vht_mcs_rate_nss2 (git-fixes).
- wifi: ath10k: fix invalid VHT parameters in
  supported_vht_mcs_rate_nss1 (git-fixes).
- wifi: ath9k: add range check for conn_rsp_epid in
  htc_connect_service() (git-fixes).
- wifi: mwifiex: Fix memcpy() field-spanning write warning in
  mwifiex_config_scan() (git-fixes).
- wifi: mwifiex: Use IRQF_NO_AUTOEN flag in request_irq()
  (git-fixes).
- wifi: p54: Use IRQF_NO_AUTOEN flag in request_irq() (git-fixes).
- commit c54011d
* Fri Nov 22 2024 lduncan@suse.com
- blacklist.conf: add git-fix that cannot apply
- commit c0e5d27
* Fri Nov 22 2024 lduncan@suse.com
- scsi: kABI: restore no_start_on_resume to scsi_device
  (git-fixes).
- scsi: sd_zbc: Use kvzalloc() to allocate REPORT ZONES buffer
  (git-fixes).
- scsi: mpi3mr: Validate SAS port assignments (git-fixes).
- scsi: scsi_transport_fc: Allow setting rport state to current
  state (git-fixes).
- scsi: wd33c93: Don't use stale scsi_pointer value (git-fixes).
- scsi: pm8001: Do not overwrite PCI queue mapping (git-fixes).
- scsi: smartpqi: correct stream detection (git-fixes).
- scsi: NCR5380: Initialize buffer for MSG IN and STATUS transfers
  (git-fixes).
- scsi: NCR5380: Check for phase match during PDMA fixup
  (git-fixes).
- scsi: mac_scsi: Disallow bus errors during PDMA send
  (git-fixes).
- scsi: mac_scsi: Refactor polling loop (git-fixes).
- scsi: mac_scsi: Revise printk(KERN_DEBUG ...) messages
  (git-fixes).
- scsi: smartpqi: revert
  propagate-the-multipath-failure-to-SML-quickly (git-fixes).
- scsi: aacraid: Rearrange order of struct aac_srb_unit
  (git-fixes).
- scsi: sd: Ignore command SYNCHRONIZE CACHE error if format in
  progress (git-fixes).
- scsi: core: Fix the return value of scsi_logical_block_count()
  (git-fixes).
- scsi: mpt3sas: Avoid IOMMU page faults on REPORT ZONES
  (git-fixes).
- scsi: mpi3mr: Avoid IOMMU page faults on REPORT ZONES
  (git-fixes).
- scsi: pm80xx: Set phy->enable_completion only when we wait
  for it (git-fixes).
- scsi: libsas: Fix exp-attached device scan after probe failure
  scanned in again after probe failed (git-fixes).
- scsi: mpi3mr: Fix ATA NCQ priority support (git-fixes).
- scsi: core: Disable CDL by default (git-fixes).
- scsi: core: Handle devices which return an unusually large
  VPD page count (git-fixes).
- scsi: qedf: Set qed_slowpath_params to zero before use
  (git-fixes).
- scsi: sr: Fix unintentional arithmetic wraparound (git-fixes).
- scsi: core: alua: I/O errors for ALUA state transitions
  (git-fixes).
- scsi: hpsa: Fix allocation size for Scsi_Host private data
  (git-fixes).
- scsi: libsas: Fix the failure of adding phy with zero-address
  to port (git-fixes).
- scsi: mpi3mr: Avoid possible run-time warning with long
  manufacturer strings (git-fixes).
- scsi: core: Fix handling of SCMD_FAIL_IF_RECOVERING (git-fixes).
- scsi: hisi_sas: Handle the NCQ error returned by D2H frame
  (git-fixes).
- scsi: mpi3mr: Avoid memcpy field-spanning write WARNING
  (git-fixes).
- scsi: spi: Fix sshdr use (git-fixes).
- scsi: Remove scsi device no_start_on_resume flag (git-fixes).
- commit d5d37f8
* Thu Nov 21 2024 tiwai@suse.de
- Update config and supported.conf for intel_tpmi_power_domains (jsc#PED-10664)
- commit fef5f35
* Thu Nov 21 2024 tiwai@suse.de
- Correct reference for thermal fixes (jsc#PED-11567)
- commit 270371a
* Thu Nov 21 2024 tiwai@suse.de
- Update MFD patch reference (jsc#PED-10104 jsc#PED-10230 jsc#PED-10653 jsc#PED-10174)
- commit 5fff944
* Thu Nov 21 2024 tiwai@suse.de
- doc: TPMI: Add entry for Performance Limit Reasons
  (jsc#PED-10664).
- platform/x86/intel: TPMI domain id and CPU mapping
  (jsc#PED-10664).
- platform/x86/intel/tpmi: Add API to get debugfs root
  (jsc#PED-10664).
- platform/x86/intel/tpmi: Add support for performance limit
  reasons (jsc#PED-10664).
- platform/x86/intel/tpmi: Add additional TPMI header fields
  (jsc#PED-10664).
- platform/x86/intel/tpmi: Align comments in kernel-doc
  (jsc#PED-10664).
- platform/x86/intel/tpmi: Check major version change for TPMI
  Information (jsc#PED-10664).
- platform/x86/intel/tpmi: Move TPMI ID definition
  (jsc#PED-10664).
- platform/x86/intel/tpmi: Modify external interface to get
  read/write state (jsc#PED-10664).
- platform/x86/intel/tpmi: Don't create devices for disabled
  features (jsc#PED-10664).
- platform/x86/intel/tpmi: Add defines to get version information
  (jsc#PED-10664).
- doc: TPMI: Add debugfs documentation (jsc#PED-10664).
- commit 0665018
* Thu Nov 21 2024 tiwai@suse.de
- Update patch reference for MFD patch (jsc#PED-10104 jsc#PED-10230 jsc#PED-10653)
- commit e4a5c0d
* Thu Nov 21 2024 tiwai@suse.de
- thermal: intel: intel_tcc_cooling: Use a model-specific bitmask
  for TCC offset (jsc#PED-11469).
- thermal: intel: intel_tcc: Add model checks for temperature
  registers (jsc#PED-11469).
- hwmon: (coretemp) Extend the bitmask to read temperature to 0xff
  (jsc#PED-11469).
- commit 9b44fe9
* Thu Nov 21 2024 tiwai@suse.de
- media: v4l2-core: v4l2-dv-timings: check cvt/gtf result
  (git-fixes).
- commit a1a4c5f
* Thu Nov 21 2024 tiwai@suse.de
- soc: fsl: rcpm: fix missing of_node_put() in
  copy_ippdexpcr1_setting() (git-fixes).
- firmware: arm_scpi: Check the DVFS OPP count returned by the
  firmware (git-fixes).
- soc: ti: smartreflex: Use IRQF_NO_AUTOEN flag in request_irq()
  (git-fixes).
- soc: qcom: geni-se: fix array underflow in geni_se_clk_tbl_get()
  (git-fixes).
- drivers: soc: xilinx: add the missing kfree in
  xlnx_add_cb_for_suspend() (git-fixes).
- efi/libstub: Free correct pointer on failure (git-fixes).
- tpm: fix signed/unsigned bug when checking event logs
  (git-fixes).
- efi/libstub: fix efi_parse_options() ignoring the default
  command line (git-fixes).
- platform/x86: panasonic-laptop: Return errno correctly in show
  callback (git-fixes).
- media: uvcvideo: Skip parsing frames of type UVC_VS_UNDEFINED
  in uvc_parse_format (git-fixes).
- media: platform: exynos4-is: Fix an OF node reference leak in
  fimc_md_is_isp_available (git-fixes).
- media: atomisp: Add check for rgby_data memory allocation
  failure (git-fixes).
- media: gspca: ov534-ov772x: Fix off-by-one error in
  set_frame_rate() (git-fixes).
- media: venus: Fix pm_runtime_set_suspended() with runtime pm
  enabled (git-fixes).
- media: amphion: Fix pm_runtime_set_suspended() with runtime
  pm enabled (git-fixes).
- media: i2c: dw9768: Fix pm_runtime_set_suspended() with runtime
  pm enabled (git-fixes).
- media: mantis: remove orphan mantis_core.h (git-fixes).
- media: vb2: Fix comment (git-fixes).
- media: uvcvideo: Stop stream during unregister (git-fixes).
- media: ts2020: fix null-ptr-deref in ts2020_probe() (git-fixes).
- media: platform: allegro-dvt: Fix possible memory leak in
  allocate_buffers_internal() (git-fixes).
- media: i2c: tc358743: Fix crash in the probe error path when
  using polling (git-fixes).
- media: wl128x: Fix atomicity violation in fmc_send_cmd()
  (git-fixes).
- media: imx-jpeg: Ensure power suppliers be suspended before
  detach them (git-fixes).
- media: amphion: Set video drvdata before register video device
  (git-fixes).
- media: imx-jpeg: Set video drvdata before register video device
  (git-fixes).
- media: mtk-jpeg: Fix null-ptr-deref during unload module
  (git-fixes).
- media: uvcvideo: Require entities to have a non-zero unique ID
  (git-fixes).
- HID: wacom: Interpret tilt data from Intuos Pro BT as signed
  values (git-fixes).
- mmc: mmc_spi: drop buggy snprintf() (git-fixes).
- =?UTF-8?q?spi:=20zynqmp-gqspi:=20Undo=20runtime=20PM=20ch?=
  =?UTF-8?q?anges=20at=20driver=20exit=20time=E2=80=8B?=
  (git-fixes).
- spi: tegra210-quad: Avoid shift-out-of-bounds (git-fixes).
- regmap: irq: Set lockdep class for hierarchical IRQ domains
  (git-fixes).
- Documentation: kgdb: Correct parameter error (git-fixes).
- efi/libstub: zboot.lds: Discard .discard sections
  (stable-fixes).
- commit fbb8e93
* Wed Nov 20 2024 mwilck@suse.com
- scsi: hpsa: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY
  (jsc#PED-11375).
- scsi: hpsa: Fix allocation size for Scsi_Host private data
  (jsc#PED-11375).
- commit f5d5fc4
* Wed Nov 20 2024 mwilck@suse.com
- scsi: smartpqi: update driver version to 2.1.30-031
  (jsc#PED-11377).
- scsi: smartpqi: fix volume size updates (jsc#PED-11377).
- scsi: smartpqi: fix rare system hang during LUN reset
  (jsc#PED-11377).
- scsi: smartpqi: add new controller PCI IDs (jsc#PED-11377).
- scsi: smartpqi: add counter for parity write stream requests
  (jsc#PED-11377).
- scsi: smartpqi: correct stream detection (jsc#PED-11377).
- scsi: smartpqi: Add fw log to kdump (jsc#PED-11377).
- scsi: smartpqi: Update driver version to 2.1.28-025
  (jsc#PED-11377).
- scsi: smartpqi: Improve handling of multipath failover
  (jsc#PED-11377).
- scsi: smartpqi: revert
  propagate-the-multipath-failure-to-SML-quickly (jsc#PED-11377).
- scsi: smartpqi: Improve accuracy/performance of
  raid-bypass-counter (jsc#PED-11377).
- scsi: smartpqi: Add new controller PCI IDs (jsc#PED-11377).
- commit fc4e5c3
* Wed Nov 20 2024 mwilck@suse.com
- scsi: smartpqi: Replace deprecated strncpy() with strscpy()
  (jsc#PED-11377).
- commit 3c2189d
* Wed Nov 20 2024 mwilck@suse.com
- scsi: megaraid_sas: Remove trailing space after \n newline
  (jsc#PED-11258).
- scsi: megaraid_sas: struct MR_HOST_DEVICE_LIST: Replace
  1-element array with flexible array (jsc#PED-11258).
- scsi: megaraid_sas: struct MR_LD_VF_MAP: Replace 1-element
  arrays with flexible arrays (jsc#PED-11258).
- megaraid_sas: don't set QUEUE_FLAG_NOMERGES (jsc#PED-11258).
- scsi: megaraid_sas: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY
  (jsc#PED-11258).
- scsi: megaraid_sas: Switch to using ->device_configure
  (jsc#PED-11258).
- scsi: megaraid: Indent Kconfig option help text (jsc#PED-11258).
- commit 4c10ba2
* Wed Nov 20 2024 mwilck@suse.com
- scsi: mpt3sas: Remove trailing space after \n newline
  (jsc#PED-11253).
- scsi: mpt3sas: Simplify an alloc_ordered_workqueue() invocation
  (jsc#PED-11253).
- scsi: mpt3sas: Avoid IOMMU page faults on REPORT ZONES
  (jsc#PED-11253).
- commit d7765dd
* Wed Nov 20 2024 mwilck@suse.com
- scsi: mpt3sas: Switch to using ->device_configure
  (jsc#PED-11253).
- commit 1ad32d3
* Wed Nov 20 2024 mwilck@suse.com
- mpt3sas_scsih: don't set QUEUE_FLAG_NOMERGES (jsc#PED-11253).
- scsi: mpi3mr: Fix ATA NCQ priority support (jsc#PED-11253).
- scsi: mpt3sas: Add missing kerneldoc parameter descriptions
  (jsc#PED-11253).
- scsi: mpt3sas: Avoid possible run-time warning with long
  manufacturer strings (jsc#PED-11253).
- scsi: mpt3sas: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY
  (jsc#PED-11253).
- scsi: mpt3sas: Replace deprecated strncpy() with strscpy()
  (jsc#PED-11253).
- scsi: mpt3sas: Update driver version to 48.100.00.00
  (jsc#PED-11253).
- commit c38656d
* Wed Nov 20 2024 tiwai@suse.de
- blacklist.conf: drop entries that have been already backported for SP7
- commit 6e28180
* Wed Nov 20 2024 tiwai@suse.de
- cleanup: Remove address space of returned pointer (git-fixes).
- crypto: qat - Fix missing destroy_workqueue in adf_init_aer()
  (git-fixes).
- crypto: hisilicon/qm - disable same error report before
  resetting (git-fixes).
- crypto: qat/qat_420xx - fix off by one in uof_get_name()
  (git-fixes).
- commit fe4b9ac
* Wed Nov 20 2024 tiwai@suse.de
- doc: rcu: update printed dynticks counter bits (git-fixes).
- hwmon: (nct6775-core) Fix overflows seen when writing limit
  attributes (git-fixes).
- ACPI: CPPC: Fix _CPC register setting issue (git-fixes).
- thermal: core: Initialize thermal zones before registering them
  (git-fixes).
- amd-pstate: Set min_perf to nominal_perf for active mode
  performance gov (git-fixes).
- crypto: cavium - Fix an error handling path in
  cpt_ucode_load_fw() (git-fixes).
- crypto: bcm - add error check in the ahash_hmac_init function
  (git-fixes).
- crypto: caam - add error check to caam_rsa_set_priv_key_form
  (git-fixes).
- crypto: inside-secure - Fix the return value of
  safexcel_xcbcmac_cra_init() (git-fixes).
- crypto: cavium - Fix the if condition to exit loop after timeout
  (git-fixes).
- crypto: x86/aegis128 - access 32-bit arguments as 32-bit
  (git-fixes).
- crypto: pcrypt - Call crypto layer directly when
  padata_do_parallel() return -EBUSY (git-fixes).
- crypto: qat - remove faulty arbiter config reset (git-fixes).
- crypto: qat/qat_4xxx - fix off by one in uof_get_name()
  (git-fixes).
- crypto: qat - remove check after debugfs_create_dir()
  (git-fixes).
- crypto: caam - Fix the pointer passed to caam_qi_shutdown()
  (git-fixes).
- firmware: google: Unregister driver_info on failure (git-fixes).
- platform/chrome: cros_ec_typec: fix missing fwnode reference
  decrement (git-fixes).
- acpi/arm64: Adjust error handling procedure in
  gtdt_parse_timer_block() (git-fixes).
- commit af7e948
* Tue Nov 19 2024 fdmanana@suse.com
- btrfs: reinitialize delayed ref list after deleting it from
  the list (bsc#1233462 CVE-2024-50273).
- commit 174bbc2
* Tue Nov 19 2024 neelx@suse.com
- btrfs: don't commit transaction for every subvol create (bsc#1233319)
  Refresh patches.suse/btrfs-qgroup-fix-qgroup-prealloc-rsv-leak-in-subvolu.patch
  - keep the patch matching upstream
- commit 2457e23
* Mon Nov 18 2024 tiwai@suse.de
- ASoC: qcom: Select missing common Soundwire module code on
  SDM845 (git-fixes).
- commit 5cf5bc0
* Mon Nov 18 2024 tiwai@suse.de
- ASoC: qcom: sc7280: Fix missing Soundwire runtime stream alloc
  (git-fixes).
- ASoC: qcom: sdm845: add missing soundwire runtime stream alloc
  (git-fixes).
- commit fd8e059
* Mon Nov 18 2024 msuchanek@suse.de
- kernel-binary: Enable livepatch package only when livepatch is enabled
  Otherwise the filelist may be empty failing the build (bsc#1218644).
- commit f730eec
* Mon Nov 18 2024 msuchanek@suse.de
- Update config files (bsc#1218644).
  LIVEPATCH_IPA_CLONES=n => LIVEPATCH=n
- commit cabd446
* Mon Nov 18 2024 tiwai@suse.de
- ASoC: audio-graph-card2: Purge absent supplies for device tree
  nodes (stable-fixes).
- ALSA: hda/realtek: fix mute/micmute LEDs for a HP EliteBook
  645 G10 (stable-fixes).
- ALSA: hda/realtek - Fixed Clevo platform headset Mic issue
  (stable-fixes).
- ALSA: usb-audio: Fix Yamaha P-125 Quirk Entry (stable-fixes).
- commit 03ba04a
* Mon Nov 18 2024 tiwai@suse.de
- drm/amdgpu: fix check in gmc_v9_0_get_vm_pte() (git-fixes).
- drm/bridge: tc358768: Fix DSI command tx (git-fixes).
- nouveau/dp: handle retries for AUX CH transfers with GSP
  (git-fixes).
- nouveau: handle EBUSY and EAGAIN for GSP aux errors (git-fixes).
- nouveau: fw: sync dma after setup is called (git-fixes).
- drm/rockchip: vop: Fix a dereferenced before check warning
  (git-fixes).
- Revert "mmc: dw_mmc: Fix IDMAC operation with pages bigger
  than 4K" (git-fixes).
- mmc: sunxi-mmc: Fix A100 compatible description (git-fixes).
- ALSA: hda/realtek - update set GPIO3 to default for Thinkpad
  with ALC1318 (git-fixes).
- ASoC: fsl_micfil: Add sample rate constraint (stable-fixes).
- ASoC: rt722-sdca: increase clk_stop_timeout to fix clock stop
  issue (stable-fixes).
- ASoC: amd: yc: Fix non-functional mic on ASUS E1404FA
  (stable-fixes).
- ASoC: amd: yc: Add quirk for ASUS Vivobook S15 M3502RA
  (stable-fixes).
- net: usb: qmi_wwan: add Fibocom FG132 0x0112 composition
  (stable-fixes).
- net: wwan: fix global oob in wwan_rtnl_policy (git-fixes).
- HID: lenovo: Add support for Thinkpad X1 Tablet Gen 3 keyboard
  (stable-fixes).
- HID: multitouch: Add quirk for Logitech Bolt receiver w/
  Casa touchpad (stable-fixes).
- drm/vmwgfx: Limit display layout ioctl array size to
  VMWGFX_NUM_DISPLAY_UNITS (stable-fixes).
- drm/amdkfd: Accounting pdd vram_usage for svm (stable-fixes).
- crypto: api - Fix liveliness check in crypto_alg_tested
  (stable-fixes).
- HID: multitouch: Add quirk for HONOR MagicBook Art 14 touchpad
  (stable-fixes).
- HID: multitouch: Add support for B2402FVA track point
  (stable-fixes).
- commit 42778ee
* Mon Nov 18 2024 nmorey@suse.com
- Revert "RDMA/core: Fix ENODEV error for iWARP test over vlan" (git-fixes)
- commit 46de62d
* Mon Nov 18 2024 nmorey@suse.com
- RDMA/bnxt_re: Remove some dead code (jsc#PED-11232)
- commit 14b2958
* Mon Nov 18 2024 ailiop@suse.com
- ocfs2: uncache inode which has failed entering the group
  (git-fixes).
- commit 4caa305
* Mon Nov 18 2024 ailiop@suse.com
- ocfs2: fix UBSAN warning in ocfs2_verify_volume() (git-fixes).
- commit fe96ee2
* Mon Nov 18 2024 ailiop@suse.com
- ocfs2: remove entry once instead of null-ptr-dereference in
  ocfs2_xa_remove() (git-fixes).
- commit 7a347a0
* Mon Nov 18 2024 ailiop@suse.com
- fs: Fix uninitialized value issue in from_kuid and from_kgid
  (git-fixes).
- commit 46de67d
* Mon Nov 18 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix some error handling paths in bnxt_re_probe() (git-fixes)
- commit f114f3f
* Mon Nov 18 2024 nmorey@suse.com
- Revert "RDMA/core: Fix ENODEV error for iWARP test over vlan" (git-fixes)
- commit 89dc95f
* Mon Nov 18 2024 nmorey@suse.com
- RDMA/siw: Add sendpage_ok() check to disable MSG_SPLICE_PAGES (git-fixes)
- commit 1e78f0f
* Sat Nov 16 2024 mfranc@suse.cz
- Bluetooth: ISO: Fix UAF on iso_sock_timeout (CVE-2024-50124
  bsc#1232926).
- commit 25f5727
* Fri Nov 15 2024 trenn@suse.com
- tools/power turbostat: Increase the limit for fd opened
  (bsc#1233119).
- commit 58c7a4f
* Fri Nov 15 2024 lduncan@suse.com
- scsi: qedf: Remove trailing space after \n newline
  (jsc#PED-11298 bsc#1233340).
- scsi: qedf: Simplify alloc_workqueue() invocations
  (jsc#PED-11298 bsc#1233340).
- scsi: Expand all create*_workqueue() invocations (jsc#PED-11298
  bsc#1233340).
- scsi: qedf: Set qed_slowpath_params to zero before use
  (jsc#PED-11298 bsc#1233340).
- scsi: qedf: Replace deprecated strncpy() with strscpy()
  (jsc#PED-11298 bsc#1233340).
- commit 048a6af
* Fri Nov 15 2024 dsterba@suse.com
- posix-clock: Fix missing timespec64 check in pc_clock_settime() (CVE-2024-50195 bsc#1233103)
- commit 5c410cf
* Fri Nov 15 2024 dsterba@suse.com
- bpf: Use raw_spinlock_t in ringbuf (CVE-2024-50138 bsc#1232935)
- commit 949411a
* Fri Nov 15 2024 dsterba@suse.com
- net: systemport: fix potential memory leak in bcm_sysport_xmit() (CVE-2024-50171 bsc#1233057)
- commit 24f9c7b
* Fri Nov 15 2024 jbohac@suse.cz
- fadump: reserve param area if below boot_mem_top (jsc#PED-9891).
- powerpc/fadump: allocate memory for additional parameters early
  (jsc#PED-9891).
- powerpc/fadump: Fix section mismatch warning (jsc#PED-9891).
- powerpc/fadump: update documentation about bootargs_append
  (jsc#PED-9891).
- powerpc/fadump: pass additional parameters when fadump is active
  (jsc#PED-9891).
- powerpc/fadump: setup additional parameters for dump capture
  kernel (jsc#PED-9891).
- powerpc/pseries/fadump: add support for multiple boot memory
  regions (jsc#PED-9891).
- commit 714cc39
* Fri Nov 15 2024 msuchanek@suse.de
- crypto: aes-gcm-p10 - Use the correct bit to test for P10
  (bsc#1232704).
- commit 52eb6a0
* Fri Nov 15 2024 ohering@suse.de
- add bugreference to a hv_netvsc patch (bsc#1232413).
- commit 14b76c0
* Fri Nov 15 2024 neelx@suse.com
- btrfs: fix unwritten extent buffer after snapshotting a new subvolume (bsc#1233319).
- commit ca2fad6
* Fri Nov 15 2024 jlee@suse.com
- EDAC/mc_sysfs: Convert sprintf()/snprintf() to sysfs_emit()
  (jsc#PED-11164).
- EDAC: Remove unused struct members (jsc#PED-11164).
- EDAC: Remove dynamic attributes from
  edac_device_alloc_ctl_info() (jsc#PED-11164).
- EDAC/device: Remove edac_dev_sysfs_block_attribute::store()
  (jsc#PED-11164).
- EDAC/device: Remove
  edac_dev_sysfs_block_attribute::{block,value} (jsc#PED-11164).
- EDAC/amd64: Remove unused struct member amd64_pvt::ext_nbcfg
  (jsc#PED-11164).
- commit e3ace32
* Fri Nov 15 2024 mfranc@suse.cz
- scsi: target: core: Fix null-ptr-deref in target_alloc_device()
  (CVE-2024-50153 bsc#1233061).
- commit 76e65bc
* Fri Nov 15 2024 mfranc@suse.cz
- octeon_ep: Add SKB allocation failures handling in
  __octep_oq_process_rx() (CVE-2024-50145 bsc#1233044).
- octeon_ep: Implement helper for iterating packets in Rx queue
  (CVE-2024-50145 bsc#1233044).
- commit 6b574c1
* Fri Nov 15 2024 sjaeckel@suse.de
- Fix for kABI fix for Bluetooth: L2CAP: Fix
  div-by-zero in l2cap_le_flowctl_init() (CVE-2024-36968 bsc#1226130).
  The chosen position of `mtu` in the `struct hci_conn` in the first
  iteration of this patch was done based on the wrong version of the header
  and therefore on the wrong position. Correct that.
  Fixes: d93ac77c0df4b8dfe469c26e60d4fb45fc305341
- commit 77fc56a
* Fri Nov 15 2024 mfranc@suse.cz
- net: wwan: fix global oob in wwan_rtnl_policy (CVE-2024-50128
  bsc#1232905).
- commit c939671
* Fri Nov 15 2024 mfranc@suse.cz
- xfrm: fix one more kernel-infoleak in algo dumping
  (CVE-2024-50110 bsc#1232885).
- commit 2ae0e01
* Fri Nov 15 2024 mfranc@suse.cz
- scsi: ufs: core: Set SDEV_OFFLINE when UFS is shut down
  (CVE-2024-50098 bsc#1232881).
- commit f344a8e
* Fri Nov 15 2024 mfranc@suse.cz
- Update
  patches.suse/thermal-intel-int340x-processor-Fix-warning-during-m.patch
  (git-fixes bsc#1232877 CVE-2024-50093).
- commit 6ec2cb2
* Fri Nov 15 2024 tiwai@suse.de
- Bluetooth: btintel: Direct exception event to bluetooth stack
  (git-fixes).
- Bluetooth: hci_core: Fix calling mgmt_device_connected
  (git-fixes).
- USB: serial: qcserial: add support for Sierra Wireless EM86xx
  (stable-fixes).
- USB: serial: option: add Quectel RG650V (stable-fixes).
- USB: serial: option: add Fibocom FG132 0x0112 composition
  (stable-fixes).
- tools/lib/thermal: Fix sampling handler context ptr (git-fixes).
- drm/amdgpu: add missing size check in
  amdgpu_debugfs_gprwave_read() (stable-fixes).
- drm/amdgpu: Adjust debugfs eviction and IB access permissions
  (stable-fixes).
- drm/amdgpu: Adjust debugfs register access permissions
  (stable-fixes).
- drm/amdgpu: prevent NULL pointer dereference if ATIF is not
  supported (git-fixes).
- net: phy: ti: add PHY_RST_AFTER_CLK_EN flag (git-fixes).
- net: wwan: t7xx: Fix off-by-one error in
  t7xx_dpmaif_rx_buf_alloc() (git-fixes).
- net: phy: dp83822: Fix reset pin definitions (git-fixes).
- commit 48ec995
* Fri Nov 15 2024 tiwai@suse.de
- Delete patches.suse/wifi-mac80211-fix-RCU-list-iterations.patch
  It was reverted on 6.6.x stable
- commit e2ead50
* Fri Nov 15 2024 mfranc@suse.cz
- net: explicitly clear the sk pointer, when pf->create fails
  (CVE-2024-50186 bsc#1233110).
- commit dfaff4b
* Fri Nov 15 2024 mfranc@suse.cz
- secretmem: disable memfd_secret() if arch cannot set direct map
  (CVE-2024-50182 bsc#1233129).
- commit 0d23f21
* Fri Nov 15 2024 jslaby@suse.cz
- Update
  patches.suse/0479-drm-amd-display-Stop-amdgpu_dm-initialize-when-link-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-46816 bsc#1231197).
- Update
  patches.suse/0482-drm-amd-display-Add-missing-NULL-pointer-check-withi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-46808 bsc#1231140).
- Update
  patches.suse/0567-drm-amdgpu-vcn-remove-irq-disabling-in-vcn-5-suspend.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-46820 bsc#1231168).
- Update
  patches.suse/1730-drm-amd-display-Disable-DMCUB-timeout-for-DCN35.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-46870 bsc#1231435).
- Update
  patches.suse/2455-drm-v3d-Prevent-out-of-bounds-access-in-performance-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-42264 bsc#1229333).
- Update
  patches.suse/2613-drm-panthor-Restrict-high-priorities-on-group_create.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-46837 bsc#1231099).
- Update
  patches.suse/2625-drm-amd-display-Avoid-race-between-dcn35_set_drr-and.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-46850 bsc#1231080).
- Update
  patches.suse/2644-drm-xe-client-fix-deadlock-in-show_meminfo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-46867 bsc#1231106).
- Update
  patches.suse/2645-drm-xe-client-add-missing-bo-locking-in-show_meminfo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2024-46866 bsc#1231109).
- Update
  patches.suse/ASoC-Intel-soc-acpi-intel-rpl-match-add-missing-empt.patch
  (git-fixes CVE-2024-50011 bsc#1232081).
- Update
  patches.suse/Bluetooth-ISO-Fix-UAF-on-iso_sock_timeout.patch
  (git-fixes CVE-2024-50124 bsc#1232926).
- Update
  patches.suse/Bluetooth-MGMT-Fix-possible-crash-on-mgmt_index_remo.patch
  (git-fixes CVE-2024-49951 bsc#1232158).
- Update
  patches.suse/Bluetooth-SCO-Fix-UAF-on-sco_sock_timeout.patch
  (git-fixes CVE-2024-50125 bsc#1232928).
- Update
  patches.suse/Bluetooth-hci_conn-Fix-UAF-in-hci_enhanced_setup_syn.patch
  (git-fixes CVE-2024-50029 bsc#1231949).
- Update
  patches.suse/IB-mlx5-Fix-UMR-pd-cleanup-on-error-flow-of-driver-i.patch
  (jsc#PED-9900 jsc#PED-11429 CVE-2024-47694 bsc#1232014).
- Update
  patches.suse/bonding-Fix-unnecessary-warnings-and-logs-from-bond_.patch
  (jsc#PED-10564 CVE-2024-47734 bsc#1232055).
- Update
  patches.suse/ice-fix-memleak-in-ice_init_tx_topology.patch
  (jsc#PED-9947 CVE-2024-50190 bsc#1233090).
- Update
  patches.suse/iommu-vt-d-Fix-incorrect-pci_for_each_dma_alias-for-non-PCI-devi
  (jsc#PED-10539 CVE-2024-50101 bsc#1232869).
- Update
  patches.suse/iommufd-Require-drivers-to-supply-the-cache_invalidate_user-ops
  (jsc#PED-10539 CVE-2024-46824 bsc#1231113).
- Update patches.suse/net-pse-pd-Fix-out-of-bound-for-loop.patch
  (bsc#1232798 CVE-2024-50129 bsc#1232856).
- Update
  patches.suse/pinctrl-intel-platform-fix-error-path-in-device_for_.patch
  (git-fixes CVE-2024-50197 bsc#1233089).
- Update
  patches.suse/platform-x86-intel-pmc-Fix-pmc_core_iounmap-to-call-.patch
  (git-fixes CVE-2024-50107 bsc#1232883).
- Update
  patches.suse/sfc-Don-t-invoke-xdp_do_flush-from-netpoll.patch
  (jsc#PED-11367 CVE-2024-50094 bsc#1232875).
- Update
  patches.suse/wifi-ath11k-use-work-queue-to-process-beacon-tx-even.patch
  (git-fixes CVE-2024-47724 bsc#1232073).
- commit 00bffec
* Fri Nov 15 2024 jslaby@suse.cz
- Update
  patches.suse/ACPI-CPPC-Make-rmw_lock-a-raw_spin_lock.patch
  (git-fixes CVE-2024-50249 bsc#1233197).
- Update
  patches.suse/ACPI-PRM-Find-EFI_MEMORY_RUNTIME-block-for-PRM-handl.patch
  (git-fixes CVE-2024-50141 bsc#1233065).
- Update
  patches.suse/ALSA-firewire-lib-Avoid-division-by-zero-in-apply_co.patch
  (git-fixes CVE-2024-50205 bsc#1233293).
- Update
  patches.suse/ALSA-hda-cs8409-Fix-possible-NULL-dereference.patch
  (git-fixes CVE-2024-50160 bsc#1233074).
- Update
  patches.suse/ASoC-qcom-Fix-NULL-Dereference-in-asoc_qcom_lpass_cp.patch
  (git-fixes CVE-2024-50103 bsc#1232878).
- Update
  patches.suse/Bluetooth-bnep-fix-wild-memory-access-in-proto_unreg.patch
  (git-fixes CVE-2024-50148 bsc#1233063).
- Update
  patches.suse/Bluetooth-hci-fix-null-ptr-deref-in-hci_read_support.patch
  (git-fixes CVE-2024-50255 bsc#1233238).
- Update
  patches.suse/HID-amd_sfh-Switch-to-device-managed-dmam_alloc_cohe.patch
  (git-fixes CVE-2024-50189 bsc#1233105).
- Update
  patches.suse/RDMA-bnxt_re-Add-a-check-for-memory-allocation.patch
  (git-fixes CVE-2024-50209 bsc#1233114).
- Update
  patches.suse/RDMA-bnxt_re-Avoid-CPU-lockups-due-fifo-occupancy-ch.patch
  (git-fixes CVE-2024-50157 bsc#1233032).
- Update
  patches.suse/RDMA-bnxt_re-Fix-a-bug-while-setting-up-Level-2-PBL-.patch
  (git-fixes CVE-2024-50208 bsc#1233117).
- Update
  patches.suse/RDMA-bnxt_re-Fix-a-possible-memory-leak.patch
  (git-fixes CVE-2024-50172 bsc#1233029).
- Update patches.suse/RDMA-bnxt_re-Fix-out-of-bound-check.patch
  (git-fixes CVE-2024-50158 bsc#1233036).
- Update
  patches.suse/RDMA-mad-Improve-handling-of-timed-out-WRs-of-mad-ag.patch
  (git-fixes CVE-2024-50095 bsc#1232873).
- Update
  patches.suse/USB-gadget-dummy-hcd-Fix-task-hung-problem.patch
  (git-fixes CVE-2024-50100 bsc#1232876).
- Update
  patches.suse/arm64-probes-Fix-uprobes-for-big-endian-kernels.patch
  (git-fixes CVE-2024-50194 bsc#1233111).
- Update
  patches.suse/arm64-probes-Remove-broken-LDR-literal-uprobe-support.patch
  (git-fixes CVE-2024-50099 bsc#1232887).
- Update
  patches.suse/ceph-remove-the-incorrect-Fw-reference-check-when-dir.patch
  (bsc#1231182 CVE-2024-50179 bsc#1233123).
- Update
  patches.suse/clk-imx-Remove-CLK_SET_PARENT_GATE-for-DRAM-mux-for-.patch
  (stable-fixes CVE-2024-50181 bsc#1233127).
- Update
  patches.suse/drm-amd-Guard-against-bad-data-for-ATIF-ACPI-method.patch
  (git-fixes CVE-2024-50117 bsc#1232897).
- Update
  patches.suse/drm-amd-display-Disable-PSR-SU-on-Parade-08-01-TCON-.patch
  (stable-fixes CVE-2024-50108 bsc#1232884).
- Update
  patches.suse/drm-amd-pm-Vangogh-Fix-kernel-memory-out-of-bounds-w.patch
  (git-fixes CVE-2024-50221 bsc#1233185).
- Update
  patches.suse/drm-msm-Avoid-NULL-dereference-in-msm_disp_state_pri.patch
  (git-fixes CVE-2024-50156 bsc#1233073).
- Update patches.suse/drm-radeon-Fix-encoder-possible_clones.patch
  (git-fixes CVE-2024-50201 bsc#1233104).
- Update
  patches.suse/drm-vboxvideo-Replace-fake-VLA-at-end-of-vbva_mouse_.patch
  (stable-fixes CVE-2024-50134 bsc#1232890).
- Update
  patches.suse/drm-vc4-Stop-the-active-perfmon-before-being-destroy.patch
  (git-fixes CVE-2024-50187 bsc#1233108).
- Update
  patches.suse/ext4-fix-slab-use-after-free-in-ext4_split_extent_at.patch
  (bsc#1232201 CVE-2024-49884 bsc#1232198).
- Update patches.suse/fbdev-sisfb-Fix-strbuf-array-overflow.patch
  (stable-fixes CVE-2024-50180 bsc#1233125).
- Update
  patches.suse/firmware-arm_scmi-Fix-the-double-free-in-scmi_debugf.patch
  (git-fixes CVE-2024-50159 bsc#1233041).
- Update
  patches.suse/iio-adc-ad7124-fix-division-by-zero-in-ad7124_set_ch.patch
  (git-fixes CVE-2024-50232 bsc#1233209).
- Update
  patches.suse/iio-gts-helper-Fix-memory-leaks-in-iio_gts_build_ava.patch
  (git-fixes CVE-2024-50231 bsc#1233208).
- Update
  patches.suse/iio-light-veml6030-fix-IIO-device-retrieval-from-emb.patch
  (git-fixes CVE-2024-50198 bsc#1233100).
- Update
  patches.suse/iommu-vt-d-Fix-incorrect-pci_for_each_dma_alias-for-.patch
  (git-fixes CVE-2024-50101 bsc#1232869).
- Update
  patches.suse/maple_tree-correct-tree-corruption-on-spanning-store.patch
  (git-fixes CVE-2024-50200 bsc#1233088).
- Update
  patches.suse/media-qcom-camss-Remove-use_count-guard-in-stop_stre.patch
  (git-fixes CVE-2024-50175 bsc#1233092).
- Update
  patches.suse/net-mlx5-Fix-command-bitmask-initialization.patch
  (git-fixes CVE-2024-50147 bsc#1233067).
- Update
  patches.suse/net-mlx5-Unregister-notifier-on-eswitch-init-failure.patch
  (git-fixes CVE-2024-50136 bsc#1232914).
- Update
  patches.suse/net-mlx5e-Don-t-call-cleanup-on-profile-rollback-fai.patch
  (git-fixes CVE-2024-50146 bsc#1233056).
- Update
  patches.suse/net-phy-dp83869-fix-memory-corruption-when-enabling-.patch
  (git-fixes CVE-2024-50188 bsc#1233107).
- Update
  patches.suse/netdevsim-use-cond_resched-in-nsim_dev_trap_report_w.patch
  (git-fixes CVE-2024-50155 bsc#1233035).
- Update
  patches.suse/nfsd-cancel-nfsd_shrinker_work-using-sync-mode-in-nf.patch
  (git-fixes CVE-2024-50121 bsc#1232925).
- Update
  patches.suse/nilfs2-fix-kernel-bug-due-to-missing-clearing-of-buffer-delay-flag.patch
  (git-fixes CVE-2024-50116 bsc#1232892).
- Update
  patches.suse/nilfs2-fix-potential-deadlock-with-newly-created-symlinks.patch
  (git-fixes CVE-2024-50229 bsc#1233205).
- Update
  patches.suse/nouveau-dmem-Fix-vulnerability-in-migrate_to_ram-upo.patch
  (git-fixes CVE-2024-50096 bsc#1232870).
- Update
  patches.suse/nvme-pci-fix-race-condition-between-reset-and-nvme_d.patch
  (git-fixes CVE-2024-50135 bsc#1232888).
- Update
  patches.suse/nvmet-auth-assign-dh_key-to-NULL-after-kfree_sensiti.patch
  (git-fixes CVE-2024-50215 bsc#1233189).
- Update
  patches.suse/ocfs2-pass-u64-to-ocfs2_truncate_inline-maybe-overflow.patch
  (git-fixes CVE-2024-50218 bsc#1233191).
- Update
  patches.suse/phy-qcom-qmp-usb-fix-NULL-deref-on-runtime-suspend.patch
  (git-fixes CVE-2024-50240 bsc#1233217).
- Update
  patches.suse/pinctrl-ocelot-fix-system-hang-on-level-based-interr.patch
  (stable-fixes CVE-2024-50196 bsc#1233113).
- Update
  patches.suse/remoteproc-k3-r5-Fix-error-handling-when-power-up-fa.patch
  (git-fixes CVE-2024-50176 bsc#1233091).
- Update
  patches.suse/scsi-lpfc-Ensure-DA_ID-handling-completion-before-de.patch
  (bsc#1232757 CVE-2024-50183 bsc#1233130).
- Update
  patches.suse/spi-spi-fsl-dspi-Fix-crash-when-not-using-GPIO-chip-.patch
  (git-fixes CVE-2024-50224 bsc#1233188).
- Update
  patches.suse/staging-iio-frequency-ad9832-fix-division-by-zero-in.patch
  (git-fixes CVE-2024-50233 bsc#1233210).
- Update
  patches.suse/thermal-intel-int340x-processor-Fix-warning-during-m.patch
  (git-fixes CVE-2024-50093 bsc#1232877).
- Update
  patches.suse/tracing-Consider-the-NULL-character-when-validating-the-event-length.patch
  (git-fixes CVE-2024-50131 bsc#1232896).
- Update
  patches.suse/tracing-timerlat-Drop-interface_lock-in-stop_kthread.patch
  (git-fixes CVE-2024-49976 bsc#1232103).
- Update
  patches.suse/tracing-timerlat-Only-clear-timer-if-a-kthread-exists.patch
  (git-fixes CVE-2024-46845 bsc#1231076).
- Update
  patches.suse/unicode-Don-t-special-case-ignorable-code-points.patch
  (stable-fixes CVE-2024-50089 bsc#1232860).
- Update
  patches.suse/uprobe-avoid-out-of-bounds-memory-access-of-fetching-args.patch
  (git-fixes CVE-2024-50067 bsc#1232416).
- Update
  patches.suse/uprobes-fix-kernel-info-leak-via-uprobes-vma.patch
  (bsc#1231114 CVE-2024-46828 CVE-2024-49975 bsc#1232104).
- Update
  patches.suse/usb-typec-altmode-should-keep-reference-to-parent.patch
  (git-fixes CVE-2024-50150 bsc#1233051).
- Update
  patches.suse/wifi-ath10k-Fix-memory-leak-in-management-tx.patch
  (git-fixes CVE-2024-50236 bsc#1233212).
- Update
  patches.suse/wifi-cfg80211-clear-wdev-cqm_config-pointer-on-free.patch
  (git-fixes CVE-2024-50235 bsc#1233176).
- Update
  patches.suse/wifi-iwlegacy-Clear-stale-interrupts-before-resuming.patch
  (stable-fixes CVE-2024-50234 bsc#1233211).
- Update
  patches.suse/wifi-mac80211-do-not-pass-a-stopped-vif-to-the-drive.patch
  (git-fixes CVE-2024-50237 bsc#1233216).
- Update
  patches.suse/x86-fix-user-address-masking-non-canonical-speculation-iss.patch
  (git-fixes CVE-2024-50102 bsc#1232880).
- Update
  patches.suse/xfs-fix-finding-a-last-resort-AG-in-xfs_filestream_pick_ag.patch
  (git-fixes CVE-2024-50216 bsc#1233179).
- commit 7d67ea3
* Thu Nov 14 2024 dsterba@suse.com
- btrfs: fix error propagation of split bios (CVE-2024-50225 bsc#1233193)
- commit ec9c552
* Thu Nov 14 2024 dsterba@suse.com
- btrfs: merge btrfs_orig_bbio_end_io() into btrfs_bio_end_io() (bsc#1233193)
- commit b9564da
* Thu Nov 14 2024 dsterba@suse.com
- Update references in patches.suse/ntfs3-Add-bounds-checking-to-mi_enum_attr.patch (CVE-2024-50248 bsc#1233219 bsc#1233207)
- commit 56e1d55
* Thu Nov 14 2024 dsterba@suse.com
- fs/ntfs3: Sequential field availability check in mi_enum_attr() (bsc#1233207)
- commit 95663e2
* Thu Nov 14 2024 dsterba@suse.com
- fs/ntfs3: Add rough attr alloc_size check (CVE-2024-50246 bsc#1233207)
- commit 378df6a
* Thu Nov 14 2024 dsterba@suse.com
- ntfs3: Add bounds checking to mi_enum_attr() (bsc#1233207)
- commit 418f82a
* Thu Nov 14 2024 dsterba@suse.com
- fs/ntfs3: Fixed overflow check in mi_enum_attr() (bsc#1233207)
- commit 6744037
* Thu Nov 14 2024 dsterba@suse.com
- fs/ntfs3: Add more attributes checks in mi_enum_attr() (bsc#1233207)
- commit 766ca6e
* Thu Nov 14 2024 dsterba@suse.com
- fs/ntfs3: Fix possible deadlock in mi_read (CVE-2024-50245 bsc#1233203)
- commit 5f9c2da
* Thu Nov 14 2024 sjaeckel@suse.de
- Rename to
  patches.kabi/kABI-fix-for-Bluetooth-L2CAP-Fix-div-by-zero-in-l2ca.patch.
  Fixes: d93ac77c0df4b8dfe469c26e60d4fb45fc305341
- commit 1f6a42b
* Thu Nov 14 2024 jgross@suse.com
- virtio_pmem: Check device status before requesting flush
  (CVE-2024-50184 bsc#1233135).
- commit 4e28ae6
* Thu Nov 14 2024 jgross@suse.com
- KVM: SEV-ES: Fix svm_get_msr()/svm_set_msr() for KVM_SEV_ES_INIT
  guests (bsc#1232207).
- commit 4b9eff5
* Thu Nov 14 2024 iivanov@suse.de
- blacklist.conf: Disable revert of "ARM64: Dynamically allocate cpumasks and increase supported CPUs to 512" (jsc#PED-11431)
- commit 300ee50
* Thu Nov 14 2024 jgross@suse.com
- KVM: SEV-ES: Prevent MSR access post VMSA encryption
  (bsc#1232207).
- commit 61f28ae
* Thu Nov 14 2024 ptesarik@suse.com
- u64_stats: fix u64_stats_init() for lockdep when used repeatedly
  in one file (git-fixes).
- commit 017d59a
* Thu Nov 14 2024 jack@suse.cz
- Update tags in
  patches.suse/ext4-fix-slab-use-after-free-in-ext4_split_extent_at.patch
  (bsc#1232201 CVE-2024-49884 bsc#1232198).
- commit 9d4c3ec
* Thu Nov 14 2024 sjaeckel@suse.de
- tcp/dccp: Don't use timer_pending() in reqsk_queue_unlink()
  (CVE-2024-50154 bsc#1233070).
- commit 43fc2d5
* Thu Nov 14 2024 svarbanov@suse.de
- PCI: acpiphp: Allow built-in drivers for Attention Indicators (jsc#PED-11435)
- commit acd8254
* Thu Nov 14 2024 svarbanov@suse.de
- supported.conf: Mark Ampere Altra extensions driver as supported (jsc#PED-11435)
- commit 399b97d
* Thu Nov 14 2024 sjaeckel@suse.de
- qlcnic: make read-only const array key static (jsc#PED-11300).
- qlcnic: Remove unused declarations (jsc#PED-11300).
- commit 71b393c
* Thu Nov 14 2024 svarbanov@suse.de
- PCI: hotplug: Add Ampere Altra Attention Indicator extension driver (jsc#PED-11435)
- commit ef2b1b9
* Thu Nov 14 2024 iivanov@suse.de
- ARM64: Dynamically allocate cpumasks and increase supported CPUs to (jsc#PED-11431)
  Enable CPUMASK_OFFSTACK=y in arm64 configuration.
- commit ef1a314
* Thu Nov 14 2024 shung-hsi.yu@suse.com
- Refresh patches.kabi/bpf-verifier-kABI-workarounds.patch (bsc#1233350)
  Correctly workaround kABI breakage that was introduced with fixes
  backported for bsc#1225903.
- commit 52684a5
* Thu Nov 14 2024 tiwai@suse.de
- ASoC: SOF: ipc4-topology: Only handle dai_config with HW_PARAMS
  for ChainDMA (bsc#1233305).
- commit 1b06409
* Wed Nov 13 2024 krisman@suse.de
- io_uring/rw: fix missing NOWAIT check for O_DIRECT start write
  (git-fixes).
- io_uring/sqpoll: close race on waiting for sqring entries
  (git-fixes).
- commit 83eaece
* Wed Nov 13 2024 mgorman@suse.de
- mm: shmem: fix data-race in shmem_getattr() (CVE-2024-50228,
  bsc#1233204, git fixes (mm/shmem)).
- commit 89c94b7
* Wed Nov 13 2024 jslaby@suse.cz
- irqchip/gic-v4: Correctly deal with set_affinity on
  lazily-mapped VPEs (CVE-2024-50192 bsc#1233106).
- commit 4258dbe
* Wed Nov 13 2024 jslaby@suse.cz
- irqchip/gic-v4: Don't allow a VMOVP on a dying VPE
  (CVE-2024-50192 bsc#1233106).
- kABI: Don't allow a VMOVP on a dying VPE (kabi CVE-2024-50192
  bsc#1233106).
- irqchip/gic-v3-its: Avoid explicit cpumask allocation on stack
  (git-fixes).
- commit 9bd7834
* Wed Nov 13 2024 shung-hsi.yu@suse.com
- selftests/bpf: add stack access precision test (bsc#1232823
  CVE-2023-52920).
- bpf: support non-r10 register spill/fill to/from stack in
  precision tracking (bsc#1232823 CVE-2023-52920).
- Refresh patches.suse/bpf-Fix-accesses-to-uninit-stack-slots.patch
- Refresh patches.kabi/bpf-verifier-kABI-workarounds.patch
- commit 2dc84ae
* Wed Nov 13 2024 sjaeckel@suse.de
- kABI fix for - Bluetooth: L2CAP: Fix
  div-by-zero in l2cap_le_flowctl_init()
  (CVE-2024-36968 bsc#1226130). - Refresh
  patches.suse/Bluetooth-Ignore-too-large-handle-values-in-BIG.patch.
- Refresh
  patches.suse/Bluetooth-L2CAP-Fix-deadlock.patch. - Refresh
  patches.suse/Bluetooth-btnxpuart-Enable-Power-Save-feature-on-sta.patch.
- Refresh
  patches.suse/bluetooth-hci-disallow-setting-handle-bigger-than-HC.patch.
- Refresh
  patches.suse/bluetooth-l2cap-sync-sock-recv-cb-and-release.patch.
- commit d93ac77
* Wed Nov 13 2024 tbogendoerfer@suse.de
- macsec: Fix use-after-free while sending the offloading packet
  (CVE-2024-50261 bsc#1233253).
- commit 493a21e
* Wed Nov 13 2024 tiwai@suse.de
- kABI workaround for ASoC SOF (bsc#1233305).
- commit d8b041e
* Wed Nov 13 2024 tiwai@suse.de
- ASoC: SOF: ipc4-topology: Add definition for generic switch/enum
  control (bsc#1233305).
- Refresh
  patches.suse/ASoC-SOF-ipc4-topology-Correct-data-structures-for-t-e238b68.patch.
- commit 6d4ee28
* Wed Nov 13 2024 tiwai@suse.de
- ASoC: SOF: topology: Parse DAI type token for dspless mode
  (bsc#1233305).
- ASoC: SOF: topology: dynamically allocate and store DAI
  widget->private (bsc#1233305).
- ASoC: SOF: ipc4-topology: change chain_dma handling in
  dai_config (bsc#1233305).
- ASoC: SOF: ipc4-topology: set config_length based on
  device_count (bsc#1233305).
- ASoC: SOF: Rename amd_bt sof_dai_type (bsc#1233305).
- ASoC: SOF: Add i2s bt dai configuration support for AMD
  platforms (bsc#1233305).
- ASoC: SOF: Refactor sof_i2s_tokens reading to update acpbt dai
  (bsc#1233305).
- ASoC: SOF: IPC4: synchronize fw_config_params with fw
  definitions (bsc#1233305).
- ASoC: SOF: Wire up buffer flags (bsc#1233305).
- ASoC: SOF: add alignment for topology header file struct
  definition (bsc#1233305).
- ASoC: SOF: align topology header file with sof topology header
  (bsc#1233305).
- ASoC: SOF: ipc4-topology: Add module ID print during module
  set up (bsc#1233305).
- ASoC: SOF: ipc4: Add data struct for module notification
  message from firmware (bsc#1233305).
- ASoC: SOF: ipc4-topology: Helper to find an swidget by
  module/instance id (bsc#1233305).
- ASoC: SOF: Add support for configuring PDM interface from
  topology (bsc#1233305).
- ASoC: SOF: IPC4: get pipeline priority from topology
  (bsc#1233305).
- ASoC: SOF: ipc4-mtrace: move debug slot related definitions
  to header.h (bsc#1233305).
- ASoC: SOF: ipc4-control: Add support for ALSA enum control
  (bsc#1233305).
- ASoC: SOF: ipc4-control: Add support for ALSA switch control
  (bsc#1233305).
- ASoC: SOF: ipc4-topology: export
  sof_ipc4_copier_is_single_format (bsc#1233305).
- ASoC: SOF: ipc4: Add new message type:
  SOF_IPC4_GLB_LOAD_LIBRARY_PREPARE (bsc#1233305).
- ASoC: SOF: ipc4-topology: Add deep buffer size to debug prints
  (bsc#1233305).
- ASoC: SOF: Deprecate invalid enums in IPC3 (bsc#1233305).
- commit ccbfc43
* Wed Nov 13 2024 tiwai@suse.de
- ima: fix buffer overrun in ima_eventdigest_init_common
  (git-fixes).
- commit 200c852
* Tue Nov 12 2024 vkarasulli@suse.de
- KVM: arm64: Fix shift-out-of-bounds bug (CVE-2024-50139
  bsc#1233062).
- commit dc4add6
* Tue Nov 12 2024 vkarasulli@suse.de
- KVM: nSVM: Ignore nCR3[4:0] when loading PDPTEs from memory
  (CVE-2024-50115 bsc#1232919).
- commit b8f7c4d
* Tue Nov 12 2024 sjaeckel@suse.de
- Bluetooth: L2CAP: Fix div-by-zero in l2cap_le_flowctl_init()
  (CVE-2024-36968 bsc#1226130).
- Refresh
  patches.suse/Bluetooth-Ignore-too-large-handle-values-in-BIG.patch.
- Refresh patches.suse/Bluetooth-L2CAP-Fix-deadlock.patch.
- Refresh
  patches.suse/Bluetooth-btnxpuart-Enable-Power-Save-feature-on-sta.patch.
- Refresh
  patches.suse/bluetooth-hci-disallow-setting-handle-bigger-than-HC.patch.
- Refresh
  patches.suse/bluetooth-l2cap-sync-sock-recv-cb-and-release.patch.
- commit c95a285
* Tue Nov 12 2024 sjaeckel@suse.de
- net: sched: fix use-after-free in taprio_change()
  (CVE-2024-50127 bsc#1232907).
- commit 8d80c7f
* Tue Nov 12 2024 rgoldwyn@suse.com
- fsdax: dax_unshare_iter needs to copy entire blocks
  (bsc#1233226, CVE-2024-50250).
- fsdax: remove zeroing code from dax_unshare_iter  (bsc#1233226,
  CVE-2024-50250).
- commit 94457ab
* Tue Nov 12 2024 jbohac@suse.cz
- Refresh
  patches.suse/powerpc-crash-add-crash-CPU-hotplug-support.patch.
  Fix compile warnings in arch/powerpc/include/asm/kexec.h
- commit f65f876
* Tue Nov 12 2024 ailiop@suse.com
- nilfs2: fix kernel bug due to missing clearing of checked flag
  (bsc#1233206 CVE-2024-50230).
- commit ba9ac5c
* Tue Nov 12 2024 msuchanek@suse.de
- KVM: PPC: Book3S HV: Mask off LPCR_MER for a vCPU before running
  it to avoid spurious interrupts (jsc#PED-11016 git-fixes).
- commit 85bbcce
* Tue Nov 12 2024 tzimmermann@suse.com
- drm/amd/display: Check null pointers before used (bsc#1232371 CVE-2024-49921)
- commit 3bf6629
* Mon Nov 11 2024 tbogendoerfer@suse.de
- net/ncsi: Disable the ncsi work before freeing the associated
  structure (CVE-2024-49945 bsc#1232165).
- commit 75d875c
* Mon Nov 11 2024 tbogendoerfer@suse.de
- e1000e: Remove Meteor Lake SMBUS workarounds (git-fixes).
- i40e: fix race condition by adding filter's intermediate sync
  state (git-fixes).
- commit f4e661d
* Mon Nov 11 2024 sjaeckel@suse.de
- net: make SK_MEMORY_PCPU_RESERV tunable (jsc#PED-11437).
- Update
  patches.suse/net-fix-sk_memory_allocated_-add-sub-vs-softirqs.patch
  (bsc#1228757 jsc#PED-11437).
- commit 0babf16
* Mon Nov 11 2024 sjaeckel@suse.de
- net: Namespace-ify sysctl_optmem_max (jsc#PED-11437).
- net: increase optmem_max default value (jsc#PED-11437).
- commit 76397bf
* Mon Nov 11 2024 davide.benini@suse.com
- blacklist.conf: Irrelevant in our code
- commit fce3ae4
* Mon Nov 11 2024 tonyj@suse.de
- perf/x86/intel: Add PMU support for ArrowLake-H (jsc#PED-10365).
- perf/x86/intel: Support hybrid PMU with multiple atom uarchs
  (jsc#PED-10365).
- x86/cpu/intel: Define helper to get CPU core native ID
  (jsc#PED-10365).
- perf/x86: Refine hybrid_pmu_type defination (jsc#PED-10365).
- commit c4725a5
* Mon Nov 11 2024 tbogendoerfer@suse.de
- supported.conf: mark hns3/hclge-common supported
- commit f9f38f8
* Mon Nov 11 2024 tbogendoerfer@suse.de
- drivers: net: ionic: add missed debugfs cleanup to ionic_probe()
  error path (jsc#PED-11379).
- idpf: fix idpf_vc_core_init error path (jsc#PED-11153).
- idpf: avoid vport access in idpf_get_link_ksettings
  (jsc#PED-11153).
- net: hns3: fix kernel crash when uninstalling driver
  (jsc#PED-11472).
- RDMA/nldev: Fix NULL pointer dereferences issue in
  rdma_nl_notify_event (jsc#PED-11324).
- bonding: Fix unnecessary warnings and logs from
  bond_xdp_get_xmit_slave() (jsc#PED-10564).
- RDMA/nldev: Add missing break in rdma_nl_notify_err_msg()
  (jsc#PED-11324).
- RDMA/nldev: Expose whether RDMA monitoring is supported
  (jsc#PED-11324).
- RDMA/nldev: Add support for RDMA monitoring (jsc#PED-11324).
- bonding: Remove setting of RX software timestamp
  (jsc#PED-10564).
- bonding: support xfrm state update (jsc#PED-10564).
- bonding: Add ESN support to IPSec HW offload (jsc#PED-10564).
- bonding: add common function to check ipsec device
  (jsc#PED-10564).
- net: hns3: Remove setting of RX software timestamp
  (jsc#PED-11472).
- bonding: Correct spelling in headers (jsc#PED-10564).
- net: refactor ->ndo_bpf calls into dev_xdp_propagate
  (jsc#PED-10564).
- net: hns3: Use ARRAY_SIZE() to improve readability
  (jsc#PED-11472).
- net: hns3: Use ipv6_addr_{cpu_to_be32,be32_to_cpu} helpers
  (jsc#PED-11472).
- ipv6: Add ipv6_addr_{cpu_to_be32,be32_to_cpu} helpers
  (jsc#PED-11472).
- commit 6dec533
* Mon Nov 11 2024 jack@suse.cz
- Revert "mm/writeback: fix possible divide-by-zero in
  wb_dirty_limits(), again" (CVE-2024-42102 bsc#1233132).
- commit 696592c
* Mon Nov 11 2024 tbogendoerfer@suse.de
- bonding: fix bond_ipsec_offload_ok return type (jsc#PED-10564).
- Refresh
  patches.suse/bonding-fix-null-pointer-deref-in-bond_ipsec_offload.patch.
- commit 83baa98
* Mon Nov 11 2024 tbogendoerfer@suse.de
- bonding: use bond_set_slave_arr to simplify code
  (jsc#PED-10564).
- Refresh
  patches.suse/bonding-change-ipsec_lock-from-spin-lock-to-mutex.patch.
- commit 46d706d
* Mon Nov 11 2024 tbogendoerfer@suse.de
- net: hns3: Remove unused function declarations (jsc#PED-11472).
- Refresh
  patches.suse/net-hns3-move-dump-regs-function-to-a-separate-file.patch.
- commit 09fec5a
* Mon Nov 11 2024 tbogendoerfer@suse.de
- bonding: Pass string literal as format argument of
  alloc_ordered_workqueue() (jsc#PED-10564).
- bonding: fix xfrm state handling when clearing active slave
  (jsc#PED-10564).
- net: hns3: use correct release function during uninitialization
  (jsc#PED-11472).
- net: hns3: void array out of bound when loop tnl_num
  (jsc#PED-11472 CVE-2024-46833 bsc#1231119).
- net: hns3: fix a deadlock problem when config TC during
  resetting (jsc#PED-11472).
- net: hns3: use the user's cfg after reset (jsc#PED-11472).
- net: hns3: fix wrong use of semaphore up (jsc#PED-11472).
- net: bonding: correctly annotate RCU in
  bond_should_notify_peers() (jsc#PED-10564).
- hns3: avoid linking objects into multiple modules
  (jsc#PED-11472).
- net: hns3: add cond_resched() to hns3 ring buffer init process
  (jsc#PED-11472).
- net: hns3: flower: validate control flags (jsc#PED-11472).
- net: hns3: add support to query scc version by devlink info
  (jsc#PED-11472).
- net: hns3: dump more reg info based on ras mod (jsc#PED-11472).
- net: hns3: move constants from hclge_debugfs.h to
  hclge_debugfs.c (jsc#PED-11472).
- net: hns3: add command queue trace for hns3 (jsc#PED-11472).
- net: hns3: fix port vlan filter not disabled issue
  (jsc#PED-11472).
- net: hns3: use appropriate barrier function after setting a
  bit value (jsc#PED-11472).
- net: hns3: change type of numa_node_mask as nodemask_t
  (jsc#PED-11472).
- net: hns3: direct return when receive a unknown mailbox message
  (jsc#PED-11472).
- net: hns3: using user configure after hardware reset
  (jsc#PED-11472).
- net: hns3: add checking for vf id of mailbox (jsc#PED-11472).
- net: hns3: fix reset timeout under full functions and queues
  (jsc#PED-11472).
- net: hns3: fix delete tc fail issue (jsc#PED-11472).
- net: hns3: Disable SerDes serial loopback for HiLink H60
  (jsc#PED-11472).
- net: hns3: add new 200G link modes for hisilicon device
  (jsc#PED-11472).
- bonding: 802.3ad replace MAC_ADDRESS_EQUAL with
  __agg_has_partner (jsc#PED-10564).
- bonding: rate-limit bonding driver inspect messages
  (jsc#PED-10564).
- bonding: Add independent control state machine (jsc#PED-10564).
- net: hns3: reduce stack usage in hclge_dbg_dump_tm_pri()
  (jsc#PED-11472).
- net: hns3: add some link modes for hisilicon device
  (jsc#PED-11472).
- net: hns3: add vf fault detect support (jsc#PED-11472).
- net: hns3: add hns3 vf fault detect cap bit support
  (jsc#PED-11472).
- net: hns3: Support query tx timeout threshold by debugfs
  (jsc#PED-11472).
- bonding: update port speed when getting bond speed
  (jsc#PED-10564).
- net: hns3: Support tlv in regs data for HNS3 VF driver
  (jsc#PED-11472).
- bonding: remove unnecessary NULL check in bond_destructor
  (jsc#PED-10564).
- bonding: add modifier to initialization function and exit
  function (jsc#PED-10564).
- net: bonding: convert to ndo_hwtstamp_get() / ndo_hwtstamp_set()
  (jsc#PED-10564).
- bonding: 3ad: Remove unused declaration
  bond_3ad_update_lacp_active() (jsc#PED-10564).
- net: hns3: remove unnecessary (void*) conversions
  (jsc#PED-11472).
- net: hns3: restore user pause configure when disable autoneg
  (jsc#PED-11472).
- net: hns3: add tm flush when setting tm (jsc#PED-11472).
- net: hns3: clear hns unused parameter alarm (jsc#PED-11472).
- net: hns3: refine the tcam key convert handle (jsc#PED-11472).
- net: bonding: Add SPDX identifier to remaining files
  (jsc#PED-10564).
- commit 6255c77
* Mon Nov 11 2024 tbogendoerfer@suse.de
- blacklist.conf: remove CVE, which is now applicable
- commit ebeba73
* Mon Nov 11 2024 tiwai@suse.de
- thunderbolt: Fix connection issue with Pluggable UD-4VPD dock
  (git-fixes).
- commit 137975b
* Mon Nov 11 2024 tiwai@suse.de
- i2c: designware: do not hold SCL low when I2C_DYNAMIC_TAR_UPDATE
  is not set (git-fixes).
- USB: serial: io_edgeport: fix use after free in debug printk
  (git-fixes).
- usb: typec: fix potential out of bounds in
  ucsi_ccg_update_set_new_cam_cmd() (git-fixes).
- usb: musb: sunxi: Fix accessing an released usb phy (git-fixes).
- commit d16f490
* Sat Nov  9 2024 tiwai@suse.de
- ALSA: ump: Don't enumeration invalid groups for legacy rawmidi
  (stable-fixes).
- commit 44d5473
* Sat Nov  9 2024 tiwai@suse.de
- ASoC: stm: Prevent potential division by zero in
  stm32_sai_get_clk_div() (stable-fixes).
- ASoC: stm: Prevent potential division by zero in
  stm32_sai_mclk_round_rate() (stable-fixes).
- ASoC: amd: yc: Support dmic on another model of Lenovo Thinkpad
  E14 Gen 6 (stable-fixes).
- ASoC: amd: yc: fix internal mic on Xiaomi Book Pro 14 2022
  (stable-fixes).
- ASoC: tas2781: Add new driver version for tas2563 & tas2781
  qfn chip (stable-fixes).
- commit 1f9992e
* Sat Nov  9 2024 tiwai@suse.de
- drm/amdgpu: Fix DPX valid mode check on GC 9.4.3 (git-fixes).
- ASoC: SOF: sof-client-probes-ipc4: Set param_size extension bits
  (git-fixes).
- ASoC: stm32: spdifrx: fix dma channel release in
  stm32_spdifrx_remove (git-fixes).
- ALSA: firewire-lib: fix return value on fail in
  amdtp_tscm_init() (git-fixes).
- media: pulse8-cec: fix data timestamp at pulse8_setup()
  (git-fixes).
- media: stb0899_algo: initialize cfr before using it (git-fixes).
- media: adv7604: prevent underflow condition when reporting
  colorspace (git-fixes).
- media: cx24116: prevent overflows on SNR calculus (git-fixes).
- media: ar0521: don't overflow when checking PLL values
  (git-fixes).
- media: s5p-jpeg: prevent buffer overflows (git-fixes).
- media: dvb_frontend: don't play tricks with underflow values
  (git-fixes).
- media: dvbdev: prevent the risk of out of memory access
  (git-fixes).
- media: v4l2-tpg: prevent the risk of a division by zero
  (git-fixes).
- media: v4l2-ctrls-api: fix error handling for v4l2_g_ctrl()
  (git-fixes).
- thunderbolt: Honor TMU requirements in the domain when setting
  TMU mode (stable-fixes).
- wifi: iwlegacy: Clear stale interrupts before resuming device
  (stable-fixes).
- USB: gadget: dummy-hcd: Fix "task hung" problem (git-fixes).
- usb: gadget: dummy_hcd: execute hrtimer callback in softirq
  context (git-fixes).
- usb: gadget: dummy_hcd: Set transfer interval to 1 microframe
  (stable-fixes).
- usb: gadget: dummy_hcd: Switch to hrtimer transfer scheduler
  (stable-fixes).
- commit c5281d0
* Sat Nov  9 2024 ailiop@suse.com
- nfs: avoid i_lock contention in nfs_clear_invalid_mapping
  (git-fixes).
- commit e6016a1
* Sat Nov  9 2024 ailiop@suse.com
- nfs: Fix KMSAN warning in decode_getfattr_attrs() (git-fixes).
- commit 9358249
* Sat Nov  9 2024 ailiop@suse.com
- NFS: remove revoked delegation from server's delegation list
  (git-fixes).
- commit 6feb8eb
* Sat Nov  9 2024 ailiop@suse.com
- SUNRPC: Remove BUG_ON call sites (git-fixes).
- commit 5969339
* Sat Nov  9 2024 ailiop@suse.com
- nilfs2: fix potential deadlock with newly created symlinks
  (git-fixes).
- commit 002996c
* Fri Nov  8 2024 tbogendoerfer@suse.de
- net/mlx5: HWS, added API and enabled HWS support (jsc#PED-9900
  jsc#PED-11429).
- Update config files.
- commit 3edf163
* Fri Nov  8 2024 tbogendoerfer@suse.de
- net/mlx5e: Support updating coalescing configuration without
  resetting channels (jsc#PED-9900 jsc#PED-11429).
- Refresh
  patches.suse/s390-Fix-mlx5-RoCE-throuput-degradtion.patch.
- commit db94d56
* Fri Nov  8 2024 tbogendoerfer@suse.de
- net/mlx5e: Use DIM constants for CQ period mode parameter
  (jsc#PED-9900 jsc#PED-11429).
- Refresh
  patches.suse/s390-Fix-mlx5-RoCE-throuput-degradtion.patch.
- commit ad7a43a
* Fri Nov  8 2024 tbogendoerfer@suse.de
- net/mlx5e: Un-expose functions in en.h (jsc#PED-9900
  jsc#PED-11429).
- Refresh
  patches.suse/net-Add-struct-kernel_ethtool_ts_info.patch.
- commit dfb9409
* Fri Nov  8 2024 tbogendoerfer@suse.de
- net/mlx5e: Support cross-vhca RSS (jsc#PED-9900 jsc#PED-11429).
- Refresh
  patches.suse/net-mlx5e-RSS-Block-XOR-hash-with-over-128-channels.patch.
- commit 98a840e
* Fri Nov  8 2024 tbogendoerfer@suse.de
- net/mlx5e: Create EN core HW resources for all secondary devices
  (jsc#PED-9900 jsc#PED-11429).
- Refresh patches.suse/net-mlx5e-Fix-netif-state-handling.patch.
- commit e390470
* Fri Nov  8 2024 tbogendoerfer@suse.de
- net/mlx5e: Create single netdev per SD group (jsc#PED-9900
  jsc#PED-11429).
- Refresh patches.suse/net-mlx5e-Fix-netif-state-handling.patch.
- commit b6625c2
* Fri Nov  8 2024 ggherdovich@suse.cz
- cpufreq: amd-pstate: add check for cpufreq_cpu_get's return
  value (CVE-2024-50009 bsc#1232318).
- commit 15f7e86
* Fri Nov  8 2024 tbogendoerfer@suse.de
- gve: Add header split ethtool stats (bsc#1233139).
- Refresh
  patches.suse/gve-Account-for-stopped-queues-when-reading-NIC-stat.patch.
- commit 601aba3
* Fri Nov  8 2024 tbogendoerfer@suse.de
- gve: Add header split data path (bsc#1233139).
- Refresh
  patches.suse/gve-Clear-napi-skb-before-dev_kfree_skb_any.patch.
- commit 20d0db7
* Fri Nov  8 2024 tbogendoerfer@suse.de
- net/mlx5: Remove initial segmentation duplicate definitions
  (jsc#PED-9900 jsc#PED-11429).
- Refresh
  patches.suse/net-mlx5-Stop-waiting-for-PCI-if-pci-channel-is-offl.patch.
- commit a83ad65
* Fri Nov  8 2024 tbogendoerfer@suse.de
- net: ena: Reduce lines with longer column width boundary
  (bsc#1233139).
- Refresh
  patches.suse/net-ena-Add-validation-for-completion-descriptors-co.patch.
- Refresh
  patches.suse/net-ena-Fix-redundant-device-NUMA-node-override.patch.
- commit 482da41
* Fri Nov  8 2024 tbogendoerfer@suse.de
- net: ena: Add more information on TX timeouts (bsc#1233139).
- Refresh
  patches.suse/net-ena-Add-validation-for-completion-descriptors-co.patch.
- commit 9d40775
* Fri Nov  8 2024 tbogendoerfer@suse.de
- ice: change q_index variable type to s16 to store -1 value
  (jsc#PED-9947).
- ice: Fix use after free during unload with ports in bridge
  (jsc#PED-9947).
- ice: fix crash on probe for DPLL enabled E810 LOM
  (jsc#PED-9947).
- ice: block SF port creation in legacy mode (jsc#PED-9947).
- macsec: Fix use-after-free while sending the offloading packet
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: HWS, use lock classes for bwc locks (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: HWS, don't destroy more bwc queue locks than allocated
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: HWS, fixed double free in error flow of definer layout
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: HWS, removed wrong access to a number of rules
  variable (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: SHAMPO, Fix overflow of hd_per_wq (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: HWS, changed E2BIG error to a negative return code
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: HWS, fixed double-free in error flow of creating SQ
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Fix wrong reserved field in hca_cap_2 in mlx5_ifc
  (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Postpone MR deletion (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Introduce init/destroy for MR resources (jsc#PED-9900
  jsc#PED-11429).
- vdpa/mlx5: Rename mr_mtx -> lock (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Extract mr members in own resource struct
  (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Rename function (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Delete direct MKEYs in parallel (jsc#PED-9900
  jsc#PED-11429).
- vdpa/mlx5: Create direct MKEYs in parallel (jsc#PED-9900
  jsc#PED-11429).
- vdpa/mlx5: Parallelize VQ suspend/resume for CVQ MQ command
  (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Small improvement for change_num_qps() (jsc#PED-9900
  jsc#PED-11429).
- vdpa/mlx5: Keep notifiers during suspend but ignore
  (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Parallelize device resume (jsc#PED-9900
  jsc#PED-11429).
- vdpa/mlx5: Parallelize device suspend (jsc#PED-9900
  jsc#PED-11429).
- vdpa/mlx5: Use async API for vq modify commands (jsc#PED-9900
  jsc#PED-11429).
- vdpa/mlx5: Use async API for vq query command (jsc#PED-9900
  jsc#PED-11429).
- vdpa/mlx5: Introduce async fw command wrapper (jsc#PED-9900
  jsc#PED-11429).
- vdpa/mlx5: Introduce error logging function (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: Support throttled commands from async API
  (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Add the support of set mac address (jsc#PED-9900
  jsc#PED-11429).
- vdpa: support set mac address from vdpa tool (jsc#PED-9900
  jsc#PED-11429).
- RDMA/mlx5: Use IB set_netdev and get_netdev functions
  (jsc#PED-9900 jsc#PED-11429).
- RDMA/mlx5: Initialize phys_port_cnt earlier in RDMA device
  creation (jsc#PED-9900 jsc#PED-11429).
- RDMA/mlx5: Check RoCE LAG status before getting netdev
  (jsc#PED-9900 jsc#PED-11429).
- RDMA/mlx5: Consider the query_vuid cap for data_direct
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Handle memory scheme ODP capabilities (jsc#PED-9900
  jsc#PED-11429).
- RDMA/mlx5: Add implicit MR handling to ODP memory scheme
  (jsc#PED-9900 jsc#PED-11429).
- RDMA/mlx5: Add handling for memory scheme page fault events
  (jsc#PED-9900 jsc#PED-11429).
- RDMA/mlx5: Split ODP mkey search logic (jsc#PED-9900
  jsc#PED-11429).
- RDMA/mlx5: Add new ODP memory scheme eqe format (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: Expose HW bits for Memory scheme ODP (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: Expand mkey page size to support 6 bits (jsc#PED-9900
  jsc#PED-11429).
- RDMA/mlx5: Enable ATS when allocating kernel MRs (jsc#PED-9900
  jsc#PED-11429).
- IB/mlx5: Fix UMR pd cleanup on error flow of driver init
  (jsc#PED-9900 jsc#PED-11429).
- RDMA/mlx5: Remove two unused declarations (jsc#PED-9900
  jsc#PED-11429).
- RDMA/mlx5: Introduce GET_DATA_DIRECT_SYSFS_PATH ioctl
  (jsc#PED-9900 jsc#PED-11429).
- RDMA/mlx5: Add support for DMABUF MR registrations with
  Data-direct (jsc#PED-9900 jsc#PED-11429).
- RDMA/mlx5: Add the initialization flow to utilize the 'data
  direct' device (jsc#PED-9900 jsc#PED-11429).
- RDMA/mlx5: Introduce the 'data direct' driver (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: Add IFC related stuff for data direct (jsc#PED-9900
  jsc#PED-11429).
- RDMA/mlx5: Expose vhca id for all ports in multiport mode
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: HWS, check the correct variable in
  hws_send_ring_alloc_sq() (jsc#PED-9900 jsc#PED-11429).
- ice: Fix a NULL vs IS_ERR() check in probe() (jsc#PED-9947).
- ice: Fix a couple NULL vs IS_ERR() bugs (jsc#PED-9947).
- net/mlx5e: Match cleanup order in mlx5e_free_rq in reverse of
  mlx5e_alloc_rq (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: SHAMPO, Add no-split ethtool counters for header/data
  split (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Add NOT_READY command return status (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: Allow users to configure affinity for SFs
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Skip HotPlug check on sync reset using hot reset
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Add support for sync reset using hot reset
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Add device cap for supporting hot reset in sync
  reset flow (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: fs, add support for no append at software level
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: fs, separate action and destination into distinct
  struct (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: fs, remove unused member (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: fs, move hardware fte deletion function reset
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: fs, make get_root_namespace API function (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: fs, move steering common function to fs_cmd.h
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: HWS, fixed error flow return values of some functions
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: HWS, updated API functions comments to kernel doc
  (jsc#PED-9900 jsc#PED-11429).
- net: ena: Extend customer metrics reporting support
  (bsc#1233139).
- net: ena: Add ENA Express metrics support (bsc#1233139).
- ice: subfunction activation and base devlink ops (jsc#PED-9947).
- ice: basic support for VLAN in subfunctions (jsc#PED-9947).
- ice: support subfunction devlink Tx topology (jsc#PED-9947).
- ice: implement netdevice ops for SF representor (jsc#PED-9947).
- ice: check if SF is ready in ethtool ops (jsc#PED-9947).
- ice: don't set target VSI for subfunction (jsc#PED-9947).
- ice: create port representor for SF (jsc#PED-9947).
- ice: make representor code generic (jsc#PED-9947).
- ice: implement netdev for subfunction (jsc#PED-9947).
- ice: base subfunction aux driver (jsc#PED-9947).
- ice: allocate devlink for subfunction (jsc#PED-9947).
- ice: treat subfunction VSI the same as PF VSI (jsc#PED-9947).
- ice: add basic devlink subfunctions support (jsc#PED-9947).
- ice: export ice ndo_ops functions (jsc#PED-9947).
- ice: add new VSI type for subfunctions (jsc#PED-9947).
- net/mlx5: HWS, added send engine and context handling
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: HWS, added debug dump and internal headers
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: HWS, added backward-compatible API handling
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: HWS, added memory management handling (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: HWS, added vport handling (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: HWS, added modify header pattern and args handling
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: HWS, added FW commands handling (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: HWS, added matchers functionality (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: HWS, added definers handling (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: HWS, added rules handling (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: HWS, added tables handling (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: HWS, added actions handling (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: Added missing definitions in preparation for HW
  Steering (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Added missing mlx5_ifc definition for HW Steering
  (jsc#PED-9900 jsc#PED-11429).
- net: atlantic: convert comma to semicolon (jsc#PED-11288).
- ice: Remove setting of RX software timestamp (jsc#PED-9947).
- ice: Adjust over allocation of memory in
  ice_sched_add_root_node() and ice_sched_add_node()
  (jsc#PED-9947).
- ice: Report NVM version numbers on mismatch during load
  (jsc#PED-9947).
- ice: remove unnecessary control queue cmd_buf arrays
  (jsc#PED-9947).
- ice: reword comments referring to control queues (jsc#PED-9947).
- ice: stop intermixing AQ commands/responses debug dumps
  (jsc#PED-9947).
- ice: do not clutter debug logs with unused data (jsc#PED-9947).
- ice: improve debug print for control queue messages
  (jsc#PED-9947).
- ice: implement and use rd32_poll_timeout for ice_sq_done timeout
  (jsc#PED-9947).
- ice: add callbacks for Embedded SYNC enablement on dpll pins
  (jsc#PED-9947).
- dpll: add Embedded SYNC feature for a pin (jsc#PED-9947).
- net: atlantic: Avoid warning about potential string truncation
  (jsc#PED-11288).
- ice: Fix a 32bit bug (jsc#PED-9947).
- net/mlx5: E-Switch, Remove unused declarations (jsc#PED-9900
  jsc#PED-11429).
- gve: Remove unused declaration gve_rx_alloc_rings()
  (bsc#1233139).
- ice: enable FDIR filters from raw binary patterns for VFs
  (jsc#PED-9947).
- ice: add method to disable FDIR SWAP option (jsc#PED-9947).
- ice: add API for parser profile initialization (jsc#PED-9947).
- ice: add UDP tunnels support to the parser (jsc#PED-9947).
- ice: support turning on/off the parser's double vlan mode
  (jsc#PED-9947).
- ice: add parser execution main loop (jsc#PED-9947).
- ice: add parser internal helper functions (jsc#PED-9947).
- ice: add debugging functions for the parser sections
  (jsc#PED-9947).
- ice: parse and init various DDP parser sections (jsc#PED-9947).
- ice: add parser create and destroy skeleton (jsc#PED-9947).
- net/mlx5: Use cpumask_local_spread() instead of custom code
  (jsc#PED-9900 jsc#PED-11429).
- gve: Add RSS adminq commands and ethtool support (bsc#1233139).
- gve: Add RSS device option (bsc#1233139).
- eth: mlx5: allow disabling queues when RSS contexts exist
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: CT: Update connection tracking steering entries
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: CT: 'update' rules instead of 'replace' (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: Use extack in get module eeprom by page callback
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: Use extack in set coalesce callback (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: Use extack in get coalesce callback (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: Use extack in set ringparams callback (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: Be consistent with bitmap handling of link modes
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: TC, Offload rewrite and mirror to both internal
  and external dests (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: TC, Offload rewrite and mirror on tunnel over ovs
  internal port (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: Enable remove flow for hard packet limit
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: E-Switch, Increase max int port number for offload
  (jsc#PED-9900 jsc#PED-11429).
- net: atlantic: use ethtool_sprintf (jsc#PED-11288).
- net/mlx5: Add support for enabling PTM PCI capability
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Add support for MTPTM and MTCTR registers
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Reclaim max 50K pages at once (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: Verify support for scheduling element and TSAR type
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: XPS, Fix oversight of Multi-PF Netdev changes
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: SHAMPO, Release in progress headers (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: SHAMPO, Fix page leak (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: Fix queue stats access to non-existing channels splat
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: SHAMPO, Increase timeout to improve latency
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: SD, Do not query MPIR register if no sd_group
  (jsc#PED-9900 jsc#PED-11429).
- gve: Fix use of netif_carrier_ok() (bsc#1233139).
- net/mlx5: DR, Fix 'stack guard page was hit' error in dr_rule
  (jsc#PED-9900 jsc#PED-11429).
- driver core: auxiliary bus: Fix documentation of
  auxiliary_device (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Don't enable non-active VQs in .set_vq_ready()
  (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Don't reset VQs more than necessary (jsc#PED-9900
  jsc#PED-11429).
- vdpa/mlx5: Re-create HW VQs under certain conditions
  (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Pre-create hardware VQs at vdpa .dev_add time
  (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Use suspend/resume during VQP change (jsc#PED-9900
  jsc#PED-11429).
- vdpa/mlx5: Forward error in suspend/resume device (jsc#PED-9900
  jsc#PED-11429).
- vdpa/mlx5: Consolidate all VQ modify to Ready to use resume_vq()
  (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Add error code for suspend/resume VQ (jsc#PED-9900
  jsc#PED-11429).
- vdpa/mlx5: Accept Init -> Ready VQ transition in resume_vq()
  (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Allow creation of blank VQs (jsc#PED-9900
  jsc#PED-11429).
- vdpa/mlx5: Set mkey modified flags on all VQs (jsc#PED-9900
  jsc#PED-11429).
- vdpa/mlx5: Start off rqt_size with max VQPs (jsc#PED-9900
  jsc#PED-11429).
- vdpa/mlx5: Set an initial size on the VQ (jsc#PED-9900
  jsc#PED-11429).
- vdpa/mlx5: Add support for modifying the VQ features field
  (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Add support for modifying the virtio_version VQ field
  (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Rename init_mvqs (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Clear and reinitialize software VQ data on reset
  (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Initialize and reset device with one queue pair
  (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Remove duplicate suspend code (jsc#PED-9900
  jsc#PED-11429).
- vdpa/mlx5: Iterate over active VQs during suspend/resume
  (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Drop redundant check in teardown_virtqueues()
  (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Drop redundant code (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Make setup/teardown_vq_resources() symmetrical
  (jsc#PED-9900 jsc#PED-11429).
- vdpa/mlx5: Clarify meaning thorough function rename
  (jsc#PED-9900 jsc#PED-11429).
- RDMA/core: Introduce "name_assign_type" for an IB device
  (jsc#PED-9900 jsc#PED-11429).
- RDMA/mlx5: Support per-plane port IB counters by querying
  PPCNT register (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: mlx5_ifc update for accessing ppcnt register of
  plane ports (jsc#PED-9900 jsc#PED-11429).
- RDMA/mlx5: Add plane index support when querying PTYS registers
  (jsc#PED-9900 jsc#PED-11429).
- RDMA/mlx5: Support plane device and driver APIs to add and
  delete it (jsc#PED-9900 jsc#PED-11429).
- RDMA: Set type of rdma_ah to IB for a SMI sub device
  (jsc#PED-9900 jsc#PED-11429).
- RDMA/mlx5: Add support to multi-plane device and port
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: mlx5_ifc update for multi-plane support (jsc#PED-9900
  jsc#PED-11429).
- RDMA/mlx5: Send UAR page index as ioctl attribute (jsc#PED-9900
  jsc#PED-11429).
- IB/mlx5: Allocate resources just before first QP/SRQ is created
  (jsc#PED-9900 jsc#PED-11429).
- IB/mlx5: Create UMR QP just before first reg_mr occurs
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Expose SFs IRQs (jsc#PED-9900 jsc#PED-11429).
- driver core: auxiliary bus: show auxiliary device IRQs
  (jsc#PED-9900 jsc#PED-11429).
- RDMA/mlx5: Add Qcounters
  req_transport_retries_exceeded/req_rnr_retries_exceeded
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Reimplement write combining test (jsc#PED-9900
  jsc#PED-11429).
- eth: mlx5: expose NETIF_F_NTUPLE when ARFS is compiled out
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Use set number of max EQs (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: Set default max eqs for SFs (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: Set sf_eq_usage for SF max EQs (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: IFC updates for SF max IO EQs (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: CT: Initialize err to 0 to avoid warning
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: SHAMPO, Add missing aggregate counter (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: DR, Remove definer functions from SW Steering API
  (jsc#PED-9900 jsc#PED-11429).
- gve: Add flow steering ethtool support (bsc#1233139).
- gve: Add flow steering adminq commands (bsc#1233139).
- gve: Add flow steering device option (bsc#1233139).
- gve: Add adminq extended command (bsc#1233139).
- gve: Add adminq mutex lock (bsc#1233139).
- net/mlx5e: Add per queue netdev-genl stats (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: Add txq to sq stats mapping (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: Support SWP-mode offload L4 csum calculation
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: Use tcp_v_check checksum helpers (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: Fix outdated comment in features check (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: Replace strcpy with strscpy (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: CT: Separate CT and CT-NAT tuple entries (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: Correct TASR typo into TSAR (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: flower: validate encapsulation control flags
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: SHAMPO, Coalesce skb fragments to page size
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: SHAMPO, Re-enable HW-GRO (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: SHAMPO, Use KSMs instead of KLMs (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: SHAMPO, Add header-only ethtool counters for header
  data split (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: SHAMPO, Drop rx_gro_match_packets counter
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: SHAMPO, Make GRO counters more precise (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: SHAMPO, Skipping on duplicate flush of the same
  SHAMPO SKB (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: SHAMPO, Specialize mlx5e_fill_skb_data()
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: SHAMPO, Simplify header page release in teardown
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: SHAMPO, Disable gso_size for non GRO packets
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: SHAMPO, Fix FCS config when HW GRO on (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: SHAMPO, Use net_prefetch API (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: Approximate IPsec per-SA payload data bytes count
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: Present succeeded IPsec SA bytes and packet
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Use max_num_eqs_24b when setting max_io_eqs
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Use max_num_eqs_24b capability if set (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: IFC updates for changing max EQs (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: Do not use ptp structure for tx ts stats when not
  initialized (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Do not query MPIR on embedded CPU function
  (jsc#PED-9900 jsc#PED-11429).
- net: atlantic: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY
  (jsc#PED-11288).
- RDMA/mlx5: Remove NULL check before dev_{put, hold}
  (jsc#PED-9900 jsc#PED-11429).
- RDMA/mlx5: Track DCT, DCI and REG_UMR QPs as diver_detail
  resources (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Remove unused msix related exported APIs (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: Modifying channels number and updating TX queues
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Enable 8 ports LAG (jsc#PED-9900 jsc#PED-11429).
- net: ena: Change initial rx_usec interval (bsc#1233139).
- net: ena: Changes around strscpy calls (bsc#1233139).
- net: ena: Reduce holes in ena_com structures (bsc#1233139).
- net: ena: Add a counter for driver's reset failures
  (bsc#1233139).
- gve: Use ethtool_sprintf/puts() to fill stats strings
  (bsc#1233139).
- gve: Avoid unnecessary use of comma operator (bsc#1233139).
- gve: Implement queue api (bsc#1233139).
- gve: Alloc and free QPLs with the rings (bsc#1233139).
- gve: Reset Rx ring state in the ring-stop funcs (bsc#1233139).
- gve: Avoid rescheduling napi if on wrong cpu (bsc#1233139).
- gve: Make gve_turnup work for nonempty queues (bsc#1233139).
- gve: Make gve_turn(up|down) ignore stopped queues (bsc#1233139).
- gve: Add adminq funcs to add/remove a single Rx queue
  (bsc#1233139).
- gve: Make the GQ RX free queue funcs idempotent (bsc#1233139).
- net/mlx5e: flower: check for unsupported control flags
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: Implement ethtool callbacks for supporting per-queue
  coalescing (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: Dynamically allocate DIM structure for SQs/RQs
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: Move DIM function declarations to en/dim.h
  (jsc#PED-9900 jsc#PED-11429).
- gve: Remove qpl_cfg struct since qpl_ids map with queues
  respectively (bsc#1233139).
- gve: Correctly report software timestamping capabilities
  (bsc#1233139).
- net/mlx5e: Expose the VF/SF RX drop counter on the representor
  (jsc#PED-9900 jsc#PED-11429).
- mlx5/core: Support max_io_eqs for a function (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: Implement ethtool hardware timestamping statistics
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: Introduce timestamps statistic counter for Tx DMA
  layer (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: Introduce lost_cqe statistic counter for PTP Tx
  port timestamping CQ (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: Support FEC settings for 100G/lane modes
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: Extract checking of FEC support for a link mode
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Don't call give_pages() if request 0 page
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Skip pages EQ creation for non-page supplier function
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Support matching on l4_type for ttc_table
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: Add support for 800Gbps link modes (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: Convert uintX_t to uX (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: XDP, Fix an inconsistent comment (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: debugfs, Add reset option for command interface stats
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: Make stats group fill_stats callbacks consistent
  with the API (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: Use ethtool_sprintf/puts() to fill stats strings
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: Use ethtool_sprintf/puts() to fill selftests strings
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: Use ethtool_sprintf/puts() to fill priv flags strings
  (jsc#PED-9900 jsc#PED-11429).
- gve: add support to change ring size via ethtool (bsc#1233139).
- gve: add support to read ring size ranges from the device
  (bsc#1233139).
- gve: set page count for RX QPL for GQI and DQO queue formats
  (bsc#1233139).
- gve: make the completion and buffer ring size equal for DQO
  (bsc#1233139).
- gve: simplify setting decriptor count defaults (bsc#1233139).
- gve: Add counter adminq_get_ptype_map_cnt to stats report
  (bsc#1233139).
- net/mlx5e: Advertise mlx5 ethernet driver updates sk_buff
  md_dst for MACsec (jsc#PED-9900 jsc#PED-11429).
- macsec: Detect if Rx skb is macsec-related for offloading
  devices that update md_dst (jsc#PED-9900 jsc#PED-11429).
- ethernet: Add helper for assigning packet type when dest address
  does not match device address (jsc#PED-9900 jsc#PED-11429).
- macsec: Enable devices to advertise whether they update sk_buff
  md_dst during offloads (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: Acquire RTNL lock before RQs/SQs
  activation/deactivation (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: Use channel mdev reference instead of global mdev
  instance for coalescing (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: SD, Handle possible devcom ERR_PTR (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: fix possible stack overflows (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: Disallow SRIOV switchdev mode when in multi-PF netdev
  (jsc#PED-9900 jsc#PED-11429).
- dpll: indent DPLL option type by a tab (jsc#PED-9947).
- RDMA/mlx5: Delete unused mlx5_ib_copy_pas prototype
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Enable SD feature (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: Block TLS device offload on combined SD netdev
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: Support per-mdev queue counter (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: Let channels be SD-aware (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: SD, Add debugfs (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: SD, Add informative prints in kernel log (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5: SD, Implement steering for primary and secondaries
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: SD, Implement devcom communication and primary
  election (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: SD, Implement basic query and instantiation
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: SD, Introduce SD lib (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Add MPIR bit in mcam_access_reg (jsc#PED-9900
  jsc#PED-11429).
- net: macsec: Leverage core stats allocator (jsc#PED-9900
  jsc#PED-11429).
- net: introduce page_frag_cache_drain() (bsc#1233139).
- gve: Add header split device option (bsc#1233139).
- net: ena: Remove unlikely() from IS_ERR() condition
  (bsc#1233139).
- net: ena: Remove redundant assignment (bsc#1233139).
- net/mlx5e: link NAPI instances to queues and IRQs (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: XDP, Exclude headroom and tailroom from memory
  calculations (jsc#PED-9900 jsc#PED-11429).
- net/mlx5e: XSK, Exclude tailroom from non-linear SKBs memory
  calculations (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: DR, Change SWS usage to debug fs seq_file interface
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Change missing SyncE capability print to debug
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Return specific error code for timeout on wait_fw_init
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: remove fw reporter dump option for non PF
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: remove fw_fatal reporter dump option for non PF
  (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: Rename mlx5_sf_dev_remove (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: Delete obsolete IPsec code (jsc#PED-9900
  jsc#PED-11429).
- net/mlx5e: Connect mlx5 IPsec statistics with XFRM core
  (jsc#PED-9900 jsc#PED-11429).
- xfrm: get global statistics from the offloaded device
  (jsc#PED-9900 jsc#PED-11429).
- xfrm: generalize xdo_dev_state_update_curlft to allow statistics
  update (jsc#PED-9900 jsc#PED-11429).
- net/mlx5: DPLL, Implement lock status error value (jsc#PED-9900
  jsc#PED-11429).
- net: ena: handle ena_calc_io_queue_size() possible errors
  (bsc#1233139).
- net: ena: Change default print level for netif_ prints
  (bsc#1233139).
- net: ena: Relocate skb_tx_timestamp() to improve time stamping
  accuracy (bsc#1233139).
- net: ena: Change error print during ena_device_init()
  (bsc#1233139).
- net: ena: Remove CQ tail pointer update (bsc#1233139).
- net: ena: Enable DIM by default (bsc#1233139).
- net: ena: Minor cosmetic changes (bsc#1233139).
- net: ena: Remove an unused field (bsc#1233139).
- gve: Modify rx_buf_alloc_fail counter centrally and closer to
  failure (bsc#1233139).
- gve: Alloc before freeing when changing features (bsc#1233139).
- gve: Alloc before freeing when adjusting queues (bsc#1233139).
- gve: Refactor gve_open and gve_close (bsc#1233139).
- gve: Switch to config-aware queue allocation (bsc#1233139).
- gve: Refactor napi add and remove functions (bsc#1233139).
- gve: Define config structs for queue allocation (bsc#1233139).
- net: ena: Take xdp packets stats into account in
  ena_get_stats64() (bsc#1233139).
- net: ena: Make queue stats code cleaner by removing the if block
  (bsc#1233139).
- net: ena: Always register RX queue info (bsc#1233139).
- net: ena: Add more debug prints to XDP related function
  (bsc#1233139).
- net: ena: Refactor napi functions (bsc#1233139).
- net: ena: Don't check if XDP program is loaded in
  ena_xdp_execute() (bsc#1233139).
- net: ena: Introduce total_tx_size field in ena_tx_buffer struct
  (bsc#1233139).
- net: ena: Put orthogonal fields in ena_tx_buffer in a union
  (bsc#1233139).
- net: macsec: introduce mdo_insert_tx_tag (jsc#PED-9900
  jsc#PED-11429).
- net: macsec: revert the MAC address if mdo_upd_secy fails
  (jsc#PED-9900 jsc#PED-11429).
- net: macsec: documentation for macsec_context and macsec_ops
  (jsc#PED-9900 jsc#PED-11429).
- net: macsec: move sci_to_cpu to macsec header (jsc#PED-9900
  jsc#PED-11429).
- net: ena: replace deprecated strncpy with strscpy (bsc#1233139).
- RDMA Remove unused function declarations (jsc#PED-9900
  jsc#PED-11429).
- net: atlantic: Remove unnecessary (void*) conversions
  (jsc#PED-11288).
- netdevsim: add dummy macsec offload (jsc#PED-9900
  jsc#PED-11429).
- commit c1f18bf
* Fri Nov  8 2024 jack@suse.cz
- ext4: fix error message when rejecting the default hash
  (bsc#1232264 CVE-2024-49968).
- commit 5d137c7
* Fri Nov  8 2024 ggherdovich@suse.cz
- sched/deadline: Fix task_struct reference leak (CVE-2024-41023
  bsc#1228430).
- commit 3a83981
* Fri Nov  8 2024 tbogendoerfer@suse.de
- be2net: fix potential memory leak in be_xmit() (CVE-2024-50167
  bsc#1233049).
- commit 376f8c7
* Fri Nov  8 2024 tiwai@suse.de
- blacklist.conf: Move SP7-specific entries into the own section
- commit b82add6
* Fri Nov  8 2024 tiwai@suse.de
- can: mcp251xfd: mcp251xfd_get_tef_len(): fix length calculation
  (git-fixes).
- can: mcp251xfd: mcp251xfd_ring_alloc(): fix coalescing
  configuration when switching CAN modes (git-fixes).
- can: c_can: fix {rx,tx}_errors statistics (git-fixes).
- pwm: imx-tpm: Use correct MODULO value for EPWM mode
  (git-fixes).
- commit c5fa961
* Thu Nov  7 2024 dsterba@suse.com
- blk-rq-qos: fix crash on rq_qos_wait vs. rq_qos_wake_function race (CVE-2024-50082 bsc#1232500)
- commit 6a67bac
* Thu Nov  7 2024 dsterba@suse.com
- btrfs: fix uninitialized pointer free on read_alloc_one_name() error (CVE-2024-50087 bsc#1232499)
- commit a3c097a
* Thu Nov  7 2024 dsterba@suse.com
- btrfs: fix uninitialized pointer free in add_inode_ref() (CVE-2024-50088 bsc#1232498)
- commit 75b1127
* Thu Nov  7 2024 dsterba@suse.com
- net: microchip: vcap api: Fix memory leaks in vcap_api_encode_rule_test() (CVE-2024-50084 bsc#1232494)
- commit e53e21a
* Thu Nov  7 2024 dsterba@suse.com
- blacklist.conf: CVE-2024-49990 bsc#1232484: not applicable, code does not exist
- commit 602009f
* Thu Nov  7 2024 dsterba@suse.com
- drm/amd/display: fix double free issue during amdgpu module unload (CVE-2024-49989 bsc#1232483)
- commit 6511376
* Thu Nov  7 2024 dsterba@suse.com
- blacklist.conf: CVE-2024-49971 bsc#1232473: not applicable, code does not exist
  No DML2 shared types.
- commit 791ed43
* Thu Nov  7 2024 rgoldwyn@suse.com
- blacklist.conf: Add fuzzer/crafted image fix for erofs (unsupported)
- commit bba425e
* Thu Nov  7 2024 dsterba@suse.com
- drm/amd/display: update DML2 policy EnhancedPrefetchScheduleAccelerationFinal DCN35 (CVE-2024-50004 bsc#1232396)
- commit d5739f8
* Thu Nov  7 2024 dsterba@suse.com
- drm/amd/display: Fix system hang while resume with TBT monitor (CVE-2024-50003 bsc#1232385)
- commit 24ceb7a
* Thu Nov  7 2024 tbogendoerfer@suse.de
- netdev: add qstat for csum complete (jsc#PED-11221).
- page_pool: fix &page_pool_params kdoc issues (jsc#PED-11221).
- net: do not consume a cacheline for system_page_pool
  (jsc#PED-11221).
- commit 0a3ea5d
* Thu Nov  7 2024 tbogendoerfer@suse.de
- ice: Remove unused members from switch API (jsc#PED-9947).
- Refresh patches.suse/ice-Fix-recipe-read-procedure.patch.
- commit 9022f34
* Thu Nov  7 2024 tbogendoerfer@suse.de
- net: add netmem to skb_frag_t (jsc#PED-11221).
- Refresh
  patches.suse/net-remove-gfp_mask-from-napi_alloc_skb.patch.
- commit eb5ac85
* Thu Nov  7 2024 tbogendoerfer@suse.de
- page_pool: disable direct recycling based on pool->cpuid on
  destroy (jsc#PED-11221).
- Refresh
  patches.suse/page_pool-constify-some-read-only-function-arguments.patch.
- commit dd3f2f8
* Thu Nov  7 2024 tbogendoerfer@suse.de
- net: add generic percpu page_pool allocator (jsc#PED-11221).
- Refresh
  patches.suse/net-Allow-to-use-SMP-threads-for-backlog-NAPI.patch.
- commit 20769de
* Thu Nov  7 2024 tbogendoerfer@suse.de
- net: veth: make PAGE_POOL_STATS optional (jsc#PED-11221).
- Refresh patches.suse/net-veth-fix-ethtool-stats-reporting.patch.
- commit a3126a6
* Thu Nov  7 2024 tbogendoerfer@suse.de
- bnxt_en: replace ptp_lock with irqsave variant (jsc#PED-11221).
- sfc: Don't invoke xdp_do_flush() from netpoll (jsc#PED-11367).
- sfc: Add X4 PF support (jsc#PED-11367).
- bnxt_en: resize bnxt_irq name field to fit format string
  (jsc#PED-11221).
- bnxt_en: Add MSIX check in bnxt_check_rings() (jsc#PED-11221).
- bnxt_en: Increase the number of MSIX vectors for RoCE device
  (jsc#PED-11221).
- ionic: Allow XDP program to be hot swapped (jsc#PED-11379).
- ionic: convert Rx queue buffers to use page_pool
  (jsc#PED-11379).
- ionic: Fully reconfigure queues when going to/from a NULL XDP
  program (jsc#PED-11379).
- ionic: always use rxq_info (jsc#PED-11379).
- ionic: use per-queue xdp_prog (jsc#PED-11379).
- ionic: rename ionic_xdp_rx_put_bufs (jsc#PED-11379).
- ionic: debug line for Tx completion errors (jsc#PED-11379).
- sfc/siena: Remove setting of RX software timestamp
  (jsc#PED-11367).
- sfc: Remove setting of RX software timestamp (jsc#PED-11367).
- bnxt_en: Remove setting of RX software timestamp
  (jsc#PED-11221).
- sfc: siena: rip out rss-context dead code (jsc#PED-11367).
- sfc: convert comma to semicolon (jsc#PED-11367).
- sfc/siena: Convert comma to semicolon (jsc#PED-11367).
- ionic: Convert comma to semicolon (jsc#PED-11379).
- ionic: Remove redundant null pointer checks in
  ionic_debugfs_add_qcq() (jsc#PED-11379).
- ionic: Remove setting of RX software timestamp (jsc#PED-11379).
- sfc: Convert to use ERR_CAST() (jsc#PED-11367).
- bnxt_en: Support dynamic MSIX (jsc#PED-11221).
- bnxt_en: Allocate the max bp->irq_tbl size for dynamic msix
  allocation (jsc#PED-11221).
- bnxt_en: Replace deprecated PCI MSIX APIs (jsc#PED-11221).
- bnxt_en: Remove register mapping to support INTX
  (jsc#PED-11221).
- bnxt_en: Remove BNXT_FLAG_USING_MSIX flag (jsc#PED-11221).
- bnxt_en: Deprecate support for legacy INTX mode (jsc#PED-11221).
- bnxt_en: Support QOS and TPID settings for the SRIOV VLAN
  (jsc#PED-11221).
- bnxt_en: add support for retrieving crash dump using ethtool
  (jsc#PED-11221).
- bnxt_en: add support for storing crash dump into host memory
  (jsc#PED-11221).
- ethtool: Add new result codes for TDR diagnostics (bsc#1232798).
- bnxt_en: avoid truncation of per rx run debugfs filename
  (jsc#PED-11221).
- bnxt_en: Extend maximum length of version string by 1 byte
  (jsc#PED-11221).
- Documentation: networking: correct spelling (bsc#1232798).
- netlink: specs: decode indirection table as u32 array
  (bsc#1232798).
- ethtool: rss: support skipping contexts during dump
  (bsc#1232798).
- ethtool: rss: support dumping RSS contexts (bsc#1232798).
- ethtool: rss: report info about additional contexts from XArray
  (bsc#1232798).
- ethtool: rss: move the device op invocation out of
  rss_prepare_data() (bsc#1232798).
- ethtool: rss: don't report key if device doesn't support it
  (bsc#1232798).
- eth: remove .cap_rss_ctx_supported from updated drivers
  (bsc#1232798).
- ethtool: make ethtool_ops::cap_rss_ctx_supported optional
  (bsc#1232798).
- eth: mvpp2: implement new RSS context API (bsc#1232798).
- bnxt_en: only set dev->queue_mgmt_ops if supported by FW
  (jsc#PED-11221).
- bnxt_en: stop packet flow during bnxt_queue_stop/start
  (jsc#PED-11221).
- bnxt_en: set vnic->mru in bnxt_hwrm_vnic_cfg() (jsc#PED-11221).
- bnxt_en: Check the FW's VNIC flush capability (jsc#PED-11221).
- bnxt_en: Add support to call FW to update a VNIC
  (jsc#PED-11221).
- bnxt_en: Update firmware interface to 1.10.3.68 (jsc#PED-11221).
- ethtool: refactor checking max channels (bsc#1232798).
- net: ethtool: check rxfh_max_num_contexts != 1 at register time
  (bsc#1232798).
- ethtool: cmis_cdb: Remove unused declaration
  ethtool_cmis_page_fini() (bsc#1232798).
- ethtool: Don't check for NULL info in prepare_data callbacks
  (bsc#1232798).
- net/mlx4: Add support for EEPROM high pages query for
  QSFP/QSFP+/QSFP28 (jsc#PED-9945 jsc#PED-11337).
- ice: stop calling pci_disable_device() as we use pcim
  (jsc#PED-9947).
- ice: remove ICE_CFG_BUSY locking from AF_XDP code
  (jsc#PED-9947).
- ice: check ICE_VSI_DOWN under rtnl_lock when preparing for reset
  (jsc#PED-9947).
- ice: check for XDP rings instead of bpf program when
  unconfiguring (jsc#PED-9947).
- ice: protect XDP configuration with a mutex (jsc#PED-9947).
- ionic: Prevent tx_timeout due to frequent doorbell ringing
  (jsc#PED-11379).
- ice: use internal pf id instead of function number
  (jsc#PED-9947).
- bnxt_en: Don't clear ntuple filters and rss contexts during
  ethtool ops (jsc#PED-11221).
- ice: Fix incorrect assigns of FEC counts (jsc#PED-9947).
- ice: Skip PTP HW writes during PTP reset procedure
  (jsc#PED-9947).
- net: ethtool: fix off-by-one error in max RSS context IDs
  (jsc#PED-11221).
- bnxt_en : Fix memory out-of-bounds in bnxt_fill_hw_rss_tbl()
  (jsc#PED-11221).
- ice: xsk: fix txq interrupt mapping (jsc#PED-9947).
- ice: improve updating ice_{t,r}x_ring::xsk_pool (jsc#PED-9947).
- ice: toggle netif_carrier when setting up XSK pool
  (jsc#PED-9947).
- ice: modify error handling when setting XSK pool in ndo_bpf
  (jsc#PED-9947).
- eth: bnxt: populate defaults in the RSS context struct
  (jsc#PED-11221).
- eth: bnxt: reject unsupported hash functions (jsc#PED-11221).
- bnxt_en: Fix RSS logic in __bnxt_reserve_rings()
  (jsc#PED-11221).
- bnxt_en: update xdp_rxq_info in queue restart logic
  (jsc#PED-11221).
- auxbus: make to_auxiliary_drv accept and return a constant
  pointer (jsc#PED-11221).
- ice: Add tracepoint for adding and removing switch rules
  (jsc#PED-9947).
- ice: Optimize switch recipe creation (jsc#PED-9947).
- ice: remove unused recipe bookkeeping data (jsc#PED-9947).
- ice: Simplify bitmap setting in adding recipe (jsc#PED-9947).
- ice: Remove reading all recipes before adding a new one
  (jsc#PED-9947).
- ice: Remove unused struct ice_prot_lkup_ext members
  (jsc#PED-9947).
- ice: remove eswitch rebuild (jsc#PED-9947).
- ice: Add support for devlink local_forwarding param
  (jsc#PED-9947).
- sfc: falcon: Make I2C terminology more inclusive
  (jsc#PED-11367).
- page_pool: use __cacheline_group_{begin, end}_aligned()
  (jsc#PED-11221).
- eth: bnxt: use the indir table from ethtool context
  (jsc#PED-11221).
- eth: bnxt: bump the entry size in indir tables to u32
  (jsc#PED-11221).
- eth: bnxt: pad out the correct indirection table
  (jsc#PED-11221).
- eth: bnxt: use the RSS context XArray instead of the local list
  (jsc#PED-11221).
- eth: bnxt: use context priv for struct bnxt_rss_ctx
  (jsc#PED-11221).
- eth: bnxt: depend on core cleaning up RSS contexts
  (jsc#PED-11221).
- eth: bnxt: remove rss_ctx_bmap (jsc#PED-11221).
- eth: bnxt: move from .set_rxfh to .create_rxfh_context and
  friends (jsc#PED-11221).
- eth: bnxt: allow deleting RSS contexts when the device is down
  (jsc#PED-11221).
- ice: Implement driver functionality to dump serdes equalizer
  values (jsc#PED-9947).
- ice: Implement driver functionality to dump fec statistics
  (jsc#PED-9947).
- ice: Extend Sideband Queue command to support flags
  (jsc#PED-9947).
- net: page_pool: fix warning code (jsc#PED-11221).
- page_pool: convert to use netmem (jsc#PED-11221).
- bnxt_en: unlink page pool when stopping Rx queue
  (jsc#PED-11221).
- page_pool: export page_pool_disable_direct_recycling()
  (jsc#PED-11221).
- ice: do not init struct ice_adapter more times than needed
  (jsc#PED-9947).
- ice: Distinguish driver reset and removal for AQ shutdown
  (jsc#PED-9947).
- ice: Allow different FW API versions based on MAC type
  (jsc#PED-9947).
- ice: Check all ice_vsi_rebuild() errors in function
  (jsc#PED-9947).
- ice: Add get/set hw address for VFs using devlink commands
  (jsc#PED-9947).
- bnxt_en: Remove atomic operations on ptp->tx_avail
  (jsc#PED-11221).
- bnxt_en: Increase the max total outstanding PTP TX packets to 4
  (jsc#PED-11221).
- bnxt_en: Let bnxt_stamp_tx_skb() return error code
  (jsc#PED-11221).
- bnxt_en: Remove an impossible condition check for PTP TX
  pending SKB (jsc#PED-11221).
- bnxt_en: Refactor all PTP TX timestamp fields into a struct
  (jsc#PED-11221).
- bnxt_en: Add BCM5760X specific PHC registers mapping
  (jsc#PED-11221).
- bnxt_en: Add TX timestamp completion logic (jsc#PED-11221).
- bnxt_en: Allow some TX packets to be unprocessed in NAPI
  (jsc#PED-11221).
- bnxt_en: Add is_ts_pkt field to struct bnxt_sw_tx_bd
  (jsc#PED-11221).
- bnxt_en: Add new TX timestamp completion definitions
  (jsc#PED-11221).
- sfc: remove get_rxfh_context dead code (jsc#PED-11367).
- sfc: use new rxfh_context API (jsc#PED-11367).
- ice: update representor when VSI is ready (jsc#PED-9947).
- ice: move VSI configuration outside repr setup (jsc#PED-9947).
- ice: move devlink locking outside the port creation
  (jsc#PED-9947).
- ice: store representor ID in bridge port (jsc#PED-9947).
- bnxt_en: implement netdev_queue_mgmt_ops (jsc#PED-11221).
- bnxt_en: split rx ring helpers out from ring helpers
  (jsc#PED-11221).
- ionic: Only run the doorbell workaround for certain asic_type
  (jsc#PED-11379).
- ionic: Use an u16 for rx_copybreak (jsc#PED-11379).
- ionic: check for queue deadline in doorbell_napi_work
  (jsc#PED-11379).
- ionic: add per-queue napi_schedule for doorbell check
  (jsc#PED-11379).
- ionic: add work item for missed-doorbell check (jsc#PED-11379).
- ionic: add private workqueue per-device (jsc#PED-11379).
- ionic: Keep interrupt affinity up to date (jsc#PED-11379).
- ionic: remove missed doorbell per-queue timer (jsc#PED-11379).
- net/mlx4_en: Use ethtool_puts/sprintf to fill stats strings
  (jsc#PED-9945 jsc#PED-11337).
- net/mlx4_en: Use ethtool_puts to fill selftest strings
  (jsc#PED-9945 jsc#PED-11337).
- net/mlx4_en: Use ethtool_puts to fill priv flags strings
  (jsc#PED-9945 jsc#PED-11337).
- ice: flower: validate encapsulation control flags
  (jsc#PED-9947).
- sfc: use flow_rule_is_supp_enc_control_flags() (jsc#PED-11367).
- flow_offload: add encapsulation control flag helpers
  (jsc#PED-11367).
- ice: use irq_update_affinity_hint() (jsc#PED-9947).
- ice: add and use roundup_u64 instead of open coding equivalent
  (jsc#PED-9947).
- page_pool: remove WARN_ON() with OR (jsc#PED-11221).
- ionic: advertise 52-bit addressing limitation for MSI-X
  (jsc#PED-11379).
- bnxt_en: fix atomic counter for ptp packets (jsc#PED-11221).
- bnxt_en: add timestamping statistics support (jsc#PED-11221).
- ice: Adjust PTP init for 2x50G E825C devices (jsc#PED-9947).
- ice: Add NAC Topology device capability parser (jsc#PED-9947).
- ice: Add support for E825-C TS PLL handling (jsc#PED-9947).
- ice: Change CGU regs struct to anonymous (jsc#PED-9947).
- ice: Introduce ETH56G PHY model for E825C products
  (jsc#PED-9947).
- ice: Introduce ice_get_base_incval() helper (jsc#PED-9947).
- ice: Move CGU block (jsc#PED-9947).
- ice: Add PHY OFFSET_READY register clearing (jsc#PED-9947).
- ice: Implement Tx interrupt enablement functions (jsc#PED-9947).
- ice: Introduce helper to get tmr_cmd_reg values (jsc#PED-9947).
- ice: Introduce ice_ptp_hw struct (jsc#PED-9947).
- ionic: fix up ionic_if.h kernel-doc issues (jsc#PED-11379).
- ionic: only sync frag_len in first buffer of xdp
  (jsc#PED-11379).
- ionic: Use netdev_name() function instead of netdev->name
  (jsc#PED-11379).
- ionic: Mark error paths in the data path as unlikely
  (jsc#PED-11379).
- ionic: Pass ionic_txq_desc to ionic_tx_tso_post (jsc#PED-11379).
- ionic: Reset LIF device while restarting LIF (jsc#PED-11379).
- ionic: fix potential irq name truncation (jsc#PED-11379).
- net/mlx4: support per-queue statistics via netlink (jsc#PED-9945
  jsc#PED-11337).
- net/mlx4: link NAPI instances to queues and IRQs (jsc#PED-9945
  jsc#PED-11337).
- net/mlx4: Track RX allocation failures in a stat (jsc#PED-9945
  jsc#PED-11337).
- net: ethernet: mlx4: remove unused struct 'mlx4_port_config'
  (jsc#PED-9945 jsc#PED-11337).
- bnxt_en: Fix crash in bnxt_get_max_rss_ctx_ring()
  (jsc#PED-11221).
- bnxt: fix crashes when reducing ring count with active RSS
  contexts (jsc#PED-11221).
- bnxt_en: Set TSO max segs on devices with limits
  (jsc#PED-11221).
- bnxt_en: Update firmware interface to 1.10.3.44 (jsc#PED-11221).
- page_pool: check for DMA sync shortcut earlier (jsc#PED-11221).
- page_pool: don't use driver-set flags field directly
  (jsc#PED-11221).
- page_pool: make sure frag API fields don't span between
  cachelines (jsc#PED-11221).
- bnxt_en: silence clang build warning (jsc#PED-11221).
- queue_api: define queue api (jsc#PED-11221).
- bnxt: fix bnxt_get_avail_msix() returning negative values
  (jsc#PED-11221).
- bnxt_en: Add VF PCI ID for 5760X (P7) chips (jsc#PED-11221).
- bnxt_en: Optimize recovery path ULP locking in the driver
  (jsc#PED-11221).
- bnxt_en: Add a mutex to synchronize ULP operations
  (jsc#PED-11221).
- bnxt_en: Don't call ULP_STOP/ULP_START during L2 reset
  (jsc#PED-11221).
- bnxt_en: Don't support offline self test when RoCE driver is
  loaded (jsc#PED-11221).
- bnxt_en: share NQ ring sw_stats memory with subrings
  (jsc#PED-11221).
- net: page_pool: support error injection (jsc#PED-11221).
- netdev: add queue stats (bsc#1232798).
- ice: Document tx_scheduling_layers parameter (jsc#PED-9947).
- bnxt_en: flower: validate control flags (jsc#PED-11221).
- sfc: use flow_rule_is_supp_control_flags() (jsc#PED-11367).
- net: move skb ref helpers to new header (jsc#PED-11221).
- bnxt_en: Update MODULE_DESCRIPTION (jsc#PED-11221).
- bnxt_en: Utilize ulp client resources if RoCE is not registered
  (jsc#PED-11221).
- bnxt_en: Change MSIX/NQs allocation policy (jsc#PED-11221).
- bnxt_en: Refactor bnxt_rdma_aux_device_init/uninit functions
  (jsc#PED-11221).
- bnxt_en: Remove unneeded MSIX base structure fields and code
  (jsc#PED-11221).
- bnxt_en: Remove a redundant NULL check in bnxt_register_dev()
  (jsc#PED-11221).
- bnxt_en: Skip ethtool RSS context configuration in ifdown state
  (jsc#PED-11221).
- net: remove napi_frag_unref (jsc#PED-11221).
- net: make napi_frag_unref reuse skb_page_unref (jsc#PED-11221).
- netdevsim: report stats by default, like a real device
  (bsc#1232798).
- bnxt_en: Fix PTP firmware timeout parameter (jsc#PED-11221).
- bnxt_en: Add warning message about disallowed speed change
  (jsc#PED-11221).
- bnxt_en: Update firmware interface to 1.10.3.39 (jsc#PED-11221).
- bnxt_en: Add XDP Metadata support (jsc#PED-11221).
- bnxt_en: Change bnxt_rx_xdp function prototype (jsc#PED-11221).
- bnxt_en: Allocate page pool per numa node (jsc#PED-11221).
- bnxt_en: Enable XPS by default on driver load (jsc#PED-11221).
- bnxt_en: Add delay to handle Downstream Port Containment (DPC)
  AER (jsc#PED-11221).
- page_pool: try direct bulk recycling (jsc#PED-11221).
- page_pool: check for PP direct cache locality later
  (jsc#PED-11221).
- bnxt_en: Support adding ntuple rules on RSS contexts
  (jsc#PED-11221).
- bnxt_en: Refactor bnxt_cfg_rfs_ring_tbl_idx() (jsc#PED-11221).
- bnxt_en: Support RSS contexts in ethtool .{get|set}_rxfh()
  (jsc#PED-11221).
- bnxt_en: Refactor bnxt_set_rxfh() (jsc#PED-11221).
- bnxt_en: Add a new_rss_ctx parameter to bnxt_rfs_capable()
  (jsc#PED-11221).
- bnxt_en: Simplify bnxt_rfs_capable() (jsc#PED-11221).
- bnxt_en: Refactor RSS indir alloc/set functions (jsc#PED-11221).
- bnxt_en: Introduce rss ctx structure, alloc/free functions
  (jsc#PED-11221).
- bnxt_en: Refactor VNIC alloc and cfg functions (jsc#PED-11221).
- bnxt_en: Add helper function bnxt_hwrm_vnic_rss_cfg_p5()
  (jsc#PED-11221).
- bnxt_en: Retry PTP TX timestamp from FW for 1 second
  (jsc#PED-11221).
- bnxt_en: Add a timeout parameter to bnxt_hwrm_port_ts_query()
  (jsc#PED-11221).
- net: esp: fix bad handling of pages from page_pool
  (jsc#PED-11221).
- net: page_pool: factor out page_pool recycle check
  (jsc#PED-11221).
- eth: bnxt: support per-queue statistics (jsc#PED-11221).
- netdev: add queue stat for alloc failures (bsc#1232798).
- netdev: add per-queue statistics (bsc#1232798).
- net: dsa: Leverage core stats allocator (bsc#1232178).
- net: fix pointer check in skb_pp_cow_data routine
  (jsc#PED-11221).
- net: introduce abstraction for network memory (jsc#PED-11221).
- net: page_pool: fix recycle stats for system page_pool allocator
  (jsc#PED-11221).
- veth: rely on skb_pp_cow_data utility routine (jsc#PED-11221).
- xdp: add multi-buff support for xdp running in generic mode
  (jsc#PED-11221).
- xdp: rely on skb pointer reference in do_xdp_generic and
  netif_receive_generic_xdp (jsc#PED-11221).
- net: netdev_queue: netdev_txq_completed_mb(): fix wake condition
  (bsc#1232798).
- net: kcm: fix direct access to bv_len (jsc#PED-11221).
- veth: Implement VLAN tag XDP hint (jsc#PED-11221).
- skbuff: Optimization of SKB coalescing for page pool
  (jsc#PED-11221).
- skbuff: Add a function to check if a page belongs to page_pool
  (jsc#PED-11221).
- page_pool: fix typos and punctuation (jsc#PED-11221).
- net: veth: fix packet segmentation in
  veth_convert_skb_to_xdp_buff (jsc#PED-11221).
- net: kcm: fill in MODULE_DESCRIPTION() (jsc#PED-11221).
- net: veth: use newly added page pool API for veth with xdp
  (jsc#PED-11221).
- net: add truesize debug checks in skb_{add|coalesce}_rx_frag()
  (jsc#PED-11221).
- net: skbuff: update comment about pfmemalloc propagating
  (jsc#PED-11221).
- commit 894f4d7
* Thu Nov  7 2024 tbogendoerfer@suse.de
- blacklist.conf: removed temporary backlists
- commit ea412ac
* Thu Nov  7 2024 tiwai@suse.de
- ALSA: usb-audio: Accept multiple protocols in GTBs (jsc#PED-9993
  jsc#PED-10202).
- commit cc31702
* Thu Nov  7 2024 tiwai@suse.de
- ALSA: memalloc: Use proper DMA mapping API for x86 S/G buffer
  allocations (jsc#PED-9993 jsc#PED-10202).
- ALSA: memalloc: Use proper DMA mapping API for x86 WC buffer
  allocations (jsc#PED-9993 jsc#PED-10202).
- ALSA: ump: Use %%*ph to print small buffer (jsc#PED-9993
  jsc#PED-10202).
- ALSA: memalloc: Drop Xen PV workaround again (jsc#PED-9993
  jsc#PED-10202).
- ALSA: memalloc: Move snd_malloc_ops definition into memalloc.c
  again (jsc#PED-9993 jsc#PED-10202).
- ALSA: core: timer: Use NSEC_PER_SEC macro (jsc#PED-9993
  jsc#PED-10202).
- ALSA: pcm: Fix yet more compile warning at replacement with
  kstrtoul() (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: Fix the previous conversion to kstrtoul()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: replace simple_strtoul to kstrtoul (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: Drop superfluous filter argument of
  get_event_dest_client() (jsc#PED-9993 jsc#PED-10202).
- ALSA: seq: Remove unused declarations (jsc#PED-9993
  jsc#PED-10202).
- ALSA: oss: Remove unused declarations (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: Fix missing seq port info bit return for MIDI 1.0
  block (jsc#PED-9993 jsc#PED-10202).
- ALSA: seq: Print MIDI 1.0 specific port in proc output
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: usb-audio: Update UMP group attributes for GTB blocks,
  too (jsc#PED-9993 jsc#PED-10202).
- ALSA: usb-audio: Set MIDI1 flag appropriately for GTB MIDI
  1.0 entry (jsc#PED-9993 jsc#PED-10202).
- ALSA: ump: Choose the protocol when protocol caps are changed
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: ump: Handle MIDI 1.0 Function Block in MIDI 2.0 protocol
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: memalloc: Let IOMMU handle S/G primarily (jsc#PED-9993
  jsc#PED-10202).
- ALSA: memalloc: Use DMA API for x86 WC page allocations, too
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: ump: Update substream name from assigned FB names
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: control: Annotate snd_kcontrol with __counted_by()
  (jsc#PED-9993 jsc#PED-10202).
- commit a981373
* Thu Nov  7 2024 tiwai@suse.de
- thermal: intel: int340x: processor: Fix warning during module
  unload (git-fixes).
- thermal: core: Fix rounding of delay jiffies (git-fixes).
- commit 2b35c1c
* Thu Nov  7 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: fix 6 GHz scan construction (git-fixes).
- commit f10e801
* Thu Nov  7 2024 tiwai@suse.de
- thermal: intel: int340x: processor: Fix warning during module
  unload (git-fixes).
- commit 2c3d870
* Thu Nov  7 2024 sjaeckel@suse.de
- mptcp: fix double-free on socket dismantle (CVE-2024-26782
  bsc#1222590).
- mptcp: deal with large GSO size (CVE-2023-52778 bsc#1224948).
- commit 86ee052
* Thu Nov  7 2024 jack@suse.cz
- ext4: ext4_search_dir should return a proper error (bsc#1231920
  CVE-2024-47701).
- commit 7c02130
* Thu Nov  7 2024 jack@suse.cz
- ext4: explicitly exit when ext4_find_inline_entry returns an
  error (bsc#1231920 CVE-2024-47701).
- commit e600961
* Thu Nov  7 2024 jack@suse.cz
- ext4: return error on ext4_find_inline_entry (bsc#1231920
  CVE-2024-47701).
- commit 39b6acc
* Thu Nov  7 2024 tbogendoerfer@suse.de
- igb: Disable threaded IRQ for igb_msix_other (git-fixes).
- commit b8afad1
* Thu Nov  7 2024 tbogendoerfer@suse.de
- ethtool: provide customized dim profile management
  (bsc#1232798).
- Update config files.
- commit b429cec
* Thu Nov  7 2024 jack@suse.cz
- fs/inode: Prevent dump_mapping() accessing invalid
  dentry.d_name.name (bsc#1232387 CVE-2024-49934).
- commit cf2a806
* Thu Nov  7 2024 jack@suse.cz
- ext4: filesystems without casefold feature cannot be mounted
  with siphash (bsc#1232264 CVE-2024-49968).
- commit 1907014
* Thu Nov  7 2024 jack@suse.cz
- ext4: drop ppath from ext4_ext_replay_update_ex() to avoid
  double-free (bsc#1232096 CVE-2024-49983).
- commit 4a6ac53
* Thu Nov  7 2024 jack@suse.cz
- vfs: fix race between evice_inodes() and find_inode()&iput()
  (bsc#1231930 CVE-2024-47679).
- commit dcf9f6e
* Thu Nov  7 2024 jack@suse.cz
- ext4: avoid OOB when system.data xattr changes underneath the
  filesystem (bsc#1231920 CVE-2024-47701).
- commit f292cb3
* Thu Nov  7 2024 tbogendoerfer@suse.de
- blacklist.conf: added temporary commits until backport is finished
- commit 0f8f366
* Thu Nov  7 2024 tbogendoerfer@suse.de
- net: ptp: create a mock-up PTP Hardware Clock driver
  (bsc#1232798).
- Update config files.
- supported.conf: mark ptp_mock supported
- commit 5d98adc
* Thu Nov  7 2024 tbogendoerfer@suse.de
- net: pse-pd: Introduce PSE types enumeration (bsc#1232798).
- Refresh
  patches.suse/net-pse-pd-Use-EOPNOTSUPP-error-code-instead-of-ENOT.patch.
- commit 4b3af5f
* Thu Nov  7 2024 tbogendoerfer@suse.de
- net: fec: convert to ndo_hwtstamp_get() and ndo_hwtstamp_set()
  (bsc#1232798).
- Refresh
  patches.suse/net-fec-remove-.ndo_poll_controller-to-avoid-deadloc.patch.
- commit 2c76a74
* Thu Nov  7 2024 tbogendoerfer@suse.de
- netlink: specs: ethtool: untangle stats-get (bsc#1232798).
- Refresh
  patches.suse/netlink-specs-remove-redundant-type-keys-from-attrib.patch.
- commit 2dbd9c3
* Thu Nov  7 2024 tbogendoerfer@suse.de
- net: pse-pd: Fix out of bound for loop (bsc#1232798).
- octeontx2-af: Fix potential integer overflows on integer shifts
  (jsc#PED-11318).
- net: pse-pd: Fix enabled status mismatch (bsc#1232798).
- octeontx2-af: debugfs: Add Channel info to RPM map
  (jsc#PED-11318).
- qede: Remove setting of RX software timestamp (jsc#PED-9962
  jsc#PED-11294).
- tg3: Remove setting of RX software timestamp (jsc#PED-8898
  jsc#PED-11227).
- octeontx2-pf: Make iplen __be16 in otx2_sqe_add_ext()
  (jsc#PED-11318).
- octeontx2-af: Pass string literal as format argument of
  alloc_workqueue() (jsc#PED-11318).
- bnx2x: Remove setting of RX software timestamp (jsc#PED-9872
  jsc#PED-11308).
- ixgbe: Remove setting of RX software timestamp (jsc#PED-9961).
- igc: Remove setting of RX software timestamp (jsc#PED-9944).
- igb: Remove setting of RX software timestamp (jsc#PED-9959).
- i40e: Remove setting of RX software timestamp (jsc#PED-8904
  jsc#PED-9957).
- octeontx2-pf: Remove setting of RX software timestamp
  (jsc#PED-11318).
- i40e: Add Energy Efficient Ethernet ability for X710
  Base-T/KR/KX cards (jsc#PED-8904 jsc#PED-9957).
- e1000e: avoid failing the system during pm_suspend
  (jsc#PED-9951).
- igc: Move the MULTI GBT AN Control Register to _regs file
  (jsc#PED-9944).
- igc: Add Energy Efficient Ethernet ability (jsc#PED-9944).
- igc: Get rid of spurious interrupts (jsc#PED-9944).
- igc: Add MQPRIO offload support (jsc#PED-9944).
- octeontx2-af: configure default CPT credits for CN10KA B0
  (jsc#PED-11318).
- octeontx2-af: avoid RXC register access for CN10KB
  (jsc#PED-11318).
- octeontx2-af: use dynamic interrupt vectors for CN10K
  (jsc#PED-11318).
- igbvf: Remove two unused declarations (jsc#PED-9959).
- bnx2x: Set ivi->vlan field as an integer (jsc#PED-9872
  jsc#PED-11308).
- iavf: add support for offloading tc U32 cls filters
  (jsc#PED-9955).
- iavf: refactor add/del FDIR filters (jsc#PED-9955).
- virtchnl: support raw packet in protocol header (jsc#PED-9955).
- bnx2x: Provide declaration of dmae_reg_go_c in header
  (jsc#PED-9872 jsc#PED-11308).
- octeontx2-af: Modify SMQ flush sequence to drop packets
  (jsc#PED-11318).
- pse-core: Conditionally set current limit during PI regulator
  registration (bsc#1232798).
- net: ethtool: Allow write mechanism of LPL and both LPL and EPL
  (bsc#1232798).
- ethtool: Fix context creation with no parameters (bsc#1232798).
- ethtool: fix the state of additional contexts with old API
  (bsc#1232798).
- ethtool: fix setting key and resetting indir at once
  (bsc#1232798).
- ethtool: rss: echo the context number back (bsc#1232798).
- netlink: specs: correct the spec of ethtool (bsc#1232798).
- net: pse-pd: Do not return EOPNOSUPP if config is null
  (bsc#1232798).
- net: Add struct kernel_ethtool_ts_info (bsc#1232798).
- net: Change the API of PHY default timestamp to MAC
  (bsc#1232798).
- net: phy: bcm54811: New link mode for BroadR-Reach
  (bsc#1232798).
- igc: Remove the internal 'eee_advert' field (jsc#PED-9944).
- i40e: correct i40e_addr_to_hkey() name in kdoc (jsc#PED-8904
  jsc#PED-9957).
- net: intel: Remove MODULE_AUTHORs (jsc#PED-9944).
- net: ethtool: Monotonically increase the message sequence number
  (bsc#1232798).
- net: ethtool: let drivers declare max size of RSS indir table
  and key (bsc#1232798).
- net: ethtool: let drivers remove lost RSS contexts
  (bsc#1232798).
- ethtool: use the rss context XArray in ring deactivation
  safety-check (bsc#1232798).
- netlink: specs: Expand the PSE netlink command with C33 pw-limit
  attributes (bsc#1232798).
- net: ethtool: Add new power limit get and set features
  (bsc#1232798).
- net: pse-pd: Add new power limit get and set c33 features
  (bsc#1232798).
- netlink: specs: Expand the PSE netlink command with C33 new
  features (bsc#1232798).
- net: ethtool: pse-pd: Expand C33 PSE status with class, power
  and extended state (bsc#1232798).
- ethtool: move firmware flashing flag to struct
  ethtool_netdev_state (bsc#1232798).
- net: ethtool: fix compat with old RSS context API (bsc#1232798).
- net: ethtool: Fix the panic caused by dev being null when
  dumping coalesce (bsc#1232798).
- octeontx2-af: Sync NIX and NPA contexts from NDC to LLC/DRAM
  (jsc#PED-11318).
- net: ethtool: use the tracking array for get_rxfh on custom
  RSS contexts (bsc#1232798).
- net: ethtool: add a mutex protecting RSS contexts (bsc#1232798).
- net: ethtool: add an extack parameter to new rxfh_context APIs
  (bsc#1232798).
- net: ethtool: let the core choose RSS context IDs (bsc#1232798).
- net: ethtool: record custom RSS contexts in the XArray
  (bsc#1232798).
- net: ethtool: attach an XArray of custom RSS contexts to a
  netdevice (bsc#1232798).
- net: move ethtool-related netdev state into its own struct
  (bsc#1232798).
- ethtool: Add ability to flash transceiver modules' firmware
  (bsc#1232798).
- ethtool: cmis_fw_update: add a layer for supporting firmware
  update using CDB (bsc#1232798).
- ethtool: cmis_cdb: Add a layer for supporting CDB commands
  (bsc#1232798).
- net: sfp: Add more extended compliance codes (bsc#1232798).
- ethtool: Veto some operations during firmware flashing process
  (bsc#1232798).
- ethtool: Add flashing transceiver modules' firmware
  notifications ability (bsc#1232798).
- ethtool: Add an interface for flashing transceiver modules'
  firmware (bsc#1232798).
- ethtool: Add ethtool operation to write to a transceiver module
  EEPROM (bsc#1232798).
- dim: add new interfaces for initialization and getting results
  (bsc#1232798).
- linux/dim: move useful macros to .h file (bsc#1232798).
- octeontx2-pf: Add ucast filter count configurability via devlink
  (jsc#PED-11318).
- igb: Add MII write support (jsc#PED-9959).
- net: intel: Use *-y instead of *-objs in Makefile
  (jsc#PED-9944).
- octeontx2-af: Add debugfs support to dump NIX TM topology
  (jsc#PED-11318).
- net: ethtool: remove unused struct 'cable_test_tdr_req_info'
  (bsc#1232798).
- net: ethtool: Fix RSS setting (bsc#1232798).
- ethtool: netlink: do not return SQI value if link is down
  (bsc#1232798).
- netlink: specs: Fix pse-set command attributes (bsc#1232798).
- ethtool: init tsinfo stats if requested (bsc#1232798).
- net: lan966x: Remove ptp traps in case the ptp is not enabled
  (bsc#1232798).
- net: pse-pd: Kconfig: Add missing Regulator API dependency
  (bsc#1232798).
- net: pse-pd: pse_core: Fix pse regulator type (bsc#1232798).
- net: pse-pd: pse_core: Add missing kdoc return description
  (bsc#1232798).
- net: pse-pd: Use regulator framework within PSE framework
  (bsc#1232798).
- net: pse-pd: Add support for setup_pi_matrix callback
  (bsc#1232798).
- net: pse-pd: Add support for PSE PIs (bsc#1232798).
- netlink: specs: Expand the pse netlink command with PoE
  interface (bsc#1232798).
- netlink: specs: Modify pse attribute prefix (bsc#1232798).
- net: ethtool: pse-pd: Expand pse commands with the PSE PoE
  interface (bsc#1232798).
- ethtool: Expand Ethernet Power Equipment with c33 (PoE)
  alongside PoDL (bsc#1232798).
- net: pse-pd: Rectify and adapt the naming of admin_cotrol
  member of struct pse_control_config (bsc#1232798).
- ethtool: update tsinfo statistics attribute docs with correct
  type (bsc#1232798).
- netlink: specs: ethtool: define header-flags as an enum
  (bsc#1232798).
- ethtool: add interface to read Tx hardware timestamping
  statistics (bsc#1232798).
- netlink: specs: define ethtool header flags (bsc#1232798).
- net: ethtool: Add impedance mismatch result code to cable test
  (bsc#1232798).
- net: netdevsim: don't try to destroy PHC on VFs (bsc#1232798).
- Documentation: networking: add missing PLCA messages from the
  message list (bsc#1232798).
- net: netdevsim: use mock PHC driver (bsc#1232798).
- net: omit ndo_hwtstamp_get() call when possible in
  dev_set_hwtstamp_phylib() (bsc#1232798).
- net: remove phy_has_hwtstamp() -> phy_mii_ioctl() decision
  from converted drivers (bsc#1232798).
- net: phy: provide phylib stubs for hardware timestamping
  operations (bsc#1232798).
- net: lan966x: convert to ndo_hwtstamp_get() and
  ndo_hwtstamp_set() (bsc#1232798).
- net: sparx5: convert to ndo_hwtstamp_get() and
  ndo_hwtstamp_set() (bsc#1232798).
- net: fec: delete fec_ptp_disable_hwts() (bsc#1232798).
- net: ngbe: add Wake on Lan support (bsc#1232798).
- netlink: specs: ethtool: mark pads as pads (bsc#1232798).
- netlink: specs: ethtool: untangle UDP tunnels and cable test
  a bit (bsc#1232798).
- netlink: specs: ethtool: add empty enum stringset (bsc#1232798).
- netlink: specs: ethtool: add C render hints (bsc#1232798).
- net: phy: Allow drivers to always call into ->suspend()
  (bsc#1232798).
- commit fd4c2d3
* Thu Nov  7 2024 nik.borisov@suse.com
- Update patches.suse/x86-cpufeatures-opcode-msr-Add-the-WRMSRNS-instruction-sup.patch (jsc#PED-10236 jsc#PED-10385).
- commit 613ff13
* Thu Nov  7 2024 tiwai@suse.de
- security/keys: fix slab-out-of-bounds in key_task_permission
  (git-fixes).
- platform/x86/amd/pmc: Detect when STB is not available
  (git-fixes).
- HID: core: zero-initialize the report buffer (git-fixes).
- commit 277fa5f
* Thu Nov  7 2024 tbogendoerfer@suse.de
- mlxbf_gige: disable RX filters until RX path initialized
  (git-fixes).
- commit f2b07e9
* Thu Nov  7 2024 tiwai@suse.de
- rpm/kernel-docs.spec.in: fix missing yaml module used for ynl-gen-rst.py
- commit 4c04064
* Thu Nov  7 2024 tiwai@suse.de
- Fix the build of kernel-docs
  Add missing exec bit to tools/net/ynl/ynl-gen-rst.py
- commit 49d9abb
* Thu Nov  7 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add tests for sdiv/smod overflow cases
  (CVE-2024-49888 bsc#1232208).
- commit b193d4f
* Thu Nov  7 2024 ddiss@suse.de
- initramfs: avoid filename buffer overrun (bsc#1232436).
- commit 4918398
* Thu Nov  7 2024 shung-hsi.yu@suse.com
- netfilter: bpf: must hold reference on net namespace
  (bsc#1232894 CVE-2024-50130).
- commit 7d292ad
* Thu Nov  7 2024 shung-hsi.yu@suse.com
- bpftool: Fix undefined behavior in qsort(NULL, 0,
  ...) (bsc#1232258 CVE-2024-49987).
- commit 80f8e64
* Thu Nov  7 2024 tonyj@suse.de
- perf/arm-cmn: Enable support for tertiary match group
  (jsc#PED-11433).
- perf/arm-cmn: Decouple wp_config registers from filter group
  number (jsc#PED-11433).
- perf/arm-cmn: Avoid placing cpumask on the stack
  (jsc#PED-11433).
- cpumask: add cpumask_any_and_but() (jsc#PED-11433).
- perf/arm-cmn: Improve debugfs pretty-printing for large configs
  (jsc#PED-11433).
- perf: arm-cmn: Convert to platform remove callback returning
  void (jsc#PED-11433).
- perf/arm-cmn: Workaround AmpereOneX errata AC04_MESH_1
  (incorrect child count) (jsc#PED-11433).
- perf/arm-cmn: Fix HN-F class_occup_id events (jsc#PED-11433).
- perf/arm-cmn: Fail DTC counter allocation correctly
  (jsc#PED-11433).
- perf/arm-cmn: Enable per-DTC counter allocation (jsc#PED-11433).
- perf/arm-cmn: Rework DTC counters (again) (jsc#PED-11433).
- perf/arm-cmn: Fix DTC domain detection (jsc#PED-11433).
- perf/arm-cmn: Add CMN-700 r3 support (jsc#PED-11433).
- perf/arm-cmn: Refactor HN-F event selector macros
  (jsc#PED-11433).
- perf/arm-cmn: Remove spurious event aliases (jsc#PED-11433).
- perf/arm-cmn: Add sysfs identifier (jsc#PED-11433).
- perf/arm-cmn: Revamp model detection (jsc#PED-11433).
- commit 5609cfe
* Thu Nov  7 2024 tonyj@suse.de
- cpumask: kernel-doc cleanups and additions (jsc#PED-11433).
- Refresh
  patches.suse/cpumask-define-cleanup-function-for-cpumasks.patch.
- commit 8c8e8cb
* Wed Nov  6 2024 mgorman@suse.de
- Revert "serial: 8250_omap: Set the console genpd always on if
  no console suspend" (git fixes).
- serial: qcom-geni: fix hard lockup on buffer flush (git fixes).
- serial: meson+qcom: don't advance the kfifo twice (git fixes).
- timers/migration: Prevent out of bounds access on failure
  (git fixes).
- timers: Fix removed self-IPI on global timer's enqueue in
  nohz_full (git fixes).
- ARM: bcm: stop selecing CONFIG_TICK_ONESHOT (git fixes).
- platform/x86: Add new get_serdev_controller() helper (git
  fixes).
- tty: serial: Fix bit order in RS485 flag definitions (git
  fixes).
- commit 7e445cf
* Wed Nov  6 2024 mgorman@suse.de
- blacklist.conf: Fixes for unsupported configs or drivers
- commit 4b6e4bb
* Wed Nov  6 2024 mgorman@suse.de
- blacklist.conf: Fix for unsupported configuration
- commit 416074b
* Wed Nov  6 2024 mgorman@suse.de
- blacklist.conf: Unsupported driver
- commit 8dcb38d
* Wed Nov  6 2024 tbogendoerfer@suse.de
- s390/cio: rename bitmap_size() -> idset_bitmap_size()
  (bsc#1232889).
- Refresh
  patches.suse/bitmap-introduce-generic-optimized-bitmap_size.patch.
- commit ec4e97f
* Wed Nov  6 2024 tbogendoerfer@suse.de
- dma: compile-out DMA sync op calls when not used (jsc#PED-8904
  jsc#PED-9957).
- Update config files.
- commit 2f3612a
* Wed Nov  6 2024 tbogendoerfer@suse.de
- pfcp: add PFCP module (jsc#PED-9947).
- Update config files.
- supported.conf: mark drivers/net/pfcp supported
- commit aebf79a
* Wed Nov  6 2024 tbogendoerfer@suse.de
- init/Kconfig: lower GCC version check for -Warray-bounds
  (bsc#1232889).
- Update config files.
- commit 65261f0
* Wed Nov  6 2024 tbogendoerfer@suse.de
- dma: fix DMA sync for drivers not calling dma_set_mask*()
  (jsc#PED-8904 jsc#PED-9957).
- Refresh
  patches.suse/kabi-Add-placeholders-to-a-couple-of-important-struc.patch.
- commit b92355b
* Wed Nov  6 2024 tbogendoerfer@suse.de
- dma: avoid redundant calls for sync operations (jsc#PED-8904
  jsc#PED-9957).
- Refresh
  patches.suse/kabi-Add-placeholders-to-a-couple-of-important-struc.patch.
- commit 658de29
* Wed Nov  6 2024 tbogendoerfer@suse.de
- ice: refactor struct ice_vsi_cfg_params to be inside of struct
  ice_vsi (jsc#PED-9947).
- Refresh patches.suse/ice-Fix-increasing-MSI-X-on-VF.patch.
- commit e8a817c
* Wed Nov  6 2024 tbogendoerfer@suse.de
- dpll: check that pin is registered in __dpll_pin_unregister()
  (jsc#PED-9947).
- Refresh
  patches.suse/dpll-fix-dpll_pin_on_pin_register-for-multiple-paren.patch.
- commit 7fd1206
* Wed Nov  6 2024 tbogendoerfer@suse.de
- ice: Add a new counter for Rx EIPE errors (jsc#PED-9947).
- Refresh
  patches.suse/net-intel-introduce-Intel-Ethernet-common-library.patch.
- commit 9de5ee1
* Wed Nov  6 2024 mhocko@suse.com
- Update
  patches.suse/mm-mmap-no-need-to-call-khugepaged_enter_vma-for-sta.patch
  (jsc#PED-11442).
- commit d087a3b
* Wed Nov  6 2024 tbogendoerfer@suse.de
- ice: make ice_vsi_cfg_txq() static (jsc#PED-9947).
- Refresh
  patches.suse/overflow-Change-DEFINE_FLEX-to-take-__counted_by-mem.patch.
- commit 64fa49c
* Wed Nov  6 2024 tbogendoerfer@suse.de
- ice: introduce PTP state machine (jsc#PED-9947).
- Refresh
  patches.suse/ice-Don-t-process-extts-if-PTP-is-disabled.patch.
- Refresh patches.suse/ice-Fix-improper-extts-handling.patch.
- commit 55e05a9
* Wed Nov  6 2024 tbogendoerfer@suse.de
- dpll: move all dpll<>netdev helpers to dpll code (jsc#PED-9947).
- Refresh
  patches.suse/dpll-fix-dpll_pin_on_pin_register-for-multiple-paren.patch.
- Refresh
  patches.suse/ice-Fix-improper-handling-of-refcount-in-ice_dpll_in.patch.
- commit 8416c66
* Wed Nov  6 2024 tbogendoerfer@suse.de
- dpll: fix build failure due to rcu_dereference_check() on
  unknown type (jsc#PED-9947).
- Refresh
  patches.suse/dpll-fix-dpll_pin_on_pin_register-for-multiple-paren.patch.
- commit c9c12e2
* Wed Nov  6 2024 duwe@suse.de
- supported.conf: Add ppc x25519 module (jsc#PED-9906)
- commit 07e6419
* Wed Nov  6 2024 tbogendoerfer@suse.de
- net/sched: Retire ipt action (bsc#1232889).
- Refresh
  patches.suse/net-sched-Add-module-aliases-for-cls_-sch_-act_-modules.patch.
- commit 107b880
* Wed Nov  6 2024 tbogendoerfer@suse.de
- tools: ynl: remove generated user space code from git
  (bsc#1232889).
- Refresh patches.suse/xdp-Add-VLAN-tag-hint.patch.
- commit 17c98f9
* Wed Nov  6 2024 tiwai@suse.de
- block: decouple blk_set_stacking_limits from
  blk_set_default_limits (bsc#1232797).
- commit a85b8a3
* Wed Nov  6 2024 tbogendoerfer@suse.de
- net/sched: flower: Allow matching on layer 2 miss (bsc#1232889).
- Refresh
  patches.suse/net-sched-cls_flower-Undo-tcf_bind_filter-in-case-of.patch.
- commit f72fa75
* Wed Nov  6 2024 duwe@suse.de
- crypto: ppc/curve25519 - Update Kconfig and Makefile for ppc64le
  (jsc#PED-9906).
- Update config files (ppc64le/curve25519=m, run_oldconfig.sh)
- crypto: ppc/curve25519 - Core functions for ppc64le
  (jsc#PED-9906).
- crypto: ppc/curve25519 - Low-level primitives for ppc64le
  (jsc#PED-9906).
- MAINTAINERS: adjust file entries after crypto vmx file movement
  (jsc#PED-9906).
- crypto: vmx - Move to arch/powerpc/crypto (jsc#PED-9906).
- commit c66851c
* Wed Nov  6 2024 tbogendoerfer@suse.de
- ice: Fix entering Safe Mode (jsc#PED-9947).
- ice: fix memleak in ice_init_tx_topology() (jsc#PED-9947).
- netlink: specs: mptcp: fix port endianness (bsc#1232889).
- tools/net/ynl: fix cli.py --subscribe feature (bsc#1232889).
- octeontx2-af: Fix CPT AF register offset calculation
  (jsc#PED-11318).
- doc: netlink: specs: tc: describe flower control flags
  (bsc#1232889).
- octeontx2-af: fix issue with IPv4 match for RSS (jsc#PED-11318).
- octeontx2-af: fix issue with IPv6 ext match for RSS
  (jsc#PED-11318).
- octeontx2-af: fix detection of IP layer (jsc#PED-11318).
- octeontx2-af: fix a issue with cpt_lf_alloc mailbox
  (jsc#PED-11318).
- octeontx2-af: replace cpt slot with lf id on reg write
  (jsc#PED-11318).
- octeontx2-af: Fix incorrect value output on error path in
  rvu_check_rsrc_availability() (jsc#PED-11318).
- ionic: use dev_consume_skb_any outside of napi (jsc#PED-11379).
- octeontx2-pf: Fix coverity and klockwork issues in octeon PF
  driver (jsc#PED-11318).
- ionic: fix kernel panic due to multi-buffer handling
  (jsc#PED-11379).
- octeontx2-pf: Fix linking objects into multiple modules
  (jsc#PED-11318).
- octeontx2-pf: Add error handling to VLAN unoffload handling
  (jsc#PED-11318).
- gcc: disable '-Warray-bounds' for gcc-9 (bsc#1232889).
- ionic: fix kernel panic in XDP_TX action (jsc#PED-11379).
- octeontx2-af: Always allocate PF entries from low prioriy zone
  (jsc#PED-11318).
- ice: check for unregistering correct number of devlink params
  (jsc#PED-9947).
- i40e: Fully suspend and resume IO operations in EEH case
  (jsc#PED-8904 jsc#PED-9957).
- i40e: factoring out i40e_suspend/i40e_resume (jsc#PED-8904
  jsc#PED-9957).
- Octeontx2-pf: Free send queue buffers incase of leaf to inner
  (jsc#PED-11318).
- xsk: use generic DMA sync shortcut instead of a custom one
  (jsc#PED-8904 jsc#PED-9957).
- dpll: fix return value check for kmemdup (jsc#PED-9947).
- net: qede: flower: validate control flags (jsc#PED-9962
  jsc#PED-11294).
- ynl: ensure exact-len value is resolved (bsc#1232889).
- net: e1000e & ixgbe: Remove PCI_HEADER_TYPE_MFD duplicates
  (jsc#PED-9951).
- ice: remove correct filters during eswitch release
  (jsc#PED-9947).
- igb: flower: validate control flags (jsc#PED-9959).
- ice: flower: validate control flags (jsc#PED-9947).
- iavf: flower: validate control flags (jsc#PED-9955).
- i40e: flower: validate control flags (jsc#PED-8904
  jsc#PED-9957).
- net: qede: use extack in qede_parse_actions() (jsc#PED-9962
  jsc#PED-11294).
- net: qede: propagate extack through qede_flow_spec_validate()
  (jsc#PED-9962 jsc#PED-11294).
- net: qede: use faked extack in qede_flow_spec_to_rule()
  (jsc#PED-9962 jsc#PED-11294).
- net: qede: use extack in qede_parse_flow_attr() (jsc#PED-9962
  jsc#PED-11294).
- net: qede: add extack in qede_add_tc_flower_fltr() (jsc#PED-9962
  jsc#PED-11294).
- net: qede: use extack in qede_flow_parse_udp_v4() (jsc#PED-9962
  jsc#PED-11294).
- net: qede: use extack in qede_flow_parse_udp_v6() (jsc#PED-9962
  jsc#PED-11294).
- net: qede: use extack in qede_flow_parse_tcp_v4() (jsc#PED-9962
  jsc#PED-11294).
- net: qede: use extack in qede_flow_parse_tcp_v6() (jsc#PED-9962
  jsc#PED-11294).
- net: qede: use extack in qede_flow_parse_v4_common()
  (jsc#PED-9962 jsc#PED-11294).
- net: qede: use extack in qede_flow_parse_v6_common()
  (jsc#PED-9962 jsc#PED-11294).
- net: qede: use extack in qede_set_v4_tuple_to_profile()
  (jsc#PED-9962 jsc#PED-11294).
- net: qede: use extack in qede_set_v6_tuple_to_profile()
  (jsc#PED-9962 jsc#PED-11294).
- net: qede: use extack in qede_flow_parse_ports() (jsc#PED-9962
  jsc#PED-11294).
- octeontx2-pf: Reuse Transmit queue/Send queue index of HTB class
  (jsc#PED-11318).
- netlink/specs: Add VF attributes to rt_link spec (bsc#1232889).
- ice: Deduplicate tc action setup (jsc#PED-9947).
- ice: update E830 device ids and comments (jsc#PED-9947).
- ice: add additional E830 device ids (jsc#PED-9947).
- net: qede: use return from qede_flow_parse_ports() (jsc#PED-9962
  jsc#PED-11294).
- net: qede: use return from qede_flow_spec_validate_unused()
  (jsc#PED-9962 jsc#PED-11294).
- net: qede: use return from qede_parse_actions() for flow_spec
  (jsc#PED-9962 jsc#PED-11294).
- octeontx2-pf: Treat truncation of IRQ name as an error
  (jsc#PED-11318).
- tools: ynl: add --list-ops and --list-msgs to CLI (bsc#1232889).
- i40e: Add and use helper to reconfigure TC for given VSI
  (jsc#PED-8904 jsc#PED-9957).
- i40e: Add helper to access main VEB (jsc#PED-8904 jsc#PED-9957).
- i40e: Consolidate checks whether given VSI is main (jsc#PED-8904
  jsc#PED-9957).
- i40e: Add helper to access main VSI (jsc#PED-8904 jsc#PED-9957).
- i40e: Refactor argument of i40e_detect_recover_hung()
  (jsc#PED-8904 jsc#PED-9957).
- i40e: Refactor argument of several client notification functions
  (jsc#PED-8904 jsc#PED-9957).
- i40e: Remove flags field from i40e_veb (jsc#PED-8904
  jsc#PED-9957).
- tools: ynl: don't append doc of missing type directly to the
  type (bsc#1232889).
- igc: Add Tx hardware timestamp request for AF_XDP zero-copy
  packet (jsc#PED-9944).
- iavf: switch to Page Pool (jsc#PED-9955).
- iavf: pack iavf_ring more efficiently (jsc#PED-9955).
- iavf: drop page splitting and recycling (jsc#PED-9955).
- iavf: kill "legacy-rx" for good (jsc#PED-9955).
- ice: Add tx_scheduling_layers devlink param (jsc#PED-9947).
- ice: Enable switching default Tx scheduler topology
  (jsc#PED-9947).
- ice: Adjust the VSI/Aggregator layers (jsc#PED-9947).
- ice: Support 5 layer topology (jsc#PED-9947).
- devlink: extend devlink_param *set pointer (jsc#PED-11318).
- octeontx2-pf: flower: check for unsupported control flags
  (jsc#PED-11318).
- tools/net/ynl: Add multi message support to ynl (bsc#1232889).
- tools/net/ynl: Fix extack decoding for directional ops
  (bsc#1232889).
- octeontx2-pf: Add support for offload tc with skbedit mark
  action (jsc#PED-11318).
- ice: Remove ndo_get_phys_port_name (jsc#PED-9947).
- ice: Add automatic VF reset on Tx MDD events (jsc#PED-9947).
- ice: store VF relative MSI-X index in q_vector->vf_reg_idx
  (jsc#PED-9947).
- ice: set vf->num_msix in ice_initialize_vf_entry()
  (jsc#PED-9947).
- ice: Implement 'flow-type ether' rules (jsc#PED-9947).
- ice: Remove unnecessary argument from ice_fdir_comp_rules()
  (jsc#PED-9947).
- tools: ynl: don't return None for dumps (bsc#1232889).
- flow_offload: add control flag checking helpers (jsc#PED-9959).
- devlink: add a new info version tag (bsc#1232889).
- doc/netlink/specs: Add bond support to rt_link.yaml
  (bsc#1232889).
- igc: Remove redundant runtime resume for ethtool ops
  (jsc#PED-9944).
- igb: Remove redundant runtime resume for ethtool_ops
  (jsc#PED-9959).
- e1000e: Remove redundant runtime resume for ethtool_ops
  (jsc#PED-9951).
- devlink: Support setting max_io_eqs (bsc#1232889).
- ipv4: Set scope explicitly in ip_route_output() (jsc#PED-9962
  jsc#PED-11294).
- pfcp: avoid copy warning by simplifing code (jsc#PED-9947).
- ip_tunnel: harden copying IP tunnel params to userspace
  (bsc#1232889).
- netlink: add nlmsg_consume() and use it in devlink compat
  (bsc#1232889).
- ynl: support binary and integer sub-type for indexed-array
  (bsc#1232889).
- ynl: rename array-nest to indexed-array (bsc#1232889).
- tools: ynl: ethtool.py: Output timestamping statistics from
  tsinfo-get operation (bsc#1232889).
- tools: ynl: copy netlink error to NlError (bsc#1232889).
- tg3: Remove residual error handling in tg3_suspend (jsc#PED-8898
  jsc#PED-11227).
- tools: ynl: ethtool.py: Make tool invokable from any CWD
  (bsc#1232889).
- octeontx2-pf: Reset MAC stats during probe (jsc#PED-11318).
- ice: hold devlink lock for whole init/cleanup (jsc#PED-9947).
- ice: move devlink port code to a separate file (jsc#PED-9947).
- ice: move ice_devlink. to devlink folder (jsc#PED-9947).
- ice: Remove newlines in NL_SET_ERR_MSG_MOD (jsc#PED-9947).
- ice: Add switch recipe reusing feature (jsc#PED-9947).
- ice: fold ice_ptp_read_time into ice_ptp_gettimex64
  (jsc#PED-9947).
- ice: avoid the PTP hardware semaphore in gettimex64 path
  (jsc#PED-9947).
- ice: add ice_adapter for shared data across PFs on the same NIC
  (jsc#PED-9947).
- tools: ynl: add ynl_dump_empty() helper (bsc#1232889).
- i40e: avoid forward declarations in i40e_nvm.c (jsc#PED-8904
  jsc#PED-9957).
- igc: Refactor runtime power management flow (jsc#PED-9944).
- net: intel: implement modern PM ops declarations (jsc#PED-9959).
- igb: simplify pci ops declaration (jsc#PED-9959).
- doc: netlink: Update tc spec with missing definitions
  (bsc#1232889).
- doc: netlink: Add hyperlinks to generated Netlink docs
  (bsc#1232889).
- doc: netlink: Change generated docs to limit TOC to depth 3
  (bsc#1232889).
- ice: Add support for PFCP hardware offload in switchdev
  (jsc#PED-9947).
- ice: refactor ICE_TC_FLWR_FIELD_ENC_OPTS (jsc#PED-9947).
- pfcp: always set pfcp metadata (jsc#PED-9947).
- net: net_test: add tests for IP tunnel flags conversion helpers
  (jsc#PED-9947).
- ip_tunnel: convert __be16 tunnel flags to bitmaps
  (jsc#PED-9947).
- ip_tunnel: use a separate struct to store tunnel params in
  the kernel (jsc#PED-9947).
- bitmap: make bitmap_{get,set}_value8() use bitmap_{read,write}()
  (jsc#PED-9947).
- bitmap: introduce generic optimized bitmap_size()
  (jsc#PED-9947).
- lib/bitmap: add bitmap_{read,write}() (jsc#PED-9947).
- netlink: introduce type-checking attribute iteration
  (jsc#PED-9961).
- octeontx2-pf: remove unused variables req_hdr and rsp_hdr
  (jsc#PED-11318).
- tools/net/ynl: Add extack policy attribute decoding
  (bsc#1232889).
- devlink: use kvzalloc() to allocate devlink instance resources
  (bsc#1232889).
- octeontx2-af: Increase maximum BPID channels (jsc#PED-11318).
- ice: count representor stats (jsc#PED-9947).
- ice: do switchdev slow-path Rx using PF VSI (jsc#PED-9947).
- ice: change repr::id values (jsc#PED-9947).
- ice: remove switchdev control plane VSI (jsc#PED-9947).
- ice: control default Tx rule in lag (jsc#PED-9947).
- ice: default Tx rule instead of to queue (jsc#PED-9947).
- ice: do Tx through PF netdev in slow-path (jsc#PED-9947).
- ice: remove eswitch changing queues algorithm (jsc#PED-9947).
- qed: Drop useless pci_params.pm_cap (jsc#PED-9962
  jsc#PED-11294).
- doc/netlink/specs: Add vlan attr in rt_link spec (bsc#1232889).
- ynl: support hex display_hint for integer (bsc#1232889).
- crypto: octeontx2 - add missing check for dma_map_single
  (jsc#PED-11318).
- netlink: specs: Add missing bridge linkinfo attrs (bsc#1232889).
- tools: ynl: don't ignore errors in NLMSG_DONE messages
  (bsc#1232889).
- ice: Fix freeing uninitialized pointers (jsc#PED-9947).
- tools: ynl: fix setting presence bits in simple nests
  (bsc#1232889).
- lib/bitmap: Fix bitmap_scatter() and bitmap_gather() kernel doc
  (jsc#PED-9947).
- devlink: fix port new reply cmd type (bsc#1232889).
- tools: ynl: add header guards for nlctrl (bsc#1232889).
- devlink: Fix devlink parallel commands processing (bsc#1232889).
- devlink: Fix length of eswitch inline-mode (bsc#1232889).
- netlink: specs: support generating code for genl socket priv
  (bsc#1232889).
- tools: ynl: remove trailing semicolon (bsc#1232889).
- netlink: specs: support unterminated-ok (bsc#1232889).
- tools: ynl-gen: support using pre-defined values in attr checks
  (bsc#1232889).
- ynl: samples: fix recycling rate calculation (bsc#1232889).
- lib/bitmap: Introduce bitmap_scatter() and bitmap_gather()
  helpers (jsc#PED-9947).
- ice: Implement RSS settings for GTP using ethtool
  (jsc#PED-9947).
- tools: ynl: Fix spelling mistake "Constructred" -> "Constructed"
  (bsc#1232889).
- ionic: keep stats struct local to error handling
  (jsc#PED-11379).
- ionic: better dma-map error handling (jsc#PED-11379).
- ionic: remove unnecessary NULL test (jsc#PED-11379).
- ionic: rearrange ionic_queue for better layout (jsc#PED-11379).
- ionic: rearrange ionic_qcq (jsc#PED-11379).
- ionic: carry idev in ionic_cq struct (jsc#PED-11379).
- ionic: refactor skb building (jsc#PED-11379).
- ionic: fold adminq clean into service routine (jsc#PED-11379).
- ionic: use specialized desc info structs (jsc#PED-11379).
- ionic: remove the cq_info to save more memory (jsc#PED-11379).
- ionic: remove callback pointer from desc_info (jsc#PED-11379).
- ionic: move adminq-notifyq handling to main file
  (jsc#PED-11379).
- ionic: drop q mapping (jsc#PED-11379).
- ionic: remove desc, sg_desc and cmb_desc from desc_info
  (jsc#PED-11379).
- octeontx2-pf: Add TC flower offload support for TCP flags
  (jsc#PED-11318).
- doc/netlink/specs: Add spec for nlctrl netlink family
  (bsc#1232889).
- doc/netlink: Allow empty enum-name in ynl specs (bsc#1232889).
- tools/net/ynl: Add nest-type-value decoding (bsc#1232889).
- tools/net/ynl: Fix c codegen for array-nest (bsc#1232889).
- tools/net/ynl: Report netlink errors without stacktrace
  (bsc#1232889).
- tools/net/ynl: Fix extack decoding for netlink-raw
  (bsc#1232889).
- tools: ynl: check for overflow of constructed messages
  (bsc#1232889).
- tools: ynl: add --dbg-small-recv for easier kernel testing
  (bsc#1232889).
- tools: ynl: support debug printing messages (bsc#1232889).
- tools: ynl: allow setting recv() size (bsc#1232889).
- tools: ynl: move the new line in NlMsg __repr__ (bsc#1232889).
- tools: ynl: remove __pycache__ during clean (bsc#1232889).
- tools: ynl: add distclean to .PHONY in all makefiles
  (bsc#1232889).
- tools: ynl: rename make hardclean -> distclean (bsc#1232889).
- ice: avoid unnecessary devm_ usage (jsc#PED-9947).
- ice: do not disable Tx queues twice in ice_down()
  (jsc#PED-9947).
- ice: cleanup line splitting for context set functions
  (jsc#PED-9947).
- ice: use GENMASK instead of BIT(n) - 1 in pack functions
  (jsc#PED-9947).
- ice: rename ice_write_* functions to ice_pack_ctx_*
  (jsc#PED-9947).
- ice: remove vf->lan_vsi_num field (jsc#PED-9947).
- ice: remove unnecessary duplicate checks for VF VSI ID
  (jsc#PED-9947).
- ice: pass VSI pointer into ice_vc_isvalid_q_id (jsc#PED-9947).
- Octeontx2-af: Fix an issue in firmware shared data reserved
  space (jsc#PED-11318).
- ionic: change MODULE_AUTHOR to person name (jsc#PED-11379).
- ionic: Clean RCT ordering issues (jsc#PED-11379).
- ionic: Use CQE profile for dim (jsc#PED-11379).
- ionic: change the hwstamp likely check (jsc#PED-11379).
- ionic: reduce the use of netdev (jsc#PED-11379).
- ionic: Pass local netdev instead of referencing struct
  (jsc#PED-11379).
- ionic: Check stop no restart (jsc#PED-11379).
- ionic: Clean up BQL logic (jsc#PED-11379).
- ionic: Make use napi_consume_skb (jsc#PED-11379).
- ionic: Shorten a Tx hotpath (jsc#PED-11379).
- ionic: Change default number of descriptors for Tx and Rx
  (jsc#PED-11379).
- ionic: Rework Tx start/stop flow (jsc#PED-11379).
- tools: ynl: use MSG_DONTWAIT for getting notifications
  (bsc#1232889).
- tools: ynl: remove the libmnl dependency (bsc#1232889).
- tools: ynl: stop using mnl socket helpers (bsc#1232889).
- tools: ynl: switch away from MNL_CB_* (bsc#1232889).
- tools: ynl: switch away from mnl_cb_t (bsc#1232889).
- tools: ynl: stop using mnl_cb_run2() (bsc#1232889).
- tools: ynl: use ynl_sock_read_msgs() for ACK handling
  (bsc#1232889).
- tools: ynl: wrap recv() + mnl_cb_run2() into a single helper
  (bsc#1232889).
- tools: ynl-gen: remove unused parse code (bsc#1232889).
- tools: ynl: make yarg the first member of struct ynl_dump_state
  (bsc#1232889).
- tools: ynl: create local ARRAY_SIZE() helper (bsc#1232889).
- tools: ynl: create local nlmsg access helpers (bsc#1232889).
- tools: ynl: create local for_each helpers (bsc#1232889).
- tools: ynl: create local attribute helpers (bsc#1232889).
- tools: ynl: give up on libmnl for auto-ints (bsc#1232889).
- tools: ynl: protect from old OvS headers (bsc#1232889).
- tools: ynl: fix header guards (bsc#1232889).
- tools: ynl: allow user to pass enum string instead of scalar
  value (bsc#1232889).
- tools: ynl: process all scalar types encoding in single elif
  statement (bsc#1232889).
- tools: ynl: allow user to specify flag attr with bool values
  (bsc#1232889).
- tools: ynl: don't access uninitialized attr_space variable
  (bsc#1232889).
- ionic: implement xdp frags support (jsc#PED-11379).
- ionic: add ndo_xdp_xmit (jsc#PED-11379).
- ionic: Add XDP_REDIRECT support (jsc#PED-11379).
- ionic: Add XDP_TX support (jsc#PED-11379).
- ionic: Add XDP packet headroom (jsc#PED-11379).
- ionic: add initial framework for XDP support (jsc#PED-11379).
- ionic: use dma range APIs (jsc#PED-11379).
- ionic: add helpers for accessing buffer info (jsc#PED-11379).
- Octeontx2-af: Fetch MAC channel info from firmware
  (jsc#PED-11318).
- ice: Fix debugfs with devlink reload (jsc#PED-9947).
- ice: Remove and readd netdev during devlink reload
  (jsc#PED-9947).
- ice: add support for 3k signing DDP sections for E825C
  (jsc#PED-9947).
- ice: Add helper function ice_is_generic_mac (jsc#PED-9947).
- ice: introduce new E825C devices family (jsc#PED-9947).
- tools: ynl: add support for encoding multi-attr (bsc#1232889).
- doc: netlink: specs: tc: add multi-attr to tc-taprio-sched-entry
  (bsc#1232889).
- tools: ynl: correct typo and docstring (bsc#1232889).
- ice: remove incorrect comment (jsc#PED-9947).
- ice: make ice_vsi_cfg_rxq() static (jsc#PED-9947).
- tools: ynl: auto-gen for all genetlink families (bsc#1232889).
- tools: ynl: generate code for ovs families (bsc#1232889).
- tools: ynl: include dpll and mptcp_pm in C codegen
  (bsc#1232889).
- octeontx2-af: Cleanup loopback device checks (jsc#PED-11318).
- octeontx2-af: Create BPIDs free pool (jsc#PED-11318).
- dpll: extend lock_status_get() op by status error and expose
  to user (jsc#PED-9947).
- dpll: extend uapi by lock status error attribute (jsc#PED-9947).
- doc/netlink/specs: Update the tc spec (bsc#1232889).
- tools/net/ynl: Add type info to struct members in generated docs
  (bsc#1232889).
- tools/net/ynl: Add support for nested structs (bsc#1232889).
- tools/net/ynl: Move formatted_string method out of NlAttr
  (bsc#1232889).
- tools/net/ynl: Rename _fixed_header_size() to _struct_size()
  (bsc#1232889).
- tools/net/ynl: Combine struct decoding logic in ynl
  (bsc#1232889).
- tools/net/ynl: Encode default values for binary blobs
  (bsc#1232889).
- tools/net/ynl: Add support for encoding sub-messages
  (bsc#1232889).
- tools/net/ynl: Refactor fixed header encoding into separate
  method (bsc#1232889).
- tools/net/ynl: Support sub-messages in nested attribute spaces
  (bsc#1232889).
- tools/net/ynl: Add --output-json arg to ynl cli (bsc#1232889).
- dpll: move xa_erase() call in to match dpll_pin_alloc() error
  path order (jsc#PED-9947).
- ice: stop destroying and reinitalizing Tx tracker during reset
  (jsc#PED-9947).
- ice: factor out ice_ptp_rebuild_owner() (jsc#PED-9947).
- ice: rename ice_ptp_tx_cfg_intr (jsc#PED-9947).
- ice: don't check has_ready_bitmap in E810 functions
  (jsc#PED-9947).
- ice: rename verify_cached to has_ready_bitmap (jsc#PED-9947).
- ice: pass reset type to PTP reset functions (jsc#PED-9947).
- octeontx2-af: Add filter profiles in hardware to extract packet
  headers (jsc#PED-11318).
- bitmap: Define a cleanup function for bitmaps (jsc#PED-9947).
- net: test: Fix printf format specifier in skb_segment kunit test
  (jsc#PED-9947).
- dpll: rely on rcu for netdev_dpll_pin() (jsc#PED-9947).
- devlink: fix port dump cmd type (bsc#1232889).
- devlink: avoid potential loop in
  devlink_rel_nested_in_notify_work() (bsc#1232889).
- doc/netlink/specs: Add missing attr in rt_link spec
  (bsc#1232889).
- devlink: Fix referring to hw_addr attribute during state
  validation (bsc#1232889).
- vlan: skip nested type that is not IFLA_VLAN_QOS_MAPPING
  (jsc#PED-9961).
- net/sched: Remove uapi support for tcindex classifier
  (bsc#1232889).
- net/sched: Remove uapi support for rsvp classifier
  (bsc#1232889).
- Documentation: add pyyaml to requirements.txt (bsc#1232889).
- devlink: extend multicast filtering by port index (bsc#1232889).
- devlink: add a command to set notification filter and use it
  for multicasts (bsc#1232889).
- genetlink: introduce per-sock family private storage
  (bsc#1232889).
- devlink: introduce a helper for netlink multicast send
  (bsc#1232889).
- devlink: send notifications only if there are listeners
  (bsc#1232889).
- devlink: introduce __devl_is_registered() helper and use it
  instead of xa_get_mark() (bsc#1232889).
- devlink: use devl_is_registered() helper instead xa_get_mark()
  (bsc#1232889).
- tools/net/ynl-gen-rst: Remove extra indentation from generated
  docs (bsc#1232889).
- tools/net/ynl-gen-rst: Remove bold from attribute-set headings
  (bsc#1232889).
- tools/net/ynl-gen-rst: Sort the index of generated netlink specs
  (bsc#1232889).
- tools/net/ynl-gen-rst: Add sub-messages to generated docs
  (bsc#1232889).
- doc/netlink/specs: Add a spec for tc (bsc#1232889).
- doc/netlink/specs: use pad in structs in rt_link (bsc#1232889).
- doc/netlink/specs: Add sub-message type to rt_link family
  (bsc#1232889).
- tools/net/ynl: Add binary and pad support to structs for tc
  (bsc#1232889).
- tools/net/ynl: Add 'sub-message' attribute decoding to ynl
  (bsc#1232889).
- doc/netlink: Add sub-message support to netlink-raw
  (bsc#1232889).
- tools/net/ynl: Use consistent array index expression formatting
  (bsc#1232889).
- tools: ynl-gen: print prototypes for recursive stuff
  (bsc#1232889).
- tools: ynl-gen: store recursive nests by a pointer
  (bsc#1232889).
- tools: ynl-gen: re-sort ignoring recursive nests (bsc#1232889).
- tools: ynl-gen: record information about recursive nests
  (bsc#1232889).
- tools: ynl-gen: fill in implementations for TypeUnused
  (bsc#1232889).
- tools: ynl-gen: support fixed headers in genetlink
  (bsc#1232889).
- tools: ynl-gen: use enum user type for members and args
  (bsc#1232889).
- tools: ynl-gen: add missing request free helpers for dumps
  (bsc#1232889).
- netlink: specs: devlink: add some(not all) missing attributes
  in devlink.yaml (bsc#1232889).
- tools: ynl: move private definitions to a separate header
  (bsc#1232889).
- tools: ynl: use strerror() if no extack of note provided
  (bsc#1232889).
- tools: pynl: make flags argument optional for do()
  (bsc#1232889).
- doc/netlink: Add bitfield32, s8, s16 to the netlink-raw schema
  (bsc#1232889).
- docs: netlink: link to family documentations from spec info
  (bsc#1232889).
- tools: ynl: Print xsk-features from the sample (bsc#1232889).
- devlink: warn about existing entities during reload-reinit
  (bsc#1232889).
- tools: ynl: don't skip regeneration from make targets
  (bsc#1232889).
- tools: ynl: order building samples after generated code
  (bsc#1232889).
- selftests: tc-testing: remove buildebpf plugin (bsc#1232889).
- tools: ynl-gen: use enum name from the spec (bsc#1232889).
- tools: ynl-get: use family c-name (bsc#1232889).
- tools: ynl-gen: always append ULL/LL to range types
  (bsc#1232889).
- Documentation: Document each netlink family (bsc#1232889).
- devlink: Add device lock assert in reload operation
  (bsc#1232889).
- devlink: Acquire device lock during reload command
  (bsc#1232889).
- devlink: Allow taking device lock in pre_doit operations
  (bsc#1232889).
- devlink: Enable the use of private flags in post_doit operations
  (bsc#1232889).
- devlink: Acquire device lock during netns dismantle
  (bsc#1232889).
- devlink: Move private netlink flags to C file (bsc#1232889).
- selftests: tc-testing: use parallel tdc in kselftests
  (bsc#1232889).
- selftests: tc-testing: preload all modules in kselftests
  (bsc#1232889).
- refcount: Split out refcount_types.h (jsc#PED-9947).
- crypto: octeontx2 - support setting ctx ilen for inline CPT LF
  (jsc#PED-11318).
- crypto: octeontx2 - register error interrupts for inline cptlf
  (jsc#PED-11318).
- crypto: octeontx2 - add ctx_val workaround (jsc#PED-11318).
- crypto: octeontx2 - update CPT inbound inline IPsec mailbox
  (jsc#PED-11318).
- crypto: octeontx2 - add LF reset on queue disable
  (jsc#PED-11318).
- crypto: octeontx2 - remove errata workaround for CN10KB or
  CN10KA B0 chip (jsc#PED-11318).
- crypto: octeontx2 - add devlink option to set t106 mode
  (jsc#PED-11318).
- crypto: octeontx2 - add SGv2 support for CN10KB or CN10KA B0
  (jsc#PED-11318).
- crypto: octeontx2 - remove CPT block reset (jsc#PED-11318).
- crypto: octeontx2 - By default allocate one CPT LF per CPT VF
  (jsc#PED-11318).
- i40e: Annotate struct i40e_qvlist_info with __counted_by
  (jsc#PED-8904 jsc#PED-9957).
- tools: ynl: fix header path for nfsd (bsc#1232889).
- net: gso_test: support CONFIG_MAX_SKB_FRAGS up to 45
  (jsc#PED-9947).
- nfsd: regenerate user space parsers after ynl-gen changes
  (bsc#1232889).
- bitmap: move bitmap_*_region() functions to bitmap.h
  (jsc#PED-9947).
- bitmap: drop _reg_op() function (jsc#PED-9947).
- bitmap: replace _reg_op(REG_OP_ISFREE) with find_next_bit()
  (jsc#PED-9947).
- bitmap: replace _reg_op(REG_OP_RELEASE) with bitmap_clear()
  (jsc#PED-9947).
- bitmap: replace _reg_op(REG_OP_ALLOC) with bitmap_set()
  (jsc#PED-9947).
- bitmap: fix opencoded bitmap_allocate_region() (jsc#PED-9947).
- bitmap: align __reg_op() wrappers with modern coding style
  (jsc#PED-9947).
- lib/bitmap: split-out string-related operations to a separate
  files (jsc#PED-9947).
- bitmap: Remove dead code, i.e. bitmap_copy_le() (jsc#PED-9947).
- bitmap: Fix a typo ("identify map") (jsc#PED-9947).
- doc/netlink: Update schema to support cmd-cnt-name and
  cmd-max-name (bsc#1232889).
- uapi: mptcp: use header file generated from YAML spec
  (bsc#1232889).
- Documentation: netlink: add a YAML spec for mptcp (bsc#1232889).
- net: mptcp: convert netlink from small_ops to ops (bsc#1232889).
- tools: ynl: add uns-admin-perm to genetlink legacy
  (bsc#1232889).
- net: gso_test: release each segment individually (jsc#PED-9947).
- net: gso_test: fix build with gcc-12 and earlier (jsc#PED-9947).
- net: expand skb_segment unit test with frag_list coverage
  (jsc#PED-9947).
- net: parametrize skb_segment unit test to expand coverage
  (jsc#PED-9947).
- net: add skb_segment kunit test (jsc#PED-9947).
- selftests/tc-testing: update test definitions for local
  resources (bsc#1232889).
- tools: ynl: Add source files for nfsd netlink protocol
  (bsc#1232889).
- NFSD: introduce netlink stubs (bsc#1232889).
- nfsd: add a MODULE_DESCRIPTION (bsc#1232889).
- doc/netlink: Add spec for rt link messages (bsc#1232889).
- tc: flower: support for SPI (bsc#1232889).
- bridge: Add backup nexthop ID support (jsc#PED-9947).
- ip_tunnels: Add nexthop ID field to ip_tunnel_key
  (jsc#PED-9947).
- nfsd: convert to ctime accessor functions (bsc#1232889).
- NFSD: Fix a thinko introduced by recent trace point changes
  (bsc#1232889).
- net: flower: fix stack-out-of-bounds in fl_set_key_cfm()
  (bsc#1232889).
- selftests: tc-testing: add test for qfq with stab overhead
  (bsc#1232889).
- selftests: tc-testing: add tests for qfq mtu sanity check
  (bsc#1232889).
- crypto: octeontx2 - hardware configuration for inline IPsec
  (jsc#PED-11318).
- crypto: octeontx2 - add support for AF to CPT PF uplink mbox
  (jsc#PED-11318).
- selftests: tc-testing: add one test for flushing explicitly
  created chain (bsc#1232889).
- net: flower: add support for matching cfm fields (bsc#1232889).
- crypto: octeontx2: Use alloc_ordered_workqueue() to create
  ordered workqueues (jsc#PED-11318).
- NFSD: Distinguish per-net namespace initialization
  (bsc#1232889).
- NFSD: trace nfsctl operations (bsc#1232889).
- NFSD: Clean up nfsctl_transaction_write() (bsc#1232889).
- NFSD: Clean up nfsctl white-space damage (bsc#1232889).
- commit eea4a9e
* Wed Nov  6 2024 jlee@suse.com
- fbdev: efifb: Register sysfs groups through driver core
  (bsc#1232224 CVE-2024-49925).
- commit 4fd0365
* Wed Nov  6 2024 msuchanek@suse.de
- aes-gcm-p10: Use the correct bit to test for P10 (bsc#1232704).
- commit f0dea0e
* Wed Nov  6 2024 jlee@suse.com
- thermal: gov_bang_bang: Adjust states of all uninitialized
  instances (jsc#PED-11152).
- commit 59c5f05
* Wed Nov  6 2024 mgorman@suse.de
- Update config files.
- commit a0b06d4
* Wed Nov  6 2024 mgorman@suse.de
- MAINTAINERS: Add an entry for PREEMPT_RT (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 10a75a1
* Wed Nov  6 2024 mgorman@suse.de
- arm64: Allow to enable PREEMPT_RT (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 3c417c0
* Wed Nov  6 2024 mgorman@suse.de
- x86: Allow to enable PREEMPT_RT (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 037706c
* Wed Nov  6 2024 mgorman@suse.de
- printk: Avoid false positive lockdep report for legacy printing
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 448ad7e
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Assign nice -20 for printing threads (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 9fb92e2
* Wed Nov  6 2024 mgorman@suse.de
- printk: Implement legacy printer kthread for PREEMPT_RT
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit d6bc470
* Wed Nov  6 2024 mgorman@suse.de
- tty: sysfs: Add nbcon support for 'active' (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 44a0428
* Wed Nov  6 2024 mgorman@suse.de
- proc: Add nbcon support for /proc/consoles (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 80c0dd2
* Wed Nov  6 2024 mgorman@suse.de
- proc: consoles: Add notation to c_start/c_stop (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 75c8aff
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Show replay message on takeover (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 3893df8
* Wed Nov  6 2024 mgorman@suse.de
- printk: Provide helper for message prepending (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 9475799
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Rely on kthreads for normal operation
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit f725896
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Use thread callback if in task context for legacy
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 06a0b3d
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Relocate nbcon_atomic_emit_one() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit eb876e5
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Introduce printer kthreads (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit bc6bf18
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Init @nbcon_seq to highest possible (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 3bc98ef
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Add context to usable() and emit() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit bc93ef0
* Wed Nov  6 2024 mgorman@suse.de
- printk: Flush console on unregister_console() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 56569e3
* Wed Nov  6 2024 mgorman@suse.de
- printk: Fail pr_flush() if before SYSTEM_SCHEDULING (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 216a765
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Add function for printers to reacquire ownership
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit c0bdbdc
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Use raw_cpu_ptr() instead of open coding
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 4d89b18
* Wed Nov  6 2024 mgorman@suse.de
- lockdep: Mark emergency sections in lockdep splats (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit f8fd861
* Wed Nov  6 2024 mgorman@suse.de
- rcu: Mark emergency sections in rcu stalls (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 5499163
* Wed Nov  6 2024 mgorman@suse.de
- panic: Mark emergency section in oops (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 699409b
* Wed Nov  6 2024 mgorman@suse.de
- panic: Mark emergency section in warn (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit bd3cb8a
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Implement emergency sections (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 474f6f3
* Wed Nov  6 2024 mgorman@suse.de
- printk: Add helper for flush type logic (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 7a55e8c
* Wed Nov  6 2024 mgorman@suse.de
- printk: Coordinate direct printing in panic (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 2855df1
* Wed Nov  6 2024 mgorman@suse.de
- printk: Track nbcon consoles (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 22c6fc5
* Wed Nov  6 2024 mgorman@suse.de
- printk: Avoid console_lock dance if no legacy or boot consoles
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 53208dd
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Add unsafe flushing on panic (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit fc10cc5
* Wed Nov  6 2024 mgorman@suse.de
- printk: Flush nbcon consoles first on panic (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 8390354
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Flush new records on device_release()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit d2dda67
* Wed Nov  6 2024 mgorman@suse.de
- printk: Add is_printk_legacy_deferred() (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 0ddcb0a
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Use nbcon consoles in console_flush_all()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 28d2090
* Wed Nov  6 2024 mgorman@suse.de
- printk: Track registered boot consoles (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 414613e
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Provide function to flush using write_atomic()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 8e1d586
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Add helper to assign priority based on CPU state
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 5b568fb
* Wed Nov  6 2024 mgorman@suse.de
- printk: Add @flags argument for console_is_usable() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit db775e2
* Wed Nov  6 2024 mgorman@suse.de
- printk: Let console_is_usable() handle nbcon (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit a37b5dd
* Wed Nov  6 2024 mgorman@suse.de
- printk: Make console_is_usable() available to nbcon.c
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 4d21553
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Do not rely on proxy headers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 02ea148
* Wed Nov  6 2024 mgorman@suse.de
- serial: core: Acquire nbcon context in port->lock wrapper
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 89a6160
* Wed Nov  6 2024 mgorman@suse.de
- nbcon: Add API to acquire context for non-printing operations
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit ab2241d
* Wed Nov  6 2024 mgorman@suse.de
- console: Improve console_srcu_read_flags() comments (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 6089c0b
* Wed Nov  6 2024 mgorman@suse.de
- serial: core: Introduce wrapper to set @uart_port->cons
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 8ca7e63
* Wed Nov  6 2024 mgorman@suse.de
- serial: core: Provide low-level functions to lock port
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 07aa580
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Use driver synchronization while (un)registering
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 677eaf5
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Add callbacks to synchronize with driver
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 755cfba
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Add detailed doc for write_atomic() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit 4af1ba8
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Remove return value for write_atomic()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 0821d4f
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Clarify rules of the owner/waiter matching
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 6bc8894
* Wed Nov  6 2024 mgorman@suse.de
- printk: Check printk_deferred_enter()/_exit() usage (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit 45c15bc
* Wed Nov  6 2024 mgorman@suse.de
- printk: Properly deal with nbcon consoles on seq init
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit efa7bd1
* Wed Nov  6 2024 mgorman@suse.de
- printk: nbcon: Consolidate alloc() and init() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit beaaac9
* Wed Nov  6 2024 mgorman@suse.de
- timers: Rename next_expiry_recalc() to be unique (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit b25c58d
* Wed Nov  6 2024 mgorman@suse.de
- timers: Annotate possible non critical data race of next_expiry
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit f50d89d
* Wed Nov  6 2024 mgorman@suse.de
- timers: Remove historical extra jiffie for timeout in msleep()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit f18d9b1
* Wed Nov  6 2024 mgorman@suse.de
- hrtimer: Annotate hrtimer_cpu_base_.*_expiry() for sparse
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit be10400
* Wed Nov  6 2024 mgorman@suse.de
- timers: Add sparse annotation for timer_sync_wait_running()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit c32d68a
* Wed Nov  6 2024 mgorman@suse.de
- signal: Replace BUG_ON()s (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- commit 61a6f73
* Wed Nov  6 2024 mgorman@suse.de
- signal: Remove task argument from dequeue_signal() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 64e5aeb
* Wed Nov  6 2024 mgorman@suse.de
- zram: Remove ZRAM_LOCK (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- commit 982a3cc
* Wed Nov  6 2024 mgorman@suse.de
- zram: Replace bit spinlocks with a spinlock_t (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 5743aad
* Wed Nov  6 2024 mgorman@suse.de
- udp: fix receiving fraglist GSO packets (git-fixes).
- commit c9a303a
* Wed Nov  6 2024 mgorman@suse.de
- timekeeping: Fix bogus clock_was_set() invocation in
  do_adjtimex() (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 5e975ee
* Wed Nov  6 2024 mgorman@suse.de
- timers/migration: Fix grammar in comment (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit dbb2f50
* Wed Nov  6 2024 mgorman@suse.de
- timers/migration: Spare write when nothing changed (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit ba99376
* Wed Nov  6 2024 mgorman@suse.de
- timers/migration: Rename childmask by groupmask to make naming
  more obvious (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 03dad15
* Wed Nov  6 2024 mgorman@suse.de
- timers/migration: Read childmask and parent pointer in a single
  place (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 6ad2ea1
* Wed Nov  6 2024 mgorman@suse.de
- timers/migration: Improve tracing (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers/migration: Move hierarchy setup into cpuhotplug prepare
  callback (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers/migration: Do not rely always on group->parent
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- printk: Rename console_replay_all() and update context
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 85f4c59
* Tue Nov  5 2024 tbogendoerfer@suse.de
- blacklist.conf: added temporary blacklist
- commit faa6619
* Tue Nov  5 2024 tbogendoerfer@suse.de
- net: dsa: mv88e6xxx: Fix the max_vid definition for the
  MV88E6361 (bsc#1232798).
- net: dsa: microchip: Fix Wake-on-LAN check to not return an
  error (bsc#1232798).
- bnxt_en: Fix the resource check condition for RSS contexts
  (jsc#PED-11221).
- bonding: fix incorrect software timestamping report
  (bsc#1232798).
- igc: Fix Energy Efficient Ethernet support declaration
  (jsc#PED-9944).
- net: phylink: fix sphinx complaint about invalid literal
  (bsc#1232798).
- commit 28882e7
* Tue Nov  5 2024 tbogendoerfer@suse.de
- net: altera_tse: Use the correct Kconfig option for the PCS_LYNX
  dependency (bsc#1232798).
- Update config files.
- commit 2b8ab39
* Tue Nov  5 2024 tbogendoerfer@suse.de
- lan743x: remove redundant statement in lan743x_ethtool_get_eee
  (bsc#1232798).
- commit 88b9d6d
* Tue Nov  5 2024 mgorman@suse.de
- serial: sc16is7xx: hardware reset chip if reset-gpios is
  defined in DT (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 879c35f
* Tue Nov  5 2024 mgorman@suse.de
- lwt: Don't disable migration prio invoking BPF (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit a2603de
* Tue Nov  5 2024 mgorman@suse.de
- dev: Remove PREEMPT_RT ifdefs from backlog_lock.*() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 5104016
* Tue Nov  5 2024 mgorman@suse.de
- rcu/exp: Remove redundant full memory barrier at the end of GP
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit a212379
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Remove full memory barrier on RCU stall printout
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit e54c9f0
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Remove full memory barrier on boot time eqs sanity check
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 4b0927a
* Tue Nov  5 2024 mgorman@suse.de
- rcu/exp: Remove superfluous full memory barrier upon first
  EQS snapshot (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit d6559e9
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Remove superfluous full memory barrier upon first EQS
  snapshot (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 76035ba
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Remove full ordering on second EQS snapshot (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 919a371
* Tue Nov  5 2024 mgorman@suse.de
- serial: sc16is7xx: split into core and I2C/SPI parts
  (sc16is7xx_regcfg) (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- commit 33ed6b9
* Tue Nov  5 2024 mgorman@suse.de
- serial: sc16is7xx: split into core and I2C/SPI parts
  (sc16is7xx_lines) (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- commit d18f836
* Tue Nov  5 2024 mgorman@suse.de
- serial: sc16is7xx: split into core and I2C/SPI parts (core)
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit ead4301
* Tue Nov  5 2024 mgorman@suse.de
- serial: sc16is7xx: unconditionally clear line bit in
  sc16is7xx_remove() (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- commit b92ba52
* Tue Nov  5 2024 tbogendoerfer@suse.de
- net: fill in MODULE_DESCRIPTION()s for PCS drivers
  (bsc#1232798).
- net: altera-tse: make ALTERA_TSE depend on HAS_IOMEM
  (bsc#1232798).
- net: pcs: lynxi: implement pcs_disable op (bsc#1232798).
- net: pcs: lynx: fix lynx_pcs_link_up_sgmii() not doing anything
  in fixed-link mode (bsc#1232798).
- net: phy/pcs: Explicitly include correct DT includes
  (bsc#1232798).
- net: pcs: lynx: update PCS driver to use neg_mode (bsc#1232798).
- net: pcs: lynxi: update PCS driver to use neg_mode
  (bsc#1232798).
- net: dpaa2: use pcs-lynx's check for fwnode availability
  (bsc#1232798).
- net: dpaa2-mac: use lynx_pcs_create_fwnode() (bsc#1232798).
- net: dpaa2-mac: allow lynx PCS to manage mdiodev lifetime
  (bsc#1232798).
- net: dpaa2-mac: use correct interface to free mdiodev
  (bsc#1232798).
- commit c88bae5
* Tue Nov  5 2024 mgorman@suse.de
- tty: serial: sc16is7xx: convert to use maple tree register cache
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 25fd102
* Tue Nov  5 2024 mgorman@suse.de
- serial: sifive: Remove 0 from fu540-c000-uart0 binding
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 17dbee0
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_omap: Remove unused of_gpio.h (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 1531b6c
* Tue Nov  5 2024 mgorman@suse.de
- tty: serial: switch from circ_buf to kfifo (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit b6caab4
* Tue Nov  5 2024 mgorman@suse.de
- tty: msm_serial: use dmaengine_prep_slave_sg() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit a87a3c4
* Tue Nov  5 2024 mgorman@suse.de
- tty: 8250_omap: use dmaengine_prep_slave_sg() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 96d0e6e
* Tue Nov  5 2024 mgorman@suse.de
- tty: 8250_dma: use dmaengine_prep_slave_sg() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 3d8f58c
* Tue Nov  5 2024 mgorman@suse.de
- kfifo: fix typos in kernel-doc (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit ac612a5
* Tue Nov  5 2024 mgorman@suse.de
- kfifo: add kfifo_dma_out_prepare_mapped() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit b5f5d2c
* Tue Nov  5 2024 mgorman@suse.de
- kfifo: pass offset to setup_sgl_buf() instead of a pointer
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 9f471df
* Tue Nov  5 2024 mgorman@suse.de
- kfifo: rename l to len_to_end in setup_sgl() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 80b481e
* Tue Nov  5 2024 mgorman@suse.de
- kfifo: remove support for physically non-contiguous memory
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit d885689
* Tue Nov  5 2024 mgorman@suse.de
- kfifo: add kfifo_out_linear{,_ptr}() (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 91e114a
* Tue Nov  5 2024 mgorman@suse.de
- kfifo: introduce and use kfifo_skip_count() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 5580110
* Tue Nov  5 2024 mgorman@suse.de
- kfifo: drop __kfifo_dma_out_finish_r() (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 42225db
* Tue Nov  5 2024 mgorman@suse.de
- net: Use backlog-NAPI to clean up the defer_list (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit c28092e
* Tue Nov  5 2024 mgorman@suse.de
- net: Allow to use SMP threads for backlog NAPI (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 1e9d150
* Tue Nov  5 2024 mgorman@suse.de
- timerqueue: Remove never used function timerqueue_node_expires()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit eaca60c
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Reduce synchronize_rcu() latency (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit a18e181
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Add data structures for synchronize_rcu() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 7d11293
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Mark loads from rcu_state.n_online_cpus (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 6f0b08c
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Bring diagnostic read of rcu_state.gp_flags into alignment
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 83a9b07
* Tue Nov  5 2024 mgorman@suse.de
- timers/migration: Return early on deactivation (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 79d3e4c
* Tue Nov  5 2024 mgorman@suse.de
- timers/migration: Fix ignored event due to missing CPU update
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 6674e12
* Tue Nov  5 2024 mgorman@suse.de
- timers/migration: Fix endless timer requeue after idle
  interrupts (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 3d03d8b
* Tue Nov  5 2024 mgorman@suse.de
- net: report RCU QS on threaded NAPI repolling (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 6758c5a
* Tue Nov  5 2024 mgorman@suse.de
- rcu: add a helper to report consolidated flavor QS (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit e34b4de
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_omap: Switch to use uart_read_port_properties()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/serial-8250-omap-Cleanup-on-error-in-request_irq.patch
- commit dba0cea
* Tue Nov  5 2024 mgorman@suse.de
- serial: sh-sci: Call sci_serial_{in,out}() directly (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 0dea1f7
* Tue Nov  5 2024 mgorman@suse.de
- serial: pch: Use uart_prepare_sysrq_char() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 617d42d
* Tue Nov  5 2024 mgorman@suse.de
- serial: pch: Remove eg20t_port::lock (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit c0e4b49
* Tue Nov  5 2024 mgorman@suse.de
- serial: sifive: Use uart_prepare_sysrq_char() to handle sysrq
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 692c702
* Tue Nov  5 2024 mgorman@suse.de
- serial: rda: Use uart_prepare_sysrq_char() to handle sysrq
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 6182338
* Tue Nov  5 2024 mgorman@suse.de
- serial: owl: Use uart_prepare_sysrq_char() to handle sysrq
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 8a60d26
* Tue Nov  5 2024 mgorman@suse.de
- serial: lpc32xx_hs: Use uart_prepare_sysrq_char() to handle
  sysrq (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 12de613
* Tue Nov  5 2024 mgorman@suse.de
- serial: sunplus: Use uart_prepare_sysrq_char() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 39e6956
* Tue Nov  5 2024 mgorman@suse.de
- serial: pxa: Use uart_prepare_sysrq_char() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit a466e18
* Tue Nov  5 2024 mgorman@suse.de
- serial: omap: Use uart_prepare_sysrq_char() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit fbbe85c
* Tue Nov  5 2024 mgorman@suse.de
- serial: msm: Use uart_prepare_sysrq_char() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit ce34aa4
* Tue Nov  5 2024 mgorman@suse.de
- serial: meson: Use uart_prepare_sysrq_char() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 6e04dec
* Tue Nov  5 2024 mgorman@suse.de
- serial: bcm63xx: Use uart_prepare_sysrq_char() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 4ad6c0f
* Tue Nov  5 2024 mgorman@suse.de
- serial: ar933x: Use uart_prepare_sysrq_char() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 7181fd7
* Tue Nov  5 2024 mgorman@suse.de
- serial: amba-pl011: Use uart_prepare_sysrq_char() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 4ea564e
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_pci1xxxx: Drop quirk from 8250_port (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 2fd5f8a
* Tue Nov  5 2024 mgorman@suse.de
- serial: lpc32xx_hs: remove redundant check and assignment of
  hsu_rate (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit d9be5a0
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_pci1xxxx: Don't use "proxy" headers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 20d0121
* Tue Nov  5 2024 mgorman@suse.de
- tty: serial: uartps: Add rs485 support to uartps driver
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 2202781
* Tue Nov  5 2024 mgorman@suse.de
- tty: serial: uartps: Relocate cdns_uart_tx_empty to facilitate
  rs485 (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 8c8e33b
* Tue Nov  5 2024 mgorman@suse.de
- 8250: microchip: Add 4 Mbps support in PCI1XXXX UART
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit a21d7af
* Tue Nov  5 2024 mgorman@suse.de
- 8250: microchip: pci1xxxx: Add Burst mode transmission support
  in uart driver for reading from FIFO (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 0818870
* Tue Nov  5 2024 mgorman@suse.de
- serial: max310x: fix indentation (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 3c9fe34
* Tue Nov  5 2024 mgorman@suse.de
- serial: max310x: reformat and improve comments (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 0b690e1
* Tue Nov  5 2024 mgorman@suse.de
- serial: max310x: replace bare use of 'unsigned' with 'unsigned
  int' (checkpatch) (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- commit 6965253
* Tue Nov  5 2024 mgorman@suse.de
- serial: max310x: use common power function for all variants
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 70cc1c1
* Tue Nov  5 2024 mgorman@suse.de
- serial: max310x: use common detect function for all variants
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit f2b1d83
* Tue Nov  5 2024 mgorman@suse.de
- serial: max310x: replace hardcoded masks with preferred
  GENMASK() (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit b29cddf
* Tue Nov  5 2024 mgorman@suse.de
- serial: max310x: use dev_err_probe() instead of dev_err()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit f1a8be8
* Tue Nov  5 2024 mgorman@suse.de
- serial: max310x: add explicit return for some switch default
  cases (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit f478105
* Tue Nov  5 2024 mgorman@suse.de
- serial: max310x: simplify probe() and remove() error handling
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 1a0cd67
* Tue Nov  5 2024 mgorman@suse.de
- serial: max310x: use separate regmap name for each port
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit ad4ca85
* Tue Nov  5 2024 mgorman@suse.de
- serial: max310x: add macro for max number of ports (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 16ce31e
* Tue Nov  5 2024 mgorman@suse.de
- serial: max310x: remove holes in struct max310x_devtype
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 867be29
* Tue Nov  5 2024 mgorman@suse.de
- serial: max310x: use spi_get_device_match_data() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 1b00860
* Tue Nov  5 2024 mgorman@suse.de
- serial: max310x: use i2c_get_match_data() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 057831d
* Tue Nov  5 2024 mgorman@suse.de
- serial: max310x: add I2C device table for instantiation from
  userspace (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 7bbc631
* Tue Nov  5 2024 mgorman@suse.de
- vt: remove superfluous CONFIG_HW_CONSOLE (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 0ebaabc
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: fix up kernel-doc (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- commit 4e1605d
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: document the rest of struct consw (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit f604d2a
* Tue Nov  5 2024 krisman@suse.de
- ublk: don't allow user copy for unprivileged device
  (CVE-2024-50080 bsc#1232502).
- commit 267c92f
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: remove unused consw::con_flush_scrollback()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 4c89a9a
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: remove consw::con_getxy() (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit ef1219e
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: remove consw::con_screen_pos() (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 224da66
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: change consw::con_set_origin() return type (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit bbf3c80
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: make consw::con_font_default()'s name const
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit ef8196c
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: make font of consw::con_font_set() const (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 28bc288
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: make types around consw::con_blank() bool (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 3186479
* Tue Nov  5 2024 krisman@suse.de
- blk-mq: setup queue ->tag_set before initializing hctx
  (CVE-2024-50081 bsc#1232501).
- commit 87d4a82
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: use enum constants for VESA blanking modes (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 1a70d24
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: use VESA blanking constants (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 719699b
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: define a common enum for VESA blanking constants
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 39b3834
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: stop using -1 for blank mode in consw::con_blank()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 703c048
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: make consw::con_switch() return a bool (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit adddfbb
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: remove CM_* constants (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 27f40bf
* Tue Nov  5 2024 mgorman@suse.de
- consoles: use if instead of switch-case in consw::con_cursor()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 38d35f7
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: sanitize consw::con_putcs() parameters (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 1da0909
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: sanitize consw::con_putc() parameters (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 2e88a3d
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: eliminate unneeded consw::con_putc() implementations
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 842c47b
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: add con_putc() helper (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit bbdd300
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: remove checks for count in consw::con_clear()
  implementations (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- commit 2faac95
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: sanitize arguments of consw::con_clear() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 9216631
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: make init parameter of consw::con_init() a bool
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 55b755c
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: make consw::con_debug_*() return void (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 3fa6834
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: define an enum for ascii characters (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 8f34d31
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: reflow csi_K() (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- commit 090b112
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: define an enum for CSI+K codes (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 7d164ca
* Tue Nov  5 2024 mgorman@suse.de
- don't pass vc->vc_par[0] to csi_?() handlers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 17ddd53
* Tue Nov  5 2024 mgorman@suse.de
- use clamp() for counts in csi_?() handlers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 718806a
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: reflow csi_J() (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- commit 0754394
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: define an enum for CSI+J codes (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 825ad9b
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: use case ranges for CSI+m fg/bg colors (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 6debb6c
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: define an enum for CSI+m codes (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 2ef3568
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: pass vc_resize_user as a parameter (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit be60ebf
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: push console lock from tioclinux() down to 2 functions
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 5dbf187
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: pass proper pointers from tioclinux() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit ff9f535
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: expect valid vc when in tty ops (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 91f1109
* Tue Nov  5 2024 mgorman@suse.de
- timer/migration: Remove buggy early return on deactivation
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 7e2d628
* Tue Nov  5 2024 mgorman@suse.de
- ice: make ice_vsi_cfg_rxq() static (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
  ice: make ice_vsi_cfg_txq() static (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 65d50ac
* Tue Nov  5 2024 mgorman@suse.de
- net: dst: Make dst_destroy() static and return void (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit b6e889b
* Tue Nov  5 2024 mgorman@suse.de
- string: Redefine strscpy_pad() as a macro (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/string-Allow-2-argument-strscpy.patch
- commit 384aaf0
* Tue Nov  5 2024 mgorman@suse.de
- sched/idle: Conditionally handle tick broadcast in
  default_idle_call() (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- commit 7b2fcd3
* Tue Nov  5 2024 mgorman@suse.de
- timer/migration: Fix quick check reporting late expiry
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 85694ad
* Tue Nov  5 2024 mgorman@suse.de
- tick/sched: Don't clear ts::next_tick again in
  can_stop_idle_tick() (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- commit afbf0e3
* Tue Nov  5 2024 mgorman@suse.de
- tick/sched: Rename tick_nohz_stop_sched_tick()
  to tick_nohz_full_stop_tick() (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit b11efdf
* Tue Nov  5 2024 mgorman@suse.de
- tick: Use IS_ENABLED() whenever possible (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit cf95d79
* Tue Nov  5 2024 mgorman@suse.de
- tick/sched: Remove useless oneshot ifdeffery (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 3c3b1a0
* Tue Nov  5 2024 mgorman@suse.de
- tick/nohz: Remove duplicate between lowres and highres handlers
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit ad15589
* Tue Nov  5 2024 mgorman@suse.de
- tick/nohz: Remove duplicate between tick_nohz_switch_to_nohz()
  and tick_setup_sched_timer() (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 3a37547
* Tue Nov  5 2024 mgorman@suse.de
- timers: Always queue timers on the local CPU (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 1aae8b4
* Tue Nov  5 2024 mgorman@suse.de
- timer_migration: Add tracepoints (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit e73bc43
* Tue Nov  5 2024 mgorman@suse.de
- timers: Implement the hierarchical pull model (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit d0b8074
* Tue Nov  5 2024 mgorman@suse.de
- timers: Introduce function to check timer base is_idle flag
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 1d89d12
* Tue Nov  5 2024 mgorman@suse.de
- tick/sched: Split out jiffies update helper function
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 5f13454
* Tue Nov  5 2024 mgorman@suse.de
- timers: Check if timers base is handled already (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit af6b4eb
* Tue Nov  5 2024 mgorman@suse.de
- timers: Restructure internal locking (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 075a8ee
* Tue Nov  5 2024 mgorman@suse.de
- timers: Add get next timer interrupt functionality for remote
  CPUs (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 70a3155
* Tue Nov  5 2024 mgorman@suse.de
- timers: Split out "get next timer interrupt" functionality
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit e9b24d7
* Tue Nov  5 2024 mgorman@suse.de
- timers: Retrieve next expiry of pinned/non-pinned timers
  separately (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 23ef51c
* Tue Nov  5 2024 mgorman@suse.de
- timers: Keep the pinned timers separate from the others
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 90e846f
* Tue Nov  5 2024 mgorman@suse.de
- timers: Split next timer interrupt logic (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 3cc4748
* Tue Nov  5 2024 mgorman@suse.de
- timers: Simplify code in run_local_timers() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 6801ca4
* Tue Nov  5 2024 mgorman@suse.de
- timers: Make sure TIMER_PINNED flag is set in add_timer_on()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 46fe0eb
* Tue Nov  5 2024 mgorman@suse.de
- workqueue: Use global variant for add_timer() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 7c609df
* Tue Nov  5 2024 mgorman@suse.de
- timers: Introduce add_timer() variants which modify timer flags
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 8c85aa5
* Tue Nov  5 2024 mgorman@suse.de
- timers: Optimization for timer_base_try_to_set_idle()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit b23c21c
* Tue Nov  5 2024 mgorman@suse.de
- timers: Move marking timer bases idle into tick_nohz_stop_tick()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 6a57bf2
* Tue Nov  5 2024 mgorman@suse.de
- timers: Split out get next timer interrupt (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 972ab5d
* Tue Nov  5 2024 mgorman@suse.de
- timers: Restructure get_next_timer_interrupt() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 5c16b31
* Tue Nov  5 2024 mgorman@suse.de
- timers: Add struct member description for timer_base
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit a2ece1d
* Tue Nov  5 2024 mgorman@suse.de
- tick/sched: Add function description for tick_nohz_next_event()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 877a2f2
* Tue Nov  5 2024 mgorman@suse.de
- rcu/exp: Remove rcu_par_gp_wq (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit e7240a0
* Tue Nov  5 2024 mgorman@suse.de
- rcu/exp: Handle parallel exp gp kworkers affinity (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 0e1b8ae
* Tue Nov  5 2024 mgorman@suse.de
- rcu/exp: Make parallel exp gp kworker per rcu node (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 35fb22b
* Tue Nov  5 2024 mgorman@suse.de
- rcu/exp: Move expedited kthread worker creation functions above
  rcutree_prepare_cpu() (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- commit acf41bb
* Tue Nov  5 2024 mgorman@suse.de
- rcu: s/boost_kthread_mutex/kthread_mutex (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 039f0ca
* Tue Nov  5 2024 mgorman@suse.de
- rcu/exp: Handle RCU expedited grace period kworker allocation
  failure (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 7474f0a
* Tue Nov  5 2024 mgorman@suse.de
- rcu/exp: Fix RCU expedited parallel grace period kworker
  allocation failure recovery (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 2439f2d
* Tue Nov  5 2024 mgorman@suse.de
- rcu/exp: Remove full barrier upon main thread wakeup
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit fc6b808
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_pci1xxxx: partially revert off by one patch
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 71dc2d4
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_pci1xxxx: fix off by one in
  pci1xxxx_process_read_data() (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit aae0995
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Defer RCU kthreads wakeup when CPU is dying (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit b302879
* Tue Nov  5 2024 mgorman@suse.de
- serial: sc16is7xx: refactor EFR lock (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- Refresh
  patches.suse/serial-sc16is7xx-fix-bug-in-sc16is7xx_set_baud-when-.patch
  patches.suse/serial-sc16is7xx-fix-TX-fifo-corruption.patch
  patches.suse/serial-sc16is7xx-fix-invalid-FIFO-access-with-specia.patch
- commit 8305402
* Tue Nov  5 2024 mgorman@suse.de
- serial: sc16is7xx: reorder code to remove prototype declarations
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 13056c5
* Tue Nov  5 2024 mgorman@suse.de
- serial: sc16is7xx: drop unneeded MODULE_ALIAS (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 161f2e7
* Tue Nov  5 2024 mgorman@suse.de
- serial: sc16is7xx: replace hardcoded divisor value with BIT()
  macro (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/serial-sc16is7xx-fix-bug-in-sc16is7xx_set_baud-when-.patch
- commit c50bc77
* Tue Nov  5 2024 mgorman@suse.de
- serial: sc16is7xx: add explicit return for some switch default
  cases (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit f046a97
* Tue Nov  5 2024 mgorman@suse.de
- serial: sc16is7xx: add macro for max number of UART ports
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 8a41805
* Tue Nov  5 2024 mgorman@suse.de
- serial: sc16is7xx: add driver name to struct uart_driver
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 3abe1c2
* Tue Nov  5 2024 mgorman@suse.de
- serial: sc16is7xx: use i2c_get_match_data() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 7045cee
* Tue Nov  5 2024 mgorman@suse.de
- serial: sc16is7xx: use spi_get_device_match_data() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 488ace2
* Tue Nov  5 2024 mgorman@suse.de
- serial: sc16is7xx: use DECLARE_BITMAP for sc16is7xx_lines
  bitfield (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 9be94cf
* Tue Nov  5 2024 mgorman@suse.de
- 8250: microchip: pci1xxxx: Add Burst mode reception support
  in uart driver for writing into FIFO (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit f6cbc6a
* Tue Nov  5 2024 mgorman@suse.de
- 8250: microchip: pci1xxxx: Add Syslock support for reading
  UART system registers (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- commit 53e55a3
* Tue Nov  5 2024 mgorman@suse.de
- 8250: microchip: pci1xxxx: Rearranging the structure
  declarations (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 1c55db9
* Tue Nov  5 2024 mgorman@suse.de
- tty: serial: kgdboc: Fix 8250_* kgdb over serial (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit e2d008e
* Tue Nov  5 2024 mgorman@suse.de
- tty: serial: Add RS422 flag to struct serial_rs485 (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 91794a7
* Tue Nov  5 2024 mgorman@suse.de
- tty: serial: Cleanup the bit shift with macro (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit cf9410c
* Tue Nov  5 2024 mgorman@suse.de
- serial: core: Clean up uart_update_timeout() function
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 16db2c1
* Tue Nov  5 2024 mgorman@suse.de
- tty: serial: amba-pl011: factor QDF2400 SoC erratum 44 out of
  probe (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit a7c35f5
* Tue Nov  5 2024 mgorman@suse.de
- tty: serial: amba-pl011: unindent pl011_console_get_options
  function body (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 1bf8847
* Tue Nov  5 2024 mgorman@suse.de
- tty: serial: amba-pl011: fix miscellaneous checkpatch warnings
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit dbaf6e7
* Tue Nov  5 2024 mgorman@suse.de
- tty: serial: amba-pl011: fix formatting of conditions
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 573815d
* Tue Nov  5 2024 mgorman@suse.de
- tty: serial: amba-pl011: avoid quoted string split across lines
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 48823c2
* Tue Nov  5 2024 mgorman@suse.de
- tty: serial: amba-pl011: replace TIOCMBIT macros by static
  functions (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 5e9c693
* Tue Nov  5 2024 mgorman@suse.de
- tty: serial: amba-pl011: fix whitespace formatting (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit ff45197
* Tue Nov  5 2024 mgorman@suse.de
- tty: make tty_operations::send_xchar accept u8 char (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/tty-add-the-option-to-have-a-tty-reject-a-new-ldisc.patch
- commit 614effb
* Tue Nov  5 2024 mgorman@suse.de
- serial: msm: Use OPP table for DVFS support (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 6d11c9a
* Tue Nov  5 2024 mgorman@suse.de
- serial: ucc_uart: Fix multiple address space type errors
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit a777baa
* Tue Nov  5 2024 mgorman@suse.de
- tty: fix tty_operations types in documentation (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 988f0b0
* Tue Nov  5 2024 mgorman@suse.de
- serial: max310x: change confusing comment about Tx FIFO
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit c308963
* Tue Nov  5 2024 mgorman@suse.de
- serial: sc16is7xx: change confusing comment about Tx FIFO
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit b5d1e0c
* Tue Nov  5 2024 mgorman@suse.de
- serial: core: Move tty and serdev to be children of serial core
  port device (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit fffe82c
* Tue Nov  5 2024 mgorman@suse.de
- serial: xilinx_uartps: Fix kernel doc about .remove()'s return
  code (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 44368ea
* Tue Nov  5 2024 mgorman@suse.de
- serial: sh-sci: convert not to use dma_request_slave_channel()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit f01dd0e
* Tue Nov  5 2024 mgorman@suse.de
- serial: amba-pl011: convert not to use
  dma_request_slave_channel() (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 6c654d8
* Tue Nov  5 2024 mgorman@suse.de
- serial: sifive: Declare PM operations as static (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 58c5844
* Tue Nov  5 2024 mgorman@suse.de
- serial: xilinx_uartps: Convert to platform remove callback
  returning void (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- commit c49bdcf
* Tue Nov  5 2024 mgorman@suse.de
- serial: ucc: Convert to platform remove callback returning void
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 4233cab
* Tue Nov  5 2024 mgorman@suse.de
- serial: sunplus: Convert to platform remove callback returning
  void (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 4fb25b8
* Tue Nov  5 2024 mgorman@suse.de
- serial: sifive: Convert to platform remove callback returning
  void (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 7c31b10
* Tue Nov  5 2024 mgorman@suse.de
- serial: sh-sci: Convert to platform remove callback returning
  void (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit b2c7567
* Tue Nov  5 2024 mgorman@suse.de
- serial: rda: Convert to platform remove callback returning void
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit dac38bb
* Tue Nov  5 2024 mgorman@suse.de
- serial: owl: Convert to platform remove callback returning void
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 95d85f8
* Tue Nov  5 2024 mgorman@suse.de
- serial: omap: Convert to platform remove callback returning void
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit b946139
* Tue Nov  5 2024 mgorman@suse.de
- serial: msm: Convert to platform remove callback returning void
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 0f81583
* Tue Nov  5 2024 mgorman@suse.de
- serial: meson: Convert to platform remove callback returning
  void (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit f75f006
* Tue Nov  5 2024 mgorman@suse.de
- serial: lpc32xx_hs: Convert to platform remove callback
  returning void (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- commit 0a7aee6
* Tue Nov  5 2024 mgorman@suse.de
- serial: bcm63xx: Convert to platform remove callback returning
  void (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit f6e25cb
* Tue Nov  5 2024 mgorman@suse.de
- serial: ar933x: Convert to platform remove callback returning
  void (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit c560339
* Tue Nov  5 2024 mgorman@suse.de
- serial: amba-pl011: Convert to platform remove callback
  returning void (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- commit 95306aa
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250: Convert to platform remove callback returning void
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 8615e12
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Force quiescent states only for ongoing grace period
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 93fa86f
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Restrict access to RCU CPU stall notifiers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 5268ef9
* Tue Nov  5 2024 mgorman@suse.de
- timers: Fix nextevt calculation when no timers are pending
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 33a923f
* Tue Nov  5 2024 mgorman@suse.de
- timers: Rework idle logic (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- commit fb23b64
* Tue Nov  5 2024 mgorman@suse.de
- timers: Use already existing function for forwarding timer base
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit c90a4ea
* Tue Nov  5 2024 mgorman@suse.de
- timers: Split out forward timer base functionality (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit cc6cffc
* Tue Nov  5 2024 mgorman@suse.de
- timers: Clarify check in forward_timer_base() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 82ad57a
* Tue Nov  5 2024 mgorman@suse.de
- timers: Move store of next event into __next_timer_interrupt()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 7562daf
* Tue Nov  5 2024 mgorman@suse.de
- timers: Do not IPI for deferrable timers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 06593e0
* Tue Nov  5 2024 mgorman@suse.de
- tracing/timers: Add tracepoint for tracking timer base is_idle
  flag (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 5f225d2
* Tue Nov  5 2024 mgorman@suse.de
- tracing/timers: Enhance timer_start tracepoint (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit c3a72af
* Tue Nov  5 2024 mgorman@suse.de
- tick-sched: Warn when next tick seems to be in the past
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit efcdbf2
* Tue Nov  5 2024 mgorman@suse.de
- tick/sched: Cleanup confusing variables (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit ea0dc5d
* Tue Nov  5 2024 mgorman@suse.de
- tick-sched: Fix function names in comments (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 399afb5
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Introduce rcu_cpu_online() (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 2d59f48
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Break rcu_node_0 --> &rq->__lock order (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 94da1de
* Tue Nov  5 2024 mgorman@suse.de
- kernel.h: Move ARRAY_SIZE() to a separate header (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/string-Allow-2-argument-strscpy.patch
- commit 6ab043e
* Tue Nov  5 2024 mgorman@suse.de
- serdev: Replace custom code with device_match_acpi_handle()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit a44bc9a
* Tue Nov  5 2024 mgorman@suse.de
- serdev: Simplify devm_serdev_device_open() function (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit fc6c650
* Tue Nov  5 2024 mgorman@suse.de
- serdev: Make use of device_set_node() (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit cac7e6e
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_omap: Set the console genpd always on if no console
  suspend (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/serial-8250_omap-Implementation-of-Errata-i2310.patch
- commit d320989
* Tue Nov  5 2024 mgorman@suse.de
- serial: core: tidy invalid baudrate handling in
  uart_get_baud_rate (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- commit c6ef6b5
* Tue Nov  5 2024 mgorman@suse.de
- serial: xilinx_uartps: unset STOPBRK when setting STARTBRK
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit e0711c5
* Tue Nov  5 2024 mgorman@suse.de
- serial: max310x: remove trailing whitespaces (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit eda01a7
* Tue Nov  5 2024 mgorman@suse.de
- tty: serial: meson: Add a earlycon for the S4 SoC (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 57ba312
* Tue Nov  5 2024 mgorman@suse.de
- serial: initialize retinfo in uart_get_info() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit eb99b03
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_bcm7271: Use devm_clk_get_optional_enabled()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 7f6c908
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: make vtconsole_class constant (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit b0135ff
* Tue Nov  5 2024 mgorman@suse.de
- tty: Restrict access to TIOCLINUX' copy-and-paste subcommands
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 2376bb1
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_omap: Drop pm_runtime_irq_safe() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 281717c
* Tue Nov  5 2024 mgorman@suse.de
- serial: sc16is7xx: use device_property APIs when configuring
  irda mode (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 1295bd9
* Tue Nov  5 2024 mgorman@suse.de
- serial: amba-pl011: Do not complain when DMA is absent
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit ab257b6
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_pci1xxxx: Annotate struct pci1xxxx_8250 with
  __counted_by (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 6ff9f26
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_dw: Use devm_clk_get_optional_enabled()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 10fb2e7
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_of: Use devm_clk_get_enabled() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 1efd9dd
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_aspeed_vuart: Use devm_clk_get_enabled()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 3b9b4cb
* Tue Nov  5 2024 mgorman@suse.de
- tty: stop using ndash in kernel-doc (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 632eeb0
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_bcm7271: Use dev_err_probe() instead of dev_err()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 637c05e
* Tue Nov  5 2024 mgorman@suse.de
- serial: xilinx_uartps: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit d4f1d6e
* Tue Nov  5 2024 mgorman@suse.de
- serial: vt8500: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit c95dff3
* Tue Nov  5 2024 mgorman@suse.de
- serial: ucc_uart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit cbc609f
* Tue Nov  5 2024 mgorman@suse.de
- serial: uartlite: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 3128977
* Tue Nov  5 2024 mgorman@suse.de
- serial: timbuart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 0ffce35
* Tue Nov  5 2024 mgorman@suse.de
- serial: sunzilog: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 01970bf
* Tue Nov  5 2024 mgorman@suse.de
- serial: sunsu: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 3c05cbb
* Tue Nov  5 2024 mgorman@suse.de
- serial: sunsab: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit f34279c
* Tue Nov  5 2024 mgorman@suse.de
- serial: sunplus-uart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 85173a7
* Tue Nov  5 2024 mgorman@suse.de
- serial: sunhv: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 9529b99
* Tue Nov  5 2024 mgorman@suse.de
- serial: stm32: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 740f3db
* Tue Nov  5 2024 mgorman@suse.de
- serial: st-asc: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 7f2f3bd
* Tue Nov  5 2024 mgorman@suse.de
- serial: sprd: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit cd97e73
* Tue Nov  5 2024 mgorman@suse.de
- serial: sifive: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 773ba3c
* Tue Nov  5 2024 mgorman@suse.de
- serial: sh-sci: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 01b3bb9
* Tue Nov  5 2024 mgorman@suse.de
- serial: txx9: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 2313bce
* Tue Nov  5 2024 mgorman@suse.de
- serial: mctrl_gpio: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit afc450a
* Tue Nov  5 2024 mgorman@suse.de
- serial: tegra: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit e5b11a7
* Tue Nov  5 2024 mgorman@suse.de
- serial: sb1250-duart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 2be69fb
* Tue Nov  5 2024 mgorman@suse.de
- serial: samsung_tty: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit be514a1
* Tue Nov  5 2024 mgorman@suse.de
- serial: sa1100: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit f404ae3
* Tue Nov  5 2024 mgorman@suse.de
- serial: rp2: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 524ff63
* Tue Nov  5 2024 mgorman@suse.de
- serial: rda: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 22db63a
* Tue Nov  5 2024 mgorman@suse.de
- serial: qcom-geni: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit b4a45bd
* Tue Nov  5 2024 mgorman@suse.de
- serial: pxa: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 755a58d
* Tue Nov  5 2024 mgorman@suse.de
- serial: pmac_zilog: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit f2a37a7
* Tue Nov  5 2024 mgorman@suse.de
- serial: pic32: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit f1e3bca
* Tue Nov  5 2024 mgorman@suse.de
- serial: pch: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 2f18999
* Tue Nov  5 2024 mgorman@suse.de
- serial: owl: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit bb6987c
* Tue Nov  5 2024 mgorman@suse.de
- serial: omap: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 22d2ad3
* Tue Nov  5 2024 mgorman@suse.de
- serial: mvebu-uart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit cd10d87
* Tue Nov  5 2024 mgorman@suse.de
- serial: msm: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit b2332fe
* Tue Nov  5 2024 mgorman@suse.de
- serial: mps2-uart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 628c990
* Tue Nov  5 2024 mgorman@suse.de
- serial: mpc52xx: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit e8ecd0a
* Tue Nov  5 2024 mgorman@suse.de
- serial: milbeaut_usio: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 1207fbf
* Tue Nov  5 2024 mgorman@suse.de
- serial: meson: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 65147d7
* Tue Nov  5 2024 mgorman@suse.de
- serial: men_z135_uart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit f57437f
* Tue Nov  5 2024 mgorman@suse.de
- serial: mcf: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 0f28260
* Tue Nov  5 2024 mgorman@suse.de
- serial: lpc32xx_hs: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 37ea87b
* Tue Nov  5 2024 mgorman@suse.de
- serial: liteuart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 53ce23a
* Tue Nov  5 2024 mgorman@suse.de
- serial: jsm: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit d3dd56d
* Tue Nov  5 2024 mgorman@suse.de
- serial: ip22zilog: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit ed0890e
* Tue Nov  5 2024 mgorman@suse.de
- serial: imx: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 3c7d497
* Tue Nov  5 2024 mgorman@suse.de
- serial: icom: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 8550d67
* Tue Nov  5 2024 mgorman@suse.de
- serial: fsl_lpuart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 760ecb2
* Tue Nov  5 2024 mgorman@suse.de
- serial: linflexuart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 8529e22
* Tue Nov  5 2024 mgorman@suse.de
- serial: dz: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 2ff8030
* Tue Nov  5 2024 mgorman@suse.de
- serial: digicolor: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 9cd2f93
* Tue Nov  5 2024 mgorman@suse.de
- serial: bcm63xx-uart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit bfb3847
* Tue Nov  5 2024 mgorman@suse.de
- serial: atmel: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 248f897
* Tue Nov  5 2024 mgorman@suse.de
- serial: arc_uart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 2e652b8
* Tue Nov  5 2024 mgorman@suse.de
- serial: ar933x: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 6d6d6bf
* Tue Nov  5 2024 mgorman@suse.de
- serial: apb: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit cd072e6
* Tue Nov  5 2024 mgorman@suse.de
- serial: amba-pl011: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/ARM-PL011-Fix-DMA-support.patch
- commit 33deeef
* Tue Nov  5 2024 mgorman@suse.de
- serial: amba-pl010: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit e601cf6
* Tue Nov  5 2024 mgorman@suse.de
- serial: altera_uart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 92e5556
* Tue Nov  5 2024 mgorman@suse.de
- serial: altera_jtaguart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 14717b8
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_pci1xxxx: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit aed70d2
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_omap: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 2051b14
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_mtk: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 75b15b3
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_fsl: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 1ac2f0d
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_exar: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 261d6b1
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_dw: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 359a453
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_dma: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 5c532bc
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit bdf000d
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_bcm7271: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit b77ce83
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_aspeed_vuart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 3a88ed4
* Tue Nov  5 2024 mgorman@suse.de
- serial: 21285: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit aebc22e
* Tue Nov  5 2024 mgorman@suse.de
- serial: sc16is7xx: improve comments about variants (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 74c0495
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_of: Use dev_err_probe() instead of dev_warn()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 33a0933
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_aspeed_vuart: Use dev_err_probe() instead of
  dev_err() (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 9480921
* Tue Nov  5 2024 mgorman@suse.de
- serial: sc16is7xx: remove unused to_sc16is7xx_port macro
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
  Refresh
  - patches.suse/serial-sc16is7xx-improve-regmap-debugfs-by-using-one.patch
- commit b9d89cc
* Tue Nov  5 2024 mgorman@suse.de
- extract and use FILE_LINE macro (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 024d8a5
* Tue Nov  5 2024 mgorman@suse.de
- rcu/tree: Defer setting of jiffies during stall reset
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 5da3a76
* Tue Nov  5 2024 mgorman@suse.de
- rcutorture: Add test of RCU CPU stall notifiers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit a66991b
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Add RCU CPU stall notifier (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 1f30ce4
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Eliminate check_cpu_stall() duplicate code (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 383a134
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Don't redump the stalled CPU where RCU GP kthread last ran
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit a3fa4a9
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Delete a redundant check in
  rcu_check_gp_kthread_starvation() (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 93ee97b
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Standardize explicit CPU-hotplug calls (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 09fad31
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Conditionally build CPU-hotplug teardown callbacks
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 4333646
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Assume rcu_report_dead() is always called locally
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit f36f2a8
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Assume IRQS disabled from rcu_report_dead() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit f5fd0ec
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Eliminate rcu_gp_slow_unregister() false positive
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 54dbaff
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Dump memory object info if callback function is invalid
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 0e82277
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Add sysfs to provide throttled access to rcu_barrier()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 6b2c340
* Tue Nov  5 2024 mgorman@suse.de
- rcu/tree: Remove superfluous return from void call_rcu*
  functions (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit d323218
* Tue Nov  5 2024 mgorman@suse.de
- tick/nohz: Update comments some more (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 7466ac0
* Tue Nov  5 2024 mgorman@suse.de
- tick/nohz: Don't shutdown the lowres tick from itself
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 1eb5060
* Tue Nov  5 2024 mgorman@suse.de
- tick/nohz: Update obsolete comments (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 221019f
* Tue Nov  5 2024 mgorman@suse.de
- tick/nohz: Rename the tick handlers to more self-explanatory
  names (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 81af237
* Tue Nov  5 2024 mgorman@suse.de
- serial: sc16is7xx: add missing support for rs485 devicetree
  properties (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/serial-sc16is7xx-change-EFR-lock-to-operate-on-each-.patch
  patches.suse/serial-sc16is7xx-fix-invalid-sc16is7xx_lines-bitfiel.patch
- commit 87cbf29
* Tue Nov  5 2024 mgorman@suse.de
- serial: 8250_dw: fall back to poll if there's no interrupt
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 3835129
* Tue Nov  5 2024 mgorman@suse.de
- tty: make tty_operations::write()'s count size_t (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 14f3808
* Tue Nov  5 2024 mgorman@suse.de
- tty: propagate u8 data to tty_operations::put_char()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 71125ee
* Tue Nov  5 2024 mgorman@suse.de
- tty: propagate u8 data to tty_operations::write() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 4258e8a
* Tue Nov  5 2024 mgorman@suse.de
- serial: cpm_uart: Don't include fs_uart_pd.h when not needed
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 46f0447
* Tue Nov  5 2024 mgorman@suse.de
- serial: max310x: fix typos in comments (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 2c600eb
* Tue Nov  5 2024 mgorman@suse.de
- serial: max310x: add comments for membase address workaround
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit ef807ce
* Tue Nov  5 2024 mgorman@suse.de
- tty: vt: Remove some repetitive initialization (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit ba890d7
* Tue Nov  5 2024 mgorman@suse.de
- tty: hvsi: remove an extra variable from hvsi_write()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit ee68026
* Tue Nov  5 2024 mgorman@suse.de
- serial: move WARN_ON() in uart_write() to the condition
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 559b390
* Tue Nov  5 2024 mgorman@suse.de
- serial: sc16is7xx: Put IOControl register into regmap_volatile
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 106ad3e
* Tue Nov  5 2024 mgorman@suse.de
- serial: pass state to __uart_start() directly (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/serial-core-Use-port-lock-wrappers.patch
- commit a116d08
* Tue Nov  5 2024 mgorman@suse.de
- net: dsa: hellcreek: Replace bogus comment (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit f8bb050
* Tue Nov  5 2024 mgorman@suse.de
- x86/microcode: Remove microcode_mutex (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 2d9e7ab
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Mark __rcu_irq_enter_check_tick() ->rcu_urgent_qs load
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 8ba2150
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Clarify rcu_is_watching() kernel-doc comment (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit ff0cac7
* Tue Nov  5 2024 mgorman@suse.de
- compiler_types: Introduce the Clang __preserve_most function
  attribute (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/overflow-add-DEFINE_FLEX-for-on-stack-allocs.patch
- commit c0531a8
* Tue Nov  5 2024 mgorman@suse.de
- um: Remove strlcpy declaration (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 7218dd7
* Tue Nov  5 2024 mgorman@suse.de
- net/core: Enable socket busy polling on -RT (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 455a3d4
* Tue Nov  5 2024 mgorman@suse.de
- uml: Replace strlcpy with strscpy (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit c2f8abd
* Tue Nov  5 2024 mgorman@suse.de
- string: use __builtin_memcpy() in strlcpy/strlcat (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 97238b1
* Tue Nov  5 2024 mgorman@suse.de
- fortify: strcat: Move definition to use fortified strlcat()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 2091ad5
* Tue Nov  5 2024 mgorman@suse.de
- fortify: Add protection for strlcat() (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit d6d4947
* Tue Nov  5 2024 mgorman@suse.de
- fortify: Use const variables for __member_size tracking
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/string-Allow-2-argument-strscpy.patch
- commit 8171263
* Tue Nov  5 2024 mgorman@suse.de
- fortify: strscpy: Fix flipped q and p docstring typo
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- Refresh patches.suse/string-Allow-2-argument-strscpy.patch.
- commit ee0f9f0
* Tue Nov  5 2024 mgorman@suse.de
- rcu/kvfree: Make drain_page_cache() take early return if cache
  is disabled (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 665bac5
* Tue Nov  5 2024 mgorman@suse.de
- rcu/kvfree: Make fill page cache start from krcp->nr_bkv_objs
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 61fd65b
* Tue Nov  5 2024 mgorman@suse.de
- rcu/kvfree: Do not run a page work if a cache is disabled
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 741719e
* Tue Nov  5 2024 mgorman@suse.de
- rcu/kvfree: Use consistent krcp when growing kfree_rcu()
  page cache (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 84e0c61
* Tue Nov  5 2024 mgorman@suse.de
- rcu/kvfree: Invoke debug_rcu_bhead_unqueue() after checking
  bnode->gp_snap (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- commit 7a9cb5f
* Tue Nov  5 2024 mgorman@suse.de
- rcu/kvfree: Add debug check for GP complete for kfree_rcu_cpu
  list (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit dec9917
* Tue Nov  5 2024 mgorman@suse.de
- rcu/kvfree: Add debug to check grace periods (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 0f1353b
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Mark rcu_cpu_kthread() accesses to ->rcu_cpu_has_work
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit a4d8c92
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Employ jiffies-based backstop to callback time limit
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 0f2948b
* Tue Nov  5 2024 mgorman@suse.de
- rcu: Check callback-invocation time limit for rcuc kthreads
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 7eea70d
* Tue Nov  5 2024 mgorman@suse.de
- posix-timers: Polish coding style in a few places (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 63e9812
* Tue Nov  5 2024 mgorman@suse.de
- posix-timers: Remove pointless comments (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit e7be0d1
* Tue Nov  5 2024 mgorman@suse.de
- posix-timers: Clarify posix_timer_fn() comments (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 3a01a6a
* Tue Nov  5 2024 mgorman@suse.de
- posix-timers: Clarify posix_timer_rearm() comment (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 5f71fb8
* Tue Nov  5 2024 mgorman@suse.de
- posix-timers: Comment SIGEV_THREAD_ID properly (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 00da019
* Tue Nov  5 2024 mgorman@suse.de
- posix-timers: Add proper comments in do_timer_create()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit c8c4976
* Tue Nov  5 2024 tbogendoerfer@suse.de
- net: ethernet: altera-tse: Convert to mdio-regmap and use PCS
  Lynx (bsc#1232798).
- Update config files.
- supported.conf: mark mdio-regmap unsupported
- commit 3cb4619
* Tue Nov  5 2024 mgorman@suse.de
- posix-timers: Document nanosleep() details (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 83ee2d7
* Tue Nov  5 2024 mgorman@suse.de
- posix-timers: Document sys_clock_settime() permissions in place
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit b993e39
* Tue Nov  5 2024 mgorman@suse.de
- posix-timers: Document sys_clock_getoverrun() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 17914b3
* Tue Nov  5 2024 mgorman@suse.de
- posix-timers: Document common_clock_get() correctly (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit d2505ae
* Tue Nov  5 2024 mgorman@suse.de
- posix-timers: Document sys_clock_getres() correctly (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 63c09e1
* Tue Nov  5 2024 mgorman@suse.de
- posix-timers: Split release_posix_timers() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 393a022
* Tue Nov  5 2024 mgorman@suse.de
- posix-timers: Remove pointless irqsafe from hash_lock
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit e071e3c
* Tue Nov  5 2024 tbogendoerfer@suse.de
- net: fman_memac: use pcs-lynx's check for fwnode availability
  (bsc#1232798).
- net: fman_memac: use lynx_pcs_create_fwnode() (bsc#1232798).
- net: fman_memac: allow lynx PCS to handle mdiodev lifetime
  (bsc#1232798).
- net: altera_tse: explicitly disable autoscan on the regmap-mdio
  bus (bsc#1232798).
- net: altera-tse: Initialize local structs before using it
  (bsc#1232798).
- net: enetc: use lynx_pcs_create_mdiodev() (bsc#1232798).
- commit ef067e7
* Tue Nov  5 2024 mgorman@suse.de
- posix-timers: Set k_itimer:: It_signal to NULL on exit()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 883b5e4
* Tue Nov  5 2024 mgorman@suse.de
- posix-timers: Annotate concurrent access to k_itimer:: It_signal
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit e1238d7
* Tue Nov  5 2024 mgorman@suse.de
- posix-timers: Add comments about timer lookup (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit e8ac120
* Tue Nov  5 2024 mgorman@suse.de
- posix-timers: Cleanup comments about timer ID tracking
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit ca68fa1
* Tue Nov  5 2024 mgorman@suse.de
- posix-timers: Clarify timer_wait_running() comment (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 8e1a37f
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/amd/uncore: Avoid PMU registration if counters are
  unavailable (git-fixes).
- commit 4c41b71
* Tue Nov  5 2024 tbogendoerfer@suse.de
- net: dsa: realtek: merge rtl83xx and interface modules into
  realtek_dsa (bsc#1232178).
- Update config files.
- commit 3fb538a
* Tue Nov  5 2024 oneukum@suse.com
- media: core: v4l2-ioctl: check if ioctl is known to avoid NULL
  name (git-fixes).
- commit c862b93
* Tue Nov  5 2024 tbogendoerfer@suse.de
- net: pcs: Drop the TSE PCS driver (bsc#1232178).
- Update config files.
- supported.conf: remoed pcs-altera-tse
- commit 882597a
* Tue Nov  5 2024 tbogendoerfer@suse.de
- net: dsa: mt7530: get rid of priv->info->cpu_port_config()
  (bsc#1232178).
- Refresh
  patches.suse/net-dsa-mt7530-fix-handling-of-all-link-local-frames.patch.
- Refresh
  patches.suse/net-dsa-mt7530-trap-link-local-frames-regardless-of-.patch.
- commit b180182
* Tue Nov  5 2024 tbogendoerfer@suse.de
- bnxt_en: Restore all the user created L2 and ntuple filters
  (jsc#PED-11221).
- Refresh
  patches.suse/bnxt_en-Reset-PTP-tx_avail-after-possible-firmware-r.patch.
- commit d21cc6d
* Tue Nov  5 2024 tbogendoerfer@suse.de
- net: dsa: Use conduit and user terms (bsc#1232178).
- Refresh
  patches.suse/net-dsa-bcm_sf2-Fix-a-possible-memory-leak-in-bcm_sf.patch.
- Refresh
  patches.suse/net-dsa-qca8k-put-MDIO-bus-OF-node-on-qca8k_mdio_reg.patch.
- commit 0f3afe0
* Tue Nov  5 2024 tbogendoerfer@suse.de
- net: mscc: ocelot: extend ocelot->fwd_domain_lock to cover
  ocelot->tas_lock (bsc#1232178).
- Refresh
  patches.suse/net-dsa-felix-make-vsc9959_tas_guard_bands_upda.patch.
- commit ec5371f
* Tue Nov  5 2024 tbogendoerfer@suse.de
- net: dsa: mv88e6xxx: read cmode on mv88e6320/21 serdes only
  ports (bsc#1232178).
- net: dsa: mv88e6xxx: add phylink_get_caps for the mv88e6320/21
  family (bsc#1232178).
- net: dsa: mv88e6xxx: Fix number of databases for 88E6141 /
  88E6341 (bsc#1232178).
- net: dsa: mv88e6xx: fix supported_interfaces setup in
  mv88e6250_phylink_get_caps() (bsc#1232178).
- net: dsa: mt7530: fix port mirroring for MT7988 SoC switch
  (bsc#1232178).
- net: dsa: mt7530: fix mirroring frames received on local port
  (bsc#1232178).
- net: dsa: mt7530: fix enabling EEE on MT7531 switch on all
  boards (bsc#1232178).
- net: dsa: mv88e6xxx: fix usable ports on 88e6020 (bsc#1232178).
- net: dsa: mt7530: fix improper frames on all 25MHz and 40MHz
  XTAL MT7530 (bsc#1232178).
- net: dsa: microchip: make sure drive strength configuration
  is not lost by soft reset (bsc#1232178).
- net: dsa: mt7530: disable LEDs before reset (bsc#1232178).
- ethtool: Add GTP RSS hash options to ethtool.h (bsc#1232798).
- ixgbe: pull out stats update to common routines (jsc#PED-9961).
- i40e: remove unnecessary qv_info ptr NULL checks (jsc#PED-8904
  jsc#PED-9957).
- iavf: drop duplicate iavf_{add|del}_cloud_filter() calls
  (jsc#PED-9955).
- net: dsa: mv88e6xxx: update 88e6185 PCS driver to use neg_mode
  (bsc#1232178).
- ethtool: remove ethtool_eee_use_linkmodes (bsc#1232798).
- mlxbf_gige: add support to display pause frame counters
  (jsc#PED-11319).
- ethtool: ignore unused/unreliable fields in set_eee op
  (bsc#1232798).
- net: dsa: mt7530: simplify link operations (bsc#1232178).
- net: dsa: mt7530: sort link settings ops and force link down
  on all ports (bsc#1232178).
- net: dsa: mt7530: put initialising PCS devices code back to
  original order (bsc#1232178).
- net: dsa: mt7530: get rid of mt753x_mac_config() (bsc#1232178).
- net: dsa: mt7530: get rid of useless error returns on phylink
  code path (bsc#1232178).
- net: dsa: mt7530: do not use SW_PHY_RST to reset MT7531 switch
  (bsc#1232178).
- net: dsa: mt7530: set interrupt register only for MT7530
  (bsc#1232178).
- net: dsa: mt7530: remove .mac_port_config for MT7988 and make
  it optional (bsc#1232178).
- ixgbe: Add 1000BASE-BX support (jsc#PED-9961).
- intel: make module parameters readable in sys filesystem
  (jsc#PED-9961).
- eth: igc: remove unused embedded struct net_device
  (jsc#PED-9944).
- net: adopt skb_network_header_len() more broadly (jsc#PED-9955).
- net: adopt skb_network_offset() and similar helpers
  (jsc#PED-9961).
- net: dsa: mv88e6xxx: add Amethyst specific SMI GPIO function
  (bsc#1232178).
- net: dsa: mv88e6xxx: rename mv88e6xxx_g2_scratch_gpio_set_smi
  (bsc#1232178).
- net: ethtool: eee: Remove legacy _u32 from keee (bsc#1232798).
- net: intel: igc: Use linkmode helpers for EEE (jsc#PED-9944).
- net: intel: igb: Use linkmode helpers for EEE (jsc#PED-9959).
- net: intel: e1000e: Use linkmode helpers for EEE (jsc#PED-9951).
- net: intel: i40e/igc: Remove setting Autoneg in EEE capabilities
  (jsc#PED-9944).
- net: ethernet: ixgbe: Convert EEE to use linkmodes
  (jsc#PED-9961).
- net: qlogic: qede: Use linkmode helpers for EEE (jsc#PED-9962
  jsc#PED-11294).
- net: usb: ax88179_178a: Use linkmode helpers for EEE
  (bsc#1232798).
- net: usb: r8152: Use linkmode helpers for EEE (bsc#1232798).
- net: dsa: realtek: support reset controller (bsc#1232178).
- bnxt_en: fix accessing vnic_info before allocating it
  (jsc#PED-11221).
- net: phy: simplify genphy_c45_ethtool_set_eee (bsc#1232798).
- net: dsa: microchip: Add support for bridge port isolation
  (bsc#1232178).
- net: ethtool: avoid rebuilds on UTS_RELEASE change
  (bsc#1232798).
- bnxt_en: Use the new VNIC to create ntuple filters
  (jsc#PED-11221).
- bnxt_en: Create and setup the additional VNIC for adding ntuple
  filters (jsc#PED-11221).
- bnxt_en: Provision for an additional VNIC for ntuple filters
  (jsc#PED-11221).
- bnxt_en: Define BNXT_VNIC_DEFAULT for the default vnic index
  (jsc#PED-11221).
- bnxt_en: Refactor bnxt_set_features() (jsc#PED-11221).
- bnxt_en: Add bnxt_get_total_vnics() to calculate number of VNICs
  (jsc#PED-11221).
- bnxt_en: Check additional resources in bnxt_check_rings()
  (jsc#PED-11221).
- bnxt_en: Improve RSS context reservation infrastructure
  (jsc#PED-11221).
- bnxt_en: Explicitly specify P5 completion rings to reserve
  (jsc#PED-11221).
- bnxt_en: Refactor ring reservation functions (jsc#PED-11221).
- net: phy: c45: detect 100/1000BASE-T1 linkmode advertisements
  (bsc#1232798).
- net: phy: Support 100/1000BT1 linkmode advertisements
  (bsc#1232798).
- net: phy: Add BaseT1 auto-negotiation constants (bsc#1232798).
- tg3: simplify tg3_phy_autoneg_cfg (jsc#PED-8898 jsc#PED-11227).
- tg3: copy only needed fields from userspace-provided EEE data
  (jsc#PED-8898 jsc#PED-11227).
- net: dsa: constify the struct device_type usage (bsc#1232178).
- i40e: Remove VEB recursion (jsc#PED-8904 jsc#PED-9957).
- i40e: Fix broken support for floating VEBs (jsc#PED-8904
  jsc#PED-9957).
- i40e: Add helpers to find VSI and VEB by SEID and use them
  (jsc#PED-8904 jsc#PED-9957).
- i40e: Introduce and use macros for iterating VSIs and VEBs
  (jsc#PED-8904 jsc#PED-9957).
- i40e: Use existing helper to find flow director VSI
  (jsc#PED-8904 jsc#PED-9957).
- net: phy: c45: add support for MDIO_AN_EEE_ADV2 (bsc#1232798).
- net: phy: c45: add support for EEE link partner ability 2 to
  genphy_c45_read_eee_lpa (bsc#1232798).
- net: phy: c45: add and use genphy_c45_read_eee_cap2
  (bsc#1232798).
- net: phy: add PHY_EEE_CAP2_FEATURES (bsc#1232798).
- net: mdio: add helpers for accessing the EEE CAP2 registers
  (bsc#1232798).
- net: dsa: remove OF-based MDIO bus registration from DSA core
  (bsc#1232178).
- net: dsa: realtek: fix digital interface select macro for EXT0
  (bsc#1232178).
- tg3: fix bug caused by uninitialized variable (jsc#PED-8898
  jsc#PED-11227).
- net: dsa: realtek: embed dsa_switch into realtek_priv
  (bsc#1232178).
- net: dsa: realtek: use the same mii bus driver for both
  interfaces (bsc#1232178).
- net: dsa: realtek: migrate user_mii_bus setup to realtek_dsa
  (bsc#1232178).
- net: dsa: realtek: clean user_mii_bus setup (bsc#1232178).
- net: dsa: realtek: get internal MDIO node by name (bsc#1232178).
- net: dsa: realtek: common rtl83xx module (bsc#1232178).
- net: dsa: realtek: keep variant reference in realtek_priv
  (bsc#1232178).
- net: dsa: realtek: convert variants into real drivers
  (bsc#1232178).
- net: dsa: realtek: introduce REALTEK_DSA namespace
  (bsc#1232178).
- net: dsa: realtek: drop cleanup from realtek_ops (bsc#1232178).
- igc: Unify filtering rule fields (jsc#PED-9944).
- igc: Use netdev printing functions for flex filters
  (jsc#PED-9944).
- igc: Use reverse xmas tree (jsc#PED-9944).
- net: atlantic: convert EEE handling to use linkmode bitmaps
  (bsc#1232798).
- bnx2x: convert EEE handling to use linkmode bitmaps
  (jsc#PED-9872 jsc#PED-11308).
- bnxt_en: Add RSS support for IPSEC headers (jsc#PED-11221).
- bnxt_en: Invalidate user filters when needed (jsc#PED-11221).
- bnxt_en: Add support for user configured RSS key
  (jsc#PED-11221).
- bnxt_en: Retain user configured filters when closing
  (jsc#PED-11221).
- bnxt_en: Save user configured filters in a lookup list
  (jsc#PED-11221).
- bnxt_en: Add separate function to delete the filter structure
  (jsc#PED-11221).
- bnxt_en: Add drop action support for ntuple (jsc#PED-11221).
- bnxt_en: Enhance ethtool ntuple support for ip flows besides
  TCP/UDP (jsc#PED-11221).
- bnxt_en: implement fully specified 5-tuple masks
  (jsc#PED-11221).
- bnxt_en: Support ethtool -n to display ether filters
  (jsc#PED-11221).
- bnxt_en: Add ethtool -N support for ether filters
  (jsc#PED-11221).
- bnxt_en: Use firmware provided maximum filter counts
  (jsc#PED-11221).
- ethtool: do not use rtnl in ethnl_default_dumpit()
  (bsc#1232798).
- ixgbe: Clarify the values of the returning status
  (jsc#PED-9961).
- ixgbe: Rearrange args to fix reverse Christmas tree
  (jsc#PED-9961).
- ixgbe: Convert ret val type from s32 to int (jsc#PED-9961).
- bnxt: convert EEE handling to use linkmode bitmaps
  (jsc#PED-11221).
- qed: remove duplicated assignment to variable opaque_fid
  (jsc#PED-9962 jsc#PED-11294).
- net: dsa: tag_sja1105: remove "inline" keyword (bsc#1232178).
- net: dsa: remove "inline" from dsa_user_netpoll_send_skb()
  (bsc#1232178).
- net: dsa: b53: unexport and move b53_eee_enable_set()
  (bsc#1232178).
- net: dsa: mt7530: do not clear config->supported_interfaces
  (bsc#1232178).
- net: dsa: mt7530: correct port capabilities of MT7988
  (bsc#1232178).
- net: dsa: mt7530: remove pad_setup function pointer
  (bsc#1232178).
- net: dsa: mt7530: call port 6 setup from mt7530_mac_config()
  (bsc#1232178).
- net: dsa: mt7530: simplify mt7530_pad_clk_setup() (bsc#1232178).
- net: dsa: mt7530: move XTAL check to mt7530_setup()
  (bsc#1232178).
- net: dsa: mt7530: empty default case on mt7530_setup_port5()
  (bsc#1232178).
- net: dsa: b53: remove eee_enabled/eee_active in
  b53_get_mac_eee() (bsc#1232178).
- net: dsa: mv88e6xxx: Return -ENODEV when C45 not supported
  (bsc#1232178).
- tg3: convert EEE handling to use linkmode bitmaps (jsc#PED-8898
  jsc#PED-11227).
- mlx4: Address spelling errors (jsc#PED-9945 jsc#PED-11337).
- net: dsa: qca8k: consistently use "ret" rather than "err"
  for error codes (bsc#1232178).
- net: dsa: qca8k: put MDIO controller OF node if unavailable
  (bsc#1232178).
- net: dsa: reindent arguments of dsa_user_vlan_for_each()
  (bsc#1232178).
- net: dsa: Add KSZ8567 switch support (bsc#1232178).
- net: phy: c45: change genphy_c45_ethtool_[get|set]_eee to use
  EEE linkmode bitmaps (bsc#1232798).
- ethtool: add linkmode bitmap support to struct ethtool_keee
  (bsc#1232798).
- ethtool: add suffix _u32 to legacy bitmap members of struct
  ethtool_keee (bsc#1232798).
- ethtool: adjust struct ethtool_keee to kernel needs
  (bsc#1232798).
- ethtool: switch back from ethtool_keee to ethtool_eee for ioctl
  (bsc#1232798).
- ethtool: replace struct ethtool_eee with a new struct
  ethtool_keee on kernel side (bsc#1232798).
- net: dsa: mt7530: do not run mt7530_setup_port5() if port 5
  is disabled (bsc#1232178).
- net: dsa: mt7530: do not set priv->p5_interface on
  mt7530_setup_port5() (bsc#1232178).
- net: dsa: mt7530: improve code path for setting up port 5
  (bsc#1232178).
- net: dsa: mt7530: improve comments regarding switch ports
  (bsc#1232178).
- net: dsa: mt7530: store port 5 SGMII capability of MT7531
  (bsc#1232178).
- net: dsa: mt7530: use p5_interface_select as data type for
  p5_intf_sel (bsc#1232178).
- net: dsa: mt7530: always trap frames to active CPU port on
  MT7530 (bsc#1232178).
- net: dsa: microchip: implement PHY loopback configuration for
  KSZ8794 and KSZ8873 (bsc#1232178).
- net: dsa: microchip: Remove redundant optimization in
  ksz8_w_phy_bmcr (bsc#1232178).
- net: dsa: microchip: ksz8: move BMCR specific code to separate
  function (bsc#1232178).
- net: dsa: mt7530: select MEDIATEK_GE_PHY for NET_DSA_MT7530_MDIO
  (bsc#1232178).
- net: dsa: mt7530: support OF-based registration of switch MDIO
  bus (bsc#1232178).
- net: fill in MODULE_DESCRIPTION()s for dsa_loop_bdinfo
  (bsc#1232178).
- ethtool: netlink: Add missing ethnl_ops_begin/complete
  (bsc#1232798).
- net: dsa: fix netdev_priv() dereference before check on non-DSA
  netdevice events (bsc#1232178).
- lan78xx: remove redundant statement in lan78xx_get_eee
  (bsc#1232798).
- net: fill in MODULE_DESCRIPTION()s for DSA tags (bsc#1232178).
- net: dsa: bcm_sf2: drop priv->master_mii_dn (bsc#1232178).
- net: dsa: bcm_sf2: stop assigning an OF node to the
  ds->user_mii_bus (bsc#1232178).
- net: dsa: qca8k: use "dev" consistently within
  qca8k_mdio_register() (bsc#1232178).
- net: dsa: qca8k: consolidate calls to a single
  devm_of_mdiobus_register() (bsc#1232178).
- net: dsa: qca8k: assign ds->user_mii_bus only for the non-OF
  case (bsc#1232178).
- net: dsa: qca8k: skip MDIO bus creation if its OF node has
  status = "disabled" (bsc#1232178).
- net: dsa: lantiq_gswip: ignore MDIO buses disabled in OF
  (bsc#1232178).
- net: dsa: lantiq_gswip: use devres for internal MDIO bus,
  not ds->user_mii_bus (bsc#1232178).
- net: dsa: lantiq_gswip: delete irrelevant use of
  ds->phys_mii_mask (bsc#1232178).
- ethtool: reformat kerneldoc for struct ethtool_fec_stats
  (bsc#1232798).
- ethtool: reformat kerneldoc for struct ethtool_link_settings
  (bsc#1232798).
- net: rename dsa_realloc_skb to skb_ensure_writable_head_tail
  (bsc#1232178).
- net: dsa: mv88e6xxx: Add "rmon" counter group support
  (bsc#1232178).
- net: dsa: mv88e6xxx: Limit histogram counters to ingress traffic
  (bsc#1232178).
- net: dsa: mv88e6xxx: Add "eth-mac" counter group support
  (bsc#1232178).
- net: dsa: mv88e6xxx: Give each hw stat an ID (bsc#1232178).
- net: dsa: mv88e6xxx: Create API to read a single stat counter
  (bsc#1232178).
- net: dsa: mv88e6xxx: Push locking into stats snapshotting
  (bsc#1232178).
- net: phy: c45: add genphy_c45_pma_read_ext_abilities() function
  (bsc#1232798).
- net: dsa: realtek: Rewrite RTL8366RB MTU handling (bsc#1232178).
- net: dsa: realtek: Rename bogus RTL8368S variable (bsc#1232178).
- net: dsa: microchip: use DSA_TAG_PROTO without _VALUE define
  (bsc#1232178).
- net: dsa: microchip: move ksz_chip_id enum to platform include
  (bsc#1232178).
- net: dsa: microchip: properly support platform_data probing
  (bsc#1232178).
- net: dsa: microchip: add property to select internal RMII
  reference clock (bsc#1232178).
- net: phy: mdio_device: Reset device only when necessary
  (bsc#1232798).
- net: dsa: sja1105: Use units.h instead of the copy of a
  definition (bsc#1232178).
- net: dsa: microchip: make phylink_mac_link_up() not optional
  (bsc#1232178).
- net: dsa: microchip: ksz8: Add function to configure ports
  with integrated PHYs (bsc#1232178).
- net: dsa: microchip: ksz8: Make flow control, speed, and duplex
  on CPU port configurable (bsc#1232178).
- net: ethtool: Refactor identical get_ts_info implementations
  (bsc#1232798).
- net: dsa: tag_rtl4_a: Use existing ETH_P_REALTEK constant
  (bsc#1232178).
- net: dsa: mv88e6xxx: Restore USXGMII support for 6393X
  (bsc#1232178).
- ethtool: don't propagate EOPNOTSUPP from dumps (bsc#1232798).
- net: dsa: mv88e6xxx: fix marvell 6350 probe crash (bsc#1232178).
- net: dsa: mv88e6xxx: fix marvell 6350 switch probing
  (bsc#1232178).
- net: mdio: fix typo in header (bsc#1232798).
- net: dsa: microchip: ksz9477: Fix spelling mistake "Enery" ->
  "Energy" (bsc#1232178).
- net: dsa: microchip: Ensure Stable PME Pin State for Wake-on-LAN
  (bsc#1232178).
- net: dsa: microchip: Refactor switch shutdown routine for WoL
  preparation (bsc#1232178).
- net: dsa: microchip: Add error handling for
  ksz_switch_macaddr_get() (bsc#1232178).
- net: dsa: microchip: Refactor comment for
  ksz_switch_macaddr_get() function (bsc#1232178).
- net: dsa: microchip: ksz9477: Add Wake on Magic Packet support
  (bsc#1232178).
- net: dsa: microchip: ksz9477: add Wake on LAN support
  (bsc#1232178).
- net: dsa: microchip: use wakeup-source DT property to enable
  PME output (bsc#1232178).
- net: dsa: microchip: Add missing MAC address register offset
  for ksz8863 (bsc#1232178).
- net: dsa: Rename IFLA_DSA_MASTER to IFLA_DSA_CONDUIT
  (bsc#1232178).
- net: dsa: mv88e6xxx: add an error code check in
  mv88e6352_tai_event_work (bsc#1232178).
- net: dsa: microchip: ksz8: Enable MIIM PHY Control reg access
  (bsc#1232178).
- e1000: replace deprecated strncpy with strscpy (jsc#PED-9952).
- net: dsa: vsc73xx: replace deprecated strncpy with
  ethtool_sprintf (bsc#1232178).
- net: dsa: lantiq_gswip: replace deprecated strncpy with
  ethtool_sprintf (bsc#1232178).
- net: dsa: mt7530: replace deprecated strncpy with
  ethtool_sprintf (bsc#1232178).
- net: dsa: remove dsa_port_phylink_validate() (bsc#1232178).
- net: dsa: dsa_loop: add phylink capabilities (bsc#1232178).
- net: dsa: vsc73xx: add phylink capabilities (bsc#1232178).
- net: dsa: realtek: rtl8365mb: replace deprecated strncpy with
  ethtool_sprintf (bsc#1232178).
- net: dsa: realtek: replace deprecated strncpy with
  ethtool_sprintf (bsc#1232178).
- net: dsa: qca8k: replace deprecated strncpy with ethtool_sprintf
  (bsc#1232178).
- net: dsa: microchip: Fix uninitialized var in
  ksz9477_acl_move_entries() (bsc#1232178).
- net: dsa: mt753x: remove mt753x_phylink_pcs_link_up()
  (bsc#1232178).
- net: dsa: microchip: Enable HSR offloading for KSZ9477
  (bsc#1232178).
- net: dsa: microchip: move REG_SW_MAC_ADDR to dev->info->regs
  (bsc#1232178).
- net: dsa: tag_ksz: Extend ksz9477_xmit() for HSR frame
  duplication (bsc#1232178).
- net: dsa: notify drivers of MAC address changes on user ports
  (bsc#1232178).
- net: dsa: propagate extack to ds->ops->port_hsr_join()
  (bsc#1232178).
- net: dsa: sja1105: make read-only const arrays static
  (bsc#1232178).
- net: dsa: mv88e6xxx: make const read-only array lanes static
  (bsc#1232178).
- net: dsa: vitesse-vsc73xx: Convert to platform remove callback
  returning void (bsc#1232178).
- net: dsa: rzn1_a5psw: Convert to platform remove callback
  returning void (bsc#1232178).
- net: dsa: realtek: Convert to platform remove callback returning
  void (bsc#1232178).
- net: dsa: ocelot: Convert to platform remove callback returning
  void (bsc#1232178).
- net: dsa: mt7530: Convert to platform remove callback returning
  void (bsc#1232178).
- net: dsa: lantiq_gswip: Convert to platform remove callback
  returning void (bsc#1232178).
- net: dsa: hirschmann: Convert to platform remove callback
  returning void (bsc#1232178).
- net: dsa: bcm_sf2: Convert to platform remove callback returning
  void (bsc#1232178).
- net: dsa: b53: Convert to platform remove callback returning
  void (bsc#1232178).
- net: dsa: microchip: Fix spelling mistake "unxpexted" ->
  "unexpected" (bsc#1232178).
- net: dsa: microchip: Add partial ACL support for ksz9477
  switches (bsc#1232178).
- net: dsa: microchip: Move *_port_setup code to
  dsa_switch_ops::port_setup() (bsc#1232178).
- net: dsa: microchip: Add drive strength configuration
  (bsc#1232178).
- net: dsa: rtl8366rb: Implement setting up link on CPU port
  (bsc#1232178).
- ethtool: plca: fix plca enable data type while parsing the value
  (bsc#1232798).
- net: dsa: use capital "OR" for multiple licenses in SPDX
  (bsc#1232178).
- net: dsa: rzn1-a5psw: remove redundant logs (bsc#1232178).
- net: dsa: microchip: Remove unused declarations (bsc#1232178).
- net: dsa: realtek: add phylink_get_caps implementation
  (bsc#1232178).
- net: dsa: rzn1-a5psw: Remove redundant of_match_ptr()
  (bsc#1232178).
- net: dsa: realtek: Remove redundant of_match_ptr()
  (bsc#1232178).
- ethtool: netlink: always pass genl_info to .prepare_data
  (bsc#1232798).
- ethtool: netlink: simplify arguments to ethnl_default_parse()
  (bsc#1232798).
- net: dsa: mv88e6060: add phylink_get_caps implementation
  (bsc#1232178).
- net: e1000: Remove unused declarations (jsc#PED-9952).
- net: dsa: rzn1-a5psw: add vlan support (bsc#1232178).
- net: dsa: rzn1-a5psw: add support for .port_bridge_flags
  (bsc#1232178).
- net: dsa: rzn1-a5psw: use a5psw_reg_rmw() to modify flooding
  resolution (bsc#1232178).
- net: dsa: mark parsed interface mode for legacy switch drivers
  (bsc#1232178).
- net: dsa: mt7530: improve and relax PHY driver dependency
  (bsc#1232178).
- net: transfer rtnl_lock() requirement from
  ethtool_set_ethtool_phy_ops() to caller (bsc#1232798).
- net: dsa: hellcreek: Replace bogus comment (bsc#1232178).
- net: dsa: mv88e6xxx: Add erratum 3.14 for 88E6390X and 88E6190X
  (bsc#1232178).
- net: dsa: qca8k: use dsa_for_each macro instead of for loop
  (bsc#1232178).
- net: dsa: qca8k: move qca8xxx hol fixup to separate function
  (bsc#1232178).
- net: dsa: qca8k: limit user ports access to the first CPU port
  on setup (bsc#1232178).
- net: dsa: qca8k: make learning configurable and keep off if
  standalone (bsc#1232178).
- net: dsa: tag_qca: return early if dev is not found
  (bsc#1232178).
- net: dsa: Explicitly include correct DT includes (bsc#1232178).
- net: dsa: remove deprecated strncpy (bsc#1232178).
- net: phy: c45: detect the BASE-T1 speed from the ability
  register (bsc#1232798).
- net: phy: c45: add a separate function to read BASE-T1 abilities
  (bsc#1232798).
- net: phy: c45: add support for 1000BASE-T1 forced setup
  (bsc#1232798).
- net: phy: add registers to support 1000BASE-T1 (bsc#1232798).
- net: dsa: remove legacy_pre_march2020 from drivers
  (bsc#1232178).
- net: dsa: remove legacy_pre_march2020 detection (bsc#1232178).
- net: dsa: mv88e6xxx: cleanup after phylink_pcs conversion
  (bsc#1232178).
- net: dsa: mv88e6xxx: convert 88e639x to phylink_pcs
  (bsc#1232178).
- net: dsa: mv88e6xxx: convert 88e6352 to phylink_pcs
  (bsc#1232178).
- net: dsa: mv88e6xxx: convert 88e6185 to phylink_pcs
  (bsc#1232178).
- net: dsa: mv88e6xxx: export mv88e6xxx_pcs_decode_state()
  (bsc#1232178).
- net: dsa: mv88e6xxx: add infrastructure for phylink_pcs
  (bsc#1232178).
- net: dsa: mv88e6xxx: remove handling for DSA and CPU ports
  (bsc#1232178).
- net: mdio: add unlocked mdiobus and mdiodev bus accessors
  (bsc#1232178).
- net: phylink: add support for PCS link change notifications
  (bsc#1232178).
- net: phylink: add pcs_pre_config()/pcs_post_config() methods
  (bsc#1232178).
- net: phylink: add pcs_enable()/pcs_disable() methods
  (bsc#1232178).
- net: dsa: ar9331: Use maple tree register cache (bsc#1232178).
- net: dsa: microchip: KSZ9477 register regmap alignment to 32
  bit boundaries (bsc#1232178).
- net: dsa: fix older DSA drivers using phylink (bsc#1232178).
- net: dsa: ar9331: Use explict flags for regmap single read/write
  (bsc#1232178).
- net: dsa: microchip: fix writes to phy registers >= 0x10
  (bsc#1232178).
- net: dsa: microchip: add ksz_prmw32() helper (bsc#1232178).
- net: dsa: microchip: simplify ksz_prmw8() (bsc#1232178).
- net: dsa: mt7530: update PCS driver to use neg_mode
  (bsc#1232178).
- net: dsa: b53: update PCS driver to use neg_mode (bsc#1232178).
- net: qca8k: update PCS driver to use neg_mode (bsc#1232178).
- net: pcs: xpcs: update PCS driver to use neg_mode (bsc#1232178).
- net: phylink: pass neg_mode into phylink_mii_c22_pcs_config()
  (bsc#1232178).
- net: phylink: convert phylink_mii_c22_pcs_config() to neg_mode
  (bsc#1232178).
- net: phylink: add PCS negotiation mode (bsc#1232178).
- net: phy-c45: Fix genphy_c45_ethtool_set_eee description
  (bsc#1232798).
- net: ethtool: don't require empty header nests (bsc#1232798).
- net: pcs: lynx: check that the fwnode is available prior to use
  (bsc#1232178).
- net: pcs: lynx: change lynx_pcs_create() to return
  error-pointers (bsc#1232178).
- net: pcs: lynx: make lynx_pcs_create() static (bsc#1232178).
- net: pcs: lynx: add lynx_pcs_create_fwnode() (bsc#1232178).
- net: pcs: lynx: remove lynx_get_mdio_device() (bsc#1232178).
- net: pcs: Add 10GBASE-R mode for Synopsys Designware XPCS
  (bsc#1232178).
- net: dsa: mv88e6xxx: implement USXGMII mode for mv88e6393x
  (bsc#1232178).
- net: dwmac_socfpga: initialize local data for mdio regmap
  configuration (bsc#1232798).
- net: stmmac: make the pcs_lynx cleanup sequence specific to
  dwmac_socfpga (bsc#1232798).
- net: dsa: qca8k: remove unnecessary (void*) conversions
  (bsc#1232178).
- net: dsa: microchip: remove KSZ9477 PHY errata handling
  (bsc#1232178).
- net: pcs: xpcs: remove xpcs_create() from public view
  (bsc#1232178).
- net: dsa: sja1105: use xpcs_create_mdiodev() (bsc#1232178).
- net: dsa: sja1105: allow XPCS to handle mdiodev lifetime
  (bsc#1232178).
- net: stmmac: dwmac-sogfpga: use the lynx pcs driver
  (bsc#1232798).
- net: mdio: Introduce a regmap-based mdio driver (bsc#1232798).
- net: dsa: mv88e6xxx: add support for MV88E6071 switch
  (bsc#1232178).
- net: dsa: mv88e6xxx: add support for MV88E6020 switch
  (bsc#1232178).
- net: dsa: Define .set_max_frame_size() callback for mv88e6250
  SoC family (bsc#1232178).
- net: dsa: Switch i2c drivers back to use .probe() (bsc#1232178).
- net: dsa: mv88e6xxx: enable support for 88E6361 switch
  (bsc#1232178).
- net: dsa: mv88e6xxx: pass mv88e6xxx_chip structure to
  port_max_speed_mode (bsc#1232178).
- net: dsa: mv88e6xxx: fix 88E6393X family internal phys layout
  (bsc#1232178).
- net: dsa: mv88e6xxx: add field to specify internal phys layout
  (bsc#1232178).
- net: dsa: mv88e6xxx: use mv88e6xxx_phy_is_internal in
  mv88e6xxx_port_ppu_updates (bsc#1232178).
- net: dsa: mv88e6xxx: pass directly chip structure to
  mv88e6xxx_phy_is_internal (bsc#1232178).
- dsa: lan9303: Remove stray gpiod_unexport() call (bsc#1232178).
- net: dsa: microchip: Add register access control for KSZ8873
  chip (bsc#1232178).
- net: dsa: microchip: ksz8: Prepare ksz8863_smi for regmap
  register access validation (bsc#1232178).
- net: dsa: microchip: remove ksz_port:on variable (bsc#1232178).
- net: dsa: microchip: add an enum for regmap widths
  (bsc#1232178).
- net: dsa: microchip: improving error handling for 8-bit register
  RMW operations (bsc#1232178).
- net: dsa: ocelot: use lynx_pcs_create_mdiodev() (bsc#1232178).
- net: pcs: lynx: add lynx_pcs_create_mdiodev() (bsc#1232178).
- net: stmmac: use xpcs_create_mdiodev() (bsc#1232798).
- net: pcs: xpcs: add xpcs_create_mdiodev() (bsc#1232178).
- net: mdio: add mdio_device_get() and mdio_device_put()
  (bsc#1232178).
- net: dsa: mv88e6xxx: move link forcing to mac_prepare/mac_finish
  (bsc#1232178).
- net: dsa: add support for mac_prepare() and mac_finish() calls
  (bsc#1232178).
- net: phylink: provide phylink_pcs_config() and
  phylink_pcs_link_up() (bsc#1232178).
- net: pcs: xpcs: avoid reading STAT1 more than once
  (bsc#1232178).
- net: pcs: xpcs: use phylink_resolve_c73() helper (bsc#1232178).
- net: pcs: xpcs: correct pause resolution (bsc#1232178).
- net: pcs: xpcs: correct lp_advertising contents (bsc#1232178).
- net: pcs: xpcs: use mii_c73_to_linkmode() helper (bsc#1232178).
- net: pcs: xpcs: clean up reading clause 73 link partner
  advertisement (bsc#1232178).
- net: phylink: add function to resolve clause 73 negotiation
  (bsc#1232178).
- net: phylink: remove duplicated linkmode pause resolution
  (bsc#1232178).
- net: mdio: add clause 73 to ethtool conversion helper
  (bsc#1232178).
- net: sfp: add support for setting signalling rate (bsc#1232178).
- net: stmmac: Make stmmac_pltfr_remove() return void
  (bsc#1232798).
- commit 6ecf577
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/amd/uncore: Fix uninitialized return value in
  amd_uncore_init() (git-fixes).
- perf/x86/amd/uncore: Move discovery and registration
  (jsc#PED-10398, jsc#PED-10203, jsc#PED-10390, jsc#PED-10243,
  jsc#PED-10206).
- commit 3a86ed8
* Tue Nov  5 2024 jlee@suse.com
- thermal: gov_bang_bang: Add .manage() callback (jsc#PED-11164).
- thermal: gov_bang_bang: Split bang_bang_control()
  (jsc#PED-11164).
- thermal: gov_bang_bang: Call __thermal_cdev_update() directly
  (jsc#PED-11164).
- thermal: gov_bang_bang: Drop unnecessary cooling device target
  state checks (jsc#PED-11164).
- commit c99bbe8
* Tue Nov  5 2024 jlee@suse.com
- thermal: trip: Split thermal_zone_device_set_mode()
  (jsc#PED-11164).
  Refresh
  patches.suse/thermal-core-Back-off-when-polling-thermal-zones-on-.patch.
- commit 691fdfc
* Tue Nov  5 2024 jlee@suse.com
- thermal: core: Back off when polling thermal zones on errors
  (jsc#PED-11164).
- thermal: core: Allow thermal zones to tell the core to ignore
  them (jsc#PED-11164).
- wifi: iwlwifi: mvm: add mvm-specific guard (jsc#PED-11164).
  Refresh
  patches.suse/wifi-iwlwifi-mvm-separate-non-BSS-ROC-EMLSR-blocking.patch.
  patches.suse/wifi-iwlwifi-mvm-don-t-wait-for-tx-queues-if-firmwar.patch.
- commit 99c3c63
* Tue Nov  5 2024 jlee@suse.com
- mlxsw: core_thermal: Report valid current state during cooling
  device registration (jsc#PED-11164).
- thermal: core: Fix list sorting in
  __thermal_zone_device_update() (jsc#PED-11164).
- thermal: core: Call monitor_thermal_zone() if zone temperature
  is invalid (jsc#PED-11164).
- thermal: gov_step_wise: Go straight to instance->lower when
  mitigation is over (jsc#PED-11164).
- thermal/drivers/mediatek/lvts_thermal: Remove filtered mode
  for mt8188 (jsc#PED-11164).
- thermal: core: Synchronize suspend-prepare and post-suspend
  actions (jsc#PED-11164).
  blacklist.conf:
  Removed d2278f3533a8c4933c52f85784ffa73e8250c524
- thermal: gov_step_wise: Restore passive polling management
  (jsc#PED-11164).
- thermal: trip: Trigger trip down notifications when trips
  involved in mitigation become invalid (jsc#PED-11164).
- thermal: core: Introduce thermal_trip_crossed() (jsc#PED-11164).
- thermal/debugfs: Allow tze_seq_show() to print statistics for
  invalid trips (jsc#PED-11164).
- commit c2820a3
* Tue Nov  5 2024 oneukum@suse.com
- media: videobuf2: fix typo: vb2_dbuf -> vb2_qbuf (git-fixes).
- commit 92209c4
* Tue Nov  5 2024 pjakobsson@suse.de
- drm/xe/xe_sync: initialise ufence.signalled (git-fixes).
- commit d97f733
* Tue Nov  5 2024 oneukum@suse.com
- media: bttv: use audio defaults for winfast2000 (git-fixes).
- commit 6e1da70
* Tue Nov  5 2024 mfranc@suse.cz
- scsi: elx: libefc: Fix potential use after free in
  efc_nport_vport_del() (CVE-2024-49852 bsc#1232819).
- commit 51395e6
* Tue Nov  5 2024 jlee@suse.com
- thermal: core: Fix the handling of invalid trip points
  (jsc#PED-11164).
- thermal/drivers/mediatek/lvts_thermal: Fix wrong lvts_ctrl index
  (jsc#PED-11164).
- thermal/drivers/mediatek/lvts_thermal: Remove unused members
  from struct lvts_ctrl_data (jsc#PED-11164).
- thermal: core: Move passive polling management to the core
  (jsc#PED-11164).
  Refresh
  patches.suse/thermal-gov_power_allocator-Return-early-in-manage-i.patch.
- thermal: core: Do not call handle_thermal_trip() if zone
  temperature is invalid (jsc#PED-11164).
- thermal: trip: Add missing empty code line (jsc#PED-11164).
- thermal/debugfs: Avoid printing zero duration for mitigation
  events in progress (jsc#PED-11164).
  Refresh
  patches.suse/thermal-debugfs-Print-initial-trip-temperature-and-h.patch.
  blacklist.conf:
  Removed bd700ba9adef01cf8aaeb5f5fcf911ee1a705543
- thermal: core: Introduce thermal_governor_trip_crossed()
  (jsc#PED-11164).
- thermal/debugfs: Make tze_seq_show() skip invalid trips and
  trips with no stats (jsc#PED-11164).
  Refresh
  patches.suse/thermal-debugfs-Print-initial-trip-temperature-and-h.patch.
- thermal/debugfs: Rename thermal_debug_update_temp() to
  thermal_debug_update_trip_stats() (jsc#PED-11164).
  Refresh
  patches.suse/thermal-debugfs-Pass-cooling-device-state-to-thermal.patch.
- thermal/debugfs: Clean up thermal_debug_update_temp()
  (jsc#PED-11164).
- thermal: core: Relocate critical and hot trip handling
  (jsc#PED-11164).
- thermal: core: Drop the .throttle() governor callback
  (jsc#PED-11164).
- thermal: gov_user_space: Use .trip_crossed() instead of
  .throttle() (jsc#PED-11164).
- thermal: gov_fair_share: Eliminate unnecessary integer divisions
  (jsc#PED-11164).
- thermal: gov_fair_share: Use trip thresholds instead of trip
  temperatures (jsc#PED-11164).
- thermal: gov_fair_share: Use .manage() callback instead of
  .throttle() (jsc#PED-11164).
- thermal: gov_step_wise: Clean up thermal_zone_trip_update()
  (jsc#PED-11164).
- thermal: gov_step_wise: Use trip thresholds instead of trip
  temperatures (jsc#PED-11164).
- thermal: gov_step_wise: Use .manage() callback instead of
  .throttle() (jsc#PED-11164).
- thermal: gov_power_allocator: Eliminate a redundant variable
  (jsc#PED-11164).
  Refresh
  patches.suse/thermal-gov_power_allocator-Return-early-in-manage-i.patch.
- thermal: core: Introduce .manage() callback for thermal
  governors (jsc#PED-11164).
  Refresh
  patches.suse/thermal-debugfs-Avoid-excessive-updates-of-trip-poin.patch.
- thermal: gov_bang_bang: Fold thermal_zone_trip_update() into
  its caller (jsc#PED-11164).
- thermal: gov_bang_bang: Clean up thermal_zone_trip_update()
  (jsc#PED-11164).
- thermal: gov_bang_bang: Use .trip_crossed() instead of
  .throttle() (jsc#PED-11164).
- thermal: core: Introduce .trip_crossed() callback for thermal
  governors (jsc#PED-11164).
  Refresh
  patches.suse/thermal-debugfs-Avoid-excessive-updates-of-trip-poin.patch.
- thermal/drivers/loongson2: Add Loongson-2K2000 support
  (jsc#PED-11164).
- thermal/drivers/loongson2: Trivial code style adjustment
  (jsc#PED-11164).
- thermal/drivers/mediatek/lvts_thermal: Add MT8188 support
  (jsc#PED-11164).
- thermal/drivers/mediatek/lvts_thermal: Allow early empty sensor
  slots (jsc#PED-11164).
- thermal/drivers/mediatek/lvts_thermal: Provision for gt variable
  location (jsc#PED-11164).
  Refresh
  patches.suse/thermal-drivers-mediatek-lvts_thermal-Return-error-i.patch.
- thermal/drivers/mediatek/lvts_thermal: Add MT8186 support
  (jsc#PED-11164).
- thermal/drivers/mediatek/lvts_thermal: Guard against efuse
  data buffer overflow (jsc#PED-11164).
- thermal/drivers/mediatek/lvts_thermal: Use offsets for every
  calibration byte (jsc#PED-11164).
- thermal/drivers/mediatek/lvts_thermal: Remove .hw_tshut_temp
  (jsc#PED-11164).
- thermal/drivers/mediatek/lvts_thermal: Move comment
  (jsc#PED-11164).
  Refresh
  patches.suse/thermal-drivers-mediatek-lvts_thermal-Return-error-i.patch.
- thermal/drivers/mediatek/lvts_thermal: Retrieve all calibration
  bytes (jsc#PED-11164).
- thermal/drivers/k3_bandgap: Remove some unused fields in struct
  k3_bandgap (jsc#PED-11164).
- thermal/drivers/qcom: Remove some unused fields in struct
  qpnp_tm_chip (jsc#PED-11164).
- thermal/drivers/rcar_gen3: Update temperature approximation
  calculation (jsc#PED-11164).
- thermal/drivers/rcar_gen3: Move Tj_T storage to shared private
  data (jsc#PED-11164).
- drivers/thermal/rcar_gen3_thermal: add reading fuses for Gen4
  (jsc#PED-11164).
  Refresh
  patches.suse/thermal-drivers-rcar_gen3-Add-support-for-R-Car-V4M.patch.
- drivers/thermal/rcar_gen3_thermal: refactor reading fuses into
  seprarate function (jsc#PED-11164).
- drivers/thermal/rcar_gen3_thermal: introduce 'info' structure
  (jsc#PED-11164).
  Refresh
  patches.suse/thermal-drivers-rcar_gen3-Add-support-for-R-Car-V4M.patch.
- commit 8470fee
* Tue Nov  5 2024 jwiesner@suse.de
- Update config files.
  c37e85c135ce ("clocksource: Loosen clocksource watchdog constraints")
  introduced a new default for the time skew measured by the clocksource
  watchdog. The value was raised from 100 to 125 microseconds. Reflect this
  change in the kernel config. This is an x86_64 option only.
- commit 14c1b2d
* Tue Nov  5 2024 tiwai@suse.de
- ALSA: usb-audio: Add quirk for HP 320 FHD Webcam (bsc#1232768).
- commit 7c39137
* Tue Nov  5 2024 shung-hsi.yu@suse.com
- kABI: bpf: struct bpf_func_state kABI workaround (CVE-2024-47703
  bsc#1231946).
- commit fd45833
* Tue Nov  5 2024 shung-hsi.yu@suse.com
- selftests/bpf: Workaround strict bpf_lsm return value check
  (CVE-2024-47703 bsc#1231946).
- selftests/bpf: Add verifier tests for bpf lsm (CVE-2024-47703
  bsc#1231946).
- selftests/bpf: Add return value checks for failed tests
  (CVE-2024-47703 bsc#1231946).
- bpf: Fix compare error in function retval_range_within
  (CVE-2024-47703 bsc#1231946).
- bpf, lsm: Add check for BPF LSM return value (CVE-2024-47703
  bsc#1231946).
- Refresh patches.suse/bpf-Fail-verification-for-sign-extension-of-packet-d.patch
- Refresh patches.kabi/bpf-struct-bpf_insn_access_aux-workaround.patch
- selftests/bpf: fix timer/test_bad_ret subtest on
  test_progs-cpuv4 flavor (CVE-2024-47703 bsc#1231946).
- commit a0c7d4f
* Tue Nov  5 2024 tiwai@suse.de
- rpmsg: glink: Handle rejected intent request better (git-fixes).
- firmware: arm_scmi: Fix slab-use-after-free in
  scmi_bus_notifier() (git-fixes).
- commit 01fe6bf
* Tue Nov  5 2024 jlee@suse.com
- crypto: testmgr - move pkcs1pad(rsa,sha3-*) to correct place
  (jsc#PED-11152).
- commit 974f34d
* Tue Nov  5 2024 tonyj@suse.de
- Update prior SP6 git-fixes patches with SP7 Jira references:
  - patches.suse/perf-x86-intel-ucore-support-hbm-and-cxl-pmon-counters.patch
    (bsc#1230119, jsc#PED-10049, jsc#PED-10387).
  - patches.suse/perf-x86-uncore-apply-the-unit-control-rb-tree-to-mmio.patch
    (bsc#1230119, jsc#PED-10387).
  - patches.suse/perf-x86-uncore-apply-the-unit-control-rb-tree-to-msr-uncore.patch
    (bsc#1230119, jsc#PED-10387).
  - patches.suse/perf-x86-uncore-apply-the-unit-control-rb-tree-to-pci-uncore.patch
    (bsc#1230119, jsc#PED-10387).
  - patches.suse/perf-x86-uncore-cleanup-unused-unit-structure.patch
    (bsc#1230119, jsc#PED-10387).
  - patches.suse/perf-x86-uncore-retrieve-the-unit-id-from-the-unit-control.patch
    (bsc#1230119, jsc#PED-10387).
  - patches.suse/perf-x86-uncore-save-the-unit-control-address-of-all-units.patch
    (bsc#1230119, jsc#PED-10387).
  - patches.suse/perf-x86-uncore-support-per-pmu-cpumask.patch
    (bsc#1230119, jsc#PED-10387).
- commit 6813dac
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/intel/uncore: Use D0:F0 as a default device
  (jsc#PED-10391, jsc#PED-10224).
- commit 371b7de
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/intel/uncore: Add LNL uncore iMC freerunning support
  (jsc#PED-10224).
- commit 90fb274
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/intel/uncore: Add Lunar Lake support (jsc#PED-10224).
- commit 2c82546
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/intel/uncore: Factor out common MMIO init and ops
  functions (jsc#PED-10224).
- commit 08abd33
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/intel/uncore: Add Arrow Lake support (jsc#PED-10224).
- commit 5675c55
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/intel: Support Perfmon MSRs aliasing (jsc#PED-10203).
- commit 5023c31
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/intel: Support PERFEVTSEL extension (jsc#PED-10240,
  jsc#PED-10203).
- commit ee88eef
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86: Add config_mask to represent EVENTSEL bitmask
  (jsc#PED-10203).
- commit f86a126
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/intel: Support new data source for Lunar Lake
  (jsc#PED-10203).
- commit 9eaf27d
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/intel: Rename model-specific pebs_latency_data
  functions (jsc#PED-10203).
- commit e69b493
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86: Add Lunar Lake and Arrow Lake support (jsc#PED-10390,
  jsc#PED-10243, jsc#PED-10206, jsc#PED-10203).
- commit 391f34c
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86: Support counter mask (jsc#PED-10398, jsc#PED-10203,
  jsc#PED-10390, jsc#PED-10243, jsc#PED-10206).
- Refresh
  patches.suse/perf-x86-Fix-smp_processor_id-in-preemptible-warnings.patch.
- commit 30407ac
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/intel: Support the PEBS event mask (jsc#PED-10398,
  jsc#PED-10390, jsc#PED-10243, jsc#PED-10206, jsc#PED-10203).
- commit a0d4f20
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/intel/cstate: Add Lunarlake support (jsc#PED-10203,
  jsc#PED-10389).
- Refresh
  patches.suse/perf-x86-intel-cstate-Add-pkg-C2-residency-counter-for-Sierra-Forest.patch.
- commit fa4f940
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/intel/cstate: Add Arrowlake support (jsc#PED-10061).
- Refresh
  patches.suse/perf-x86-intel-cstate-Add-pkg-C2-residency-counter-for-Sierra-Forest.patch.
- commit bc4f74e
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/amd: Use try_cmpxchg() in events/amd/{un,}core.c
  (jsc#PED-10398, jsc#PED-10203, jsc#PED-10390, jsc#PED-10243,
  jsc#PED-10206).
- commit fb071e3
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/rapl: Add support for Intel Lunar Lake (jsc#PED-10051).
- Refresh
  patches.suse/perf-x86-rapl-Switch-to-new-Intel-CPU-model-defines.patch.
- commit 48612f5
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/rapl: Add support for Intel Arrow Lake (jsc#PED-10059).
- Refresh
  patches.suse/perf-x86-rapl-Switch-to-new-Intel-CPU-model-defines.patch.
- commit ff09697
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/intel/cstate: Add Grand Ridge support (jsc#PED-10061).
- Refresh
  patches.suse/perf-x86-intel-cstate-Switch-to-new-Intel-CPU-model-define.patch.
- commit acd973a
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/intel: Correct incorrect 'or' operation for PMU
  capabilities (jsc#PED-10398, jsc#PED-10203, jsc#PED-10390,
  jsc#PED-10243, jsc#PED-10206).
- commit 2469364
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/amd/uncore: Refactor uncore management (jsc#PED-10398,
  jsc#PED-10203, jsc#PED-10390, jsc#PED-10243, jsc#PED-10206).
- commit 51cad86
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/intel: Extend the ref-cycles event to GP counters
  (jsc#PED-10398, jsc#PED-10203, jsc#PED-10390, jsc#PED-10243,
  jsc#PED-10206).
- commit 5d28657
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/intel: Fix broken fixed event constraints extension
  (jsc#PED-10398, jsc#PED-10390, jsc#PED-10243, jsc#PED-10206,
  jsc#PED-10203).
- commit dc84876
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/intel: Add common intel_pmu_init_hybrid()
  (jsc#PED-10398, jsc#PED-10390, jsc#PED-10243, jsc#PED-10206,
  jsc#PED-10203).
- Refresh
  patches.suse/perf-x86-intel-Switch-to-new-Intel-CPU-model-defines.patch.
- commit 2d5ab89
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/intel: Clean up the hybrid CPU type handling code
  (jsc#PED-10398, jsc#PED-10390, jsc#PED-10243, jsc#PED-10206,
  jsc#PED-10203).
- Refresh
  patches.suse/perf-x86-intel-Limit-the-period-on-Haswell.patch.
- commit c816fd1
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/intel: Apply the common initialization code for ADL
  (jsc#PED-10398, jsc#PED-10390, jsc#PED-10243, jsc#PED-10206,
  jsc#PED-10203).
- Refresh
  patches.suse/perf-x86-intel-Switch-to-new-Intel-CPU-model-defines.patch.
- commit 6277f39
* Tue Nov  5 2024 tonyj@suse.de
- perf/x86/intel: Factor out the initialization code for
  ADL e-core (jsc#PED-10398, jsc#PED-10390, jsc#PED-10243,
  jsc#PED-10206, jsc#PED-10203).
- Refresh
  patches.suse/perf-x86-intel-Switch-to-new-Intel-CPU-model-defines.patch.
- commit 4b03a81
* Mon Nov  4 2024 dsterba@suse.com
- Update references for patches.suse/tracing-timerlat-Fix-a-race-during-cpuhp-processing.patch (CVE-2024-49866 bsc#1232259 git-fixes)
- commit d9311d0
* Mon Nov  4 2024 jlee@suse.com
- KEYS: asymmetric: Add missing dependencies of
  FIPS_SIGNATURE_SELFTEST (jsc#PED-11152).
  Refresh
  patches.suse/certs-Move-RSA-self-test-data-to-separate-file.patch.
- KEYS: asymmetric: Add missing dependency on CRYPTO_SIG
  (jsc#PED-11152).
  Update config files.
  CONFIG_CRYPTO_SIG=y
- X.509: Introduce scope-based x509_certificate allocation
  (jsc#PED-11152).
- crypto: x509 - Add OID for NIST P521 and extend parser for it
  (jsc#PED-11152).
- crypto: asymmetric_keys - Adjust signature size calculation
  for NIST P521 (jsc#PED-11152).
- keys: update key quotas in key_put() (jsc#PED-11152).
- commit ae71a7b
* Mon Nov  4 2024 tiwai@suse.de
- Move out-of-tree patch into a proper section
- commit c581359
* Mon Nov  4 2024 tiwai@suse.de
- Revert "ALSA: hda/conexant: Mute speakers at suspend / shutdown"
  (bsc#1228269).
- commit 13ce240
* Mon Nov  4 2024 jlee@suse.com
- Revert "crypto: pkcs7 - remove sha1 support" (jsc#PED-11152).
- crypto: asymmetric_keys - remove redundant pointer secs
  (jsc#PED-11152).
- Documentation/module-signing.txt: bring up to date
  (jsc#PED-11152).
- module: enable automatic module signing with FIPS 202 SHA-3
  (jsc#PED-11152).
  Update config files.
  CONFIG_MODULE_SIG_SHA3_256 is not set
  CONFIG_MODULE_SIG_SHA3_384 is not set
  CONFIG_MODULE_SIG_SHA3_512 is not set
- crypto: asymmetric_keys - allow FIPS 202 SHA-3 signatures
  (jsc#PED-11152).
- crypto: rsa-pkcs1pad - Add FIPS 202 SHA-3 support
  (jsc#PED-11152).
- crypto: FIPS 202 SHA-3 register in hash info for IMA
  (jsc#PED-11152).
- x509: Add OIDs for FIPS 202 SHA-3 hash and signatures
  (jsc#PED-11152).
  Refresh
  patches.suse/0001-X.509-Add-CodeSigning-extended-key-usage-parsing.patch.
- crypto: qcom-rng - Add missing dependency on hw_random
  (jsc#PED-11152).
- certs: Limit MODULE_SIG_KEY_TYPE_ECDSA to SHA384 or SHA512
  (jsc#PED-11152).
  Update config files.
  Removed 'CONFIG_MODULE_SIG_KEY_TYPE_ECDSA is not set'
- commit c444b7a
* Mon Nov  4 2024 dwagner@suse.de
- scsi: lpfc: Update lpfc version to 14.4.0.5 (bsc#1232757).
- scsi: lpfc: Support loopback tests with VMID enabled
  (bsc#1232757).
- scsi: lpfc: Revise TRACE_EVENT log flag severities from KERN_ERR
  to KERN_WARNING (bsc#1232757).
- scsi: lpfc: Ensure DA_ID handling completion before deleting
  an NPIV instance (bsc#1232757).
- scsi: lpfc: Fix kref imbalance on fabric ndlps from dev_loss_tmo
  handler (bsc#1232757).
- scsi: lpfc: Restrict support for 32 byte CDBs to specific HBAs
  (bsc#1232757 bsc#1228119).
- scsi: lpfc: Update phba link state conditional before sending
  CMF_SYNC_WQE (bsc#1232757).
- scsi: lpfc: Add ELS_RSP cmd to the list of WQEs to flush in
  lpfc_els_flush_cmd() (bsc#1232757).
- scsi: lpfc: Remove trailing space after \n newline
  (bsc#1232757).
- commit 3cf27b4
* Mon Nov  4 2024 vkarasulli@suse.de
- ext4: fix timer use-after-free on failed mount (CVE-2024-49960
  bsc#1232395).
- commit bd6997d
* Mon Nov  4 2024 mfranc@suse.cz
- net/xen-netback: prevent UAF in xenvif_flush_hash()
  (CVE-2024-49936 bsc#1232424).
- commit ae05dab
* Mon Nov  4 2024 jlee@suse.com
- crypto: mscode_parser - remove sha224 authenticode support
  (jsc#PED-11152).
- crypto: pkcs7 - remove sha1 support (jsc#PED-11152).
- crypto: pkcs7 - remove md4 md5 x.509 support (jsc#PED-11152).
- X.509: Add missing IMPLICIT annotations to AKID ASN.1 module
  (jsc#PED-11152).
- KEYS: encrypted: Do not include crypto/algapi.h (jsc#PED-11152).
- certs: Only allow certs signed by keys on the builtin keyring
  (jsc#PED-11152).
  Update config files.
  CONFIG_SECONDARY_TRUSTED_KEYRING_SIGNED_BY_BUILTIN is not set
- commit 7c8c3c9
* Mon Nov  4 2024 vkarasulli@suse.de
- tipc: guard against string buffer overrun (CVE-2024-49995
  bsc#1232432).
- commit ada263e
* Mon Nov  4 2024 dwagner@suse.de
-  Update
  patches.suse/scsi-lpfc-change-diagnostic-log-flag-during-receipt-of-unknown-els.patch
  (bsc#1229429 jsc#PED-9899 jsc#PED-11255).
- Update
  patches.suse/scsi-lpfc-copyright-updates-for-14.4.0.4-patches.patch
  (bsc#1229429 jsc#PED-9899 jsc#PED-11255).
- Update patches.suse/scsi-lpfc-fix-overflow-build-issue.patch
  (bsc#1229429 jsc#PED-9899 jsc#PED-11255).
- Update
  patches.suse/scsi-lpfc-fix-unintentional-double-clearing-of-vmid_flag.patch
  (bsc#1229429 jsc#PED-9899 jsc#PED-11255).
- Update
  patches.suse/scsi-lpfc-fix-unsolicited-flogi-kref-imbalance-when-in-direct.patch
  (bsc#1229429 jsc#PED-9899 jsc#PED-11255).
- Update
  patches.suse/scsi-lpfc-remove-redundant-vport-assignment-when-building-an-abort.patch
  (bsc#1229429 jsc#PED-9899 jsc#PED-11255).
- Update
  patches.suse/scsi-lpfc-update-lpfc-version-to-14.4.0.4.patch
  (bsc#1229429 jsc#PED-9899 jsc#PED-11255).
- Update
  patches.suse/scsi-lpfc-update-prlo-handling-in-direct-attached-topology.patch
  (bsc#1229429 jsc#PED-9899 jsc#PED-11255).
- Update
  patches.suse/scsi-lpfc-validate-hdwq-pointers-before-dereferencing-in.patch
  (bsc#1229429 jsc#PED-9899 jsc#PED-11255 CVE-2024-49891
  bsc#1232218).
- commit b713b86
* Mon Nov  4 2024 tiwai@suse.de
- drm/amdkfd: amdkfd_free_gtt_mem clear the correct pointer
  (CVE-2024-49991 bsc#1232282).
- commit 1b15839
* Mon Nov  4 2024 dwagner@suse.de
- nvme: re-fix error-handling for io_uring nvme-passthrough
  (git-fixes).
- nvmet-auth: assign dh_key to NULL after kfree_sensitive
  (git-fixes).
- nvme-pci: fix race condition between reset and
  nvme_dev_disable() (git-fixes).
- nvme: null terminate nvme_tls_attrs (git-fixes).
- nvme-pci: set doorbell config before unquiescing (git-fixes).
- commit d7598b1
* Mon Nov  4 2024 jlee@suse.com
- x86/efistub: Drop redundant clearing of BSS (jsc#PED-11167).
- efi: Add missing __nocfi annotations to runtime wrappers
  (jsc#PED-11167).
- efi: pstore: Return proper errors on UEFI failures
  (jsc#PED-11167).
- efi/libstub: zboot.lds: Discard .discard sections
  (jsc#PED-11167).
- x86/efistub: Omit physical KASLR when memory reservations exist
  (jsc#PED-11167).
- efi: Clear up misconceptions about a maximum variable name size
  (jsc#PED-11167).
- efivarfs: Remove unused internal struct members (jsc#PED-11167).
- efi: pstore: Request at most 512 bytes for variable names
  (jsc#PED-11167).
- x86/efistub: Reinstate soft limit for initrd loading
  (jsc#PED-11167).
- x86/efistub: Don't clear BSS twice in mixed mode
  (jsc#PED-11167).
- driver core: Adds flags param to fwnode_link_add()
  (jsc#PED-11167).
- x86/efistub: Clear decompressor BSS in native EFI entrypoint
  (jsc#PED-11167).
- PCI/AER: Generalize TLP Header Log reading (jsc#PED-11167).
- PCI/AER: Use explicit register sizes for struct members
  (jsc#PED-11167).
- commit cd55dc9
* Mon Nov  4 2024 trenn@suse.com
- tools/power/x86/intel-speed-select: v1.20 release
  (jsc#PED-10347).
- tools/power/x86/intel-speed-select: Set TRL MSR in 100 MHz units
  (jsc#PED-10347).
- tools/power/x86/intel-speed-select: v1.19 release
  (jsc#PED-10347).
- tools/power/x86/intel-speed-select: Display CPU as None for -1
  (jsc#PED-10347).
- tools/power/x86/intel-speed-select: SST BF/TF support per level
  (jsc#PED-10347).
- tools/power/x86/intel-speed-select: Increase number of CPUs
  displayed (jsc#PED-10347).
- tools/power/x86/intel-speed-select: Present all TRL levels
  for turbo-freq (jsc#PED-10347).
- tools/power/x86/intel-speed-select: Fix display for unsupported
  levels (jsc#PED-10347).
- tools/power/x86/intel-speed-select: Support multiple dies
  (jsc#PED-10347).
- tools/power/x86/intel-speed-select: Increase die count
  (jsc#PED-10347).
- commit f29ff95
* Mon Nov  4 2024 jlee@suse.com
- x86/efistub: Remap kernel text read-only before dropping NX
  attribute (jsc#PED-11167).
- efi/libstub: Add get_event_log() support for CC platforms
  (jsc#PED-11167).
- efi/libstub: Measure into CC protocol if TCG2 protocol is absent
  (jsc#PED-11167).
- efi/libstub: Add Confidential Computing (CC) measurement
  typedefs (jsc#PED-11167).
- efi/tpm: Use symbolic GUID name from spec for final events table
  (jsc#PED-11167).
- efi/libstub: Use TPM event typedefs from the TCG PC Client spec
  (jsc#PED-11167).
- efi: pstore: Allow dynamic initialization based on module
  parameter (jsc#PED-11167).
- x86/boot: Move mem_encrypt= parsing to the decompressor
  (jsc#PED-11167).
- efi/libstub: Add generic support for parsing mem_encrypt=
  (jsc#PED-11167).
- x86/efi: Implement arch_ima_efi_boot_mode() in source file
  (jsc#PED-11167).
- x86/setup: Move internal setup_data structures into setup_data.h
  (jsc#PED-11167).
- x86/setup: Move UAPI setup structures into setup_data.h
  (jsc#PED-11167).
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch.
- commit c9d867f
* Mon Nov  4 2024 pjakobsson@suse.de
- Update patches with alt-commit entries
- blacklist.conf: Remove alt-commit entries
- Refresh patches.suse/0175-drm-msm-Use-struct-fb_info.screen_buffer.patch.
- Refresh patches.suse/0228-drm-i915-mtl-Set-has_llc-0.patch.
- Refresh
  patches.suse/0001-drm-mst-Fix-NULL-pointer-dereference-at-drm_dp_add_p.patch.
- Refresh
  patches.suse/0010-drm-amdgpu-reject-gang-submit-on-reserved-VMIDs.patch.
- Refresh
  patches.suse/0197-drm-xe-Add-process-name-to-devcoredump.patch.
- Refresh
  patches.suse/0398-drm-amd-display-Correct-unit-conversion-for-vstartup.patch.
- Refresh patches.suse/0784-drm-xe-Enable-32bits-build.patch.
- Refresh
  patches.suse/0790-drm-mediatek-Convert-to-platform-remove-callback-ret.patch.
- Refresh
  patches.suse/1003-drm-ttm-tests-Require-MMU-when-testing.patch.
- Refresh
  patches.suse/1117-drm-mediatek-Drop-chain_mode_fixup-call-in-mode_vali.patch.
- Refresh
  patches.suse/1127-drm-xe-kunit-fix-link-failure-with-built-in-xe.patch.
- Refresh
  patches.suse/1128-drm-xe-xe2-fix-64-bit-division-in-pte_update_size.patch.
- Refresh
  patches.suse/1129-drm-xe-guc-Fix-missing-topology-init.patch.
- Refresh
  patches.suse/1130-drm-xe-Remove-obsolete-async_ops-from-struct-xe_vm.patch.
- Refresh
  patches.suse/1131-drm-xe-Fix-ref-counting-leak-on-page-fault.patch.
- Refresh
  patches.suse/1132-drm-xe-Replace-grouped-target-in-Makefile-with-patte.patch.
- Refresh
  patches.suse/1173-drm-nouveau-sched-avoid-job-races-between-entities.patch.
- Refresh
  patches.suse/1174-drm-nouveau-uvmm-fix-unset-region-pointer-on-remap.patch.
- Refresh
  patches.suse/1175-drm-nouveau-uapi-don-t-pass-NO_PREFETCH-flag-implici.patch.
- Refresh
  patches.suse/1178-drm-i915-Fix-TLB-Invalidation-seqno-store.patch.
- Refresh
  patches.suse/1199-fbdev-g364fb-fix-build-failure-with-mips.patch.
- Refresh
  patches.suse/1209-drm-xe-Merge-16021540221-and-18034896535-WAs.patch.
- Refresh
  patches.suse/1220-drm-amd-display-Enable-Replay-for-static-screen-use-.patch.
- Refresh
  patches.suse/1221-drm-amdgpu-pm-Add-notification-for-no-DC-support.patch.
- Refresh
  patches.suse/1222-Documentation-gpu-Update-amdgpu-documentation.patch.
- Refresh
  patches.suse/1223-drm-amdgpu-Only-support-RAS-EEPROM-on-dGPU-platform.patch.
- Refresh
  patches.suse/1224-drm-amdgpu-update-mall-info-v2-from-discovery.patch.
- Refresh
  patches.suse/1225-drm-amdgpu-update-gc_info-v2_1-from-discovery.patch.
- Refresh
  patches.suse/1226-drm-amd-pm-Update-SMUv13.0.6-PMFW-headers.patch.
- Refresh
  patches.suse/1227-drm-amd-pm-Add-critical-temp-for-GC-v9.4.3.patch.
- Refresh
  patches.suse/1228-drm-amdgpu-jpeg-skip-change-of-power-gating-state-fo.patch.
- Refresh
  patches.suse/1229-drm-amdkfd-retry-after-EBUSY-is-returned-from-hmm_ra.patch.
- Refresh
  patches.suse/1230-drm-amdgpu-Enable-ras-for-mp0-v13_0_6-sriov.patch.
- Refresh
  patches.suse/1231-drm-amd-display-Roll-back-unit-correction.patch.
- Refresh
  patches.suse/1233-drm-amd-display-set-minimum-of-VBlank_nom.patch.
- Refresh
  patches.suse/1234-drm-amdgpu-Unset-baco-dummy-mode-on-nbio-v7.9.patch.
- Refresh
  patches.suse/1235-drm-amdkfd-use-correct-method-to-get-clock-under-SRI.patch.
- Refresh
  patches.suse/1236-drm-amdgpu-Add-bootloader-status-check.patch.
- Refresh
  patches.suse/1237-drm-amdgpu-Remove-SRAM-clock-gater-override-by-drive.patch.
- Refresh
  patches.suse/1238-drm-amd-pm-Fix-critical-temp-unit-of-SMU-v13.0.6.patch.
- Refresh
  patches.suse/1240-drm-amd-display-fix-static-screen-detection-setting.patch.
- Refresh
  patches.suse/1241-drm-amdgpu-Fix-the-return-for-gpu-mode1_reset.patch.
- Refresh
  patches.suse/1242-drm-amd-pm-fix-debugfs-pm_info-output.patch.
- Refresh
  patches.suse/1243-drm-amdgpu-Updated-TCP-UTCL1-programming.patch.
- Refresh
  patches.suse/1244-drm-amdgpu-register-a-dirty-framebuffer-callback-for.patch.
- Refresh
  patches.suse/1245-drm-amdgpu-Add-bootloader-wait-for-PSP-v13.patch.
- Refresh
  patches.suse/1245-drm-xe-Invalidate-userptr-VMA-on-page-pin-fault.patch.
- Refresh
  patches.suse/1246-drm-xe-Return-if-kobj-creation-is-failed.patch.
- Refresh
  patches.suse/1247-Partially-revert-drm-amd-display-update-add-plane-to.patch.
- Refresh
  patches.suse/1247-drm-xe-Skip-VMAs-pin-when-requesting-signal-to-the-l.patch.
- Refresh
  patches.suse/1248-drm-amdgpu-Add-SMU-v13.0.6-default-reset-methods.patch.
- Refresh
  patches.suse/1250-drm-amd-display-update-blank-state-on-ODM-changes.patch.
- Refresh
  patches.suse/1253-drm-amdgpu-Add-umc_info-v4_0-structure.patch.
- Refresh
  patches.suse/1254-drm-amdgpu-Support-query-ecc-cap-for-aqua_vanjaram.patch.
- Refresh
  patches.suse/1255-drm-amdgpu-Allocate-coredump-memory-in-a-nonblocking.patch.
- Refresh
  patches.suse/1256-drm-amdkfd-use-mask-to-get-v9-interrupt-sq-data-bits.patch.
- Refresh
  patches.suse/1257-drm-amdgpu-use-read-modify-write-mode-for-gfx-v9_4_3.patch.
- Refresh
  patches.suse/1258-drm-amdgpu-Hide-xcp-partition-sysfs-under-SRIOV.patch.
- Refresh
  patches.suse/1259-drm-amdgpu-Free-ras-cmd-input-buffer-properly.patch.
- Refresh
  patches.suse/1260-drm-amdkfd-Add-missing-gfx11-MQD-manager-callbacks.patch.
- Refresh
  patches.suse/1261-Revert-Revert-drm-amd-display-Implement-zpos-propert.patch.
- Refresh
  patches.suse/1262-drm-amdgpu-fix-amdgpu_cs_p1_user_fence.patch.
- Refresh
  patches.suse/1264-drm-amd-display-limit-the-v_startup-workaround-to-AS.patch.
- Refresh
  patches.suse/1267-drm-amdgpu-Restrict-bootloader-wait-to-SMUv13.0.6.patch.
- Refresh
  patches.suse/1274-drm-amdkfd-Fix-reg-offset-for-setting-CWSR-grace-per.patch.
- Refresh
  patches.suse/1275-drm-amdkfd-Fix-unaligned-64-bit-doorbell-warning.patch.
- Refresh
  patches.suse/1276-drm-amdgpu-Store-CU-info-from-all-XCCs-for-GFX-v9.4..patch.
- Refresh
  patches.suse/1277-drm-amdkfd-Update-cache-info-reporting-for-GFX-v9.4..patch.
- Refresh
  patches.suse/1278-drm-amdkfd-Update-CU-masking-for-GFX-9.4.3.patch.
- Refresh
  patches.suse/1280-Revert-drm-amd-Disable-S-G-for-APUs-when-64GB-or-mor.patch.
- Refresh
  patches.suse/1281-drm-amd-display-Add-dirty-rect-support-for-Replay.patch.
- Refresh patches.suse/1282-drm-amdgpu-fix-retry-loop-test.patch.
- Refresh
  patches.suse/1283-drm-amd-display-Don-t-check-registers-if-using-AUX-B.patch.
- Refresh
  patches.suse/1284-drm-amdgpu-soc21-don-t-remap-HDP-registers-for-SR-IO.patch.
- Refresh
  patches.suse/1285-drm-amdgpu-nbio4.3-set-proper-rmmio_remap.reg_offset.patch.
- Refresh
  patches.suse/1286-drm-amdgpu-fallback-to-old-RAS-error-message-for-aqu.patch.
- Refresh
  patches.suse/1287-drm-amd-display-Adjust-the-MST-resume-flow.patch.
- Refresh
  patches.suse/1288-drm-amdkfd-Checkpoint-and-restore-queues-on-GFX11.patch.
- Refresh
  patches.suse/1289-drm-amdgpu-Handle-null-atom-context-in-VBIOS-info-io.patch.
- Refresh
  patches.suse/1290-drm-amd-display-fix-replay_mode-kernel-doc-warning.patch.
- Refresh
  patches.suse/1291-drm-amd-display-Add-DPIA-Link-Encoder-Assignment-Fix.patch.
- Refresh
  patches.suse/1291-drm-fb_dma-Add-checks-in-drm_fb_dma_get_scanout_buff.patch.
- Refresh
  patches.suse/1292-drm-amd-display-Fix-2nd-DPIA-encoder-Assignment.patch.
- Refresh
  patches.suse/1293-drm-amdkfd-Insert-missing-TLB-flush-on-GFX10-and-lat.patch.
- Refresh
  patches.suse/1301-drm-xe-Remove-unused-xe_bo-props-struct.patch.
- Refresh
  patches.suse/1302-drm-xe-guc_submit-use-jiffies-for-job-timeout.patch.
- Refresh
  patches.suse/1302-nouveau-u_memcpya-use-vmemdup_user.patch.
- Refresh
  patches.suse/1303-drm-xe-queue-fix-engine_class-bounds-check.patch.
- Refresh
  patches.suse/1304-drm-xe-device-fix-XE_MAX_GT_PER_TILE-check.patch.
- Refresh
  patches.suse/1305-drm-xe-device-fix-XE_MAX_TILES_PER_DEVICE-check.patch.
- Refresh
  patches.suse/1306-drm-xe-query-fix-gt_id-bounds-check.patch.
- Refresh
  patches.suse/1307-drm-i915-gt-Prevent-error-pointer-dereference.patch.
- Refresh patches.suse/1307-drm-xe-Fix-END-redefinition.patch.
- Refresh
  patches.suse/1308-drm-amd-swsmu-add-smu-14.0.1-vcn-and-jpeg-msg.patch.
- Refresh
  patches.suse/1309-drm-amd-display-Fix-MST-recognizes-connected-display.patch.
- Refresh
  patches.suse/1310-Revert-drm-amdgpu-Report-vbios-version-instead-of-PN.patch.
- Refresh
  patches.suse/1310-drm-amd-display-Increase-Z8-watermark-times.patch.
- Refresh
  patches.suse/1311-drm-amd-display-Prevent-crash-when-disable-stream.patch.
- Refresh
  patches.suse/1311-drm-amdgpu-fix-a-memory-leak-in-amdgpu_ras_feature_e.patch.
- Refresh
  patches.suse/1312-drm-amd-display-increase-bb-clock-for-DCN351.patch.
- Refresh
  patches.suse/1313-drm-amdgpu-vpe-power-on-vpe-when-hw_init.patch.
- Refresh
  patches.suse/1313-drm-amdkfd-Use-gpu_offset-for-user-queue-s-wptr.patch.
- Refresh
  patches.suse/1314-drm-i915-gt-Fix-reservation-address-in-ggtt_reserve_.patch.
- Refresh
  patches.suse/1315-i915-guc-Get-runtime-pm-in-busyness-worker-only-if-a.patch.
- Refresh
  patches.suse/1316-drm-i915-Don-t-set-PIPE_CONTROL_FLUSH_L3-for-aux-inv.patch.
- Refresh
  patches.suse/1317-drm-i915-Register-engines-early-to-avoid-type-confus.patch.
- Refresh
  patches.suse/1318-drm-amd-display-fix-IPX-enablement.patch.
- Refresh
  patches.suse/1318-drm-i915-Invalidate-the-TLBs-on-each-GT.patch.
- Refresh
  patches.suse/1319-drm-amd-display-Update-dcn351-to-latest-dcn35-config.patch.
- Refresh
  patches.suse/1319-drm-amd-pm-add-unique_id-for-gc-11.0.3.patch.
- Refresh patches.suse/1320-drm-amdgpu-Fix-a-memory-leak.patch.
- Refresh
  patches.suse/1321-drm-amd-Fix-logic-error-in-sienna_cichlid_update_pci.patch.
- Refresh
  patches.suse/1321-drm-amd-display-fix-a-dereference-of-a-NULL-pointer.patch.
- Refresh
  patches.suse/1322-drm-amd-Fix-detection-of-_PR3-on-the-PCIe-root-port.patch.
- Refresh
  patches.suse/1323-drm-amd-display-apply-edge-case-DISPCLK-WDIVIDER-cha.patch.
- Refresh
  patches.suse/1325-drm-amdgpu-umsch-update-UMSCH-4.0-FW-interface.patch.
- Refresh patches.suse/1326-drm-amdgpu-enable-UMSCH-4.0.6.patch.
- Refresh
  patches.suse/1329-dma-buf-add-dma_fence_timestamp-helper.patch.
- Refresh
  patches.suse/1340-drm-i915-Add-includes-for-BUG_ON-BUILD_BUG_ON-in-i91.patch.
- Refresh
  patches.suse/1341-drm-i915-Stop-doing-double-audio-enable-disable-on-S.patch.
- Refresh
  patches.suse/1342-drm-i915-display-Disable-AuxCCS-framebuffers-if-buil.patch.
- Refresh
  patches.suse/1343-drm-amdgpu-add-missing-NULL-check.patch.
- Refresh
  patches.suse/1344-drm-amdgpu-fix-SI-failure-due-to-doorbells-allocatio.patch.
- Refresh
  patches.suse/1344-drm-i915-mtl-Update-workaround-14018575942.patch.
- Refresh
  patches.suse/1345-drm-i915-drrs-Refactor-CPU-transcoder-DRRS-check.patch.
- Refresh
  patches.suse/1346-drm-i915-display-debugfs-Fix-duplicate-checks-in-i91.patch.
- Refresh
  patches.suse/1351-drm-i915-Do-not-print-pxp-init-failed-with-0-when-it.patch.
- Refresh
  patches.suse/1352-drm-i915-vma-Fix-UAF-on-destroy-against-retire-race.patch.
- Refresh
  patches.suse/1353-drm-amdgpu-Reserve-fences-for-VM-update.patch.
- Refresh
  patches.suse/1359-drm-xlnx-zynqmp_dpsub-Fix-few-function-comments.patch.
- Refresh
  patches.suse/1360-drm-xlnx-zynqmp_dpsub-Fix-compilation-error.patch.
- Refresh
  patches.suse/1361-drm-xe-Use-ring-ops-TLB-invalidation-for-rebinds.patch.
- Refresh
  patches.suse/1362-drm-i915-cx0-Only-clear-set-the-Pipe-Reset-bit-of-th.patch.
- Refresh patches.suse/1362-drm-xe-Rework-rebinding.patch.
- Refresh
  patches.suse/1363-drm-i915-Retry-gtt-fault-when-out-of-fence-registers.patch.
- Refresh
  patches.suse/1363-drm-xe-Make-TLB-invalidation-fences-unordered.patch.
- Refresh
  patches.suse/1364-drm-xe-Move-vma-rebinding-to-the-drm_exec-locking-lo.patch.
- Refresh
  patches.suse/1365-drm-xe-Use-ordered-wq-for-preempt-fence-waiting.patch.
- Refresh
  patches.suse/1366-drm-i915-dp-Fix-DSC-state-HW-readout-for-SST-connect.patch.
- Refresh
  patches.suse/1368-drm-i915-psr-Calculate-PIPE_SRCSZ_ERLY_TPT-value.patch.
- Refresh
  patches.suse/1369-drm-i915-psr-Move-writing-early-transport-pipe-src.patch.
- Refresh
  patches.suse/1370-drm-amdkfd-handle-duplicate-BOs-in-reserve_bo_and_co.patch.
- Refresh
  patches.suse/1370-drm-i915-perf-Determine-context-valid-in-OA-reports.patch.
- Refresh
  patches.suse/1370-drm-i915-psr-Fix-intel_psr2_sel_fetch_et_alignment-u.patch.
- Refresh
  patches.suse/1371-drm-i915-gt-Limit-the-reserved-VM-space-to-only-the-.patch.
- Refresh
  patches.suse/1371-drm-i915-mcr-Hold-GT-forcewake-during-steering-opera.patch.
- Refresh
  patches.suse/1372-drm-i915-pmu-Check-if-pmu-is-closed-before-stopping-.patch.
- Refresh
  patches.suse/1373-drm-amd-Disable-ASPM-for-VI-w-all-Intel-systems.patch.
- Refresh
  patches.suse/1380-drm-i915-cdclk-Fix-voltage_level-programming-edge-ca.patch.
- Refresh
  patches.suse/1381-drm-i915-hdcp-Fix-get-remote-hdcp-capability-functio.patch.
- Refresh
  patches.suse/1382-drm-i915-guc-Fix-the-fix-for-reset-lock-confusion.patch.
- Refresh
  patches.suse/1383-drm-msm-remove-python-3.9-dependency-for-compiling-m.patch.
- Refresh
  patches.suse/1390-drm-amdgpu-umsch-reinitialize-write-pointer-in-hw-in.patch.
- Refresh
  patches.suse/1392-drm-amd-display-add-DCN-351-version-for-microcode-lo.patch.
- Refresh
  patches.suse/1394-drm-amdgpu-Add-mes_log_enable-to-control-mes-log-fea.patch.
- Refresh
  patches.suse/1395-drm-amdgpu-Increase-the-mes-log-buffer-size-as-per-n.patch.
- Refresh
  patches.suse/1396-drm-amd-swsmu-Update-smu-v14.0.0-headers-to-be-14.0..patch.
- Refresh
  patches.suse/1397-drm-amdgpu-add-smu-14.0.1-discovery-support.patch.
- Refresh
  patches.suse/1400-drm-amd-pm-fix-the-high-voltage-issue-after-unload.patch.
- Refresh
  patches.suse/1402-Revert-drm-i915-Remove-extra-multi-gt-pm-references.patch.
- Refresh
  patches.suse/1402-drm-amdgpu-clear-set_q_mode_offs-when-VM-changed.patch.
- Refresh
  patches.suse/1404-drm-amd-display-Return-max-resolution-supported-by-D.patch.
- Refresh
  patches.suse/1405-drm-i915-selftests-Set-always_coherent-to-false-when.patch.
- Refresh
  patches.suse/1406-drm-amd-display-always-reset-ODM-mode-in-context-whe.patch.
- Refresh
  patches.suse/1409-drm-xe-Change-pcode-timeout-to-50msec-while-polling-.patch.
- Refresh
  patches.suse/1410-drm-xe-Only-use-reserved-BCS-instances-for-usm-migra.patch.
- Refresh
  patches.suse/1411-drm-amd-display-Adjust-dprefclk-by-down-spread-perce.patch.
- Refresh
  patches.suse/1411-drm-xe-Properly-handle-alloc_guc_id-failure.patch.
- Refresh
  patches.suse/1412-drm-amdgpu-correct-hbm-field-in-boot-status.patch.
- Refresh
  patches.suse/1412-drm-amdgpu-differentiate-external-rev-id-for-gfx-11..patch.
- Refresh
  patches.suse/1414-drm-amdgpu-Adjust-logic-in-amdgpu_device_partner_ban.patch.
- Refresh
  patches.suse/1416-drm-amdgpu-fix-dereference-null-return-value-for-the.patch.
- Refresh
  patches.suse/1418-drm-amdkfd-simplify-APU-VRAM-handling.patch.
- Refresh
  patches.suse/1419-drm-amdgpu-Make-CPX-mode-auto-default-in-NPS4.patch.
- Refresh
  patches.suse/1420-drm-amd-pm-remove-deprecated-I2C_CLASS_SPD-support-f.patch.
- Refresh
  patches.suse/1421-drm-xe-pf-Update-the-LMTT-when-freeing-VF-GT-config.patch.
- Refresh
  patches.suse/1422-drm-amd-Fix-shutdown-again-on-some-SMU-v13.0.4-11-pl.patch.
- Refresh
  patches.suse/1423-drm-amdgpu-pptable-Fix-UBSAN-array-index-out-of-boun.patch.
- Refresh
  patches.suse/1428-drm-xe-xe_gt_idle-use-GT-forcewake-domain-assertion.patch.
- Refresh
  patches.suse/1429-drm-xe-display-Fix-double-mutex-initialization.patch.
- Refresh
  patches.suse/1429-drm-xe-pf-Assert-LMEM-provisioning-is-done-only-on-D.patch.
- Refresh
  patches.suse/1430-drm-xe-flush-engine-buffers-before-signalling-user-f.patch.
- Refresh
  patches.suse/1430-drm-xe-hwmon-Cast-result-to-output-precision-on-left.patch.
- Refresh patches.suse/1431-drm-xe-move-disable_c6-call.patch.
- Refresh
  patches.suse/1431-drm-xe-xe_migrate-Cast-to-output-precision-before-mu.patch.
- Refresh
  patches.suse/1432-drm-xe-Label-RING_CONTEXT_CONTROL-as-masked.patch.
- Refresh
  patches.suse/1437-drm-amd-display-Remove-redundant-idle-optimization-c.patch.
- Refresh
  patches.suse/1439-drm-amd-display-prevent-register-access-while-in-IPS.patch.
- Refresh
  patches.suse/1441-drm-amdgpu-revert-take-runtime-pm-reference-when-we-.patch.
- Refresh
  patches.suse/1442-drm-amd-display-Change-dram_clock_latency-to-34us-fo.patch.
- Refresh
  patches.suse/1444-drm-amd-display-Attempt-to-avoid-empty-TUs-when-endp.patch.
- Refresh
  patches.suse/1445-Revert-drm-amd-display-fix-USB-C-flag-update-after-e.patch.
- Refresh
  patches.suse/1447-drm-amdgpu-fix-visible-VRAM-handling-during-faults.patch.
- Refresh
  patches.suse/1448-drm-amdgpu-cleanup-MES11-command-submission.patch.
- Refresh
  patches.suse/1449-drm-amdgpu-init-TA-fw-for-psp-v14.patch.
- Refresh
  patches.suse/1450-drm-xe-vf-Don-t-touch-GuC-irq-registers-if-using-mem.patch.
- Refresh
  patches.suse/1456-drm-amd-swsmu-add-MALL-init-support-workaround-for-s.patch.
- Refresh
  patches.suse/1461-drm-amdgpu-Don-t-show-false-warning-for-reg-list.patch.
- Refresh
  patches.suse/1461-drm-xe-Fix-bo-leak-in-intel_fb_bo_framebuffer_init.patch.
- Refresh
  patches.suse/1462-drm-xe-vm-prevent-UAF-with-asid-based-lookup.patch.
- Refresh
  patches.suse/1464-drm-i915-display-For-MTL-platforms-skip-mg-dp-progra.patch.
- Refresh
  patches.suse/1465-drm-xe-fix-error-handling-in-xe_migrate_update_pgtab.patch.
- Refresh
  patches.suse/1466-drm-xe-mcr-Avoid-clobbering-DSS-steering.patch.
- Refresh
  patches.suse/1467-drm-amdkfd-Fix-eviction-fence-handling.patch.
- Refresh
  patches.suse/1469-drm-amdkfd-make-sure-VM-is-ready-for-updating-operat.patch.
- Refresh
  patches.suse/1470-drm-amdgpu-pm-Remove-gpu_od-if-it-s-an-empty-directo.patch.
- Refresh
  patches.suse/1472-drm-amdgpu-vpe-fix-vpe-dpm-setup-failed.patch.
- Refresh
  patches.suse/1474-drm-amdkfd-Fix-rescheduling-of-restore-worker.patch.
- Refresh
  patches.suse/1475-drm-amdgpu-umsch-don-t-execute-umsch-test-when-GPU-i.patch.
- Refresh
  patches.suse/1486-drm-xe-Remove-sysfs-only-once-on-action-add-failure.patch.
- Refresh
  patches.suse/1487-drm-xe-call-free_gsc_pkt-only-once-on-action-add-fai.patch.
- Refresh
  patches.suse/1488-drm-xe-guc-Fix-arguments-passed-to-relay-G2H-handler.patch.
- Refresh
  patches.suse/1491-drm-amd-display-Ensure-that-dmcub-support-flag-is-se.patch.
- Refresh
  patches.suse/1501-drm-amdgpu-fix-doorbell-regression.patch.
- Refresh
  patches.suse/1502-drm-amd-display-Disable-panel-replay-by-default-for-.patch.
- Refresh
  patches.suse/1503-drm-xe-vm-prevent-UAF-in-rebind_work_func.patch.
- Refresh
  patches.suse/1504-drm-xe-display-Fix-ADL-N-detection.patch.
- Refresh patches.suse/1520-drm-xe-ads-Use-flexible-array.patch.
- Refresh
  patches.suse/1521-drm-xe-guc-Check-error-code-when-initializing-the-CT.patch.
- Refresh
  patches.suse/1522-drm-xe-Use-ordered-WQ-for-G2H-handler.patch.
- Refresh
  patches.suse/1524-drm-amd-display-Fix-DSC-re-computing.patch.
- Refresh
  patches.suse/1525-drm-amd-display-Fix-idle-optimization-checks-for-mul.patch.
- Refresh
  patches.suse/1526-drm-amd-display-MST-DSC-check-for-older-devices.patch.
- Refresh
  patches.suse/1528-Revert-drm-amdkfd-Add-partition-id-field-to-location.patch.
- Refresh
  patches.suse/1530-drm-amdgpu-Fix-comparison-in-amdgpu_res_cpu_visible.patch.
- Refresh
  patches.suse/1581-drm-i915-gsc-take-a-wakeref-for-the-proxy-init-compl.patch.
- Refresh
  patches.suse/1582-drm-i915-huc-Fix-missing-error-code-in-intel_huc_ini.patch.
- Refresh
  patches.suse/1583-drm-i915-make-i915_drm_client_fdinfo-reference-condi.patch.
- Refresh
  patches.suse/1584-drm-i915-Fix-a-NULL-vs-IS_ERR-bug.patch.
- Refresh
  patches.suse/1595-drm-i915-adlp-Allow-DC-states-along-with-PW2-only-fo.patch.
- Refresh
  patches.suse/1596-drm-i915-mtl-Fix-SSC-selection-for-MPLLA.patch.
- Refresh
  patches.suse/1599-drm-i915-hdcp-Assign-correct-hdcp-content-type.patch.
- Refresh
  patches.suse/1600-drm-i915-Add-missing-forward-declarations-includes-t.patch.
- Refresh
  patches.suse/1670-drm-ssd130x-Fix-possible-uninitialized-usage-of-crtc.patch.
- Refresh
  patches.suse/1675-drm-i915-use-mock-device-info-for-creating-mock-devi.patch.
- Refresh
  patches.suse/1683-drm-i915-perf-Consider-OA-buffer-boundary-when-zeroi.patch.
- Refresh
  patches.suse/1684-drm-i915-Remove-dead-code-from-gen8_pte_encode.patch.
- Refresh
  patches.suse/1699-Revert-drm-i915-use-localized-__diag_ignore_all-inst.patch.
- Refresh
  patches.suse/1700-drm-amd-Use-amdgpu_device_pcie_dynamic_switching_sup.patch.
- Refresh
  patches.suse/1701-drm-amd-display-export-some-optc-function-for-reuse.patch.
- Refresh
  patches.suse/1702-drm-amd-display-add-DCN301-specific-logic-for-OTG-pr.patch.
- Refresh
  patches.suse/1707-drm-amdgpu-Allow-the-initramfs-generator-to-include-.patch.
- Refresh
  patches.suse/1714-drm-amdgpu-Allocate-root-PD-on-correct-partition.patch.
- Refresh
  patches.suse/1715-drm-amdgpu-fix-slab-out-of-bounds-issue-in-amdgpu_vm.patch.
- Refresh
  patches.suse/1715-drm-i915-mtl-Apply-notify_guc-to-all-GTs.patch.
- Refresh
  patches.suse/1716-drm-amdgpu-vm-use-the-same-xcp_id-from-root-PD.patch.
- Refresh
  patches.suse/1717-drm-amdgpu-use-a-macro-to-define-no-xcp-partition-ca.patch.
- Refresh
  patches.suse/1739-drm-amdkfd-fix-trap-handling-work-around-for-debuggi.patch.
- Refresh
  patches.suse/1740-drm-amdgpu-Fix-infinite-loop-in-gfxhub_v1_2_xcc_gart.patch.
- Refresh
  patches.suse/1744-drm-amd-display-Don-t-apply-FIFO-resync-W-A-if-rdivi.patch.
- Refresh
  patches.suse/1747-drm-amdgpu-Restore-HQD-persistent-state-register.patch.
- Refresh
  patches.suse/1784-drm-amd-pm-disable-the-SMU13-OD-feature-support-temp.patch.
- Refresh
  patches.suse/1786-drm-amd-pm-Fix-SMU-v13.0.6-energy-reporting.patch.
- Refresh
  patches.suse/1789-drm-amdgpu-gfx11-only-enable-CP-GFX-shadowing-on-SR-.patch.
- Refresh
  patches.suse/1790-drm-amdkfd-ignore-crat-by-default.patch.
- Refresh
  patches.suse/1791-drm-amdkfd-disable-IOMMUv2-support-for-KV-CZ.patch.
- Refresh
  patches.suse/1792-drm-amdkfd-disable-IOMMUv2-support-for-Raven.patch.
- Refresh
  patches.suse/1795-drm-i915-fix-display-probe-for-IVB-Q-and-IVB-D-GT2-s.patch.
- Refresh
  patches.suse/1796-drm-panel-JDI-LT070ME05000-simplify-with-dev_err_pro.patch.
- Refresh
  patches.suse/1800-drm-amd-pm-disallow-the-fan-setting-if-there-is-no-f.patch.
- Refresh
  patches.suse/1801-drm-amdgpu-disable-mcbp-if-parameter-zero-is-set.patch.
- Refresh
  patches.suse/1804-drm-amd-pm-Update-pci-link-width-for-smu-v13.0.6.patch.
- Refresh
  patches.suse/1805-drm-amdgpu-skip-xcp-drm-device-allocation-when-out-o.patch.
- Refresh
  patches.suse/1823-drm-i915-fix-Sphinx-indentation-warning.patch.
- Refresh
  patches.suse/1825-drm-i915-Fix-HPD-polling-reenabling-the-output-poll-.patch.
- Refresh
  patches.suse/1863-drm-i915-dp_mst-Fix-race-between-connector-registrat.patch.
- Refresh
  patches.suse/1879-drm-amd-display-Add-z-state-support-policy-for-dcn35.patch.
- Refresh
  patches.suse/1880-drm-amdgpu-update-xgmi-num-links-info-post-gc9.4.2.patch.
- Refresh
  patches.suse/1881-drm-amd-display-Update-DCN35-watermarks.patch.
- Refresh
  patches.suse/1882-drm-amd-display-fix-a-pipe-mapping-error-in-dcn32_fp.patch.
- Refresh
  patches.suse/1883-drm-amdgpu-optimize-RLC-powerdown-notification-on-Va.patch.
- Refresh
  patches.suse/1884-drm-amd-display-Add-Z8-watermarks-for-DML2-bbox-over.patch.
- Refresh
  patches.suse/1887-drm-amd-display-Feed-SR-and-Z8-watermarks-into-DML2-.patch.
- Refresh
  patches.suse/1888-drm-amd-display-Fix-MPCC-1DLUT-programming.patch.
- Refresh
  patches.suse/1890-drm-amd-display-Do-not-read-DPREFCLK-spread-info-fro.patch.
- Refresh
  patches.suse/1893-drm-amdgpu-add-init_registers-for-nbio-v7.11.patch.
- Refresh
  patches.suse/1899-drm-amd-display-Update-DCN35-clock-table-policy.patch.
- Refresh
  patches.suse/1900-drm-amd-display-Remove-config-update.patch.
- Refresh
  patches.suse/1903-drm-amd-display-Fix-black-screen-on-video-playback-w.patch.
- Refresh
  patches.suse/1906-drm-amdgpu-fix-AGP-addressing-when-GART-is-not-at-0.patch.
- Refresh
  patches.suse/1910-drm-amd-display-Allow-DTBCLK-disable-for-DCN35.patch.
- Refresh
  patches.suse/1913-drm-amd-display-Fix-some-HostVM-parameters-in-DML.patch.
- Refresh
  patches.suse/1916-drm-i915-Check-pipe-active-state-in-planes-vrr-_-ena.patch.
- Refresh
  patches.suse/1920-drm-i915-correct-the-input-parameter-on-_intel_dsb_c.patch.
- Refresh
  patches.suse/1930-drm-amd-display-Fix-array-index-out-of-bounds-in-dml.patch.
- Refresh
  patches.suse/1931-drm-amd-swsmu-update-smu-v14_0_0-driver-if-version-a.patch.
- Refresh
  patches.suse/1932-drm-amd-pm-support-new-mca-smu-error-code-decoding.patch.
- Refresh
  patches.suse/1933-drm-amdgpu-Update-fw-version-for-boot-time-error-que.patch.
- Refresh
  patches.suse/1934-drm-amdgpu-optimize-the-printing-order-of-error-data.patch.
- Refresh
  patches.suse/1936-drm-amdgpu-Restrict-extended-wait-to-PSP-v13.0.6.patch.
- Refresh
  patches.suse/1938-drm-amdgpu-Update-HDP-4.4.2-clock-gating-flags.patch.
- Refresh
  patches.suse/1939-drm-amdgpu-Avoid-querying-DRM-MGCG-status.patch.
- Refresh
  patches.suse/1940-drm-amdgpu-fix-buffer-funcs-setting-order-on-suspend.patch.
- Refresh
  patches.suse/1956-drm-amdgpu-fix-buffer-funcs-setting-order-on-suspend.patch.
- Refresh patches.suse/1957-drm-amd-pm-fix-pp_-clk_od-typo.patch.
- Refresh
  patches.suse/1958-drm-amd-display-fix-hw-rotated-modes-when-PSR-SU-is-.patch.
- Refresh
  patches.suse/1960-drm-amdgpu-jpeg-configure-doorbell-for-each-playback.patch.
- Refresh
  patches.suse/1962-drm-amd-display-Populate-dtbclk-from-bounding-box.patch.
- Refresh
  patches.suse/1965-drm-amd-Fix-a-probing-order-problem-on-SDMA-2.4.patch.
- Refresh
  patches.suse/1967-drm-amdgpu-warn-when-there-are-still-mappings-when-a.patch.
- Refresh
  patches.suse/1977-drm-amd-display-disable-FPO-and-SubVP-for-older-DMUB.patch.
- Refresh
  patches.suse/1980-drm-amd-display-dereference-variable-before-checking.patch.
- Refresh
  patches.suse/1982-drm-i915-display-Get-bigjoiner-config-before-dsc-con.patch.
- Refresh
  patches.suse/1994-drm-amd-pm-Use-separate-metric-table-for-APU.patch.
- Refresh
  patches.suse/1995-drm-amd-pm-Update-metric-table-for-jpeg-vcn-data.patch.
- Refresh
  patches.suse/1999-drm-amd-pm-Add-mem_busy_percent-for-GCv9.4.3-apu.patch.
- Refresh patches.suse/2000-drm-amd-pm-Add-gpu_metrics_v1_5.patch.
- Refresh
  patches.suse/2001-drm-amd-pm-Use-gpu_metrics_v1_5-for-SMUv13.0.6.patch.
- Refresh
  patches.suse/2220-drm-i915-gem-reconcile-Excess-struct-member-kernel-d.patch.
- Refresh
  patches.suse/2221-drm-i915-gt-reconcile-Excess-struct-member-kernel-do.patch.
- Refresh
  patches.suse/2222-drm-i915-guc-reconcile-Excess-struct-member-kernel-d.patch.
- Refresh
  patches.suse/2223-drm-i915-perf-reconcile-Excess-struct-member-kernel-.patch.
- Refresh
  patches.suse/2287-drm-amd-display-Init-link-enc-resources-in-dc_state-.patch.
- Refresh
  patches.suse/2288-drm-amd-display-Add-logging-resource-checks.patch.
- Refresh
  patches.suse/2290-drm-amd-display-Clear-OPTC-mem-select-on-disable.patch.
- Refresh
  patches.suse/2297-drm-amd-display-Drop-acrtc-and-add-new_crtc_state-NU.patch.
- Refresh
  patches.suse/2316-drm-xe-display-support-should-not-depend-on-EXPERT.patch.
- Refresh
  patches.suse/2338-drm-amd-pm-udpate-smu-v13.0.6-message-permission.patch.
- Refresh
  patches.suse/2344-drm-amdgpu-Fix-null-pointer-dereference.patch.
- Refresh
  patches.suse/2350-drm-amd-display-Add-Replay-IPS-register-for-DMUB-com.patch.
- Refresh
  patches.suse/2351-drm-amd-display-Add-IPS-checks-before-dcn-register-a.patch.
- Refresh
  patches.suse/2352-drm-amd-display-Replay-IPS-ABM-in-Full-Screen-VPB.patch.
- Refresh
  patches.suse/2354-drm-amd-Add-a-DC-debug-mask-for-IPS.patch.
- Refresh
  patches.suse/2355-drm-amd-display-Enable-IPS-by-default.patch.
- Refresh
  patches.suse/2400-drm-amdkfd-Use-S_ENDPGM_SAVED-in-trap-handler.patch.
- Refresh
  patches.suse/2405-drm-amd-display-Fix-DPSTREAM-CLK-on-and-off-sequence.patch.
- Refresh
  patches.suse/2407-drm-amd-display-Underflow-workaround-by-increasing-S.patch.
- Refresh
  patches.suse/2409-drm-amdgpu-Fix-the-warning-info-in-mode1-reset.patch.
- Refresh
  patches.suse/2415-drm-amdgpu-drm-amdgpu-remove-golden-setting-for-gfx-.patch.
- Refresh
  patches.suse/2416-drm-amdgpu-remove-asymmetrical-irq-disabling-in-vcn-.patch.
- Refresh
  patches.suse/2418-drm-amdgpu-pm-Use-inline-function-for-IP-version-che.patch.
- Refresh
  patches.suse/2443-drm-amd-display-set-odm_combine_policy-based-on-cont.patch.
- Refresh
  patches.suse/2446-drm-amdgpu-remove-asymmetrical-irq-disabling-in-jpeg.patch.
- Refresh
  patches.suse/2447-drm-amd-display-Increase-eval-entry-delay-for-DCN35.patch.
- Refresh
  patches.suse/2450-drm-amd-display-Update-phantom-pipe-enable-disable-s.patch.
- Refresh
  patches.suse/2451-drm-amd-display-Disable-ODM-by-default-for-DCN35.patch.
- Refresh
  patches.suse/2455-drm-amd-display-Implement-bounds-check-for-stream-en.patch.
- Refresh
  patches.suse/2492-drm-amd-display-Increase-ips2_eval-delay-for-DCN35.patch.
- Refresh
  patches.suse/2493-drm-amdkfd-update-SIMD-distribution-algo-for-GFXIP-9.patch.
- Refresh
  patches.suse/2494-drm-amdgpu-Fix-implicit-assumtion-in-gfx11-debug-fla.patch.
- Refresh
  patches.suse/2532-drm-xe-Add-uapi-for-dumpable-bos.patch.
- Refresh
  patches.suse/2540-drm-xe-xe_bo_move-Enhance-xe_bo_move-trace.patch.
- Refresh
  patches.suse/2541-drm-xe-Use-pointers-in-trace-events.patch.
- Refresh
  patches.suse/2542-drm-xe-Expose-user-fence-from-xe_sync_entry.patch.
- Refresh
  patches.suse/2543-drm-xe-Deny-unbinds-if-uapi-ufence-pending.patch.
- Refresh
  patches.suse/2544-drm-xe-xe_trace-Add-move_lacks_source-detail-to-xe_b.patch.
- Refresh
  patches.suse/Revert-Revert-drm-amdgpu-display-change-pipe-p.patch.
- Refresh
  patches.suse/Revert-drm-amd-display-Fix-sending-VSC-colorimetry-p.patch.
- Refresh
  patches.suse/Revert-drm-amd-display-Remove-v_startup-workaround-f.patch.
- Refresh
  patches.suse/Revert-drm-amd-pm-fix-the-high-voltage-and-temperatu.patch.
- Refresh
  patches.suse/Revert-drm-amd-pm-resolve-reboot-exception-for-si-ol.patch.
- Refresh
  patches.suse/Revert-drm-amdkfd-fix-gfx_target_version-for-certain.patch.
- Refresh
  patches.suse/Revert-drm-bridge-ti-sn65dsi83-Fix-enable-error-path.patch.
- Refresh
  patches.suse/Revert-drm-i915-dsi-Do-display-on-sequence-later-on-.patch.
- Refresh
  patches.suse/amd-amdkfd-sync-all-devices-to-wait-all-processes-be.patch.
- Refresh
  patches.suse/drm-Add-an-HPD-poll-helper-to-reschedule-the-p.patch.
- Refresh
  patches.suse/drm-amd-Align-SMU11-SMU_MSG_OverridePcieParamet.patch.
- Refresh
  patches.suse/drm-amd-Disable-S-G-for-APUs-when-64GB-or-more.patch.
- Refresh
  patches.suse/drm-amd-Don-t-init-MEC2-firmware-when-it-fails-to-lo.patch.
- Refresh patches.suse/drm-amd-Enable-PCIe-PME-from-D3.patch.
- Refresh
  patches.suse/drm-amd-Fix-an-error-handling-mistake-in-psp_sw.patch.
- Refresh
  patches.suse/drm-amd-Flush-GFXOFF-requests-in-prepare-stage.patch.
- Refresh
  patches.suse/drm-amd-Move-helper-for-dynamic-speed-switch-ch.patch.
- Refresh
  patches.suse/drm-amd-Stop-evicting-resources-on-APUs-in-suspend.patch.
- Refresh
  patches.suse/drm-amd-amdgpu-Assign-GART-pages-to-AMD-device-mappi.patch.
- Refresh
  patches.suse/drm-amd-display-Account-for-cursor-prefetch-BW-in-DM.patch.
- Refresh
  patches.suse/drm-amd-display-Add-NULL-check-for-kzalloc-in-amdgpu.patch.
- Refresh
  patches.suse/drm-amd-display-Add-NULL-test-for-timing-generator-i.patch.
- Refresh
  patches.suse/drm-amd-display-Add-VCO-speed-parameter-for-DCN31-FP.patch.
- Refresh patches.suse/drm-amd-display-Add-align-done-check.patch.
- Refresh
  patches.suse/drm-amd-display-Add-case-for-dcn35-to-support-usb4-d.patch.
- Refresh
  patches.suse/drm-amd-display-Add-dtbclk-access-to-dcn315.patch.
- Refresh
  patches.suse/drm-amd-display-Add-monitor-patch-for-specific-eDP-b7cdccc.patch.
- Refresh
  patches.suse/drm-amd-display-Add-monitor-patch-for-specific-eDP.patch.
- Refresh
  patches.suse/drm-amd-display-Add-polling-method-to-handle-MS.patch.
- Refresh
  patches.suse/drm-amd-display-Add-refresh-rate-range-check.patch.
- Refresh
  patches.suse/drm-amd-display-Add-smu-write-msg-id-fail-retry-proc.patch.
- Refresh
  patches.suse/drm-amd-display-Align-the-returned-error-code-with-l.patch.
- Refresh
  patches.suse/drm-amd-display-Allocate-zero-bw-after-bw-alloc-enab.patch.
- Refresh
  patches.suse/drm-amd-display-Atom-Integrated-System-Info-v2_2-for.patch.
- Refresh
  patches.suse/drm-amd-display-Clean-up-errors-warnings-in-amd.patch.
- Refresh
  patches.suse/drm-amd-display-Disable-MPC-split-by-default-on.patch.
- Refresh
  patches.suse/drm-amd-display-Disable-PSR-SU-on-Parade-0803-TCON-a.patch.
- Refresh
  patches.suse/drm-amd-display-Disable-ips-before-dc-interrupt-sett.patch.
- Refresh
  patches.suse/drm-amd-display-Disable-seamless-boot-on-128b-132b-e.patch.
- Refresh
  patches.suse/drm-amd-display-Do-not-recursively-call-manual-trigg.patch.
- Refresh
  patches.suse/drm-amd-display-Don-t-show-stack-trace-for-mis.patch.
- Refresh
  patches.suse/drm-amd-display-Enable-colorspace-property-for-MST-c.patch.
- Refresh
  patches.suse/drm-amd-display-Exit-idle-optimizations-before-attem.patch.
- Refresh
  patches.suse/drm-amd-display-Fix-DC-mode-screen-flickering-on-DCN.patch.
- Refresh
  patches.suse/drm-amd-display-Fix-DML2-watermark-calculation.patch.
- Refresh
  patches.suse/drm-amd-display-Fix-MST-Null-Ptr-for-RV.patch.
- Refresh
  patches.suse/drm-amd-display-Fix-a-regression-on-Polaris-ca.patch.
- Refresh
  patches.suse/drm-amd-display-Fix-a-switch-statement-in-populate_d.patch.
- Refresh
  patches.suse/drm-amd-display-Fix-array-index-out-of-bounds-in-dcn.patch.
- Refresh
  patches.suse/drm-amd-display-Fix-array-index-out-of-bounds-in-dml.patch.
- Refresh
  patches.suse/drm-amd-display-Fix-bounds-check-for-dcn35-DcfClocks.patch.
- Refresh
  patches.suse/drm-amd-display-Fix-buffer-overflow-in-get_host_rout.patch.
- Refresh
  patches.suse/drm-amd-display-Fix-dcn35-8k30-Underflow-Corruption-.patch.
- Refresh
  patches.suse/drm-amd-display-Fix-incorrect-DSC-instance-for-MST.patch.
- Refresh
  patches.suse/drm-amd-display-Fix-late-derefrence-dsc-check-in-lin.patch.
- Refresh
  patches.suse/drm-amd-display-Fix-memory-leak-in-dm_sw_fini.patch.
- Refresh
  patches.suse/drm-amd-display-Fix-panel_cntl-could-be-null-in-dcn2.patch.
- Refresh
  patches.suse/drm-amd-display-Fix-possible-NULL-dereference-on-dev.patch.
- Refresh
  patches.suse/drm-amd-display-Fix-possible-buffer-overflow-in-find.patch.
- Refresh
  patches.suse/drm-amd-display-Fix-possible-use-of-uninitialized-ma.patch.
- Refresh
  patches.suse/drm-amd-display-Fix-potential-null-pointer-dereferen.patch.
- Refresh
  patches.suse/drm-amd-display-Fix-refresh-rate-range-for-some-pane.patch.
- Refresh
  patches.suse/drm-amd-display-Fix-sending-VSC-colorimetry-packets-.patch.
- Refresh
  patches.suse/drm-amd-display-Fix-uninitialized-variable-usage-in-.patch.
- Refresh patches.suse/drm-amd-display-Fix-vs-typos.patch.
- Refresh
  patches.suse/drm-amd-display-Guard-DCN31-PHYD32CLK-logic-against-.patch.
- Refresh
  patches.suse/drm-amd-display-Handle-Y-carry-over-in-VCP-X.Y-calcu.patch.
- Refresh
  patches.suse/drm-amd-display-Include-udelay-when-waiting-for-INBO.patch.
- Refresh
  patches.suse/drm-amd-display-Increase-frame-larger-than-for-all-d.patch.
- Refresh
  patches.suse/drm-amd-display-Increase-frame-warning-limit-with-KA.patch.
- Refresh
  patches.suse/drm-amd-display-Increase-num-voltage-states-to-40.patch.
- Refresh
  patches.suse/drm-amd-display-Initialize-wait_time_microsec-variab.patch.
- Refresh
  patches.suse/drm-amd-display-Keep-PHY-active-for-DP-displays.patch.
- Refresh
  patches.suse/drm-amd-display-Only-allow-dig-mapping-to-pwrseq-in-.patch.
- Refresh
  patches.suse/drm-amd-display-Port-DENTIST-hang-and-TDR-fixes-to-O.patch.
- Refresh
  patches.suse/drm-amd-display-Preserve-original-aspect-ratio-in-cr.patch.
- Refresh
  patches.suse/drm-amd-display-Prevent-potential-buffer-overflow-in.patch.
- Refresh
  patches.suse/drm-amd-display-Prevent-vtotal-from-being-set-t.patch.
- Refresh
  patches.suse/drm-amd-display-Program-VSC-SDP-colorimetry-for-all-.patch.
- Refresh
  patches.suse/drm-amd-display-Remove-MPC-rate-control-logic-from-D.patch.
- Refresh
  patches.suse/drm-amd-display-Remove-min_dst_y_next_start-check-fo.patch.
- Refresh
  patches.suse/drm-amd-display-Remove-wait-while-locked.patch.
- Refresh
  patches.suse/drm-amd-display-Send-DP_TOTAL_LTTPR_CNT-during-detec.patch.
- Refresh
  patches.suse/drm-amd-display-Set-DCN351-BB-and-IP-the-same-as-DCN.patch.
- Refresh
  patches.suse/drm-amd-display-Set-VSC-SDP-Colorimetry-same-way-for.patch.
- Refresh
  patches.suse/drm-amd-display-Set-color_mgmt_changed-to-true-on-un.patch.
- Refresh
  patches.suse/drm-amd-display-Skip-on-writeback-when-it-s-not-appl.patch.
- Refresh
  patches.suse/drm-amd-display-Unlock-on-error-path-in-dm_hand.patch.
- Refresh
  patches.suse/drm-amd-display-Update-efficiency-bandwidth-for-dcn3.patch.
- Refresh
  patches.suse/drm-amd-display-Update-min-Z8-residency-time-to-2100.patch.
- Refresh
  patches.suse/drm-amd-display-Use-DRAM-speed-from-validation-for-d.patch.
- Refresh
  patches.suse/drm-amd-display-add-nv12-bounding-box.patch.
- Refresh
  patches.suse/drm-amd-display-adjust-few-initialization-order-in-d.patch.
- Refresh
  patches.suse/drm-amd-display-always-switch-off-ODM-before-committ.patch.
- Refresh
  patches.suse/drm-amd-display-change-dram_clock_latency-to-34us-fo.patch.
- Refresh
  patches.suse/drm-amd-display-check-TG-is-non-null-before-che.patch.
- Refresh
  patches.suse/drm-amd-display-check-attr-flag-before-set-cur.patch.
- Refresh
  patches.suse/drm-amd-display-enable-cursor-degamma-for-DCN3-DRM-l.patch.
- Refresh patches.suse/drm-amd-display-fix-ABM-disablement.patch.
- Refresh
  patches.suse/drm-amd-display-fix-USB-C-flag-update-after-enc10-fe.patch.
- Refresh
  patches.suse/drm-amd-display-fix-disable-otg-wa-logic-in-DCN316.patch.
- Refresh
  patches.suse/drm-amd-display-fix-incorrect-mpc_combine-array-size.patch.
- Refresh
  patches.suse/drm-amd-display-fix-mode-scaling-RMX_.patch.
- Refresh
  patches.suse/drm-amd-display-fix-null-pointer-dereference-on-edid.patch.
- Refresh
  patches.suse/drm-amd-display-fix-the-ability-to-use-lower-resolut.patch.
- Refresh
  patches.suse/drm-amd-display-fix-the-white-screen-issue-when-64GB.patch.
- Refresh
  patches.suse/drm-amd-display-fixed-integer-types-and-null-check-l.patch.
- Refresh
  patches.suse/drm-amd-display-force-toggle-rate-wa-for-first-link-.patch.
- Refresh
  patches.suse/drm-amd-display-get-dprefclk-ss-info-from-integratio.patch.
- Refresh
  patches.suse/drm-amd-display-handle-range-offsets-in-VRR-ranges.patch.
- Refresh
  patches.suse/drm-amd-display-only-accept-async-flips-for-fas.patch.
- Refresh
  patches.suse/drm-amd-display-pbn_div-need-be-updated-for-hotplug-.patch.
- Refresh
  patches.suse/drm-amd-display-prevent-potential-division-by-zero-e.patch.
- Refresh
  patches.suse/drm-amd-display-register-edp_backlight_control-for-D.patch.
- Refresh
  patches.suse/drm-amd-display-update-dcn315-lpddr-pstate-latency.patch.
- Refresh
  patches.suse/drm-amd-flush-any-delayed-gfxoff-on-suspend-en.patch.
- Refresh
  patches.suse/drm-amd-pm-Fetch-current-power-limit-from-FW.patch.
- Refresh
  patches.suse/drm-amd-pm-Fix-temperature-unit-of-SMU-v13.0.6.patch.
- Refresh
  patches.suse/drm-amd-pm-Restore-config-space-after-reset.patch.
- Refresh
  patches.suse/drm-amd-pm-conditionally-disable-pcie-lane-spee.patch.
- Refresh
  patches.suse/drm-amd-pm-correct-the-pcie-width-for-smu-13.0.patch.
- Refresh
  patches.suse/drm-amd-pm-fix-a-memleak-in-aldebaran_tables_init.patch.
- Refresh
  patches.suse/drm-amd-pm-fix-smu-i2c-data-read-risk.patch.
- Refresh
  patches.suse/drm-amd-pm-share-the-code-around-SMU13-pcie-par.patch.
- Refresh
  patches.suse/drm-amd-pm-skip-the-RLC-stop-when-S0i3-suspend.patch.
- Refresh
  patches.suse/drm-amd-pm-update-the-power-cap-setting.patch.
- Refresh
  patches.suse/drm-amd-smu-use-AverageGfxclkFrequency-to-replace-pr.patch.
- Refresh
  patches.suse/drm-amd-swsmu-modify-the-gfx-activity-scaling.patch.
- Refresh
  patches.suse/drm-amdgpu-Add-NULL-checks-for-function-pointers.patch.
- Refresh
  patches.suse/drm-amdgpu-Assign-correct-bits-for-SDMA-HDP-flush.patch.
- Refresh
  patches.suse/drm-amdgpu-Avoid-fetching-VRAM-vendor-info.patch.
- Refresh
  patches.suse/drm-amdgpu-Avoid-fetching-vram-vendor-information.patch.
- Refresh
  patches.suse/drm-amdgpu-Do-not-issue-gpu-reset-from-nbio-v7_9-bif.patch.
- Refresh
  patches.suse/drm-amdgpu-Enable-GFXOFF-for-Compute-on-GFX11.patch.
- Refresh
  patches.suse/drm-amdgpu-Fix-HDP-flush-for-VFs-on-nbio-v7.9.patch.
- Refresh
  patches.suse/drm-amdgpu-Fix-VCN-allocation-in-CPX-partition.patch.
- Refresh
  patches.suse/drm-amdgpu-Fix-VRAM-memory-accounting.patch.
- Refresh
  patches.suse/drm-amdgpu-Fix-cat-debugfs-amdgpu_regs_didt-causes-k.patch.
- Refresh
  patches.suse/drm-amdgpu-Fix-leak-when-GPU-memory-allocation-fails.patch.
- Refresh
  patches.suse/drm-amdgpu-Fix-missing-error-code-in-gmc_v6-7-8-9_0_.patch.
- Refresh
  patches.suse/drm-amdgpu-Fix-pci-state-save-during-mode-1-reset.patch.
- Refresh
  patches.suse/drm-amdgpu-Fix-shared-buff-copy-to-user.patch.
- Refresh
  patches.suse/drm-amdgpu-Fix-the-null-pointer-when-load-rlc-firmwa.patch.
- Refresh
  patches.suse/drm-amdgpu-Fix-the-ring-buffer-size-for-queue-VM-flu.patch.
- Refresh
  patches.suse/drm-amdgpu-Fix-the-runtime-resume-failure-issue.patch.
- Refresh
  patches.suse/drm-amdgpu-Force-order-between-a-read-and-write-to-t.patch.
- Refresh
  patches.suse/drm-amdgpu-Indicate-CU-havest-info-to-CP.patch.
- Refresh
  patches.suse/drm-amdgpu-Match-against-exact-bootloader-status.patch.
- Refresh
  patches.suse/drm-amdgpu-Refine-IB-schedule-error-logging.patch.
- Refresh
  patches.suse/drm-amdgpu-Reset-IH-OVERFLOW_CLEAR-bit.patch.
- Refresh
  patches.suse/drm-amdgpu-Reset-dGPU-if-suspend-got-aborted.patch.
- Refresh
  patches.suse/drm-amdgpu-Show-vram-vendor-only-if-available.patch.
- Refresh
  patches.suse/drm-amdgpu-Update-BO-eviction-priorities.patch.
- Refresh
  patches.suse/drm-amdgpu-Update-EEPROM-I2C-address-for-smu-v13_0_0.patch.
- Refresh
  patches.suse/drm-amdgpu-Use-another-offset-for-GC-9.4.3-remap.patch.
- Refresh
  patches.suse/drm-amdgpu-always-force-full-reset-for-SOC21.patch.
- Refresh
  patches.suse/drm-amdgpu-atomfirmware-add-intergrated-info-v2.3-ta.patch.
- Refresh
  patches.suse/drm-amdgpu-atomfirmware-silence-UBSAN-warning.patch.
- Refresh
  patches.suse/drm-amdgpu-avoid-restore-process-run-into-dead-.patch.
- Refresh
  patches.suse/drm-amdgpu-avoid-using-null-object-of-framebuffer.patch.
- Refresh
  patches.suse/drm-amdgpu-correct-the-amdgpu-runtime-dereference-us.patch.
- Refresh patches.suse/drm-amdgpu-disable-MCBP-by-default.patch.
- Refresh
  patches.suse/drm-amdgpu-display-Initialize-gamma-correction-mode-.patch.
- Refresh
  patches.suse/drm-amdgpu-fix-UBSAN-warning-in-kv_dpm.c.patch.
- Refresh
  patches.suse/drm-amdgpu-fix-deadlock-while-reading-mqd-from-debug.patch.
- Refresh
  patches.suse/drm-amdgpu-fix-incorrect-number-of-active-RBs-for-gf.patch.
- Refresh
  patches.suse/drm-amdgpu-fix-locking-scope-when-flushing-tlb.patch.
- Refresh
  patches.suse/drm-amdgpu-fix-memory-overflow-in-the-IB-test.patch.
- Refresh
  patches.suse/drm-amdgpu-fix-possible-UAF-in-amdgpu_cs_pass1.patch.
- Refresh
  patches.suse/drm-amdgpu-fix-tear-down-order-in-amdgpu_vm_pt_free.patch.
- Refresh
  patches.suse/drm-amdgpu-gfx10-set-UNORD_DISPATCH-in-compute-MQDs.patch.
- Refresh
  patches.suse/drm-amdgpu-gfx11-set-UNORD_DISPATCH-in-compute-MQDs.patch.
- Refresh
  patches.suse/drm-amdgpu-implement-IRQ_STATE_ENABLE-for-SDMA-v4.4..patch.
- Refresh
  patches.suse/drm-amdgpu-mes-fix-use-after-free-issue.patch.
- Refresh
  patches.suse/drm-amdgpu-once-more-fix-the-call-oder-in-amdgpu_ttm.patch.
- Refresh
  patches.suse/drm-amdgpu-pm-Fix-the-error-of-pwm1_enable-setting.patch.
- Refresh
  patches.suse/drm-amdgpu-pm-Fix-the-power-source-flag-error.patch.
- Refresh
  patches.suse/drm-amdgpu-pm-Fix-the-power1_min_cap-value.patch.
- Refresh
  patches.suse/drm-amdgpu-pm-fix-throttle_status-for-other-th.patch.
- Refresh
  patches.suse/drm-amdgpu-pm-make-gfxclock-consistent-for-sien.patch.
- Refresh
  patches.suse/drm-amdgpu-pm-make-mclk-consistent-for-smu-13.0.patch.
- Refresh
  patches.suse/drm-amdgpu-re-create-idle-bo-s-PTE-during-VM-state-m.patch.
- Refresh
  patches.suse/drm-amdgpu-remove-invalid-resource-start-check-v2.patch.
- Refresh
  patches.suse/drm-amdgpu-revert-Adjust-removal-control-flow-for-sm.patch.
- Refresh
  patches.suse/drm-amdgpu-sdma5.2-add-begin-end_use-ring-callbacks.patch.
- Refresh
  patches.suse/drm-amdgpu-sdma5.2-use-legacy-HDP-flush-for-SDMA2-3.patch.
- Refresh patches.suse/drm-amdgpu-silence-UBSAN-warning.patch.
- Refresh
  patches.suse/drm-amdgpu-skip-fence-GFX-interrupts-disable-e.patch.
- Refresh
  patches.suse/drm-amdgpu-skip-gpu_info-fw-loading-on-navi12.patch.
- Refresh
  patches.suse/drm-amdgpu-skip-to-program-GFXDEC-registers-for-susp.patch.
- Refresh
  patches.suse/drm-amdgpu-soc21-update-VCN-4-max-HEVC-encoding-reso.patch.
- Refresh
  patches.suse/drm-amdgpu-validate-the-parameters-of-bo-mapping-ope.patch.
- Refresh
  patches.suse/drm-amdgpu-vkms-relax-timer-deactivation-by-hrt.patch.
- Refresh
  patches.suse/drm-amdkfd-Add-VRAM-accounting-for-SVM-migration.patch.
- Refresh
  patches.suse/drm-amdkfd-Check-cgroup-when-returning-DMABuf-info.patch.
- Refresh
  patches.suse/drm-amdkfd-Fix-L2-cache-size-reporting-in-GFX9.4.3.patch.
- Refresh
  patches.suse/drm-amdkfd-Flush-the-process-wq-before-creating-a-kf.patch.
- Refresh
  patches.suse/drm-amdkfd-Free-gang_ctx_bo-and-wptr_bo-in-pqm_unini.patch.
- Refresh
  patches.suse/drm-amdkfd-Let-VRAM-allocations-go-to-GTT-domain-on-.patch.
- Refresh
  patches.suse/drm-amdkfd-Reset-GPU-on-queue-preemption-failure.patch.
- Refresh
  patches.suse/drm-amdkfd-Use-common-function-for-IP-version-check.patch.
- Refresh
  patches.suse/drm-amdkfd-Use-correct-drm-device-for-cgroup-permiss.patch.
- Refresh
  patches.suse/drm-amdkfd-fix-TLB-flush-after-unmap-for-GFX9.4.2.patch.
- Refresh
  patches.suse/drm-amdkfd-range-check-cp-bad-op-exception-interrupt.patch.
- Refresh
  patches.suse/drm-amdkfd-reserve-the-BO-before-validating-it.patch.
- Refresh
  patches.suse/drm-amdkfd-svm-range-always-mapped-flag-not-working-.patch.
- Refresh
  patches.suse/drm-bridge-sii902x-Fix-audio-codec-unregistration.patch.
- Refresh
  patches.suse/drm-fbdev-generic-Do-not-set-physical-framebuffer-ad.patch.
- Refresh
  patches.suse/drm-i915-Add-the-gen12_needs_ccs_aux_inv-helpe.patch.
- Refresh
  patches.suse/drm-i915-Also-check-for-VGA-converter-in-eDP-probe.patch.
- Refresh
  patches.suse/drm-i915-Bump-GLK-CDCLK-frequency-when-driving-multi.patch.
- Refresh
  patches.suse/drm-i915-Call-intel_pre_plane_updates-also-for-pipes.patch.
- Refresh
  patches.suse/drm-i915-Check-before-removing-mm-notifier.patch.
- Refresh
  patches.suse/drm-i915-Disable-live-M-N-updates-when-using-bigjoin.patch.
- Refresh
  patches.suse/drm-i915-Disable-port-sync-when-bigjoiner-is-used.patch.
- Refresh
  patches.suse/drm-i915-Do-not-match-JSL-in-ehl_combo_pll_div_frac_.patch.
- Refresh
  patches.suse/drm-i915-Don-t-explode-when-the-dig-port-we-don-t-ha.patch.
- Refresh
  patches.suse/drm-i915-Don-t-preserve-dpll_hw_state-for-slave.patch.
- Refresh patches.suse/drm-i915-Drop-Wstringop-overflow.patch.
- Refresh
  patches.suse/drm-i915-Fix-ADL-tiled-plane-stride-when-the-POT-str.patch.
- Refresh
  patches.suse/drm-i915-Fix-an-error-handling-path-in-igt_writ.patch.
- Refresh
  patches.suse/drm-i915-Fix-audio-component-initialization.patch.
- Refresh
  patches.suse/drm-i915-Fix-intel_atomic_setup_scalers-plane_state-.patch.
- Refresh
  patches.suse/drm-i915-Fix-one-wrong-caching-mode-enum-usage.patch.
- Refresh
  patches.suse/drm-i915-Fix-potential-spectre-vulnerability.patch.
- Refresh
  patches.suse/drm-i915-Fix-premature-release-of-request-s-re.patch.
- Refresh
  patches.suse/drm-i915-Fix-remapped-stride-with-CCS-on-ADL.patch.
- Refresh
  patches.suse/drm-i915-Flush-WC-GGTT-only-on-required-platforms.patch.
- Refresh
  patches.suse/drm-i915-Only-check-eDP-HPD-when-AUX-CH-is-shared.patch.
- Refresh
  patches.suse/drm-i915-Pre-populate-the-cursor-physical-dma-addres.patch.
- Refresh
  patches.suse/drm-i915-Skip-some-timing-checks-on-BXT-GLK-DSI-tran.patch.
- Refresh
  patches.suse/drm-i915-Use-internal-class-when-counting-engine-res.patch.
- Refresh
  patches.suse/drm-i915-audio-Fix-audio-time-stamp-programming-for-.patch.
- Refresh
  patches.suse/drm-i915-bios-Fix-parsing-backlight-BDB-data.patch.
- Refresh
  patches.suse/drm-i915-bios-Tolerate-devdata-NULL-in-intel_bios_en.patch.
- Refresh
  patches.suse/drm-i915-cdclk-Fix-CDCLK-programming-order-when-pipe.patch.
- Refresh
  patches.suse/drm-i915-dgfx-Enable-d3cold-at-s2idle.patch.
- Refresh
  patches.suse/drm-i915-dmc-Don-t-enable-any-pipe-DMC-events.patch.
- Refresh
  patches.suse/drm-i915-do-not-clean-GT-table-on-error-path.patch.
- Refresh
  patches.suse/drm-i915-dp-Fix-passing-the-correct-DPCD_REV-for-drm.patch.
- Refresh
  patches.suse/drm-i915-dp-Fix-the-computation-for-compressed_bpp-f.patch.
- Refresh
  patches.suse/drm-i915-dp-Fix-the-max-DSC-bpc-supported-by-source.patch.
- Refresh
  patches.suse/drm-i915-dp-Limit-SST-link-rate-to-8.1Gbps.patch.
- Refresh
  patches.suse/drm-i915-dp-Remove-support-for-UHBR13.5.patch.
- Refresh
  patches.suse/drm-i915-dpt-Make-DPT-object-unshrinkable.patch.
- Refresh
  patches.suse/drm-i915-dpt-Use-shmem-for-dpt-objects.patch.
- Refresh
  patches.suse/drm-i915-dsb-Fix-DSB-vblank-waits-when-using-VRR.patch.
- Refresh
  patches.suse/drm-i915-dsc-Fix-the-macro-that-calculates-DSCC_-DSC.patch.
- Refresh
  patches.suse/drm-i915-dsi-Go-back-to-the-previous-INIT_OTP-DISPLA.patch.
- Refresh
  patches.suse/drm-i915-edp-don-t-write-to-DP_LINK_BW_SET-when-usin.patch.
- Refresh
  patches.suse/drm-i915-gsc-Mark-internal-GSC-engine-with-reserved-.patch.
- Refresh
  patches.suse/drm-i915-gt-Automate-CCS-Mode-setting-during-engine-.patch.
- Refresh
  patches.suse/drm-i915-gt-Cleanup-aux-invalidation-registers.patch.
- Refresh
  patches.suse/drm-i915-gt-Disable-HW-load-balancing-for-CCS.patch.
- Refresh
  patches.suse/drm-i915-gt-Disarm-breadcrumbs-if-engines-are-alread.patch.
- Refresh
  patches.suse/drm-i915-gt-Do-not-generate-the-command-streamer-for.patch.
- Refresh
  patches.suse/drm-i915-gt-Enable-only-one-CCS-for-compute-workload.patch.
- Refresh
  patches.suse/drm-i915-gt-Enable-the-CCS_FLUSH-bit-in-the-pi.patch.
- Refresh
  patches.suse/drm-i915-gt-Ensure-memory-quiesced-before-inva.patch.
- Refresh
  patches.suse/drm-i915-gt-Fix-CCS-id-s-calculation-for-CCS-mode-se.patch.
- Refresh
  patches.suse/drm-i915-gt-Fix-potential-UAF-by-revoke-of-fence-reg.patch.
- Refresh
  patches.suse/drm-i915-gt-Poll-aux-invalidation-register-bit.patch.
- Refresh
  patches.suse/drm-i915-gt-Rename-flags-with-bit_group_X-acco.patch.
- Refresh
  patches.suse/drm-i915-gt-Reset-queue_priority_hint-on-parking.patch.
- Refresh
  patches.suse/drm-i915-gt-Support-aux-invalidation-on-all-en.patch.
- Refresh
  patches.suse/drm-i915-guc-avoid-FIELD_PREP-warning.patch.
- Refresh
  patches.suse/drm-i915-guc-slpc-Apply-min-softlimit-correctly.patch.
- Refresh
  patches.suse/drm-i915-guc-slpc-Restore-efficient-freq-earli.patch.
- Refresh
  patches.suse/drm-i915-hdcp-Extract-hdcp-structure-from-correct-co.patch.
- Refresh
  patches.suse/drm-i915-hdcp-Move-to-direct-reads-for-HDCP.patch.
- Refresh
  patches.suse/drm-i915-hdcp-Remove-additional-timing-for-reading-m.patch.
- Refresh
  patches.suse/drm-i915-hwmon-Fix-locking-inversion-in-sysfs-getter.patch.
- Refresh
  patches.suse/drm-i915-hwmon-Fix-static-analysis-tool-reported-iss.patch.
- Refresh
  patches.suse/drm-i915-mark-requests-for-GuC-virtual-engines-to-av.patch.
- Refresh
  patches.suse/drm-i915-mso-using-joiner-is-not-possible-with-eDP-M.patch.
- Refresh
  patches.suse/drm-i915-mst-Fix-.mode_valid_ctx-return-values.patch.
- Refresh patches.suse/drm-i915-mst-Limit-MST-DSC-to-TGL.patch.
- Refresh patches.suse/drm-i915-mst-Reject-FEC-MST-on-ICL.patch.
- Refresh
  patches.suse/drm-i915-mst-Reject-modes-that-require-the-bigjoiner.patch.
- Refresh
  patches.suse/drm-i915-mtl-Fix-HDMI-DP-PLL-clock-selection.patch.
- Refresh
  patches.suse/drm-i915-mtl-Support-HBR3-rate-with-C10-phy-and-eDP-.patch.
- Refresh
  patches.suse/drm-i915-mtl-avoid-stringop-overflow-warning.patch.
- Refresh
  patches.suse/drm-i915-perf-Update-handling-of-MMIO-triggered-repo.patch.
- Refresh
  patches.suse/drm-i915-perf-add-sentinel-to-xehp_oa_b_counter.patch.
- Refresh
  patches.suse/drm-i915-psr-Fix-BDW-PSR-AUX-CH-data-register-o.patch.
- Refresh
  patches.suse/drm-i915-psr-Only-allow-PSR-in-LPSP-mode-on-HSW-non-.patch.
- Refresh
  patches.suse/drm-i915-psr-Use-hw.adjusted-mode-when-calculat.patch.
- Refresh
  patches.suse/drm-i915-sdvo-fix-panel_type-initialization.patch.
- Refresh
  patches.suse/drm-i915-selftests-Fix-dependency-of-some-timeouts-o.patch.
- Refresh
  patches.suse/drm-i915-selftests-Fix-engine-reset-count-storage-fo.patch.
- Refresh
  patches.suse/drm-i915-tc-Fix-Wformat-truncation-in-intel_tc_port_.patch.
- Refresh patches.suse/drm-i915-tv-Fix-TV-mode.patch.
- Refresh
  patches.suse/drm-i915-vrr-Disable-VRR-when-using-bigjoiner.patch.
- Refresh
  patches.suse/drm-i915-vrr-Generate-VRR-safe-window-for-DSB.patch.
- Refresh
  patches.suse/drm-mediatek-Call-drm_atomic_helper_shutdown-at-shut.patch.
- Refresh
  patches.suse/drm-msm-dpu-drop-enum-dpu_core_perf_data_bus_id.patch.
- Refresh
  patches.suse/drm-msm-dsi-Drop-unused-regulators-from-QCM2290.patch.
- Refresh
  patches.suse/drm-msm-mdss-correct-UBWC-programming-for-SM855.patch.
- Refresh
  patches.suse/drm-nouveau-dp-Don-t-probe-eDP-ports-twice-harder.patch.
- Refresh
  patches.suse/drm-nouveau-nvkm-dp-Add-workaround-to-fix-DP-1.patch.
- Refresh
  patches.suse/drm-radeon-check-bo_va-bo-is-non-NULL-before-using-i.patch.
- Refresh
  patches.suse/drm-radeon-fix-UBSAN-warning-in-kv_dpm.c.patch.
- Refresh
  patches.suse/drm-radeon-make-fstrict-flex-arrays-3-happy.patch.
- Refresh patches.suse/drm-radeon-silence-UBSAN-warning-v3.patch.
- Refresh
  patches.suse/drm-syncobj-call-drm_syncobj_fence_add_wait-when-WAI.patch.
- Refresh
  patches.suse/drm-zynqmp_dpsub-Always-register-bridge.patch.
- Refresh
  patches.suse/i915-pmu-Move-execlist-stats-initialization-to-execl.patch.
- Refresh
  patches.suse/nouveau-gsp-use-correct-size-for-registry-rpc.patch.
- commit 5dec749
* Mon Nov  4 2024 mgorman@suse.de
- Update -rt config files.
- commit 38e2949
* Mon Nov  4 2024 tiwai@suse.de
- usb: typec: tcpm: restrict SNK_WAIT_CAPABILITIES_TIMEOUT
  transitions to non self-powered devices (git-fixes).
- commit 0dd591c
* Mon Nov  4 2024 tiwai@suse.de
- blacklist.conf: Move SP7-specific entries to its own section
- commit edb2422
* Mon Nov  4 2024 vbabka@suse.cz
- mm: split critical region in remap_file_pages() and invoke
  LSMs in between (CVE-2024-47745 bsc#1232135 git-fix).
- commit 8228ecb
* Mon Nov  4 2024 tiwai@suse.de
- Add alt-commit to AMDGPU patch
- commit 9e50980
* Mon Nov  4 2024 tiwai@suse.de
- phy: tegra: xusb: Add error pointer check in xusb.c (git-fixes).
- phy: freescale: imx8m-pcie: Do CMN_RST just before PHY PLL
  lock check (git-fixes).
- phy: ti: phy-j721e-wiz: fix usxgmii configuration (git-fixes).
- phy: qcom: qmp-combo: move driver data initialisation earlier
  (git-fixes).
- phy: qcom: qmp-usb: fix NULL-deref on runtime suspend
  (git-fixes).
- dmaengine: ti: k3-udma: Set EOP for all TRs in cyclic BCDMA
  transfer (git-fixes).
- dmaengine: sh: rz-dmac: handle configs where one address is zero
  (git-fixes).
- Revert "driver core: Fix uevent_show() vs driver detach race"
  (git-fixes).
- usb: phy: Fix API devm_usb_put_phy() can not release the phy
  (git-fixes).
- usb: typec: fix unreleased fwnode_handle in
  typec_port_register_altmodes() (git-fixes).
- xhci: Fix Link TRB DMA in command ring stopped completion event
  (git-fixes).
- xhci: Use pm_runtime_get to prevent RPM on unsupported systems
  (git-fixes).
- usbip: tools: Fix detach_port() invalid port error path
  (git-fixes).
- iio: adc: ad7124: fix division by zero in
  ad7124_set_channel_odr() (git-fixes).
- staging: iio: frequency: ad9832: fix division by zero in
  ad9832_calc_freqreg() (git-fixes).
- iio: light: veml6030: fix microlux value calculation
  (git-fixes).
- iio: gts-helper: Fix memory leaks for the error path of
  iio_gts_build_avail_scale_table() (git-fixes).
- iio: gts-helper: Fix memory leaks in
  iio_gts_build_avail_scale_table() (git-fixes).
- mei: use kvmalloc for read buffer (git-fixes).
- Input: edt-ft5x06 - fix regmap leak when probe fails
  (git-fixes).
- modpost: fix input MODULE_DEVICE_TABLE() built for 64-bit on
  32-bit host (git-fixes).
- modpost: fix acpi MODULE_DEVICE_TABLE built with mismatched
  endianness (git-fixes).
- sumversion: Fix a memory leak in get_src_version() (git-fixes).
- genirq/msi: Fix off-by-one error in msi_domain_alloc()
  (git-fixes).
- commit df7fb9d
* Mon Nov  4 2024 jslaby@suse.cz
- Refresh
  patches.suse/PCI-Fix-pci_enable_acs-support-for-the-ACS-quirks.patch.
  Update upstream status.
- commit f283868
* Mon Nov  4 2024 pjakobsson@suse.de
- Refresh patches.suse/minmax-make-generic-MIN-and-MAX-macros-available-eve.patch.
- commit eee2f17
* Mon Nov  4 2024 neilb@suse.de
- nfsd: cancel nfsd_shrinker_work using sync mode in
  nfs4_state_shutdown_net (git-fixes).
- commit ed2b339
* Mon Nov  4 2024 jlee@suse.com
- thermal/drivers/amlogic: Support A1 SoC family Thermal Sensor
  controller (jsc#PED-11164).
- thermal/drivers/tsens: Add suspend to RAM support for tsens
  (jsc#PED-11164).
- thermal/drivers/armada: Simplify name sanitization
  (jsc#PED-11164).
- commit 9f4fa3f
* Mon Nov  4 2024 neilb@suse.de
- NFSv3: only use NFS timeout for MOUNT when protocols are
  compatible (bsc#1231016).
- commit ddbeb4f
* Mon Nov  4 2024 jlee@suse.com
- Update
  patches.suse/0002-x86-mm-ident_map-Use-gbpages-only-where-full-GB-page.patch
  (bsc#1220382 CVE-2024-50017 bsc#1232312).
- Update patches.suse/ACPI-PAD-fix-crash-in-exit_round_robin.patch
  (stable-fixes CVE-2024-49935 bsc#1232370).
- Update
  patches.suse/ACPI-battery-Fix-possible-crash-when-unregistering-a.patch
  (git-fixes CVE-2024-49955 bsc#1232154).
- Update
  patches.suse/ACPI-sysfs-validate-return-type-of-_STR-method.patch
  (git-fixes CVE-2024-49860 bsc#1231861).
- Update
  patches.suse/ACPICA-check-null-return-of-ACPI_ALLOCATE_ZEROED-in-.patch
  (stable-fixes CVE-2024-49962 bsc#1232314).
- Update
  patches.suse/ALSA-asihpi-Fix-potential-OOB-array-access.patch
  (stable-fixes CVE-2024-50007 bsc#1232394).
- Update
  patches.suse/Bluetooth-Call-iso_exit-on-module-unload.patch
  (git-fixes CVE-2024-50078 bsc#1232503).
- Update
  patches.suse/Bluetooth-ISO-Fix-multiple-init-when-debugfs-is-disa.patch
  (git-fixes CVE-2024-50077 bsc#1232504).
- Update
  patches.suse/Bluetooth-RFCOMM-FIX-possible-deadlock-in-rfcomm_sk_.patch
  (git-fixes CVE-2024-50044 bsc#1231904).
- Update
  patches.suse/IB-core-Fix-ib_cache_setup_one-error-flow-cleanup.patch
  (git-fixes CVE-2024-47693 bsc#1232013).
- Update
  patches.suse/IB-core-Implement-a-limit-on-UMAD-receive-List.patch
  (bsc#1228743 CVE-2024-42145 bsc#1223384).
- Update
  patches.suse/Input-adp5589-keys-fix-NULL-pointer-dereference.patch
  (git-fixes CVE-2024-49871 bsc#1232287).
- Update
  patches.suse/KEYS-prevent-NULL-pointer-dereference-in-find_asymme.patch
  (git-fixes CVE-2024-47743 bsc#1232129).
- Update
  patches.suse/KVM-Use-dedicated-mutex-to-protect-kvm_usage_count-t.patch
  (git-fixes CVE-2024-47744 bsc#1232132).
- Update
  patches.suse/PCI-keystone-Fix-if-statement-expression-in-ks_pcie_.patch
  (git-fixes CVE-2024-47756 bsc#1232185).
- Update
  patches.suse/PCI-kirin-Fix-buffer-overflow-in-kirin_pcie_parse_po.patch
  (git-fixes CVE-2024-47751 bsc#1232127).
- Update
  patches.suse/RDMA-cxgb4-Added-NULL-check-for-lookup_atid.patch
  (git-fixes CVE-2024-47749 bsc#1232180).
- Update
  patches.suse/RDMA-hns-Fix-Use-After-Free-of-rsv_qp-on-HIP08.patch
  (git-fixes CVE-2024-47750 bsc#1232182).
- Update
  patches.suse/RDMA-hns-Fix-spin_unlock_irqrestore-called-with-IRQs.patch
  (git-fixes CVE-2024-47735 bsc#1232111).
- Update
  patches.suse/RDMA-iwcm-Fix-WARNING-at_kernel-workqueue.c-check_fl.patch
  (git-fixes CVE-2024-47696 bsc#1231864).
- Update
  patches.suse/RDMA-rtrs-clt-Reset-cid-to-con_num-1-to-stay-in-boun.patch
  (git-fixes CVE-2024-47695 bsc#1231931).
- Update
  patches.suse/RDMA-rtrs-srv-Avoid-null-pointer-deref-during-path-e.patch
  (git-fixes CVE-2024-50062 bsc#1232232).
- Update
  patches.suse/aoe-fix-the-potential-use-after-free-problem-in-more.patch
  (bsc#1218562 CVE-2023-6270 CVE-2024-49982 bsc#1232097).
- Update
  patches.suse/bpf-Fail-verification-for-sign-extension-of-packet-d.patch
  (git-fixes CVE-2024-47702 bsc#1231924).
- Update
  patches.suse/bpf-Fix-helper-writes-to-read-only-maps.patch
  (git-fixes CVE-2024-49861 bsc#1232254).
- Update
  patches.suse/bpf-Fix-use-after-free-in-bpf_uprobe_multi_link_attach.patch
  (git-fixes CVE-2024-47675 bsc#1231926).
- Update
  patches.suse/bpf-Zero-former-ARG_PTR_TO_-LONG-INT-args-in-case-of.patch
  (git-fixes CVE-2024-47728 bsc#1232076).
- Update
  patches.suse/bpf-correctly-handle-malformed-BPF_CORE_TYPE_ID_LOCA.patch
  (git-fixes CVE-2024-49850 bsc#1232189).
- Update
  patches.suse/cachefiles-fix-dentry-leak-in-cachefiles_open_file.patch
  (bsc#1231183 CVE-2024-49870 bsc#1232279).
- Update
  patches.suse/can-bcm-Clear-bo-bcm_proc_read-after-remove_proc_ent.patch
  (git-fixes CVE-2024-47709 bsc#1232048).
- Update
  patches.suse/crypto-iaa-Fix-potential-use-after-free-bug.patch
  (git-fixes CVE-2024-47732 bsc#1232109).
- Update
  patches.suse/cxl-pci-Fix-disabling-memory-if-DVSEC-CXL-Range-does.patch
  (git-fixes CVE-2024-26761 bsc#1230375).
- Update
  patches.suse/driver-core-Fix-a-potential-null-ptr-deref-in-module.patch
  (git-fixes CVE-2024-47688 bsc#1232009).
- Update
  patches.suse/driver-core-bus-Fix-double-free-in-driver-API-bus_re.patch
  (stable-fixes CVE-2024-50055 bsc#1232329).
- Update
  patches.suse/drivers-media-dvb-frontends-rtl2830-fix-an-out-of-bo.patch
  (git-fixes CVE-2024-47697 bsc#1231858).
- Update
  patches.suse/drivers-media-dvb-frontends-rtl2832-fix-an-out-of-bo.patch
  (git-fixes CVE-2024-47698 bsc#1231859).
- Update
  patches.suse/drm-amd-display-Add-null-check-for-set_output_gamma-.patch
  (git-fixes CVE-2024-47720 bsc#1232043).
- Update
  patches.suse/drm-amd-display-Check-null-pointer-before-dereferenc.patch
  (stable-fixes CVE-2024-50049 bsc#1232309).
- Update
  patches.suse/drm-amd-display-fixed-integer-types-and-null-check-l.patch
  (git-fixes CVE-2024-26767 bsc#1230339).
- Update
  patches.suse/drm-omapdrm-Add-missing-check-for-alloc_ordered_work.patch
  (git-fixes CVE-2024-49879 bsc#1232349).
- Update
  patches.suse/drm-v3d-Stop-the-active-perfmon-before-being-destroy.patch
  (git-fixes CVE-2024-50031 bsc#1231947).
- Update
  patches.suse/efistub-tpm-Use-ACPI-reclaim-memory-for-event-log-to.patch
  (stable-fixes CVE-2024-49858 bsc#1232251).
- Update
  patches.suse/ep93xx-clock-Fix-off-by-one-in-ep93xx_div_recalc_rat.patch
  (git-fixes CVE-2024-47686 bsc#1232000).
- Update
  patches.suse/exfat-fix-memory-leak-in-exfat_load_bitmap.patch
  (git-fixes CVE-2024-50013 bsc#1232080).
- Update
  patches.suse/fbcon-Fix-a-NULL-pointer-dereference-issue-in-fbcon_.patch
  (stable-fixes CVE-2024-50048 bsc#1232310).
- Update
  patches.suse/firmware-arm_scmi-Fix-double-free-in-OPTEE-transport.patch
  (git-fixes CVE-2024-49853 bsc#1232192).
- Update patches.suse/firmware_loader-Block-path-traversal.patch
  (git-fixes CVE-2024-47742 bsc#1232126).
- Update
  patches.suse/i2c-stm32f7-Do-not-prepare-unprepare-clock-during-ru.patch
  (git-fixes CVE-2024-49985 bsc#1232094).
- Update
  patches.suse/i3c-master-cdns-Fix-use-after-free-vulnerability-in-.patch
  (stable-fixes CVE-2024-50061 bsc#1232263).
- Update
  patches.suse/i3c-master-svc-Fix-use-after-free-vulnerability-in-s.patch
  (git-fixes CVE-2024-49874 bsc#1232295).
- Update
  patches.suse/i40e-Fix-XDP-program-unloading-while-removing-the-dr.patch
  (git-fixes CVE-2024-41047 bsc#1228537).
- Update
  patches.suse/idpf-fix-UAFs-when-destroying-the-queues.patch
  (git-fixes CVE-2024-44932 bsc#1229808).
- Update
  patches.suse/idpf-fix-memory-leaks-and-crashes-while-performing-a.patch
  (git-fixes CVE-2024-44964 bsc#1230220).
- Update
  patches.suse/iommufd-Protect-against-overflow-of-ALIGN-during-iov.patch
  (git-fixes CVE-2024-47719 bsc#1231865).
- Update
  patches.suse/jffs2-prevent-xattr-node-from-overflowing-the-eraseblock.patch
  (git-fixes CVE-2024-38599 bsc#1226848 bsc#1223384).
- Update patches.suse/jfs-Fix-uaf-in-dbFreeBits.patch (git-fixes
  CVE-2024-49903 bsc#1232362).
- Update
  patches.suse/jfs-Fix-uninit-value-access-of-new_ea-in-ea_buffer.patch
  (git-fixes CVE-2024-49900 bsc#1232359).
- Update
  patches.suse/jfs-check-if-leafidx-greater-than-num-leaves-per-dmap-tree.patch
  (git-fixes CVE-2024-49902 bsc#1232378).
- Update
  patches.suse/jfs-fix-out-of-bounds-in-dbNextAG-and-diAlloc.patch
  (git-fixes CVE-2024-47723 bsc#1232050).
- Update
  patches.suse/mailbox-bcm2835-Fix-timeout-during-suspend-mode.patch
  (git-fixes CVE-2024-49963 bsc#1232147).
- Update
  patches.suse/md-Don-t-ignore-suspended-array-in-md_check_recovery-1baa.patch
  (bsc#1219596 CVE-2024-26758 bsc#1230341).
- Update patches.suse/media-edia-dvbdev-fix-a-use-after-free.patch
  (git-fixes CVE-2024-27043 bsc#1223824 bsc#1218562).
- Update
  patches.suse/media-i2c-ar0521-Use-cansleep-version-of-gpiod_set_v.patch
  (git-fixes CVE-2024-49961 bsc#1232148).
- Update
  patches.suse/media-venus-fix-use-after-free-bug-in-venus_remove-d.patch
  (git-fixes CVE-2024-49981 bsc#1232098).
- Update
  patches.suse/nbd-fix-race-between-timeout-and-normal-completion.patch
  (bsc#1230918 CVE-2024-49855 bsc#1232195).
- Update
  patches.suse/net-phy-Remove-LED-entry-from-LEDs-list-on-unregiste.patch
  (git-fixes CVE-2024-50023 bsc#1231955).
- Update
  patches.suse/net-test-for-not-too-small-csum_start-in-virtio_net_.patch
  (git-fixes CVE-2024-49947 bsc#1232162).
- Update
  patches.suse/nfsd-call-cache_put-if-xdr_reserve_space-returns-NULL.patch
  (git-fixes CVE-2024-47737 bsc#1232056).
- Update
  patches.suse/nfsd-map-the-EBADMSG-to-nfserr_io-to-avoid-warning.patch
  (git-fixes CVE-2024-49875 bsc#1232333).
- Update
  patches.suse/nilfs2-fix-potential-null-ptr-deref-in-nilfs_btree_insert.patch
  (git-fixes CVE-2024-47699 bsc#1231916).
- Update
  patches.suse/nilfs2-fix-potential-oob-read-in-nilfs_btree_check_delete.patch
  (git-fixes CVE-2024-47757 bsc#1232187).
- Update
  patches.suse/nouveau-dmem-handle-kcalloc-allocation-failure.patch
  (git-fixes CVE-2024-26943 bsc#1230527).
- Update
  patches.suse/ocfs2-cancel-dqi_sync_work-before-freeing-oinfo.patch
  (git-fixes CVE-2024-49966 bsc#1232141).
- Update
  patches.suse/ocfs2-fix-null-ptr-deref-when-journal-load-failed.patch
  (git-fixes CVE-2024-49957 bsc#1232152).
- Update
  patches.suse/ocfs2-fix-possible-null-ptr-deref-in-ocfs2_set_buffer_uptodate.patch
  (git-fixes CVE-2024-49877 bsc#1232339).
- Update
  patches.suse/ocfs2-remove-unreasonable-unlock-in-ocfs2_read_blocks.patch
  (git-fixes CVE-2024-49965 bsc#1232142).
- Update
  patches.suse/parport-Proper-fix-for-array-out-of-bounds-access.patch
  (git-fixes CVE-2024-50074 bsc#1232507).
- Update
  patches.suse/pinctrl-apple-check-devm_kasprintf-returned-value.patch
  (git-fixes CVE-2024-50069 bsc#1232511).
- Update
  patches.suse/platform-x86-ISST-Fix-the-KASAN-report-slab-out-of-b.patch
  (git-fixes CVE-2024-49886 bsc#1232196).
- Update
  patches.suse/powercap-intel_rapl-Fix-off-by-one-in-get_rpi.patch
  (git-fixes CVE-2024-49862 bsc#1231871).
- Update
  patches.suse/resource-fix-region_intersects-vs-add_memory_driver_.patch
  (git-fixes CVE-2024-49878 bsc#1232340).
- Update
  patches.suse/scsi-fnic-Move-flush_work-initialization-out-of-if-b.patch
  (bsc#1230055 CVE-2024-50025 bsc#1231953).
- Update
  patches.suse/scsi-lpfc-validate-hdwq-pointers-before-dereferencing-in.patch
  (bsc#1229429 jsc#PED-9899 CVE-2024-49891 bsc#1232218).
- Update
  patches.suse/scsi-sd-Fix-off-by-one-error-in-sd_read_block_charac.patch
  (bsc#1223848 CVE-2024-47682 bsc#1231856).
- Update
  patches.suse/serial-protect-uart_port_dtr_rts-in-uart_shutdown-to.patch
  (stable-fixes CVE-2024-50058 bsc#1232285).
- Update
  patches.suse/tpm-Clean-up-TPM-space-after-command-failure.patch
  (git-fixes CVE-2024-49851 bsc#1232134).
- Update
  patches.suse/tty-n_gsm-Fix-use-after-free-in-gsm_cleanup_mux.patch
  (stable-fixes CVE-2024-50073 bsc#1232520).
- Update
  patches.suse/vhost-scsi-null-ptr-dereference-in-vhost_scsi_get_re.patch
  (git-fixes CVE-2024-49863 bsc#1232255).
- Update
  patches.suse/vhost_vdpa-assign-irq-bypass-producer-token-correctl.patch
  (git-fixes CVE-2024-47748 bsc#1232174).
- Update patches.suse/vmxnet3-Fix-missing-reserved-tailroom.patch
  (bsc#1226498 CVE-2024-27026 bsc#1223700).
- Update
  patches.suse/vt-prevent-kernel-infoleak-in-con_font_get.patch
  (git-fixes CVE-2024-50076 bsc#1232505).
- Update
  patches.suse/wifi-ath11k-fix-array-out-of-bound-access-in-SoC-sta.patch
  (stable-fixes CVE-2024-49930 bsc#1232260).
- Update
  patches.suse/wifi-ath12k-fix-array-out-of-bound-access-in-SoC-sta.patch
  (stable-fixes CVE-2024-49931 bsc#1232275).
- Update
  patches.suse/wifi-ath9k_htc-Use-__skb_set_length-for-resetting-ur.patch
  (stable-fixes CVE-2024-49938 bsc#1232552).
- Update
  patches.suse/wifi-cfg80211-Set-correct-chandef-when-starting-CAC.patch
  (stable-fixes CVE-2024-49937 bsc#1232427).
- Update
  patches.suse/wifi-iwlwifi-mvm-avoid-NULL-pointer-dereference.patch
  (stable-fixes CVE-2024-49929 bsc#1232253).
- Update
  patches.suse/wifi-mac80211-don-t-use-rate-mask-for-offchannel-TX-.patch
  (git-fixes CVE-2024-47738 bsc#1232114).
- Update
  patches.suse/wifi-mac80211-use-two-phase-skb-reclamation-in-ieee8.patch
  (git-fixes CVE-2024-47713 bsc#1232016).
- Update
  patches.suse/wifi-mt76-mt7915-fix-oops-on-non-dbdc-mt7986.patch
  (git-fixes CVE-2024-47715 bsc#1231860).
- Update
  patches.suse/wifi-mt76-mt7996-fix-NULL-pointer-dereference-in-mt7.patch
  (git-fixes CVE-2024-47681 bsc#1231855).
- Update
  patches.suse/wifi-mt76-mt7996-use-hweight16-to-get-correct-tx-ant.patch
  (git-fixes CVE-2024-47714 bsc#1232018).
- Update
  patches.suse/wifi-mwifiex-Fix-memcpy-field-spanning-write-warning.patch
  (stable-fixes CVE-2024-50008 bsc#1232317).
- Update
  patches.suse/wifi-rtw88-always-wait-for-both-firmware-loading-att.patch
  (git-fixes CVE-2024-47718 bsc#1232015).
- Update
  patches.suse/wifi-rtw89-avoid-reading-out-of-bounds-when-loading-.patch
  (stable-fixes CVE-2024-49928 bsc#1232250).
- Update
  patches.suse/wifi-rtw89-avoid-to-add-interface-to-list-twice-when.patch
  (stable-fixes CVE-2024-49939 bsc#1232381).
- Update
  patches.suse/wifi-wilc1000-fix-potential-RCU-dereference-issue-in.patch
  (git-fixes CVE-2024-47712 bsc#1232017).
- Update
  patches.suse/xhci-tegra-fix-checked-USB2-port-number.patch
  (git-fixes CVE-2024-50075 bsc#1232506).
- commit a270265
* Mon Nov  4 2024 jlee@suse.com
- Update
  patches.suse/i3c-mipi-i3c-hci-Fix-out-of-bounds-access-in-hci_dma.patch
  (git-fixes CVE-2023-52766 bsc#1230620).
- Update
  patches.suse/media-pci-cx23885-check-cx23885_vdev_init-return.patch
  (stable-fixes CVE-2023-52918 bsc#1232047).
- Update
  patches.suse/nfc-nci-fix-possible-NULL-pointer-dereference-in-sen.patch
  (git-fixes CVE-2023-52919 bsc#1231988).
- Update
  patches.suse/ntb-intel-Fix-the-NULL-vs-IS_ERR-bug-for-debugfs_cre.patch
  (git-fixes CVE-2023-52917 bsc#1231849).
- Update
  patches.suse/tcp-do-not-accept-ACK-of-bytes-we-never-sent.patch
  (CVE-2023-52881 bsc#1225611 bsc#1223384).
- Update patches.suse/wifi-ath11k-fix-htt-pktlog-locking.patch
  (git-fixes CVE-2023-52800 bsc#1230600).
- commit 9859953
* Mon Nov  4 2024 neilb@suse.de
- NFSD: Force all NFSv4.2 COPY requests to be synchronous
  (CVE-2024-49974 bsc#1232383).
- commit 16045fc
* Mon Nov  4 2024 jlee@suse.com
- thermal: core: Relocate the struct thermal_governor definition
  (jsc#PED-11164).
- thermal: core: Sort trip point crossing notifications by
  temperature (jsc#PED-11164).
  Refresh
  patches.suse/thermal-debugfs-Avoid-excessive-updates-of-trip-poin.patch.
- thermal: core: Send trip crossing notifications at init time
  if needed (jsc#PED-11164).
- thermal: core: Rewrite comments in handle_thermal_trip()
  (jsc#PED-11164).
- thermal: core: Make struct thermal_zone_device definition
  internal (jsc#PED-11164).
- thermal: core: Move threshold out of struct thermal_trip
  (jsc#PED-11164).
  Refresh
  patches.suse/thermal-debugfs-Avoid-excessive-updates-of-trip-poin.patch.
  patches.suse/thermal-core-Reference-count-the-zone-in-thermal_zon.patch.
- thermal: gov_step_wise: Simplify checks related to passive trips
  (jsc#PED-11164).
- thermal: gov_step_wise: Simplify get_target_state()
  (jsc#PED-11164).
- thermal/cpufreq: Remove arch_update_thermal_pressure()
  (jsc#PED-11164).
- commit d680456
* Sun Nov  3 2024 petr.pavlu@suse.com
- fgraph: Change the name of cpuhp state to "fgraph:online"
  (git-fixes).
- commit 59421b3
* Sun Nov  3 2024 petr.pavlu@suse.com
- fgraph: Fix missing unlock in register_ftrace_graph()
  (git-fixes).
- commit 60d91ed
* Sun Nov  3 2024 ailiop@suse.com
- blacklist.conf: add f2fs fixes aaf8c0b9ae04 and 884ee6dc85b9
  We don't enable/compile f2fs, blacklist pending fixes.
- commit ec65ea0
* Sun Nov  3 2024 ailiop@suse.com
- fs/9p: drop inodes immediately on non-.L too (git-fixes).
- commit 5fa5f19
* Sun Nov  3 2024 ailiop@suse.com
- 9p: explicitly deny setlease attempts (git-fixes).
- commit 474852b
* Sun Nov  3 2024 ailiop@suse.com
- fs/9p: fix the cache always being enabled on files with qid
  flags (git-fixes).
- commit 362152c
* Sun Nov  3 2024 ailiop@suse.com
- blacklist.conf: add f2fs fixes f9e28904e644 and 9f0c4a46be1f
  We don't enable/compile f2fs, blacklist pending fixes.
- commit aaea9b2
* Sun Nov  3 2024 ailiop@suse.com
- zonefs: Improve error handling (git-fixes).
- commit cb63c4c
* Sun Nov  3 2024 ailiop@suse.com
- debugfs: fix automount d_fsdata usage (git-fixes).
- commit 5f78a06
* Sun Nov  3 2024 ailiop@suse.com
- splice: fsnotify_access(in), fsnotify_modify(out) on success
  in tee (git-fixes).
- commit d518e6d
* Sun Nov  3 2024 ailiop@suse.com
- splice: fsnotify_access(fd)/fsnotify_modify(fd) in vmsplice
  (git-fixes).
- commit d630f18
* Sun Nov  3 2024 ailiop@suse.com
- splice: always fsnotify_access(in), fsnotify_modify(out)
  on success (git-fixes).
- commit e7f8947
* Sun Nov  3 2024 ailiop@suse.com
- keys: Fix overwrite of key expiration on instantiation
  (git-fixes).
- commit 323181d
* Sun Nov  3 2024 ailiop@suse.com
- audit: don't WARN_ON_ONCE(!current->mm) in audit_exe_compare()
  (git-fixes).
- commit e2db423
* Sun Nov  3 2024 ailiop@suse.com
- ocfs2: fix uninit-value in ocfs2_get_block() (git-fixes).
- commit 426a4b1
* Sun Nov  3 2024 ailiop@suse.com
- keys, dns: Allow key types (eg. DNS) to be reclaimed immediately
  on expiry (git-fixes).
- commit ce262a7
* Sun Nov  3 2024 ailiop@suse.com
- Revert "KEYS: encrypted: Add check for strsep" (git-fixes).
- commit 7aa308c
* Sun Nov  3 2024 ailiop@suse.com
- ubifs: add check for crypto_shash_tfm_digest (git-fixes).
- commit ea9ba15
* Sun Nov  3 2024 ailiop@suse.com
- ubifs: dbg_orphan_check: Fix missed key type checking
  (git-fixes).
- commit 465ad1a
* Sun Nov  3 2024 ailiop@suse.com
- ubifs: Fix adding orphan entry twice for the same inode
  (git-fixes).
- commit 93096ab
* Sun Nov  3 2024 ailiop@suse.com
- Revert "ubifs: ubifs_symlink: Fix memleak of inode->i_link in
  error path" (git-fixes).
- commit 0a7c17d
* Sun Nov  3 2024 ailiop@suse.com
- ubifs: Fix unattached xattr inode if powercut happens after
  deleting (git-fixes).
- commit 6c90268
* Sun Nov  3 2024 ailiop@suse.com
- blacklist.conf: add drbd fixes a5e61b50c9f4 and 2f02b5af3a44
  We don't enable/compile the in-kernel DRBD driver, so we can blacklist
  all pending fixes.
- commit 66a9b5d
* Sun Nov  3 2024 ailiop@suse.com
- blacklist.conf: add smack fixes 9c82169208dd and ac02f007d64e
  SMACK LSM is unsupported, and we don't compile it on any of our
  branches, so blacklist the fixes.
- commit 3e8de74
* Sun Nov  3 2024 ailiop@suse.com
- audit: don't take task_lock() in audit_exe_compare() code path
  (git-fixes).
- Refresh patches.suse/vfs-add-super_operations-get_inode_dev.
- commit d4e23ef
* Sun Nov  3 2024 mgorman@suse.de
- series.conf: Move superseded patch order
- commit 481aeb1
* Sun Nov  3 2024 mgorman@suse.de
- Delete
  patches.suse/powerpc-Add-support-for-lazy-preemption.patch.
- commit 3522e3f
* Sun Nov  3 2024 mgorman@suse.de
- Update patches.suse/sysfs-Add-sys-kernel-realtime-entry.patch
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit c4fd32a
* Sun Nov  3 2024 mgorman@suse.de
- Delete
  patches.suse/powerpc-kvm-Disable-in-kernel-MPIC-emulation-for-PREEMPT_RT.patch.
- Delete
  patches.suse/powerpc-pseries-Select-the-generic-memory-allocator.patch.
- Delete
  patches.suse/powerpc-pseries-iommu-Use-a-locallock-instead-local_irq_save.patch.
- Delete
  patches.suse/powerpc-stackprotector-work-around-stack-guard-init-from-atomic.patch.
- Delete patches.suse/powerpc-traps-Use-PREEMPT_RT.patch.
- commit 1ee4dbf
* Sun Nov  3 2024 mgorman@suse.de
- series.conf: Move ARM patches into order used by v6.12-rc4-rt6
- commit 02cae4a
* Sun Nov  3 2024 mgorman@suse.de
- series.conf: Move drm patches into order used by v6.12-rc4-rt6
- commit 2128cea
* Sun Nov  3 2024 mgorman@suse.de
- time: Allow to preempt after a callback (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- softirq: Add function to preempt serving softirqs (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 44f9651
* Sun Nov  3 2024 mgorman@suse.de
- Update
  patches.suse/sched-core-Provide-a-method-to-check-if-a-task-is-PI-boosted.patch
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 698e1c0
* Sun Nov  3 2024 mgorman@suse.de
- locking/rt: Add sparse annotation PREEMPT_RT's sleeping locks
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- locking/rt: Add sparse annotation for RCU (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- locking/rt: Annotate unlock followed by lock for sparse
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- locking/rt: Remove one __cond_lock() in RT's
  spin_trylock_irqsave() (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- rcutorture: Also force sched priority to timersd on boosting
  test (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- sched/rt: Don't try push tasks if there are none (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: 8250: Revert "drop lockdep annotation from
  serial8250_clear_IER()" (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- serial: 8250: Switch to nbcon console (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- softirq: Use a dedicated thread for timer wakeups (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- softirq: Wake ktimers thread also in softirq (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- tick: Fix timer storm since introduction of timersd (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 58cc9c9
* Sun Nov  3 2024 petr.pavlu@suse.com
- uprobes: fix kernel info leak via "[uprobes]" vma (bsc#1231114
  CVE-2024-46828).
- uprobes: turn xol_area->pages into xol_area->page (bsc#1231114).
- uprobes: introduce the global struct vm_special_mapping
  xol_mapping (bsc#1231114).
- commit 4f9954c
* Sun Nov  3 2024 mgorman@suse.de
- timers: Rename next_expiry_recalc() to be unique (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit e6ded01
* Sun Nov  3 2024 mgorman@suse.de
- MAINTAINERS: Add an entry for PREEMPT_RT (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 2a38dc4
* Sun Nov  3 2024 mgorman@suse.de
- arm64: Allow to enable PREEMPT_RT (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- x86: Allow to enable PREEMPT_RT (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- Delete patches.suse/ARM64-Allow-to-enable-RT.patch.
- Delete patches.suse/x86-Allow-to-enable-RT.patch.
- Delete patches.suse/x86-Enable-RT-also-on-32bit.patch.
- commit dee20f8
* Sun Nov  3 2024 mgorman@suse.de
- printk: nbcon: Use raw_cpu_ptr() instead of open coding
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers: Annotate possible non critical data race of next_expiry
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers: Remove historical extra jiffie for timeout in msleep()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers: Add sparse annotation for timer_sync_wait_running()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- signal: Replace BUG_ON()s (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- signal: Remove task argument from dequeue_signal() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- zram: Remove ZRAM_LOCK (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- zram: Replace bit spinlocks with a spinlock_t (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- Delete
  patches.suse/zram-Replace-bit-spinlocks-with-spinlock_t-for-PREEMPT_RT.patch.
- timekeeping: Fix bogus clock_was_set() invocation in
  do_adjtimex() (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers/migration: Fix grammar in comment (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- timers/migration: Spare write when nothing changed (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- timers/migration: Rename childmask by groupmask to make naming
  more obvious (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers/migration: Read childmask and parent pointer in a single
  place (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers/migration: Use a single struct for hierarchy walk data
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers/migration: Improve tracing (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- timers/migration: Move hierarchy setup into cpuhotplug prepare
  callback (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers/migration: Do not rely always on group->parent
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- drm/ttm/tests: Let ttm_bo_test consider different ww_mutex
  implementation (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- lwt: Don't disable migration prio invoking BPF (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- dev: Remove PREEMPT_RT ifdefs from backlog_lock.*() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- timerqueue: Remove never used function timerqueue_node_expires()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 0ea4560
* Sun Nov  3 2024 mgorman@suse.de
- tick/sched: Don't clear ts::next_tick again in
  can_stop_idle_tick() (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- tick/sched: Rename tick_nohz_stop_sched_tick()
  to tick_nohz_full_stop_tick() (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- tick: Use IS_ENABLED() whenever possible (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- tick/sched: Remove useless oneshot ifdeffery (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- tick/nohz: Remove duplicate between lowres and highres handlers
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit ba61bd5
* Sun Nov  3 2024 mgorman@suse.de
- tick/nohz: Remove duplicate between tick_nohz_switch_to_nohz()
  and tick_setup_sched_timer() (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- tick/sched: Split out jiffies update helper function
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 879a8fc
* Sun Nov  3 2024 mgorman@suse.de
- timers/migration: Return early on deactivation (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- timers/migration: Fix ignored event due to missing CPU update
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers/migration: Fix endless timer requeue after idle
  interrupts (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timer/migration: Remove buggy early return on deactivation
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timer/migration: Fix quick check reporting late expiry
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit 732511d
* Sun Nov  3 2024 mgorman@suse.de
- sched/idle: Conditionally handle tick broadcast in
  default_idle_call() (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- commit c82d6c4
* Sun Nov  3 2024 mgorman@suse.de
- timer_migration: Add tracepoints (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- timers: Add get next timer interrupt functionality for remote
  CPUs (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers: Always queue timers on the local CPU (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- timers: Check if timers base is handled already (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- timers: Implement the hierarchical pull model (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- timers: Introduce function to check timer base is_idle flag
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers: Keep the pinned timers separate from the others
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers: Restructure internal locking (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- timers: Retrieve next expiry of pinned/non-pinned timers
  separately (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers: Simplify code in run_local_timers() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- timers: Split next timer interrupt logic (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- timers: Split out "get next timer interrupt" functionality
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- Delete
  patches.suse/rcutorture-Also-force-sched-priority-to-timersd-on-boosting-test.patch.
- Delete
  patches.suse/softirq-Add-function-to-preempt-serving-softirqs.patch.
- Delete
  patches.suse/softirq-Use-a-dedicated-thread-for-timer-wakeups.patch.
- Delete
  patches.suse/softirq-Wake-ktimers-thread-also-in-softirq.patch.
- Delete
  patches.suse/tick-Fix-timer-storm-since-introduction-of-timersd.patch.
- Delete
  patches.suse/time-Allow-to-preempt-after-a-callback.patch.
- commit 9a19658
* Sun Nov  3 2024 petr.pavlu@suse.com
- sched: sch_cake: fix bulk flow accounting logic for host
  fairness (bsc#1231114 CVE-2024-46828).
- commit ad42d5f
* Sun Nov  3 2024 ailiop@suse.com
- xfs: fix finding a last resort AG in xfs_filestream_pick_ag
  (git-fixes).
- commit a10af4c
* Sat Nov  2 2024 petr.pavlu@suse.com
- static_call: Handle module init failure correctly in
  static_call_del_module() (bsc#1232083 CVE-2024-50002).
- commit af953b9
* Sat Nov  2 2024 tiwai@suse.de
- ALSA: hda/realtek: Refactor and simplify Samsung Galaxy Book
  init (stable-fixes).
- Refresh
  patches.suse/ALSA-hda-realtek-Add-quirk-for-Huawei-MateBook-13-KL.patch.
- commit 98d4026
* Sat Nov  2 2024 tiwai@suse.de
- ALSA: hda/realtek: Enable mic on Vaio VJFH52 (stable-fixes).
- commit 7075c22
* Sat Nov  2 2024 tiwai@suse.de
- ALSA: hda/realtek: tas2781: Fix ROG ALLY X audio (stable-fixes).
- commit e26a542
* Sat Nov  2 2024 tiwai@suse.de
- ALSA: hda/realtek: Fix headset mic on TUXEDO Stellaris 16 Gen6
  mb1 (stable-fixes).
- ALSA: hda/realtek: Fix headset mic on TUXEDO Gemini 17 Gen3
  (stable-fixes).
- ALSA: usb-audio: Add quirks for Dell WD19 dock (stable-fixes).
- ASoC: dapm: fix bounds checker error in dapm_widget_list_create
  (git-fixes).
- ASoC: Intel: sst: Fix used of uninitialized ctx to log an error
  (git-fixes).
- ASoC: Intel: sst: Support LPE0F28 ACPI HID (stable-fixes).
- ASoC: Intel: bytcr_rt5640: Add DMI quirk for Vexia Edu Atla
  10 tablet (stable-fixes).
- ASoC: Intel: bytcr_rt5640: Add support for non ACPI instantiated
  codec (stable-fixes).
- ASoC: codecs: rt5640: Always disable IRQs from
  rt5640_cancel_work() (stable-fixes).
- ALSA: hda/realtek: Add subwoofer quirk for Infinix ZERO BOOK 13
  (stable-fixes).
- ALSA: hda/realtek: Limit internal Mic boost on Dell platform
  (stable-fixes).
- commit 0d350ca
* Sat Nov  2 2024 tiwai@suse.de
- drm/mediatek: Fix get efuse issue for MT8188 DPTX (git-fixes).
- drm/amd/pm: Vangogh: Fix kernel memory out of bounds write
  (git-fixes).
- ACPI: CPPC: Make rmw_lock a raw_spin_lock (git-fixes).
- firmware: arm_sdei: Fix the input parameter of
  cpuhp_remove_state() (git-fixes).
- kasan: Fix Software Tag-Based KASAN with GCC (git-fixes).
- commit 2a07e04
* Sat Nov  2 2024 tiwai@suse.de
- Bluetooth: hci: fix null-ptr-deref in hci_read_supported_codecs
  (git-fixes).
- wifi: cfg80211: clear wdev->cqm_config pointer on free
  (git-fixes).
- Revert "wifi: iwlwifi: remove retry loops in start" (git-fixes).
- wifi: iwlwifi: mvm: don't add default link in fw restart flow
  (git-fixes).
- wifi: iwlwifi: mvm: Fix response handling in
  iwl_mvm_send_recovery_cmd() (git-fixes).
- wifi: iwlwifi: mvm: don't leak a link on AP removal (git-fixes).
- wifi: ath11k: Fix invalid ring usage in full monitor mode
  (git-fixes).
- wifi: ath10k: Fix memory leak in management tx (git-fixes).
- wifi: brcm80211: BRCM_TRACING should depend on TRACING
  (git-fixes).
- wifi: mac80211: skip non-uploaded keys in ieee80211_iter_keys
  (git-fixes).
- wifi: mac80211: do not pass a stopped vif to the driver in
  .get_txpower (git-fixes).
- mac80211: MAC80211_MESSAGE_TRACING should depend on TRACING
  (git-fixes).
- wifi: iwlegacy: Fix "field-spanning write" warning in
  il_enqueue_hcmd() (git-fixes).
- ASoC: cs42l51: Fix some error handling paths in cs42l51_probe()
  (git-fixes).
- platform/x86: dell-wmi: Ignore suspend notifications
  (stable-fixes).
- ACPI: button: Add DMI quirk for Samsung Galaxy Book2 to fix
  initial lid detection issue (stable-fixes).
- ACPI: resource: Add LG 16T90SP to irq1_level_low_skip_override[]
  (stable-fixes).
- drm/amd/display: Disable PSR-SU on Parade 08-01 TCON too
  (stable-fixes).
- drm/amd: Guard against bad data for ATIF ACPI method
  (git-fixes).
- usb: gadget: f_uac2: fix return value for UAC2_ATTRIBUTE_STRING
  store (git-fixes).
- accel/qaic: Fix the for loop used to walk SG table (git-fixes).
- drm/amd/amdgpu: Fix double unlock in amdgpu_mes_add_ring
  (git-fixes).
- drm/msm/dpu: don't always program merge_3d block (git-fixes).
- drm/msm: Allocate memory for disp snapshot with kvzalloc()
  (git-fixes).
- drm/msm: Avoid NULL dereference in msm_disp_state_print_regs()
  (git-fixes).
- drm/msm/dsi: fix 32-bit signed integer extension in pclk_rate
  calculation (git-fixes).
- drm/msm/dsi: improve/fix dsc pclk calculation (git-fixes).
- drm/msm/dpu: check for overflow in _dpu_crtc_setup_lm_bounds()
  (git-fixes).
- drm/msm/dpu: move CRTC resource assignment to
  dpu_encoder_virt_atomic_check (git-fixes).
- drm/msm/dpu: make sure phys resources are properly initialized
  (git-fixes).
- platform/x86: dell-sysman: add support for alienware products
  (stable-fixes).
- drm/vboxvideo: Replace fake VLA at end of
  vbva_mouse_pointer_shape with real VLA (stable-fixes).
- usb: gadget: f_uac2: fix non-newline-terminated function name
  (stable-fixes).
- usb: gadget: f_uac2: Replace snprintf() with the safer
  scnprintf() variant (stable-fixes).
- commit 09f40f7
* Sat Nov  2 2024 jlee@suse.com
- ARM: 9379/1: coresight: tpda: drop owner assignment
  (jsc#PED-11164).
- ARM: 9378/1: coresight: etm4x: drop owner assignment
  (jsc#PED-11164).
- ARM: 9377/1: hwrng: nomadik: drop owner assignment
  (jsc#PED-11164).
- ARM: 9376/1: coresight: tpdm: drop owner assignment
  (jsc#PED-11164).
- ARM: 9375/1: coresight: stm: drop owner assignment
  (jsc#PED-11164).
- ARM: 9374/1: coresight: etb10: drop owner assignment
  (jsc#PED-11164).
- ARM: 9373/1: coresight: funnel: drop owner assignment
  (jsc#PED-11164).
- ARM: 9372/1: memory: pl353-smc: drop owner assignment
  (jsc#PED-11164).
- ARM: 9371/1: coresight: cti: drop owner assignment
  (jsc#PED-11164).
- ARM: 9370/1: vfio: amba: drop owner assignment (jsc#PED-11164).
- ARM: 9369/1: Input: ambakmi - drop owner assignment
  (jsc#PED-11164).
- ARM: 9368/1: dmaengine: pl330: drop owner assignment
  (jsc#PED-11164).
- ARM: 9367/1: i2c: nomadik: drop owner assignment
  (jsc#PED-11164).
- ARM: 9366/1: coresight: tpiu: drop owner assignment
  (jsc#PED-11164).
- ARM: 9365/1: coresight: tmc: drop owner assignment
  (jsc#PED-11164).
- ARM: 9364/1: coresight: replicator: drop owner assignment
  (jsc#PED-11164).
- ARM: 9363/1: coresight: etm3x: drop owner assignment
  (jsc#PED-11164).
- ARM: 9362/1: coresight: catu: drop owner assignment
  (jsc#PED-11164).
- commit 1eb1f05
* Sat Nov  2 2024 jlee@suse.com
- sound: virtio: drop owner assignment (jsc#PED-11164).
- fuse: virtio: drop owner assignment (jsc#PED-11164).
- scsi: virtio: drop owner assignment (jsc#PED-11164).
- rpmsg: virtio: drop owner assignment (jsc#PED-11164).
- nvdimm: virtio_pmem: drop owner assignment (jsc#PED-11164).
- vsock/virtio: drop owner assignment (jsc#PED-11164).
- net: 9p: virtio: drop owner assignment (jsc#PED-11164).
- net: virtio: drop owner assignment (jsc#PED-11164).
- net: caif: virtio: drop owner assignment (jsc#PED-11164).
- iommu: virtio: drop owner assignment (jsc#PED-11164).
- gpio: virtio: drop owner assignment (jsc#PED-11164).
- firmware: arm_scmi: virtio: drop owner assignment
  (jsc#PED-11164).
- crypto: virtio - drop owner assignment (jsc#PED-11164).
- virtio_console: drop owner assignment (jsc#PED-11164).
- hwrng: virtio: drop owner assignment (jsc#PED-11164).
- virtio_blk: drop owner assignment (jsc#PED-11164).
- commit bc9b80f
* Sat Nov  2 2024 jlee@suse.com
- um: virt-pci: drop owner assignment (jsc#PED-11164).
- virtio: mem: drop owner assignment (jsc#PED-11164).
- virtio: input: drop owner assignment (jsc#PED-11164).
- virtio: balloon: drop owner assignment (jsc#PED-11164).
- commit 1b970b3
* Sat Nov  2 2024 jlee@suse.com
- virt: vmgenid: drop owner assignment (jsc#PED-11164).
- ptp: vmw: drop owner assignment (jsc#PED-11164).
- platform/x86/wireless-hotkey: drop owner assignment
  (jsc#PED-11164).
- platform/x86/toshiba_haps: drop owner assignment
  (jsc#PED-11164).
- platform/x86/toshiba_bluetooth: drop owner assignment
  (jsc#PED-11164).
- platform/x86/toshiba_acpi: drop owner assignment
  (jsc#PED-11164).
- platform/x86/sony-laptop: drop owner assignment (jsc#PED-11164).
- platform/x86/lg-laptop: drop owner assignment (jsc#PED-11164).
- platform/x86/intel/smartconnect: drop owner assignment
  (jsc#PED-11164).
- platform/x86/intel/rst: drop owner assignment (jsc#PED-11164).
- platform/x86/eeepc: drop owner assignment (jsc#PED-11164).
- platform/x86/dell: drop owner assignment (jsc#PED-11164).
- platform: classmate-laptop: drop owner assignment
  (jsc#PED-11164).
- platform: asus-laptop: drop owner assignment (jsc#PED-11164).
- platform/chrome: wilco_ec: drop owner assignment
  (jsc#PED-11164).
- net: fjes: drop owner assignment (jsc#PED-11164).
- Input: atlas - drop owner assignment (jsc#PED-11164).
- commit a70a00a
* Fri Nov  1 2024 dsterba@suse.com
- drm/amd/display: Check null pointers before using them (CVE-2024-49922 bsc#1232374)
- commit 342005c
* Fri Nov  1 2024 dsterba@suse.com
- drm/amd/display: Handle null 'stream_status' in 'planes_changed_for_existing_stream' (CVE-2024-49912 bsc#1232367)
- commit 2394db2
* Fri Nov  1 2024 dsterba@suse.com
- drm/amd/display: Add NULL check for function pointer in dcn20_set_output_transfer_func (CVE-2024-49911 bsc#1232366)
- commit 6c83ea7
* Fri Nov  1 2024 dsterba@suse.com
- blacklist.conf: CVE-2024-49910 bsc#1232365: not applicable, code does not exist
- commit 84768ce
* Fri Nov  1 2024 dsterba@suse.com
- drm/amd/display: Pass non-null to dcn20_validate_apply_pipe_split_flags (CVE-2024-49923 bsc#1232361)
- commit 3759560
* Fri Nov  1 2024 dsterba@suse.com
- drm/amd/display: Fix index out of bounds in DCN30 degamma hardware format translation (CVE-2024-49895 bsc#1232352)
- commit f36c162
* Fri Nov  1 2024 dsterba@suse.com
- drm/amd/display: Initialize denominators' default to 1 (CVE-2024-49899 bsc#1232358)
- commit 282fa51
* Fri Nov  1 2024 dsterba@suse.com
- Update references for patches.suse/0001-drm-amd-display-Add-null-check-for-afb-in-amdgpu_dm_.patch (bsc#1232335 CVE-2024-49908 bsc#1232357 CVE-2024-49905)
- commit fa3a85a
* Fri Nov  1 2024 dsterba@suse.com
- drm/amd/display: Check phantom_stream before it is used (CVE-2024-49897 bsc#1232355)
- commit d3fcaed
* Fri Nov  1 2024 dsterba@suse.com
- drm/amd/display: Fix index out of bounds in degamma hardware format translation (CVE-2024-49894 bsc#1232354)
- commit db76ccb
* Fri Nov  1 2024 dsterba@suse.com
- drm/amd/display: Add NULL check for function pointer in dcn32_set_output_transfer_func (CVE-2024-49909 bsc#1232337)
- commit 11facc9
* Fri Nov  1 2024 dsterba@suse.com
- drm/amd/display: Add null check for top_pipe_to_program in commit_planes_for_stream (CVE-2024-49913 bsc#1232307)
- commit 60f7853
* Fri Nov  1 2024 dsterba@suse.com
- drm/msm/adreno: Assign msm_gpu->pdev earlier to avoid nullptrs (CVE-2024-49901 bsc#1232305)
- commit 69be7bb
* Fri Nov  1 2024 pjakobsson@suse.de
- blacklist.conf: Blacklist git-fixes for DRM v6.11 backport
- commit 8e812dc
* Fri Nov  1 2024 nik.borisov@suse.com
- EDAC/igen6: Add Intel Arrow Lake-U/H SoCs support (jsc#PED-10172).
- commit 087072d
* Fri Nov  1 2024 nik.borisov@suse.com
- x86/cpu: Add model number for Intel Clearwater Forest processor (jsc#PED-10181).
- Refresh
  patches.suse/x86-cpu-vfm-Update-arch-x86-include-asm-intel-family.h.patch.
- commit c43b253
* Fri Nov  1 2024 jlee@suse.com
- ACPI: mipi-disco-img: Switch to new Intel CPU model defines
  (jsc#PED-11164).
- ACPI: AC: Properly notify powermanagement core about changes
  (jsc#PED-11164).
- commit f05a41c
* Fri Nov  1 2024 nik.borisov@suse.com
- RAS/AMD/ATL: Implement DF 4.5 NP2 denormalization (jsc#PED-10559).
- commit 52d40f4
* Fri Nov  1 2024 nik.borisov@suse.com
- RAS/AMD/ATL: Validate address map when information is gathered (jsc#PED-10559).
- commit 94e412f
* Fri Nov  1 2024 nik.borisov@suse.com
- RAS/AMD/ATL: Expand helpers for adding and removing base and hole (jsc#PED-10559).
- commit 2b18348
* Fri Nov  1 2024 nik.borisov@suse.com
- RAS/AMD/ATL: Read DRAM hole base early (jsc#PED-10559).
- commit e1cf5b5
* Fri Nov  1 2024 nik.borisov@suse.com
- RAS/AMD/ATL: Add amd_atl pr_fmt() prefix (jsc#PED-10559).
- commit 17f78f9
* Fri Nov  1 2024 tzimmermann@suse.com
- drm/amd/display: Check null pointer before try to access it (bsc#1232332 CVE-2024-49906)
- commit f2b2892
* Fri Nov  1 2024 tzimmermann@suse.com
- drm/amd/display: Add null check for pipe_ctx->plane_state in (bsc#1232369 CVE-2024-49914)
- commit c236474
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/irdma: Annotate flexible array with __counted_by() in struct irdma_qvlist_info (jsc#PED-11232)
- commit f55c592
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/bridge-connector: move to DRM_DISPLAY_HELPER module (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit c4d4577
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/vc4: hdmi: Switch to HDMI connector (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit af0958b
* Fri Nov  1 2024 tzimmermann@suse.com
- drm/amd/display: Add null check for 'afb' in amdgpu_dm_update_cursor (bsc#1232335 CVE-2024-49908)
- commit 64a943f
* Fri Nov  1 2024 tzimmermann@suse.com
- drm/amd/display: Check null pointers before using dc->clk_mgr (bsc#1232334 CVE-2024-49907)
- commit 366c63a
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Nuke simple error capture (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit ad146dd
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/panel: add lincolntech lcd197 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit d576783
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/panel: add Ilitek ILI9806E panel driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 24bebab
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/panel: himax-hx83102: Break out as separate driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 5df593b
* Fri Nov  1 2024 nmorey@suse.com
- IB/qib: Remove unused declarations in header file (jsc#PED-11232)
- commit b3b8cd5
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/qib: Simplify an alloc_ordered_workqueue() invocation (jsc#PED-11232)
- commit 0813bad
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/siw: Add sendpage_ok() check to disable MSG_SPLICE_PAGES (jsc#PED-11232)
- commit 6239f88
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/siw: Remove NETDEV_GOING_DOWN event handler (jsc#PED-11232)
- commit 4d058f5
* Fri Nov  1 2024 nmorey@suse.com
- IB/iser: Remove unused declaration in header file (jsc#PED-11232)
- commit 08c04a5
* Fri Nov  1 2024 nmorey@suse.com
- IB/isert: remove the handling of last WQE reached event (jsc#PED-11232)
- commit ce68d19
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/bnxt_re: synchronize the qp-handle table array (jsc#PED-11232)
- commit 41feb3f
* Fri Nov  1 2024 pjakobsson@suse.de
- backlight: Add new lm3509 backlight driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 4ef1af1
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix the usage of control path spin locks (jsc#PED-11232)
- commit e209fd8
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/vmw_pvrdma: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (jsc#PED-11232)
- commit c20c1bf
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Support replaying GPU hangs with captured context image (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 9ef7d50
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/rtrs-clt: Remove an extra space (jsc#PED-11232)
- commit 223a267
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/rtrs-clt: Do local invalidate after write io completion (jsc#PED-11232)
- commit 8c9998f
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/rtrs: Register ib event handler (jsc#PED-11232)
- commit d0f2901
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/rtrs-clt: Print request type for errors (jsc#PED-11232)
- commit a2c2522
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/rtrs-clt: Reuse need_inval from mr (jsc#PED-11232)
- commit 76a1268
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/rtrs-clt: Rate limit errors in IO path (jsc#PED-11232)
- commit fe3d8ff
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/rtrs-clt: Fix need_inv setting in error case (jsc#PED-11232)
- commit 7a194e3
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/rtrs: For HB error add additional clt/srv specific logging (jsc#PED-11232)
- commit f1f0bb0
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: fix Kconfig for ISP v2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit a1a966e
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/client: add missing bo locking in show_meminfo() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9e2ee17
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/client: fix deadlock in show_meminfo() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit efee322
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/oa: Enable Xe2+ PES disaggregation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f79094e
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/display: fix compat IS_DISPLAY_STEP() range end (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 22d1d95
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Fix access_ok check in user_fence_create (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ad8c168
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Fix possible UAF in guc_exec_queue_process_msg (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7f8d4ba
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Remove fence check from send_tlb_invalidation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bd8085e
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/gt: Remove double include (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a7311b1
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/stm: add COMMON_CLK dependency (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d5035b7
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: Add all planes on CRTC to state for overlay cursor (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 17f01b8
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/amdgpu: apply command submission parser for JPEG v1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ea91362
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/amdgpu: apply command submission parser for JPEG v2+ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2521ecd
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/pm: fix the pp_dpm_pcie issue on smu v14.0.2/3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0d9a44c
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/pm: update the features set on smu v14.0.2/3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d14f4fb
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/cxgb4: Dump vendor specific QP details (jsc#PED-11232)
- commit 1425a9a
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: Do not reset planes based on crtc zpos_changed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 056e9c1
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: Avoid race between dcn35_set_drr() and dc_state_destruct() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- blacklist.conf: Now applicable
- commit 4d53773
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/cxgb4: Remove unused declarations (jsc#PED-11232)
- commit 7e25a7a
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/cxgb4: use dma_mmap_coherent() for mapping non-contiguous memory (jsc#PED-11232)
- commit 88aeb84
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/cxgb4: Delete unused c4iw_ep_redirect prototype (jsc#PED-11232)
- commit c592be6
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdkfd: Add cache line size info (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 351dcba
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: Block timing sync for different signals in PMO (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 02610a0
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: Lock DC and exit IPS when changing backlight (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2f24ea6
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: always allocate cleared VRAM for GEM allocations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe980ec
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu/mes: add mes mapping legacy queue switch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1e29cee
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: Determine IPS mode by ASIC and PMFW versions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dc6c689
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/fbdev-dma: Only install deferred I/O if necessary (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6ebf0d0
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/panthor: flush FW AS caches in slow reset path (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a0263e6
* Fri Nov  1 2024 pjakobsson@suse.de
- drm: panel: nv3052c: Correct WL-355608-A8 panel compatible (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8fc05f9
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/panthor: Restrict high priorities on group_create (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 53ca4a7
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/bridge-connector: reset the HDMI connector state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 085d53f
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/display: stop depending on DRM_DISPLAY_HELPER (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ccea700
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/imagination: Free pvr_vm_gpuva after unlink (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 461e8f2
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/display: Avoid encoder_suspend at runtime suspend (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit db611f9
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Suspend/resume user access only during system s/r (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 203d249
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/display: Match i915 driver suspend/resume sequences better (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 56eaef6
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Add missing runtime reference to wedged upon gt_reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 031f070
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/pcode: Treat pcode as per-tile rather than per-GT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit efd58d2
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/gsc: Do not attempt to load the GSC multiple times (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit be12e87
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/display: Increase Fast Wake Sync length as a quirk (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9f50e8c
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/display: Add mechanism to use sink model when applying quirk (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ed5323b
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Fix readout degamma_lut mismatch on ilk/snb (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c3af354
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/v3d: Disable preemption while updating GPU stats (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4d048e9
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/vmwgfx: Disable coherent dumb buffers without 3d (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6475934
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/vmwgfx: Prevent unmapping active read buffers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022 bsc#1230540 CVE-2024-46710)
- commit 43fb88a
* Fri Nov  1 2024 pjakobsson@suse.de
- Revert "drm/ttm: increase ttm pre-fault value to PMD size" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 656e6a7
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/hwmon: Fix WRITE_I1 param from u32 to u16 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8842c10
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Invalidate media_gt TLBs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 15edd31
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Fix MST state after a sink reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1b04c21
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: ARL requires a newer GSC firmware (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fb0589c
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/pm: Drop unsupported features on smu v14_0_2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 850bc82
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/pm: Add support for new P2S table revision (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 891c2ec
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: support for gc_info table v1.3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ffd464
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu/gfx12: set UNORD_DISPATCH in compute MQDs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 553980c
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/pm: update message interface for smu v14.0.2/3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ca38b47
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu/smu13.0.7: print index for profiles (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a852df1
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Free job before xe_exec_queue_put (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1df1ec2
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Drop HW fence pointer to HW fence ctx (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e4c5ad1
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Fix missing workqueue destroy in xe_gt_pagefault (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5658bf3
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/uc: Use devm to register cleanup that includes exec_queues (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d414435
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: use devm instead of drmm for managed bo (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b61e3fc
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/xe2hpg: Add Wa_14021821874 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 28f9f9b
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: fix WA 14018094691 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit baf515b
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/xe2: Add Wa_15015404425 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ea032ca
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/xe2: Make subsequent L2 flush sequential (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9765dc0
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/xe2lpg: Extend workaround 14021402888 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7242c27
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/xe2lpm: Extend Wa_16021639441 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0e59fed
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/bmg: implement Wa_16023588340 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a497724
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/oa/uapi: Make bit masks unsigned (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c2dc76d
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/display: Make display suspend/resume work on discrete (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8332140
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: prevent UAF around preempt fence (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit 9b2a703
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/erdma: Add disassociate ucontext support (jsc#PED-11232)
- commit 03e6174
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/erdma: Refactor the initialization and destruction of EQ (jsc#PED-11232)
- commit 7f70e7c
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/erdma: Remove unnecessary __GFP_ZERO flag (jsc#PED-11232)
- commit bb48cf0
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/erdma: Unify the names related to doorbell records (jsc#PED-11232)
- commit 6a5fbcc
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/erdma: Allocate doorbell records from dma pool (jsc#PED-11232)
- commit 84e9a78
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/mlx4: Simplify an alloc_ordered_workqueue() invocation (jsc#PED-11232)
- commit 6b7daf9
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Fix tile fini sequence (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 97bb940
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Move VM dma-resv lock from xe_exec_queue_create to (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e29f06f
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/observation: Drop empty sysctl table entry (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b9027dc
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Fix opregion leak (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b19162c
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/hdcp: Use correct cp_irq_count (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d16c8ce
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: fix eGPU hotplug regression (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 24d424e
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: fixing rlc firmware loading failure issue (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 997300d
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/msm: fix the highest_bank_bit for sc7180 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd8f51a
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/msm/dpu: relax YUV requirements (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit afb63d5
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/msm/dpu: limit QCM2290 to RGB formats only (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d4c2d33
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Hold a PM ref when GT TLB invalidations are inflight (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9752bc7
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/mlx4: Simplify an alloc_ordered_workqueue() invocation (jsc#PED-11232)
- commit 558de6a
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Drop xe_gt_tlb_invalidation_wait (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8f96c37
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Add xe_gt_tlb_invalidation_fence_init helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 523d1a7
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/pf: Fix VF config validation on multi-GT platforms (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7e1e84a
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Build PM into GuC CT layer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bceca15
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/vf: Fix register value lookup (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 96222d5
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Fix use after free when client stats are captured (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 43f18a1
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Take a ref to xe file when user creates a VM (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 051e64e
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Add ref counting for xe_file (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2f266b1
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Move part of xe_file cleanup to a helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 13a776c
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Validate user fence during creation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 228dca5
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/rockchip: inno-hdmi: Fix infoframe upload (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9dfccdb
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/v3d: Fix out-of-bounds read in `v3d_csd_job_run()` (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 565507b
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/amdgpu: add HDP_SD support on gc 12.0.0/1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9c9af10
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: Update kmd_fw_shared for VCN5 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ae5c996
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/amdgpu: command submission parser for JPEG (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 82cec51
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: fix suspend issue (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ce66b58
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: sw/hw fini for unified mes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d2e46ca
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: configure two pipes hardware resources (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0990977
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: adjust mes12 sw/hw init for multiple pipes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9722a1b
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: add mes pipe switch support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2464ddf
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: load unified mes fw on pipe0 and pipe1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 67cb612
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu/mes: add multiple mes ring instances support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 538de0e
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: update mes_v12_api_def.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1054907
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: Fix MST BW calculation Regression (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8945f97
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: Enable otg synchronization logic for DCN321 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a510e05
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu/mes: fix mes ring buffer overflow (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9e31b3c
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Attempt to get pages without eviction first (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8f0c7b7
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Allow evicting to use the requested placement (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 21f893c
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/display: correct dual pps handling for MTL_PCH+ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a47113f
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Take ref to VM in delayed snapshot (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 744fdb4
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/hwmon: Fix PL1 disable flow in xe_hwmon_power_max_write (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0e4f810
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Use dma_fence_chain_free in chain fence unused as a sync (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5800b8e
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/rtp: Fix off-by-one when processing rules (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f153bff
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: Add DCC GFX12 flag to enable address alignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3587e12
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: correct sdma7 max dw (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 035c4d1
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: Add address alignment support to DCC buffers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cb0c9ad
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: change non-dcc buffer copy configuration (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 88d199d
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: add golden setting for gc v12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f99d588
* Fri Nov  1 2024 jlee@suse.com
- ACPI: platform-profile: add platform_profile_cycle()
  (jsc#PED-11164).
- ACPI: IPMI: Add helper to wait for when SMI is selected
  (jsc#PED-11164).
- ACPI: APEI: EINJ: mark remove callback as __exit
  (jsc#PED-11164).
- ACPI: Move acpi_blacklisted() declaration to asm/acpi.h
  (jsc#PED-11164).
- ACPI: x86: utils: Mark SMO8810 accel on Dell XPS 15 9550 as
  always present (jsc#PED-11164).
  Refresh
  patches.suse/ACPI-x86-Switch-to-new-Intel-CPU-model-defines.patch.
- ACPI: x86: Move LPSS to x86 folder (jsc#PED-11164).
  Refresh
  patches.suse/ACPI-LPSS-Switch-to-new-Intel-CPU-model-defines.patch.
- ACPI: x86: Move blacklist to x86 folder (jsc#PED-11164).
- ACPI: x86: Move acpi_cmos_rtc to x86 folder (jsc#PED-11164).
- commit 4c5bb37
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/buddy: Add start address support to trim function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 507ec17
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: Add missing program DET segment call to pipe init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 70c4523
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: Add missing DCN314 to the DML Makefile (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b430e61
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: force to use legacy inv in mmhub (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3546a90
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/pm: update powerplay structure on smu v14.0.2/3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6b8fe74
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: Add missing mcache registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8781a1f
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: Add dcc propagation value (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 27f5f3b
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: Add missing DET segments programming (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5eb283c
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/atomic: allow no-op FB_ID updates for async flips (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2c74b59
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/bridge-connector: Fix double free in error handling paths (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a9a37c0
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/omap: add CONFIG_MMU dependency (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cd6e36f
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/test: fix the gem shmem test to map the sg table. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4def9bd
* Fri Nov  1 2024 pjakobsson@suse.de
- Revert "nouveau: rip out busy fence waits" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0d23ec8
* Fri Nov  1 2024 pjakobsson@suse.de
- nouveau: set placement to original placement on uvmm validate. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 90f4919
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/atomic: Allow userspace to use damage clips with async flips (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 713ba28
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/atomic: Allow userspace to use explicit sync with atomic async (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bd39b73
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/ast: astdp: Wake up during connector status detection (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f55f955
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/client: Fix error code in drm_client_buffer_vmap_local() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb13bdd
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/vmwgfx: Trigger a modeset when the screen moves (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 629cd1b
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/vmwgfx: Add basic support for external buffers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ee26a70
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/vmwgfx: Fix handling of dumb buffers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7a08c68
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/vmwgfx: Make sure the screen surface is ref counted (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 75ee292
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/ast: Fix black screen after resume (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d359dfd
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/v3d: Validate passed in drm syncobj handles in the performance (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0255749
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/v3d: Validate passed in drm syncobj handles in the timestamp (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 637e236
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/v3d: Fix potential memory leak in the performance extension (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aceea23
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/v3d: Fix potential memory leak in the timestamp extension (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 732f09b
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/v3d: Prevent out of bounds access in performance query extensions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-v3d-Prevent-out-of-bounds-access-in-performance-.patch.
- commit a46c063
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: Fix APU handling in amdgpu_pm_load_smu_firmware() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ba7c40
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: increase mes log buffer size for gfx12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b8ccf6
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu/pm: support gpu_metrics sysfs interface for smu v14.0.2/3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb643ac
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: add missed harvest check for VCN IP v4/v5 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 59f049b
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: Fix eeprom max record count (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4660673
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: fix ras UE error injection failure issue (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 79a54c1
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: Remove ASSERT if significance is zero in math_ceil2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f5a027e
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu/vcn: Use offsets local to VCN/JPEG in VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9f5df7e
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: Add empty HDP flush function to VCN v4.0.3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ea3c653
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: Add empty HDP flush function to JPEG v4.0.3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c0000f5
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: Fix atomics on GFX12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8d99434
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Allow NULL memory region (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cbca015
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: fix corruption with high refresh rates on DCN 3.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1ff795c
* Fri Nov  1 2024 pjakobsson@suse.de
- Documentation/amdgpu: Fix duplicate declaration (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b54b108
* Fri Nov  1 2024 pjakobsson@suse.de
- Documentation/gpu: Remove undocumented files from dcn-blockshubbub.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f46150
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: Add simple struct doc to remove doc build warning (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4edee60
* Fri Nov  1 2024 pjakobsson@suse.de
- Documentation/gpu: Adjust DCN documentation paths (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b6aaf86
* Fri Nov  1 2024 pjakobsson@suse.de
- Documentation/gpu: Remove ':export:' option from DCN documentation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 675bf45
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: Move DIO documentation to the right place (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6c3036b
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/swsmu: enable Pstates profile levels for SMU v14.0.4 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ca5de8c
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/pm: early return if disabling DPMS for GFX IP v11.5.2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d6b9e87
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: add mutex to protect ras shared memory (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4331bc2
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: Add function banner for idle_workqueue (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 74ebe67
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: Add doc entry for program_3dlut_size (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d8cea68
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu/vcn: not pause dpg for unified queue (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb9bb0b
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu/vcn: identify unified queue in sw init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9efb4ab
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: fix doc entry for bb_from_dmub (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b52a90b
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd: Bump KMS_DRIVER_MINOR version (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dffd6e5
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/v3d: Fix Indirect Dispatch configuration for V3D 7.1.6 and later (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ba09c12
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/v3d: Add V3D tech revision to the device information (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 88c6122
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Don't suspend device upon wedge (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8d574e2
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Wedge the entire device (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8789916
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/pf: Limit fair VF LMEM provisioning (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2066400
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/exec: Fix minor bug related to xe_sync_entry_cleanup (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9ed4e7b
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/dp: Reset intel_dp->link_trained before retraining the link (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9419f46
* Fri Nov  1 2024 pjakobsson@suse.de
- gpu: ipu-v3: Convert to platform remove callback returning void (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ae1162c
* Fri Nov  1 2024 pjakobsson@suse.de
- gpu: host1x: Convert to platform remove callback returning void (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3745c57
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/imagination: Convert to platform remove callback returning void (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 182368d
* Fri Nov  1 2024 pjakobsson@suse.de
- gpu: host1x: mipi: Benefit from devm_clk_get_prepared() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 82c85bf
* Fri Nov  1 2024 pjakobsson@suse.de
- kernel-wide: fix spelling mistakes like "assocative" -> "associative" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 34b0125
* Fri Nov  1 2024 pjakobsson@suse.de
- udmabuf: add back support for mapping hugetlb pages (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0ed425d
* Fri Nov  1 2024 pjakobsson@suse.de
- udmabuf: use vmf_insert_pfn and VM_PFNMAP for handling mmap (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1813dbc
* Fri Nov  1 2024 pjakobsson@suse.de
- udmabuf: add CONFIG_MMU dependency (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 444bcf2
* Fri Nov  1 2024 pjakobsson@suse.de
- mei: bus-fixup: set timeout for MKHI send operations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1f4012a
* Fri Nov  1 2024 pjakobsson@suse.de
- fbdev: viafb: Make I2C terminology more inclusive (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8d3c955
* Fri Nov  1 2024 pjakobsson@suse.de
- fbdev: smscufx: Make I2C terminology more inclusive (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aae7804
* Fri Nov  1 2024 pjakobsson@suse.de
- fbdev: omap2: Return clk_prepare_enable to transfer the error (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 23432bc
* Fri Nov  1 2024 pjakobsson@suse.de
- fbdev: mmp: Constify struct mmp_overlay_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 043ba49
* Fri Nov  1 2024 pjakobsson@suse.de
- fbdev: Drop explicit initialization of struct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1babb16
* Fri Nov  1 2024 pjakobsson@suse.de
- video: console: add missing MODULE_DESCRIPTION() macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 73d697b
* Fri Nov  1 2024 jlee@suse.com
- ACPI: x86: Introduce a Makefile (jsc#PED-11164).
- ACPI: LPSS: Remove nested ifdeffery for CONFIG_PM
  (jsc#PED-11164).
- ACPI/NUMA: Squash acpi_numa_memory_affinity_init() into
  acpi_parse_memory_affinity() (jsc#PED-11164).
- ACPI/NUMA: Squash acpi_numa_slit_init() into acpi_parse_slit()
  (jsc#PED-11164).
- commit c7f927e
* Fri Nov  1 2024 pjakobsson@suse.de
- fbdev: amifb: add missing MODULE_DESCRIPTION() macro (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3230704
* Fri Nov  1 2024 pjakobsson@suse.de
- fbdev: c2p_planar: add missing MODULE_DESCRIPTION() macro (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e7f9a61
* Fri Nov  1 2024 pjakobsson@suse.de
- fbdev: vesafb: Detect VGA compatibility from screen info's VESA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a11f709
* Fri Nov  1 2024 pjakobsson@suse.de
- fbdev: omapfb: use of_graph_get_remote_port() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3d755ae
* Fri Nov  1 2024 pjakobsson@suse.de
- fbdev: omapdss: use for_each_endpoint_of_node() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e6d6302
* Fri Nov  1 2024 pjakobsson@suse.de
- fbdev: offb: add missing MODULE_DESCRIPTION() macro (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f5a4f4c
* Fri Nov  1 2024 pjakobsson@suse.de
- fbdev: vfb: add missing MODULE_DESCRIPTION() macro (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 162abde
* Fri Nov  1 2024 pjakobsson@suse.de
- fbdev: macmodes: add missing MODULE_DESCRIPTION() macro (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 785f2d9
* Fri Nov  1 2024 pjakobsson@suse.de
- fbdev: goldfishfb: add missing MODULE_DESCRIPTION() macro (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6c71403
* Fri Nov  1 2024 pjakobsson@suse.de
- fbdev: kyro: add missing MODULE_DESCRIPTION() macro (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d7993b3
* Fri Nov  1 2024 pjakobsson@suse.de
- fbdev: viafb: add missing MODULE_DESCRIPTION() macro (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a69bfdc
* Fri Nov  1 2024 pjakobsson@suse.de
- fbdev: matroxfb: add missing MODULE_DESCRIPTION() macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3ae583d
* Fri Nov  1 2024 pjakobsson@suse.de
- video/logo: Make logo data const again (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c0b91c3
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: add missing opcode string (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6dc0cb7
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu/mes11: update opcode strings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0f67986
* Fri Nov  1 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Reset freesync config before update new (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7674808
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: remove exp hw support check for gfx12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a49affb
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: timely save bad pages to eeprom after gpu ras reset is (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8542342
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: flush all cached ras bad pages to eeprom (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d522fc3
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: select compute ME engines dynamically (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b33d55a
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: Allow display DCC for DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 002b15c
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: select compute ME engines dynamically (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 67582ae
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu/job: Replace DRM_INFO/ERROR logging (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d6294c7
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: select compute ME engines dynamically (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9f7cbfb
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/pm: Ignore initial value in smu response register (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 22d662d
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: Initialize VF partition mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 28ae2f8
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/amdgpu: fix SDMA IRQ client ID <-> req mapping. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c06a348
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: set CP_HQD_PQ_DOORBELL_CONTROL.DOORBELL_MODE to 1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c6e8734
* Fri Nov  1 2024 pjakobsson@suse.de
- Documentation/amdgpu: Clarify MI200 and MI300 entries (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 093cff9
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: add ras event state device attribute support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b1570dc
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/swsmu: enable more Pstates profile levels for SMU v14.0.0 and (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a89892f
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: add ras POSION_CONSUMPTION event id support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8b62713
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdkfd: Use mode1 reset for GFX v9.4.4 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 42432d1
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: add ras POSION_CREATION event id support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f57973a
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: refine amdgpu ras event id core code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d7d5c2e
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/display: Solve mst monitors blank out problem after resume (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7bf066d
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: enable dpg for vcn and jpeg on GC 11_5_2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bde8a66
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: remove redundant semicolons in RAS_EVENT_LOG (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 81715f6
* Fri Nov  1 2024 jlee@suse.com
- ACPI/NUMA: Remove architecture dependent remainings
  (jsc#PED-11164).
- ACPI: property: Add reference to UEFI DSD Guide (jsc#PED-11164).
- ACPI: resource: Skip IRQ override on Asus Vivobook Pro N6506MV
  (jsc#PED-11164).
  Refresh
  patches.suse/ACPI-resource-Remove-duplicate-Asus-E1504GAB-IRQ-ove.patch.
- ACPI: resource: Do IRQ override on GMxBGxx (XMG APEX 17 M23)
  (jsc#PED-11164).
  Refresh
  patches.suse/ACPI-resource-Do-IRQ-override-on-MECHREV-GM7XG0M.patch.
- ACPI: scan: Avoid enumerating devices with clearly invalid
  _STA values (jsc#PED-11164).
- ACPI: scan: Introduce typedef:s for struct acpi_hotplug_context
  members (jsc#PED-11164).
- ACPI: scan: Use standard error checking pattern (jsc#PED-11164).
  Refresh patches.suse/iommu-Resolve-fwspec-ops-automatically.
  Refresh patches.suse/ACPI-Retire-acpi_iommu_fwspec_ops.
- ACPI: scan: Move misleading comment to acpi_dma_configure_id()
  (jsc#PED-11164).
  Refresh patches.suse/dma-mapping-Simplify-arch_setup_dma_ops.
  Refresh patches.suse/ACPI-Retire-acpi_iommu_fwspec_ops.
- ACPI: scan: Use list_first_entry_or_null() in acpi_device_hid()
  (jsc#PED-11164).
- ACPI: bus: Don't use "proxy" headers (jsc#PED-11164).
- ACPI: bus: Make container_of() no-op where it makes sense
  (jsc#PED-11164).
- ACPI: drop redundant owner from acpi_driver (jsc#PED-11164).
- ACPI: store owner from modules with acpi_bus_register_driver()
  (jsc#PED-11164).
- commit b43883d
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: restore dcc bo tilling configs while moving (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2b0c3f2
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: add gfx queue support for gfx12 ipdump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 584f53d
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: add cp queue registers for gfx12 ipdump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 735f9a2
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: enable redirection of irq's for IH v7.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 500e420
* Fri Nov  1 2024 pjakobsson@suse.de
- drm:amdgpu: enable IH ring1 for IH v7.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 877ebc2
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: add print support for gfx12 ipdump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e60a227
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: add gfx12 register support in ipdump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 646fd24
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: update gfxhub client id for gfx12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8b6aeb0
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amd/pm: avoid to load smu firmware for APUs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e6c071c
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/amdgpu: sysfs node disable query error count during gpu reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa50b74
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/omap: Restrict compile testing to PAGE_SIZE less than 64KB (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a563014
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Drop trace_xe_hw_fence_free (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 55c2c93
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe/uapi: Rename xe perf layer as xe observation layer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1e52f45
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/mtl: Skip PLL state verification in TBT mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9dfd0bf
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/dsb: Try to document that DSB_STATUS bit 16 is level (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 44055e7
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/psr: Modify dg2_activate_panel_replay to support eDP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 04efc01
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/psr: Check Early Transport for Panel Replay as well (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2862e9d
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/psr: Perform scanline indication check for Panel Replay as (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fc90236
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/psr: Perform psr2 checks related to ALPM for Panel Replay (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8688e26
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/alpm: Make crtc_state as const in intel_alpm_compute_params (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 42b45b6
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/psr: HW will not allow PR on eDP when HDCP enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ef801ab
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/psr: 128b/132b Panel Replay is not supported on eDP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 62c1c85
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/psr: Check panel Early Transport capability for eDP PR (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 613f4cf
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/psr: enable sink for eDP1.5 Panel Replay (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d5598b8
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/psr: Inform Panel Replay source support on eDP as well (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit efd0e75
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/psr: Check panel ALPM capability for eDP Panel Replay (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 69be3cd
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Use the same vblank worker for atomic unpin (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1f89b0e
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Use vblank worker to unpin old legacy cursor fb safely (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8297b20
* Fri Nov  1 2024 pjakobsson@suse.de
- drm: Add drm_vblank_work_flush_all(). (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 344ec07
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Nuke the TGL+ chroma plane tile row alignment stuff (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8c09f1f
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Update plane alignment requirements for TGL+ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 766f31b
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Move intel_surf_alignment() into skl_univerals_plane.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9038664
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Split pre-skl platforms out from intel_surf_alignment() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 65a0db4
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Split cursor alignment to per-platform vfuncs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f85a5c0
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Introduce fb->min_alignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1873f28
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Introduce the plane->min_alignment() vfunc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3065f6e
* Fri Nov  1 2024 pjakobsson@suse.de
- drm: Export drm_plane_has_format() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b59970e
* Fri Nov  1 2024 pjakobsson@suse.de
- drm: Rename drm_plane_check_pixel_format() to drm_plane_has_format() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7269673
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/display: Consider adjusted_pixel_rate to be u64 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b554de
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/psr: Set DP_PSR_SU_REGION_SCANLINE_CAPTURE bit when needed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e631ff9
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/xe: Use the encoder suspend helper also used by the i915 driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b442ef8
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Pass intel_display to the encoder suspend/shutdown helpers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd63d51
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Move encoder suspend/shutdown helpers to intel_encoder.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7f4b98f
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/dsb: Document that the ATS fault bits are for mtl+ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0ced4c1
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Drop useless intel_dsb.h include (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3581e8
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/dsb: Add i915.enable_dsb module parameter (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 355a52d
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/dsb: Convert the DSB code to use intel_display rather than (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aaa40b7
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915/dsb: Plumb the whole atomic state into intel_dsb_prepare() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 416da3a
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Pass the whole atomic state to intel_color_prepare_commit() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b192991
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Introduce intel_mode_vdisplay() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 952bd97
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Add flip done tracepoint (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8d91680
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Add async flip tracepoint (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8b86555
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Extract intel_crtc_arm_vblank_event() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3ff1595
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Enable plane/pipeDMC ATS fault interrupts on mtl (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 35175b7
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Enable pipeDMC fault interrupts on tgl+ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6e353e8
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Nuke the intermediate pipe fault bitmasks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5956c32
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Extend GEN9_PIPE_PLANE_FLIP_DONE() to cover all universal (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c8a7eb1
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Sort bdw+ pipe interrupt bits (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b4c208a
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Document bdw+ pipe interrupt bits (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7e1de2c
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/i915: Use REG_BIT() for bdw+ pipe interrupts (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e458ad1
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/qxl: Pin buffer objects for internal mappings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9876181
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/panel: sharp-lq101r1sx01: Fixed reversed "if" in remove (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 412a312
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/msm/gem: Add missing rcu_dereference() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6eebe6f
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/msm/a6xx: Add missing __always_unused (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 10eacd1
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/msm/adreno: Add support for Adreno 505 GPU (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5c7b18f
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/msm/dpu: check ubwc support before adding compressed formats (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9153a5a
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/msm/adreno: Introduce gmu_chipid for a740 & a750 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e2901ff
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/msm/adreno: Add support for X185 GPU (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 024d8c0
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/msm/adreno: fix a743 and a740 cx mem init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 320c418
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/msm/adreno: fix a7xx gpu init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ee61990
* Fri Nov  1 2024 pjakobsson@suse.de
- Revert "drm/msm/a6xx: Poll for GBIF unhalt status in hw_init" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cd948ec
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/msm/adreno: De-spaghettify the use of memory barriers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ff2ce1c
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/msm/dpu: remove CRTC frame event callback registration (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a02485f
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/msm/dsi: Add phy configuration for MSM8937 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cd76726
* Fri Nov  1 2024 pjakobsson@suse.de
- drm/msm/mdp5: Add MDP5 configuration for MSM8937 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 77c6e66
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/bnxt_re: synchronize the qp-handle table array (git-fixes)
- commit 866dbc5
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix the usage of control path spin locks (git-fixes)
- commit c834f25
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/mlx5: Round max_rd_atomic/max_dest_rd_atomic up instead of down (git-fixes)
- commit 3c270f2
* Fri Nov  1 2024 nmorey@suse.com
- RDMA/cxgb4: Dump vendor specific QP details (git-fixes)
- commit 587d3b0
* Fri Nov  1 2024 jlee@suse.com
- ACPI: bus: Indicate support for more than 16 p-states thru _OSC
  (jsc#PED-11164).
  Refresh
  patches.suse/ACPI-bus-Indicate-support-for-the-Generic-Event-Devi.patch.
  patches.suse/ACPI-Fix-Generic-Initiator-Affinity-_OSC-bit.patch.
  patches.suse/ACPI-bus-Indicate-support-for-IRQ-ResourceSource-thr.patch.
- ACPICA: AEST: Add support for the AEST V2 table (jsc#PED-11164).
- ACPICA: Update acpixf.h for new ACPICA release 20240322
  (jsc#PED-11164).
- ACPICA: events/evgpeinit: don't forget to increment registered
  GPE count (jsc#PED-11164).
- ACPICA: Fix CXL 3.0 structure (RDPAS) in the CEDT table
  (jsc#PED-11164).
- ACPICA: SRAT: Add dump and compiler support for RINTC affinity
  structure (jsc#PED-11164).
- ACPICA: SRAT: Add RISC-V RINTC affinity structure
  (jsc#PED-11164).
- ACPICA: Modify ACPI_OBJECT_COMMON_HEADER (jsc#PED-11164).
- ACPICA: Fix spelling and typos (jsc#PED-11164).
- ACPICA: Clean up the fix for Issue #900 (jsc#PED-11164).
- ACPICA: Fix various spelling mistakes in text files and code
  comments (jsc#PED-11164).
- ACPICA: Attempt 1 to fix issue #900 (jsc#PED-11164).
- ACPICA: ACPI 6.5: RAS2: Add support for RAS2 table
  (jsc#PED-11164).
- ACPICA: actbl1.h: Add EINJ CXL error types (jsc#PED-11164).
- cppc_acpi: print error message if CPPC is unsupported
  (jsc#PED-11164).
- ACPICA: Detect FACS even for hardware reduced platforms
  (jsc#PED-11164).
- commit 33d601c
* Thu Oct 31 2024 dsterba@suse.com
- ext4: fix access to uninitialised lock in fc replay path (CVE-2024-50014 bsc#1232446)
- commit 1b2ba45
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/dp: switch to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-msm-dp-fix-the-max-supported-bpp-logic.patch.
- commit 3139ec5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/dpu: guard ctl irq callback register/unregister (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c1651e7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/dpu: rename dpu_hw_setup_vsync_source functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0e1b7b7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/dpu: support setting the TE source (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 394e882
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/dsi: parse vsync source from device tree (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 390c2aa
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/dpu: rework vsync_source handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5771d6f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/dpu: pull the is_cmd_mode out of (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit edeb24d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/dsi: drop unused GPIOs handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f67bee1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/dpu: convert vsync source defines to the enum (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bf26513
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm: mdss: Add SM7150 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 35e65de
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/dpu: Add SM7150 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d19e26
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/dsi: add a comment to explain pkt_per_line encoding (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit df3c326
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/dsi: set video mode widebus enable bit when widebus is (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4c02cd5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/dpu: enable compression bit in cfg2 for DSC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 22e18fe
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/dpu: adjust data width for widen bus case (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f997f5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/dpu: fix video mode DSC for DSI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 29bd5ba
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/dsi: Remove dsi_phy_write_[un]delay() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f9d61e3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/dsi: Remove dsi_phy_read/write() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ae375b9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/a7xx: Add missing register writes from downstream (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c8a6c75
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm: Add MSM_PARAM_RAYTRACING uapi (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dde74df
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/a7xx: Initialize a750 "software fuse" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 47e96ce
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/adreno: Check for zap node availability (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d7a568d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm: Add obj flags to gpu devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b44d290
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm: Add GPU memory traces (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 54d0d22
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/a6xx: Fix A702 UBWC mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cf12ef5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/a6xx: use __unused__ to fix compiler warnings for gen7_* (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cab3675
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/adreno: Move CP_PROTECT settings to hw catalog (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5b39793
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/adreno: Move hwcg table into a6xx specific info (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c4eb66e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/adreno: Move hwcg regs to a6xx hw catalog (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bf7f55d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/adreno: Split catalog into separate files (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 486f0b5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/adreno: Split up giant device table (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7fb83cf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/dp: fix runtime_pm handling in dp_wait_hpd_asserted (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 645b563
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/msm/dpu: drop duplicate drm formats from wb2_formats arrays (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 90ffdb4
* Thu Oct 31 2024 pjakobsson@suse.de
- Revert "drm/msm/dpu: drop dpu_encoder_phys_ops.atomic_mode_set" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 298e9af
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panthor: Record devfreq busy as soon as a job is started (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cec112d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mgag200: Rename constant MGAREG_Status to MGAREG_STATUS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 276d7e9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/display/dsc: Add a helper to dump the DSC configuration (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 57fdbe0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: Add helpers for q4 fixed point values (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 73fbcd9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/managed: Simplify if condition (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1417918
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ast: Use drm_atomic_helper_commit_tail() helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 722bb9f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ast: Inline ast_crtc_dpms() into callers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f7d1f1d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ast: Only set VGA SCREEN_DISABLE bit in CRTC code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cc5a1fa
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ast: Remove gamma LUT updates from DPMS code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 79ba347
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ast: Handle primary-plane format setup in atomic_update (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 769c485
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ast: Move mode-setting code into mode_set_nofb CRTC helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8e501d7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ast: Program mode for AST DP in atomic_mode_set (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7ac83f6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ast: Implement atomic enable/disable for encoders (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 56cae78
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tests: Add tests for the new Monochrome value of tv_mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa975cc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/stm: dsi: expose DSI PHY internal clock (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1f25d24
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/stm: dsi: add pm runtime ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e8d6a51
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/stm: dsi: use new SYSTEM_SLEEP_PM_OPS() macro (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0a83b37
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/stm: lvds: add new STM32 LVDS Display Interface Transmitter (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1726556
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: jd9365da: Add the function of adjusting orientation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 211531a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: jd9365da: Support for kd101ne3-40ti MIPI-DSI panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 59b28bd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: panel-jadard-jd9365da-h3: use wrapped MIPI DCS functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dc50dbc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: jd9365da: Modify the method of sending commands (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d12a39a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: simple: Add AUO G104STN01 panel entry (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9426171
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/gem: Suppress oom warning in favour of ENOMEM to userspace (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 163a10b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/gem: Use the correct format specifier for resource_size_t (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 81b0101
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/gem: Return NULL instead of '0' (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4268f29
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/gt/uc: Evaluate GuC priority within locks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 917adc8
* Thu Oct 31 2024 dsterba@suse.com
- ext4: fix i_data_sem unlock order in ext4_ind_migrate() (CVE-2024-50006 bsc#1232442)
- commit de0e62b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/gt/uc: Fix typo in comment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0c85bbb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/gem: Downgrade stolen lmem setup warning (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fc3abb1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/gt: debugfs: Evaluate forcewake usage within locks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ce196b2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix out of bounds access in gfx11 during ip dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 10c63df
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add firmware for PSP IP v14.0.4 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 641a206
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: enable mode2 reset for SMU IP v14.0.4 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0f2fcd6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add SMU IP v14.0.4 discovery support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 37f28a3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: add SMU IP v14.0.4 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7ec9c7e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: smu v14.0.4 reuse smu v14.0.0 dpmtable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f9941e3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add PSP IP v14.0.4 discovery support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8c0d3bd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add PSP IP v14.0.4 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit be621bc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add firmware for VPE IP v6.1.3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 15196b6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add VPE IP v6.1.3 discovery support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0b52de0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add VPE IP v6.1.3 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fb7856e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add NBIO IP v7.11.3 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0d7d2b5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add NBIO IP v7.11.3 discovery support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 439ffc3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add firmware for SDMA IP v6.1.2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1a0c5bc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: add KFD support for SDMA IP v6.1.2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cee09cd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add SDMA IP v6.1.2 discovery support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 87e4b17
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add firmware for GC IP v11.5.2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 02dd7fc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: add KFD support for GC IP v11.5.2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 380f98d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add GC IP v11.5.2 to GC 11.5.0 family (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dfef78f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add GC IP v11.5.2 soc21 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b9e95cd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add tmz support for GC IP v11.5.2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 780b6fe
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add GFXHUB IP v11.5.2 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 67c23b3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: initialize GC IP v11.5.2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ae1c7cb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix out of bounds access in gfx10 during ip dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dafe415
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix warning comparing pointer to 0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2c1e055
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix warning comparing pointer to 0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ef3746a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix warning comparing pointer to 0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dbfeb14
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix warning comparing pointer to 0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 50f7517
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix unsigned comparison with less than zero (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit afe5fe4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: rewrite convert_tiling_flags_to_modifier_gfx12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 31a6641
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Use device based logging for errors (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 51c964b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Fix hbm stack id in boot error report (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7140ad5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add amdgpu_framebuffer::gfx12_dcc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2f48d48
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/display: add all gfx12 modifiers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 153f4ea
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/display: set plane attributes for gfx12 correctly (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f46d0a0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Correct register used to clear fault status (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dc3adc2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: don't use amdgpu_lookup_format_info on gfx12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bd2f3b1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/display: handle gfx12 in dm_check_cursor_fb (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2c69462
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: remove AMD_FMT_MOD_GFX12_DCC_MAX_COMPRESSED_BLOCK_* (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2b0a567
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/gfx12: remove GDS leftovers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0ea565e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/gfx12: remove superfluous cache flags (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c6c0e56
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/gfx11: remove superfluous cache flags (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 284d9d4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.291 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 18db1db
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: replace CRTC disable function call (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d3a1451
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Move dio files into dio folder (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 272bb17
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: fix a crash when clock source is reference for non (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d58ea07
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix dmub timeout after fams2 enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2e4ded3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add debug option for disabling SLDO optimizations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 270eabe
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: un-block 8k with single dimm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 47aa1b3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add available bandwidth calculation for audio (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 116da02
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Cleanup dce_get_dp_ref_freq_khz (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 89efece
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Adjust cursor visibility between MPC slices (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 921afde
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Skip unnecessary abm disable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ccaa9a9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix possible overflow in integer multiplication (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ef12229
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add ASIC cap to limit DCC surface width (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bde3233
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Revert Add workaround to restrict max frac urgent (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a56e86f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Choose HUBP unbounded request based on DML output (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f9200e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove unnecessary error message (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6d2d8d8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix divide by zero in CURSOR_DST_X_OFFSET (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0ca498c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Reset freesync config before update new state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c45cfff
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add replay state entry to replay_state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 180f75a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: use vmalloc for struct dc_state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7c8c0b7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd: Don't initialize ISP hardware without FW (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0336b11
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: refine isp firmware loading (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 56bcf74
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: Enable MMHUB prefetch for ISP v4.1.0 and 4.1.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 125b961
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: Fix 'snprintf' output truncation warning (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 150e007
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: Disable MMHUB prefetch for ISP v4.1.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 28e64db
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: Add ISP4.1.0 and ISP4.1.1 modules (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 08d03d8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: Map ISP interrupts as generic IRQs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a2fd81c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: Enable ISP in amdgpu_discovery (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f13c72b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: Add ISP driver support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9c16600
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: Add ISP support to amdgpu_discovery (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 575d36f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/jpeg5: Add support for DPG mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f2f6ccd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: tolerate allocating GTT bo with dcc flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ae365bf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add null check before access structs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f6e2474
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: normalize registers as local xcc to read/write in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe27f98
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd: Add some missing register definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a2cec7a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add gpu reset check and exception handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7b28adb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: refine poison consumption interrupt handler (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6fb180e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: refine poison creation interrupt handler (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 73f59c4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: process RAS fatal error MB notification (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1f9ede5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add variable to record the deferred error number read by (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 50b5172
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Use dev_ prints for virtualization as it supports multi (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4e562bd
* Thu Oct 31 2024 pjakobsson@suse.de
- Revert "drm/amd/amdgpu: add module parameter for jpeg" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fbd4696
* Thu Oct 31 2024 pjakobsson@suse.de
- Documentation/amdgpu: Add Ryzen 9000 series processors (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 454fa64
* Thu Oct 31 2024 pjakobsson@suse.de
- Documentation/amdgpu: Add Ryzen AI 300 series processors (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0c67bc0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: use swap() in is_config_schedulable() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 06125e0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove unused function reverse_planes_order (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 097914e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Use ARRAY_SIZE for array length (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 096b254
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix Makefile copyright notices (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 09d8cdb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.290 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3498760
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Enable DCC on DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 889502b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd: Add reg definitions for DCN401 DCC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7e3a416
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove duplicate null check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d07ecec
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove always true condition (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a89002d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Validate function returns (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022 bsc#1230774 CVE-2024-46775)
- commit 1cef25a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Ensure curve to hw translation succeed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e1cd234
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Use periodic detection for ipx/headless (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9703162
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix 1DLUT setting for NL SDR blending (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd15907
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Adjust reg field for DSC wait for disconnect (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6b4fd0f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add HW cursor visual confirm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd72717
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix cursor issues with ODMs and magnification (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7babc90
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Wait for double buffer update on ODM changes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit df8be83
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Reset DSC memory status (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5ad4934
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Program CURSOR_DST_X_OFFSET in viewport space (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1c6be7f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add null checks before accessing struct elements (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 550b76a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix reduced resolution and refresh rate (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8c67de4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Make DML2.1 P-State method force per stream (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ebc8dce
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add workaround to restrict max frac urgent for DPM0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 272565d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Call dpmm when checking mode support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3d9a0cc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: resync OTG after DIO FIFO resync (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e79221e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Always enable HPO for DCN4 dGPU (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 847580d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Use sw cursor for DCN401 with rotation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 93972b9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add Replay general cmd (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 76562dc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Check and log for function error codes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f318863
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Check and log for function error codes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cd78650
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove useless function call (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2e9e2f6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix uninitialized variables in dcn401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit da47a77
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix cursor size issues (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a31cc49
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove redundant checks for pipe_ctx->stream (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 17de81d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix cursor issues with ODMs and HW rotations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 54af458
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove unnecessary variable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8267c67
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Fix register access violation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f41a447
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove redundant var from display_rq_dig_calc in dml (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d0f2470
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Refactor dccg401_get_other_enable_symclk_fe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bbf6bc3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Temporarily disable HPO PG on DCN35 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7a9fe63
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: access ltr through pci cfg space (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c831ecc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: refine gfx12 firmware loading (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d4ccfb8
* Thu Oct 31 2024 pjakobsson@suse.de
- Revert "drm/amd/pm: workaround to pass jpeg unit test" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f72ceac
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: update MTYPE mapping for gfx12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f64ae8d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/kfd: Add unlock() on error path to add_queue_mes() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3ad49b7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove redundant code and semicolons (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f960c09
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Clean up indenting in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0545340
* Thu Oct 31 2024 pjakobsson@suse.de
- amdgpu: don't dereference a NULL resource in sysfs code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7800800
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: refine gfx11 firmware loading (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 09bb07d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/jpeg5: reprogram doorbell setting after power up for each (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cb4c33e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/atomfirmware: fix parsing of vram_info (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 661d9e2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mediatek/dp: Fix spurious kfree() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f560151
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mediatek: dpi/dsi: Fix possible_crtcs calculation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ef27b2f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mediatek: Log errors in probe with dev_err_probe() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b6a8aab
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mediatek: Remove less-than-zero comparison of an unsigned value (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dbd0033
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mediatek: Fix bit depth overwritten for mtk_ovl_set bit_depth() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 38754b8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mediatek: Support RGBA8888 and RGBX8888 in OVL on MT8195 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 63716b2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mediatek: Support more 10bit formats in OVL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a6240a6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mediatek: Add new color format MACROs in OVL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a7fdba3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mediatek: Add DRM_MODE_ROTATE_0 to rotation property (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7e5ae72
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mediatek: Add missing plane settings when async update (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0da2345
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mediatek: Convert to platform remove callback returning void (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit de91c31
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/etnaviv: reduce number of ktime_get calls in IRQ handler (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c91e530
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/etnaviv: switch devcoredump allocations to GFP_NOWAIT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f52feaf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/etnaviv: don't disable TS on MMUv2 core when moving the linear (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dbf87d1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/etnaviv: Read some FE registers twice (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6c86387
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/etnaviv: Disable SH_EU clock gating on VIPNano-Si+ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9ba0dd5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/etnaviv: Turn etnaviv_is_model_rev() into a function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f9393fe
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/etnaviv: Update hardware headers from rnndb (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 80a0a42
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/etnaviv: drop driver owner assignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a23c91a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/exynos/vidi: convert to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ed6790a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/exynos/vidi: simplify fake edid handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9f57915
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/exynos/vidi: use drm_edid_duplicate() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3c51184
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/bmg: Apply Wa_22019338487 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c140d6c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Prevent use of uninitialized mutex (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 858ee6f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa: Destroy the stream_lock mutex (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 85b4c07
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/rtp: Fix out-of-bounds array access (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 956b42e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/pf: Restart VFs provisioning after GT reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c59f7fe
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/pf: Skip fair VFs provisioning if already provisioned (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e46be12
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/pf: Remove inlined #ifdef CONFIG_PCI_IOV (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b2ac555
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Configure TLB timeout based on CT buffer size (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6647223
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/mocs: Clarify difference between hw and sw sizes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d0ca385
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/mocs: Update MOCS assertions and remove redundant checks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6d5ed81
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Get hwe domain specific FW to read RING_TIMESTAMP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3496231
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/client: Check return value of xe_force_wake_get (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a1e679d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/hwmon: Remove xe_hwmon_process_reg (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b7d437b
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: gradual sleep in polling memory macro (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d83c5d5
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: move heartbeat work initialization to early init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d81d253
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: print timestamp of last PQ heartbeat on EQ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5128ef0
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: dump the EQ entries headers on EQ heartbeat failure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 73c1eae
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: revise print on EQ heartbeat failure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9256d08
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: add more info upon cpu pkt timeout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 66aacab
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: additional print in device-in-use info (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 327ee28
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalbs/gaudi2: reduce interrupt count to 128 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6a453be
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: disable EQ interrupt after disabling pci (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e7a5764
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: change the heartbeat scheduling point (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 368f25b
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: unsecure edma max outstanding register (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4d59d8e
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: remove timestamp registration debug prints (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b4f87f
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: add cpld ts cpld_timestamp cpucp (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d9a8940
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: add a common handler for clock change events (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0fc740c
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: add GAUDI2D revision support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 89c60d4
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: move hl_eq_heartbeat_event_handle() to common code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2f66770
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: add an EQ size ASIC property (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d99ea44
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: separate nonce from max_size in cpucp_packet struct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 82c41ef
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: assume hard-reset by FW upon MC SEI severe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f93e34
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: revise return value handling in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8592026
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: align interrupt names to table (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 419de33
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: check for errors after preboot is ready (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c76cb27
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: use msg_header instead of desc_header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 18c1ba0
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: add heartbeat debug info (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e120e3f
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: add device name to invalidation failure msg (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e34468a
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: expose server type in debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 69ca7ce
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: use parent device for trace events (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1668173
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: no CPUCP prints on heartbeat failure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 38e3d4d
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: align embedded specs headers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 024ac36
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: restructure function that checks heartbeat received (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4c0dbe0
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: update interrupts related headers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1503554
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs: add device name to error print (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e7a82b2
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: use single function to compare FW versions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd6789d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: analogix_dp: handle AUX transfer timeouts (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d395185
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: analogix_dp: only read AUX status when an error occured (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 90142b5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: analogix_dp: simplify and correct PLL lock checks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b770b3b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: analogix_dp: don't wait for PLL lock too early (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5cb68d2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: analogix_dp: move macro reset after link bandwidth (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8f2e111
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: analogix_dp: remove PLL lock check from (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0504686
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: analogix_dp: move basic controller init into runtime PM (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5dcafe5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: analogix_dp: move platform and PHY power handling into (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ea7716b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: analogix_dp: remove clk handling from (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4dba8a0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: analogix_dp: remove unused analogix_dp_remove (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2a0963b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: analogix_dp: handle clock via runtime PM (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 44ade97
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: analogix_dp: register AUX bus after enabling runtime PM (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d99d1ef
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/rockchip: analogix_dp: add runtime PM handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f77f765
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: analogix_dp: remove unused platform power_on_end callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 819e0b7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panic: Restrict graphical logo handling to built-in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ecc4898
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panic: Do not select DRM_KMS_HELPER (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e2df09e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: tc358767: Set LSCLK divider for SYSCLK to 1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 56453a1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: tc358767: Drop line_pixel_subtract (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6d3fbeb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: tc358767: Use tc_pxl_pll_calc() to correct adjusted_mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9d85885
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: tc358767: Split tc_pxl_pll_en() into parameter (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2aca460
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ast: Inline drm_simple_encoder_init() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7c9eaf2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mipi-dsi: add mipi_dsi_usleep_range helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5ea5985
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: sitronix-st7703: transition to mipi_dsi wrapped functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c8eeed7
* Thu Oct 31 2024 pjakobsson@suse.de
- gpu: ipu-v3: pre: don't use fixed timeout when waiting for safe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 43925db
* Thu Oct 31 2024 pjakobsson@suse.de
- gpu: ipu-v3: pre: add dynamic buffer layout reconfiguration (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b5a47c1
* Thu Oct 31 2024 pjakobsson@suse.de
- gpu: ipu-v3: pre: move state into struct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 49b9de5
* Thu Oct 31 2024 pjakobsson@suse.de
- gpu: ipu-v3: pre: replace of_node_put() with __free (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eaa41e5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mediatek: select DRM_GEM_DMA_HELPER if DRM_FBDEV_EMULATION=y (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 318ebf7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/connector: hdmi: shorten too long function name (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a92a1c0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ttm/tests: add missing MODULE_DESCRIPTION() macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 487d739
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panic: Add support for drawing a monochrome graphical logo (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 719c160
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panic: Rename logo to logo_ascii (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd58206
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panic: Spelling s/formater/formatter/ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 979c458
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panic: Fix off-by-one logo size checks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8d332ed
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panic: Fix uninitialized drm_scanout_buffer.set_pixel() crash (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4bccec9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ttm/tests: Use u32 and u64 over uint*_t types (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b8d878c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ttm/tests: Correct modules' licenses (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e448cf6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ttm/tests: Add TODO file (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a38f205
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ttm/tests: Add tests for ttm_tt_populate (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 54b5bbc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ttm/tests: Add eviction testing (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 243729c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ttm/tests: Add test cases dependent on fence signaling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f0c7c5d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ttm/tests: Add tests with mock resource managers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 30780c0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ttm/tests: Test simple BO creation and validation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3154159
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ttm/tests: Use an init function from the helpers lib (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2994219
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ttm/tests: Set DMA mask in KUnit device (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f73d782
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ttm/tests: Delete unnecessary config option (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1425b18
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ttm/tests: Fix a warning in ttm_bo_unreserve_bulk (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c7b0005
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: raydium-rm692e5: transition to mipi_dsi wrapped functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f010619
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: asus-z00t-tm5p5-n35596: transition to mipi_dsi wrapped (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 74739e5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: tc358767: Add format negotiation hooks for DPI/DSI to (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 30e76b9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: truly-nt35521: transition to mipi_dsi wrapped functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9a31d49
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ttm: increase ttm pre-fault value to PMD size (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f34f684
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tests: add drm_hdmi_state_helper_test MODULE_DESCRIPTION() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4cc5d99
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/vc4: vec: Add the margin properties to the connector (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit abc87aa
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/vc4: Add monochrome mode to the VEC. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fc8b514
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ttm/tests: Let ttm_bo_test consider different ww_mutex (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4b9000d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa/uapi: Allow preemption to be disabled on the stream exec (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 858b631
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa: Allow stream enable/disable functions to return error (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 44a72b4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/pf: Disable VFs on remove (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e17db0d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/irq: remove xe_irq_shutdown (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 58b37de
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/pf: Trigger explicit FLR while disabling VFs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3ff6a77
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Print GuC error codes as hex value (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit df79743
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Add more GuC error codes to ABI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a78ad5d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Demote the H2G retry log message to debug (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 525cd9f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Skip attempt to start GuC PC if VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c8b1a2f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa: Fix kernel doc in xe_drm.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 129e83c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/huc: Use GT oriented error messages in xe_huc.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ed4da98
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Request max GT freq during resume (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 285fce8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/lnl: Apply Wa_22019338487 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb5e3aa
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Simplify locking in new_vma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dda4c9a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Invert runnable_state / pending enable check and assert (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 10ab078
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Custom HuC initialization if VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3f9f88c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Skip engine ring enabling if VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e595ddb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Don't use register based TLB invalidation if VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 19648a7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Don't support gtidle if VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ba66a53
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Don't initialize OA if VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4bc864b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Don't change hwe IRQ masks if using memory IRQs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2575412
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Don't apply tile workarounds if VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 78f1a99
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Don't run any save-restore RTP actions if VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 78ae7cb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Disable features that do not apply to VFs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6b7638c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/xelpgp: Extend Wa_14019877138 to graphics 12.74 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c2a6f2b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa: Remove WARN_ON's for unsupported configurations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4443565
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa: Call xe_oa_emit_oa_config() with new config when updating (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5c45cf1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa: Fix potential NPD when OA is not initialized (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0214272
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Move ARAT interrupts enabling to the upload step (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2d35957
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Use ttm_uncached for BO with NEEDS_UC flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 086d1dc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa: Enable Xe2+ overrun mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bf24500
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa: Changes to OA_TAKEN (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d058d60
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa: Override GuC RC with OA on PVC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9e4bcc6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa: Add MMIO trigger support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c4d2e8c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa/uapi: OA buffer mmap (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c7849cf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa/uapi: Query OA unit properties (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c423751
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa: Add OAC support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3bb49ad
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa: Add OAR support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 577fd3e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa/uapi: Read file_operation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 12dfc4e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa/uapi: Expose OA stream fd (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 18bffa7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa: OA stream initialization (OAG) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f0fe090
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa/uapi: Define and parse OA stream properties (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 37890b3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa/uapi: Add/remove OA config perf ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 115674c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa/uapi: Initialize OA units (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 10dd6f6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/oa/uapi: Add OA data formats (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 86582cc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/perf/uapi: Add perf_stream_paranoid sysctl (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fac9a37
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/perf/uapi: "Perf" layer to support multiple perf counter (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b3136d5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/xe2: Add proper check for media in Wa_14020756599 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1b0f0a6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/rtp: Add match on any GT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0970875
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/rtp: Allow to OR rules (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1919dc1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/rtp: Expand max rules/actions per entry (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2197c16
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/rtp: Allow to match 0 sr entries (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b6954cc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Allow const pointer when checking SR-IOV mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e555778
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/exec_queue: Rename xe_exec_queue::compute to xe_exec_queue::lr (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8883b03
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/xe2lpg: Add Wa_14021490052 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd637f8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/uc: Fix and start using xe_uc_fw_sanitize() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9a3f371
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Use fixed CCS mode when running in SR-IOV mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8fd0a27
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/sched_job: Promote xe_sched_job_add_deps() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8feb24d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Drop duplicated declaration (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8a8f5d8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Use correct check for being a VF driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 847139f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Sample ctx timestamp to determine if jobs have timed out (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a5767e0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add killed, banned, or wedged as stick bit during GuC reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d3e4425
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add pending disable assert to handle_sched_done (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit da312e9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add GuC state asserts to deregister_exec_queue (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit df74128
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Assert runnable state in handle_sched_done (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit af845db
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Improve unexpected state error messages (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb3a977
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add xe_gt_clock_interval_to_ms helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 49cb79a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add ctx timestamp to LRC snapshot (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 53a2e5e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Emit ctx timestamp copy in ring ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4d6ef04
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add MI_COPY_MEM_MEM GPU instruction definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 78f8094
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add LRC ctx timestamp support functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 13e3ec3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/bmg: Add PCI IDs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9a2d809
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add reg read/write trace (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit de9620b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/trace: Print device_id in xe_trace events (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit af32fc6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/trace: Print device_id in xe_trace_guc events (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 22afb4a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/trace: Print device_id in xe_trace_bo events (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3c846df
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/trace: Extract guc related traces (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c912693
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/trace: Extract bo, vm, vma traces (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 719bc49
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Increase devcoredump timeout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit beda22d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Ignore force-wake requests if VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3650c0a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Combine common force-wake code into helpers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f5837d3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Include additional info on failed force-wake operation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 907d541
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Kill fw_to_gt() helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0a445a8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Prefer GT oriented messages in xe_force_wake.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d365c4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/xe2lpm: Fixup Wa_14020756599 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 224c647
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Add kernel-doc for HXG Fast Request (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6b67ba8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Drop unused legacy GuC message ABI definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 80e10ad
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Check valid domain is passed in xe_force_wake_ref (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 582d0c3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Ensure caller uses sole domain for xe_force_wake_assert_held (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6ab981d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Prefer GT oriented messages in xe_guc_pc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bd39456
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Add pc_to_ct() helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b674634
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Move H2G SETUP_PC_GUCRC definition to SLPC ABI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 76b3573
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Drop EXEC_QUEUE_FLAG_BANNED (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9883791
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Cleanup force wake registers bit definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fffed04
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Rework GPU page fault handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5aa07ec
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: do not select ACPI_BUTTON (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4366941
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Allow CTB G2H processing without G2H IRQ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d63f975
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Split g2h worker function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b9f118e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/mtl: Update workaround 14018575942 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a890fd8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/guc: Enable w/a 16021333562 for DG2, MTL and ARL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2bbc482
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/gt: Delete the live_hearbeat_fast selftest (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f55ccf9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Increase FLR timeout from 3s to 9s (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f451ad8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Shadow default engine context image in the context (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d5540f0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/gem/i915_gem_ttm_move: Fix typo (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b64e6c9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Remove counter productive REGION_* wrappers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 45e70fe
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Pass the region ID rather than a bitmask to HAS_REGION() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b59cf6c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Fix HAS_REGION() usage in intel_gt_probe_lmem() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit df705eb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: refine gfx6 firmware loading (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b4a0234
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: powerplay: Add `__counted_by` attribute for flexible (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d108a93
* Thu Oct 31 2024 pjakobsson@suse.de
- Revert "drm/amdgpu: change aca bank error lock type to spinlock" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit da49cbb
* Thu Oct 31 2024 pjakobsson@suse.de
- Revert "drm/amdgpu: change bank cache lock type to spinlock" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4da9456
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: remove amdgpu_mes_fence_wait_polling() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 16899fb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: cleanup MES12 command submission (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 90c2c27
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: refine gfx10 firmware loading (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e286512
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: refine gfx9 firmware loading (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 53163bb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix using the reserved VMID with gang submit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit edc7d2f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Do not wait for MP0_C2PMSG_33 IFWI init in SRIOV (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f944b8d
* Thu Oct 31 2024 pjakobsson@suse.de
- Revert "drm/amdgpu: Add missing locking for MES API calls" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2364e82
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.289 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c557729
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.222.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 859832d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove redundant null checks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 09bc0ec
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove redundant checks for context (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 399c12c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove redundant checks for opp (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8510685
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove redundant null checks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f2217b5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove unused value set from 'min_hratio_fact' in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 315951c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove redundant checks for ctx->dc_bios (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0125577
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove redundant checks for res_pool->dccg (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fca865e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Improve warning log for get OPP for OTG master (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 85670db
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix warning caused by an attempt to configure a (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f263aa6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Covert integers to double before divisions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 917eac6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Check pipe_ctx before it is used (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 326caeb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Check dc_stream_state before it is used (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f7ba8e1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Make sure to reprogram ODM when resync fifo (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c53af6b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix NULL pointer dereference for DTN log in DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f21964e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: mirror case cleanup for cursors (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit de9e6dd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add null checker before access structs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit feb9268
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Explicitly extend unsigned 16 bit to 64 bit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0adecda
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Send message to notify the DPIA host router (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 15aa1ba
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add null check to dml21_find_dc_pipes_for_plane (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit afd10d5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Refactor DCN3X into component folder (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 16e2c68
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: On clock init, maintain DISPCLK freq (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b3ffb6b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: fix minor coding errors where dml21 phase 5 uses (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cd4d980
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove redundant condition in VBA 314 func (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 353a676
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove redundant condition with DEADCODE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 863944a
* Thu Oct 31 2024 pjakobsson@suse.de
- Revert "drm/amd/display: workaround for oled eDP not lighting up on (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 733b596
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add dcn401 DIG fifo enable/disable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0379460
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Enable DCN401 idle optimizations by default (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 039a793
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: DCN401 full power down in HW init if any link (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cf0eb7e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: refine gfx8 firmware loading (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b84c95a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: add ASIC version check for the reset selection of RAS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3e7a9c9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: use mode1 reset for RAS poison consumption (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d4abf10
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: update check condition for SMU mode1 reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5340fb2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: set RAS fed status for more cases (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4e67cf9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: create amdgpu_ras_in_recovery to simplify code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6607e54
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: trigger mode1 reset for RAS RMA status (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3315fc5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Disable PHYSYMCLK RCO (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 61a9cbc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.221.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 86ecb6f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.288 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c014817
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Update idle hardmins if uclk or fclk requirement (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ab1c3e0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Do not override dml2.1 reinit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aec2182
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix missed targets in FAMS2+HWFQ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2ded9b1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add null check for phantom pipes in prepare mcache (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c26a7a3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Block SubVP if hardware rotation is used in DML2.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b754a28
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Explicitly cast v_total to signed in a subtraction (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ece08be
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove NO_EFFECT self-assignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a42681d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove reduntant comparisons by Coverity (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb6fff8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: populate hardware_release hook for dcn401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6d73c7d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: make ODM segment width of YCbCr422 two pixel aligned (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit adaec00
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Disable IPS when it is not allowed. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5e833dc
* Thu Oct 31 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Handle HPD_IRQ for internal link" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 630dbdf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove useless comparison of unsigned int vs. 0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f13e654
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix uninitialized variables in dcn401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aabd7ba
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix incorrect size calculation for loop in dcn401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit da3fb45
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Minor cleanup for DCN401 cursor related code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4a8a520
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Check otg_master pointer before use it (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 450032d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Disable DMCUB timeout for DCN35 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5bdf96e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: remove ODM combine before bandwidth validation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9996a8c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: remove dpp pipes on failure to update pipe params (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8f57a3d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Move PRIMARY plane zpos higher (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d713a7b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Introduce overlay cursor mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e765dc4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: define abm debug interface (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5831059
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Refactor function dm_dp_mst_is_port_support_mode() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 200a5db
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Don't refer to dc_sink in is_dsc_need_re_compute (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5019bbe
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Defer the setting of link hpd status for usb4/tbt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6672a7d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Adjust debug msg for usb4/tbt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c6458de
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Avoid programming DTO if Refclk is 0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit be2e855
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Disable boot optimization for DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8f50ac9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Prevent overflow on DTO calculation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4670e58
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: DCN401 cusor code update (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cf1f849
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Use the SPDX license identifier for dmub_replay (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 58b45b1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove duplicate 'update_idle_uclk' in dcn401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0967b35
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Ignore UHBR13.5 cable ID cap for passive cable max (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d6f3e99
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add config support entry to replay caps debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3929519
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: refine gfx7 firmware loading (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 86e35d5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Extend gfx12 trap handler fix to gfx10/11 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e7e37d4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.220.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7ee48f5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add sequential ONO sequencing for DCN35 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b89d5fc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Ignore phantom DTBCLK requirement (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4da3698
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add fallback defaults for invalid LTTPR DPCD caps (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4bb4076
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Update FIXED_VS retimer training pattern delay (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5d1cd13
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: reduce ODM slice count to initial new dc state only (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3c09832
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix multiple cursors when using 4 displays on a (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fded816
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Return after Init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4ee1086
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Change AVI Info Frame version to 4 for OVT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7b267d5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove NULL assignment for stream_status (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4b6a23b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove dcn32_smu13 duplicate header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4ba392e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove redundant ternary operation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 938e728
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove unreachable check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 914513f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove redundant if conditions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9227aba
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: add odm_slice_rect parameter in spl_in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0e6d950
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: use even ODM slice width for two pixels per (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f977894
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix Replay Desync Error Test (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7ff605b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Replay + IPS + ABM in Full Screen VPB (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 751b1aa
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Expand supported Replay residency mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 75e0967
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Replay low hz (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cd0b4d3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Use TPS3 for ALPM on Specific Panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5344ac9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Use dc wake for get the replay state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1ee95ef
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: refine imu firmware loading (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3c188e6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: refine pmfw/smu firmware loading (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 36fa25a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: refine gmc firmware loading (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 05a01c4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: refine vpe firmware loading (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1362857
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: refine vcn firmware loading (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a059186
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: move aca/mca init functions into ras_init() stage (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a6702b4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Skip coredump during resets for debug (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a1cfc0d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: refine sdma firmware loading (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 63bf473
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: refine psp firmware loading (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 75baf9b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: refine mes firmware loading (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 993a2b9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add missing locking for MES API calls (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9373ee2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Set default brightness according to ACPI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 08769b7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: drop some kernel messages in VCN code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a97cf1f
* Thu Oct 31 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Add null check for 'afb' in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bd632d4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: refine gpu_info firmware loading (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2de8326
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: enhance amdgpu_ucode_request() function flexibility (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1e77dac
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix the overflowed constant warning for RREG32_SOC15() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a0a4b50
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: call flush_gpu_tlb directly in gfxhub enable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4a0c527
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: use helper in amdgpu_gart_unbind (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit be92334
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: remove tlb flush in amdgpu_gtt_mgr_recover (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ef1418e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/kfd: remove is_hws_hang and is_resetting (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 68d75a6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix sriov host flr handler (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c0fac68
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add reset source in various cases (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f05ec97
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix NULL pointer in amdgpu_reset_get_desc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d88d99c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: dc 3.2.287 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6bfa597
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix DSC slice and delay calculations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5dc1283
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Increase MAX_LINKS by 2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7184e10
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Guard reading 3DLUT registers for dcn32/dcn35 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a88fc2f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Various DML2 fixes for FAMS2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ab64483
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Program DIG FE source select for DVI before PHY en (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 10c52d8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: remove dead code in navi10_emit_clk_levels and (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3fc229e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: remove dead code in atom_get_src_int (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd23be9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Introduce deferred Replay coasting vtotal update (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5e90e58
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add null check for 'afb' in amdgpu_dm_update_cursor (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a8ddbc4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add monitor patch skip disable crtc during psr and (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 668c0d9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: add set ips disable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5981609
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add recovery timeout to FAMS2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a317ad4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Force max clocks unconditionally when p-state is (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b752113
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Change the order of setting DP_IS_USB_C flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0d881e2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: bypass ODM before CRTC off (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9a49b8a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display/dcn401: use pre-allocated temp structure for bounding (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 17f5001
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: use pre-allocated temp structure for bounding box (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 468e939
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add sdma 7.0 support for copy dcc buffer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 76643b8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: support for DCC feature (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b3ef1bf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add additional VM bits (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a001d8a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Simplify if conditions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6ffa094
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Extend PSRSU residency mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8d9c292
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add outbox notification support for HPD redetect (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a0304c8
* Thu Oct 31 2024 pjakobsson@suse.de
- intel_alpm: Fix wrong offset for PORT_ALPM_* registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb207bd
* Thu Oct 31 2024 pjakobsson@suse.de
- Revert "drm/i915/psr: Disable early transport by default" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ebfde4a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Add new debug bit to disable Panel Replay (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe8647b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Disable PSR/Panel Replay on sink side for PSR only (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 951ff69
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Disable PSR2 SU Region ET if enable_psr module (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4bcbdd5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Disable Panel Replay if PSR mode is set via module (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3ac41ff
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/alpm: Fix port clock usage in AUX Less wake time calculation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f2cb9ba
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: Wa 16021440873 is writing wrong register (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 37e3abd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Set SU area width as pipe src width (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 75de3fe
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: Update calculation to avoid overflow (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b8e5b1d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: update handling of FBC when VT-d active workaround (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b174e0f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: move comments about FSB straps to proper place (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 66b9236
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/cdclk: use i9xx_fsb_freq() for rawclk_freq initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a818cbb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: use i9xx_fsb_freq() for GT clock frequency (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b20d471
* Thu Oct 31 2024 krisman@suse.de
- scsi: ufs: core: Remove SCSI host only if added (CVE-2024-46843
  bsc#1231100).
- commit b455bee
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: extend the fsb_freq initialization to more platforms (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 662cf76
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: convert fsb_freq and mem_freq to kHz (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 31d4b12
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/gt: remove mem freq from gt debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 38dc282
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dram: rearrange mem freq init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 697e955
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dram: split out pnv DDR3 detection (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 826f22a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dram: separate fsb freq detection from mem freq (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b27f573
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/wm: clarify logging on not finding CxSR latency config (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 46bdcb7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/wm: rename intel_get_cxsr_latency -> pnv_get_cxsr_latency (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f57b0e2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Remove bogus MST check in intel_dp_has_audio() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 391ff89
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Utilize edp_disable_dsc from VBT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb9456d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Reuse intel_dp_supports_dsc() for MST (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 613583f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Use intel_dp_has_dsc() during .compute_config() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bdbaab7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Handle MST in intel_dp_has_dsc() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9af1aac
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Extract intel_dp_has_dsc() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 07ccfa0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Drop redundant dsc_decompression_aux check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e47aa27
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: remove unused pipe/plane B register macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 17ee7b9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: relocate some DSPCNTR reg bit definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8539eda
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/gvt: do not use implict dev_priv in DSPSURF_TO_PIPE() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8b8bc7b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/gvt: rename range variable to stride (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3d9b8fb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/gvt: use proper i915_reg_t for calc_index() parameters (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d395673
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/gvt: remove the unused end parameter from calc_index() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d71f7f6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Add debugfs entry to get the link retrain disabled state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9e83785
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Add debugfs entry to force link retrain (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f771309
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Add debugfs entry to force link training failure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 67b9a37
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Add debugfs entries to get the max link rate/lane count (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 04e15cd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Add debugfs entries to force the link rate/lane count (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 90a7e3a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Enable link training fallback for MST (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7816ed2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Reset intel_dp->link_trained during disabling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d3abff7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Disable link retraining after the last fallback step (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 650adf3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Use check link state work in the HPD IRQ handler (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2adfc5c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Use check link state work in the detect handler (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6fc3150
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Use check link state work in the hotplug handler (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b817eb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Send a link training modeset-retry uevent to all MST (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1716935
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Pass atomic state to link training function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9cb704e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Reduce link params only after retrying with unchanged (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f1f91ce
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Recheck link state after modeset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-i915-dp-Don-t-switch-the-LTTPR-mode-on-an-active.patch.
- commit 332646d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Use a commit modeset for link retraining MST links (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a1a00d6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Factor out function to modeset commit a set of pipes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6d076f0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Sanitize intel_dp_get_link_train_fallback_values() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit affa765
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Move link train fallback to intel_dp_link_training.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8607f19
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Move link train params to a substruct in intel_dp (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 084602c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Align TUs to avoid splitting symbols across MTPs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6c287a9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Fix DSC input BPP computation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6bdc2cc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: Send vrr vsync params whne vrr is enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 41f4a5b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Rename bigjoiner master/slave to bigjoiner (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 320c6a0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Rename all bigjoiner to joiner (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c3534d2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Wake time is aux less wake time for Panel Replay (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9007e4b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Check vblank against IO buffer wake time on Lunarlake (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ba81bfd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Take into account SU SDP scanline indication in vblank (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f945c10
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Move vblank length check to separate function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d6ac988
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Print Panel Replay status instead of frame lock status (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5ba9122
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Add Panel Replay support to intel_psr2_config_et_valid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f26d1cb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/alpm: Share alpm support checks with PSR code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 23c8324
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Split enabling sink for PSR and Panel Replay (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 248c7da
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/display: Add missing Panel Replay Enable SU Region ET bit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb60d46
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: Skip Panel Replay on pipe comparison if no active (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a15dda8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: Take panel replay into account in vsc sdp unpacking (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6ef0d7e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/alpm: Write also AUX Less Wake lines into ALPM_CTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7562e97
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/alpm: Do not use fast_wake_lines for aux less wake time (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 120c968
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Compute CMRR and calculate vtotal (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c1ece36
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: Compute vrr vsync params (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 708e349
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: Compute Adaptive sync SDP params (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 75609f5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: Add support for pack and unpack (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a510830
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/dp: Add refresh rate divider to struct representing AS SDP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b597cb2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Update trans_vrr_ctl flag when cmrr is computed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d0a78c8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Define and compute Transcoder CMRR registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c3e338d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Separate VRR related register definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5972431
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Update indentation for VRR registers and bits (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ca0fb03
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display/bmg: Add platform descriptor (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a57493d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to HSW_STEREO_3D_CTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cf0ba07
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define the "luminance and gamma" sub-struct of block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fd40e30
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define block 46 chromaticity coordinates properly (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4ecd762
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: do not select ACPI_BUTTON (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d7a1e4d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to MTL_CLKGATE_DIS_TRANS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 594c8a8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_SET_CONTEXT_LATENCY (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f127718
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_MSA_MISC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2f6a437
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TGL_DP_TP_STATUS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f80b7db
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TGL_DP_TP_CTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3262f8d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_DDI_FUNC_CTL2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e1a758a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_DDI_FUNC_CTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e0182d3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPE_LINK_N2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4370670
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPE_LINK_M2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dc5bfa0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPE_LINK_N1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8b12503
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPE_LINK_M1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb476f8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPE_DATA_N2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0bb8ba7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPE_DATA_M2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4abdd26
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPE_DATA_N1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c1b2fb2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPE_DATA_M1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fcea196
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to SWF3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e3902d4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to SWF1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4f7ff70
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to SWF0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a4a67fb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to CHV_CANVAS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 192fa95
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to CHV_BLEND (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7632708
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPE_FLIPCOUNT_G4X (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 555ab75
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPE_FRMCOUNT_G4X (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit efe3cd6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to DSPFW3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aaa3580
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to DSPFW2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 141c829
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to DSPFW1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e8b9657
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to DSPARB (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4d6b6fe
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to ICL_PIPESTATUS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 49559d7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPE_ARB_CTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f4b6556
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPESTAT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 23e19cc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPEFRAMEPIXEL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4e26734
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPEFRAME (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4941b15
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPEDSL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e5f51ab
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANSCONF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d7c6862
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PFIT_AUTO_RATIOS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4d9bd1d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PFIT_PGM_RATIOS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8b788cf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PFIT_CONTROL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a66b2d1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PORT_HOTPLUG_STAT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 672fb1a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PORT_HOTPLUG_EN (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6562a46
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_MULT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 62a5920
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPESRC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fc2746f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_VSYNCSHIFT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6cfbb2d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to BCLRPAT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c38e5a7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_VSYNC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 30dddf9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_VBLANK (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bc40506
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_VTOTAL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0c82717
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_HSYNC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5c6e23d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_HBLANK (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 389d8fd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_HTOTAL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7197355
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to DPLL_MD (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 588e24a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to DPLL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 665dd9f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/overlay: convert intel_overlay_print_error_state() to (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7598706
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dmc: convert intel_dmc_print_error_state() to drm_printer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0fb8b06
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Reduce DDI clock gating printk level from NOTICE to DEBUG (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8a0829e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/display: drop i915_drv.h include from xe code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4fb7fa8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/display: reduce includes in compat i915_drv.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8d236ed
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/display: move compat runtime pm stubs to the correct file (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cd420dd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/display: move compat uncore stubs to the correct file (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 988942d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: include xe_bo.h, gem_object_types etc. where needed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6978573
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: include intel_step.h where needed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0eea571
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: include intel_uncore.h where needed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bec0395
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: include i915_gpu_error.h where needed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9c0e4d0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: include gt/intel_gt_types.h where needed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 70f1310
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: include gem/i915_gem_stolen.h where needed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e683d87
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: drop redundant W=1 warnings from Makefile (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2283287
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Protect CRC reg macro arguments for consistency (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e97a438
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Define the PIPE_CRC_EXP registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 96fdfc7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Document which platforms have which CRC registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ff32cde
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Add a separate definition for PIPE_CRC_RES_HSW (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ea5dabb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Regroup pipe CRC regs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit da80d6e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Switch PIPE_CRC_RES_*_IVB to _MMIO_PIPE() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0f05609
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Extract intel_pipe_crc_regs.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cd5e15d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dsb: Use intel_color_uses_dsb() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9d9fdc0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dsb: Pass DSB engine ID to intel_dsb_prepare() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 21a5230
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dsb: Move DSB ID definition to the header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5c95fda
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dsb: Polish the DSB ID enum (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1c5ca5f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Fix assert on pending async-put power domain work when it (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ad8fae3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Add Early Transport into psr debugfs interface (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit acb91e3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Allow setting I915_PSR_DEBUG_SU_REGION_ET_DISABLE via (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6aa97d5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: Selective fetch Y position on Region Early (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f57ce39
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Use enable boolean from intel_crtc_state for Early (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b4f42b9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Get Early Transport status in intel_psr_pipe_get_config (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 32e1c6e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Add Early Transport status boolean into intel_psr (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dcb16ec
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: move i915_hdcp_interface.h under include/drm/intel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2b599fc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: move xe_pciids.h under include/drm/intel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7d02c30
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: move i915_pciids.h under include/drm/intel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 459bbc9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: move i915_pxp_tee_interface.h under include/drm/intel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fead917
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: move i915_drm.h under include/drm/intel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit 9647e75
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: move intel_lpe_audio.h under include/drm/intel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bf020cf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: move i915_component.h under include/drm/intel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f6dd042
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: move i915_gsc_proxy_mei_interface.h under include/drm/intel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 685a35b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: move intel-gtt.h under include/drm/intel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c970b82
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: reduce includes in intel_clock_gating.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b67a2f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: drop unnecessary i915_reg.h includes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8b1ad73
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: remove intermediate _PCH_DP_* macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3ed7791
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: move PCH DP AUX CH regs to intel_dp_aux_regs.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ff08d2f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: rearrange DP AUX register macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1c45184
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: remove unused DP AUX CH register macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ee470e0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/gvt: use proper macros for DP AUX CH CTL registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3267e73
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Switch intel_usecs_to_scanlines() to 64bit maths (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d7ac25e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Move intel_crtc_scanline_offset() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 573ef83
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Simplify scanline_offset handling for gen2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4bd720e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Extract intel_mode_vtotal() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ae6c4e4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Extract intel_mode_vblank_end() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f282253
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Reuse intel_mode_vblank_start() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 25177a1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Plumb the full atomic state into (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f8ccb75
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Plumb the full atomic state into icl_check_nv12_planes() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f0bf700
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/cdclk: Plumb the full atomic state deeper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit def6a1d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: add probe message (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e6d77bb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: add support for subplatforms (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9d94339
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: identify platforms with enum and name (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7732dc1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: change display probe to identify GMD ID based (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a6e3921
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: add LNL PCI IDs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f38616
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: add platform descriptors (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 819eb46
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: change GMD ID display ip ver propagation at probe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 43b32c3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: check platforms without display one level higher (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ed56413
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: change probe for no display case (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4b141ea
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: move params copy at probe earlier (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c354b86
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/alpm: Add debugfs for LOBF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6ef1cc1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/alpm: Enable lobf from source in ALPM_CTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9d7946f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/alpm: Add compute config for lobf (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f56d6df
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/display: Add missing aux less alpm wake related bits (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0143a7c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/alpm: Move alpm related code to a new file (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3f94a21
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/alpm: Move alpm parameters from intel_psr (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe11449
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: move uapi.event outside spinlock in intel_crtc_vblank_work (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6eab7a1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: double check array-boundary in parse_sdvo_lvds_data (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6e52f59
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: Add compare config for MTL+ platforms (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 39de923
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: Revert "drm/i915/display: Skip C10 state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f4c1f16
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/hdcp: Fix IS_METEORLAKE usage for HDCP line rekeying (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 101f4cc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: modify psr status debugfs to support eDP Panel Replay (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 655db80
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Move printing PSR mode to own function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b15d89d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Move printing sink PSR support to own function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit beeef26
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel replay: Add edp1.5 Panel Replay bits and register (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 805d779
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Store pr_dpcd in intel_dp (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 61c1ab9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to ADL_TVIDEO_DIP_AS_SDP_DATA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0901514
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to ICL_VIDEO_DIP_PPS_ECC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6a0dda9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to ICL_VIDEO_DIP_PPS_DATA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e313146
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to GLK_TVIDEO_DIP_DRM_DATA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6610c94
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to HSW_TVIDEO_DIP_VSC_DATA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 57a2c28
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to HSW_TVIDEO_DIP_GMP_DATA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 023411f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to HSW_TVIDEO_DIP_SPD_DATA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2a66f98
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to HSW_TVIDEO_DIP_VS_DATA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe7acd6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to HSW_TVIDEO_DIP_AVI_DATA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f7449e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to HSW_TVIDEO_DIP_GCP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6ab67b2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to HSW_TVIDEO_DIP_CTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ad9ca08
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PP_DIVISOR (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd459e6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PP_OFF_DELAYS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e91c4fa
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PP_ON_DELAYS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f31f507
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PP_CONTROL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7e33bc3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PP_STATUS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3af6631
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to _MMIO_PPS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5521282
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Bury c8_planes_changed() in intel_color_check() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 277ecd9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Hide the intel_crtc_needs_color_update() inside (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e59b2da
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Plumb the entire atomic state into intel_color_check() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 363b55f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Fix SEL_FETCH_{SIZE,OFFSET} registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 69307fe
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPEGCMAX (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f43114
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PRIMCNSTALPHA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e469225
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PRIMSIZE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d26c32
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PRIMPOS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 76b7b84
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to DSPGAMC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f08f3bb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to DSPSURFLIVE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c3d3cda
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to DSPOFFSET (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 42005c3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to DSPTILEOFF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0101a46
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to DSPSURF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6d280e7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to DSPSIZE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 64c27fe
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to DSPPOS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aeed6d7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to DSPSTRIDE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f10acfc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to DSPLINOFF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b5a6bb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to DSPADDR (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d95bc45
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to DSPCNTR (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f314149
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to DSPADDR_VLV (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a71a796
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Define SEL_FETCH_PLANE registers via PICK_EVEN_2RANGES() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 79243c3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Document which platforms use which sprite registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5dd3e14
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Polish sprite plane register definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d0d7e26
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Document a few pre-skl primary plane platform dependencies (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4d305fe
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Polish pre-skl primary plane registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c331835
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Extract i9xx_plane_regs.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 20c6a1f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Move PIPEGCMAX to intel_color_regs.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f4bd896
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Add separate defines for cursor WM/DDB register bits (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f1d60e4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Rename selective fetch plane registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c0b2930
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Simplify PIPESRC_ERLY_TPT definition (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6d23ac5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Add separate define for SEL_FETCH_CUR_CTL() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa9b9b5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Clean up the cursor register defines (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c0ebd1f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Add skl+ plane name aliases to enum plane_id (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 77b3800
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Bump max TMDS bitrate to 6 Gbps on ADL-S/ADL-P/DG2+ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0cc0f8e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bmg: Load DMC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe12540
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/hdcp: Check mst_port to determine connector type (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a824820
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/hdcp: Move aux assignment after connector type check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 772afe3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: stop redefining INTEL_VGA_DEVICE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8870bcc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/pciids: switch to xe driver style PCI ID macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 211bc80
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: PSR2_CTL[Block Count Number] not needed for LunarLake (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 55a0293
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: LunarLake PSR2_CTL[IO Wake Lines] is 6 bits wide (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d8b436d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: LunarLake IO and Fast Wake time line count maximums are (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e6b4558
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to CURSURFLIVE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bba289e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to CUR_CHICKEN (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e0f566e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to CUR_FBC_CTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6709384
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to CURSIZE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 70adf52
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to CURPOS_ERLY_TPT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 84d4f04
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to CURPOS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 901c2d5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to CURBASE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 82fd52c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to CURCNTR (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7a33203
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/pciids: don't include RPL-U PCI IDs in RPL-P (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c53f9cf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/pciids: remove 12 from INTEL_TGL_IDS() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7063716
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/pciids: remove 11 from INTEL_ICL_IDS() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0ec182b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/pciids: don't include WHL/CML PCI IDs in CFL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9bac425
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/pciids: add INTEL_IVB_IDS() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f7682ea
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/pciids: add INTEL_SNB_IDS() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cfde39d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/pciids: add INTEL_ILK_IDS(), use acronym (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d621bf7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/pciids: add INTEL_PNV_IDS(), use acronym (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 819ab4d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Handle SKL+ WM/DDB registers next to all other plane (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 11b8b02
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Nuke skl_write_wm_level() and skl_ddb_entry_write() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 888afbf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Extract skl_plane_{wm,ddb}_reg_val() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 61da96b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Refactor skl+ plane register offset calculations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d9a69fa
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Drop a few unwanted tabs from skl+ plane reg defines (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4053442
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Use REG_BIT for PLANE_WM bits (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d95fa1c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Shuffle the skl+ plane register definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e6d7f5f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Drop useless PLANE_FOO_3 register defines (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9f45f92
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/gvt: Use PLANE_CTL and PLANE_SURF defines (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f75c824
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/gvt: Use the full PLANE_KEY*() defines (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f880a0a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/gvt: Use the proper PLANE_AUX_OFFSET() define (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 716b4e1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/gvt: Use the proper PLANE_AUX_DIST() define (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 59f3653
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Move skl+ wm/ddb registers to proper headers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 74542a6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Extract intel_cursor_regs.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ad11e07
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Extract skl_universal_plane_regs.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 843da09
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Nuke _MMIO_PLANE_GAMC() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e5fa76f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Add panel replay sel update support to debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 798130e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Split intel_psr2_config_valid for panel replay (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c7761f4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Update PSR module parameter descriptions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1ce8292
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Do not apply workarounds in case of panel replay (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 87164d1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Panel replay uses SRD_STATUS to track it's status (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 14dc629
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Modify intel_dp_get_su_granularity to support panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bff5902
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Detect panel replay selective update support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 78e4f14
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panelreplay: dpcd register definition for panelreplay SU (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb85d3f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Rename psr2_enabled as sel_update_enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7542c13
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Use always vsc revision 0x6 for Panel Replay (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9f19504
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: Do not print "psr: enabled" for on Panel Replay (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fb207d5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/psr: Rename has_psr2 as has_sel_update (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 060da28
* Thu Oct 31 2024 pjakobsson@suse.de
- Documentation/i915: remove kernel-doc for DMC wakelocks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b1fec08
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/display: remove unused xe->sb_lock (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6968b64
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/display: remove unused xe->enabled_irq_mask (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4de7092
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Rename the fb pinning functions to indicate the address (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 068ed3f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Cleanup fbdev fb setup (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2dbc533
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Change intel_fbdev_fb_alloc() return type (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ec2aed4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Constify 'fb' in during pinning (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b2f525d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Implement Audio WA_14020863754 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d8157e5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Write panel override luminance values (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cb4c59f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Enable AUX based backlight for HDR (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0f4af26
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Drop comments on EDP HDR DPCD registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e379e7f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Fix Register bit naming (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5da3e8d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Add TCON HDR capability checks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 05490c4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Rename intel struct inside intel_panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit db9944f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/dp: Make has_gamut_metadata_dip() non static (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3ce58e7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Polish types in fb calculations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ea81a55
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Extract intel_plane_needs_physical() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 510fcfd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Drop 'uses_fence' parameter from intel_pin_fb_obj_dpt() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a26a506
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Clean up skl+ plane stride limits (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5c21046
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Split gen2 vs. gen3 .max_stride() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cb3a167
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_VRR_VSYNC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 68dce0a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_PUSH (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ac6e436
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_VRR_STATUS2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 91d8b9c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_VRR_FLIPLINE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ac06114
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_VRR_VTOTAL_PREV (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ebbcd7f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_VRR_STATUS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d324455
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_VRR_VMAXSHIFT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e1d2425
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_VRR_VMIN (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8fbbec5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_VRR_VMAX (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2d6c28e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_VRR_CTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7849cd7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/hdcp: Disable HDCP Line Rekeying for HDCP2.2 on HDMI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b6573b6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Nuke xe's copy of intel_fbdev_fb.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cfafedb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Use drm_crtc_vblank_crtc() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2566d59
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 253 (PRD Table) contents (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 80948fe
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 252 (int15 Hook) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f046d92
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 55 (Compression Parameters) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 16c278b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 50 (MIPI) contents (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 04138d9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 57 (Vswing PreEmphasis Table) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d0725dc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 55 (RGB Palette Table) contents (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 30fe621
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 51 (Fixed Set Mode Table) contents (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f305441
* Thu Oct 31 2024 mgorman@suse.de
- Replace OOT patches with mainline versions (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- New patches
  patches.suse/nbcon-Add-API-to-acquire-context-for-non-printing-operations.patch
  patches.suse/printk-Rename-console_replay_all-and-update-context.patch
  patches.suse/printk-nbcon-Clarify-rules-of-the-owner-waiter-matching.patch
  patches.suse/printk-nbcon-Consolidate-alloc-and-init.patch
  patches.suse/serial-core-Acquire-nbcon-context-in-port-lock-wrapper.patch
  patches.suse/printk-Make-console_is_usable-available-to-nbcon.c.patch
  patches.suse/printk-Let-console_is_usable-handle-nbcon.patch
  patches.suse/8250-microchip-Add-4-Mbps-support-in-PCI1XXXX-UART.patch
  patches.suse/8250-microchip-pci1xxxx-Add-Burst-mode-reception-support-in-uart-driver-for-writing-into-FIFO.patch
  patches.suse/8250-microchip-pci1xxxx-Add-Burst-mode-transmission-support-in-uart-driver-for-reading-from-FIFO.patch
  patches.suse/8250-microchip-pci1xxxx-Add-Syslock-support-for-reading-UART-system-registers.patch
  patches.suse/8250-microchip-pci1xxxx-Rearranging-the-structure-declarations.patch
  patches.suse/lockdep-Mark-emergency-sections-in-lockdep-splats.patch
  patches.suse/printk-Add-helper-for-flush-type-logic.patch
  patches.suse/printk-Add-is_printk_legacy_deferred.patch
  patches.suse/printk-Flush-nbcon-consoles-first-on-panic.patch
  patches.suse/printk-nbcon-Flush-new-records-on-device_release.patch
  patches.suse/rcu-Mark-emergency-sections-in-rcu-stalls.patch
  patches.suse/serdev-Make-use-of-device_set_node.patch
  patches.suse/serdev-Replace-custom-code-with-device_match_acpi_handle.patch
  patches.suse/serdev-Simplify-devm_serdev_device_open-function.patch
  patches.suse/serial-8250_aspeed_vuart-Use-dev_err_probe-instead-of-dev_err.patch
  patches.suse/serial-8250_aspeed_vuart-Use-devm_clk_get_enabled.patch
  patches.suse/serial-8250_bcm7271-Use-dev_err_probe-instead-of-dev_err.patch
  patches.suse/serial-8250_bcm7271-Use-devm_clk_get_optional_enabled.patch
  patches.suse/serial-8250-Convert-to-platform-remove-callback-returning-void.patch
  patches.suse/serial-8250_dw-fall-back-to-poll-if-there-s-no-interrupt.patch
  patches.suse/serial-8250_dw-Use-devm_clk_get_optional_enabled.patch
  patches.suse/serial-8250_of-Use-dev_err_probe-instead-of-dev_warn.patch
  patches.suse/serial-8250_of-Use-devm_clk_get_enabled.patch
  patches.suse/serial-8250_omap-Drop-pm_runtime_irq_safe.patch
  patches.suse/serial-8250_omap-Remove-unused-of_gpio.h.patch
  patches.suse/serial-8250_omap-Set-the-console-genpd-always-on-if-no-console-suspend.patch
  patches.suse/serial-8250_omap-Switch-to-use-uart_read_port_properties.patch
  patches.suse/serial-8250_pci1xxxx-Annotate-struct-pci1xxxx_8250-with-__counted_by.patch
  patches.suse/serial-8250_pci1xxxx-Don-t-use-proxy-headers.patch
  patches.suse/serial-8250_pci1xxxx-Drop-quirk-from-8250_port.patch
  patches.suse/serial-8250_pci1xxxx-fix-off-by-one-in-pci1xxxx_process_read_data.patch
  patches.suse/serial-8250_pci1xxxx-partially-revert-off-by-one-patch.patch
  patches.suse/serial-amba-pl011-convert-not-to-use-dma_request_slave_channel.patch
  patches.suse/serial-amba-pl011-Convert-to-platform-remove-callback-returning-void.patch
  patches.suse/serial-amba-pl011-Do-not-complain-when-DMA-is-absent.patch
  patches.suse/serial-amba-pl011-Use-uart_prepare_sysrq_char.patch
  patches.suse/serial-core-Clean-up-uart_update_timeout-function.patch
  patches.suse/serial-core-Move-tty-and-serdev-to-be-children-of-serial-core-port-device.patch
  patches.suse/serial-core-tidy-invalid-baudrate-handling-in-uart_get_baud_rate.patch
  patches.suse/serial-cpm_uart-Don-t-include-fs_uart_pd.h-when-not-needed.patch
  patches.suse/serial-initialize-retinfo-in-uart_get_info.patch
  patches.suse/serial-max310x-add-comments-for-membase-address-workaround.patch
  patches.suse/serial-max310x-add-explicit-return-for-some-switch-default-cases.patch
  patches.suse/serial-max310x-add-I2C-device-table-for-instantiation-from-userspace.patch
  patches.suse/serial-max310x-add-macro-for-max-number-of-ports.patch
  patches.suse/serial-max310x-change-confusing-comment-about-Tx-FIFO.patch
  patches.suse/serial-max310x-fix-indentation.patch
  patches.suse/serial-max310x-fix-typos-in-comments.patch
  patches.suse/serial-max310x-reformat-and-improve-comments.patch
  patches.suse/serial-max310x-remove-holes-in-struct-max310x_devtype.patch
  patches.suse/serial-max310x-remove-trailing-whitespaces.patch
  patches.suse/serial-max310x-replace-bare-use-of-unsigned-with-unsigned-int-checkpatch.patch
  patches.suse/serial-max310x-replace-hardcoded-masks-with-preferred-GENMASK.patch
  patches.suse/serial-max310x-simplify-probe-and-remove-error-handling.patch
  patches.suse/serial-max310x-use-common-detect-function-for-all-variants.patch
  patches.suse/serial-max310x-use-common-power-function-for-all-variants.patch
  patches.suse/serial-max310x-use-dev_err_probe-instead-of-dev_err.patch
  patches.suse/serial-max310x-use-i2c_get_match_data.patch
  patches.suse/serial-max310x-use-separate-regmap-name-for-each-port.patch
  patches.suse/serial-max310x-use-spi_get_device_match_data.patch
  patches.suse/serial-move-WARN_ON-in-uart_write-to-the-condition.patch
  patches.suse/serial-pass-state-to-__uart_start-directly.patch
  patches.suse/serial-sc16is7xx-add-driver-name-to-struct-uart_driver.patch
  patches.suse/serial-sc16is7xx-add-explicit-return-for-some-switch-default-cases.patch
  patches.suse/serial-sc16is7xx-add-macro-for-max-number-of-UART-ports.patch
  patches.suse/serial-sc16is7xx-add-missing-support-for-rs485-devicetree-properties.patch
  patches.suse/serial-sc16is7xx-change-confusing-comment-about-Tx-FIFO.patch
  patches.suse/serial-sc16is7xx-drop-unneeded-MODULE_ALIAS.patch
  patches.suse/serial-sc16is7xx-hardware-reset-chip-if-reset-gpios-is-defined-in-DT.patch
  patches.suse/serial-sc16is7xx-improve-comments-about-variants.patch
  patches.suse/serial-sc16is7xx-Put-IOControl-register-into-regmap_volatile.patch
  patches.suse/serial-sc16is7xx-refactor-EFR-lock.patch
  patches.suse/serial-sc16is7xx-remove-unused-to_sc16is7xx_port-macro.patch
  patches.suse/serial-sc16is7xx-reorder-code-to-remove-prototype-declarations.patch
  patches.suse/serial-sc16is7xx-replace-hardcoded-divisor-value-with-BIT-macro.patch
  patches.suse/serial-sc16is7xx-split-into-core-and-I2C-SPI-parts-core.patch
  patches.suse/serial-sc16is7xx-split-into-core-and-I2C-SPI-parts-sc16is7xx_lines.patch
  patches.suse/serial-sc16is7xx-split-into-core-and-I2C-SPI-parts-sc16is7xx_regcfg.patch
  patches.suse/serial-sc16is7xx-unconditionally-clear-line-bit-in-sc16is7xx_remove.patch
  patches.suse/serial-sc16is7xx-use-DECLARE_BITMAP-for-sc16is7xx_lines-bitfield.patch
  patches.suse/serial-sc16is7xx-use-device_property-APIs-when-configuring-irda-mode.patch
  patches.suse/serial-sc16is7xx-use-i2c_get_match_data.patch
  patches.suse/serial-sc16is7xx-use-spi_get_device_match_data.patch
  patches.suse/serial-sh-sci-Call-sci_serial_-in-out-directly.patch
  patches.suse/serial-sh-sci-convert-not-to-use-dma_request_slave_channel.patch
  patches.suse/serial-sh-sci-Convert-to-platform-remove-callback-returning-void.patch
  patches.suse/serial-ucc-Convert-to-platform-remove-callback-returning-void.patch
  patches.suse/serial-ucc_uart-Fix-multiple-address-space-type-errors.patch
  patches.suse/serial-xilinx_uartps-Convert-to-platform-remove-callback-returning-void.patch
  patches.suse/serial-xilinx_uartps-Fix-kernel-doc-about-.remove-s-return-code.patch
  patches.suse/serial-xilinx_uartps-unset-STOPBRK-when-setting-STARTBRK.patch
  patches.suse/tty-8250_dma-use-dmaengine_prep_slave_sg.patch
  patches.suse/tty-8250_omap-use-dmaengine_prep_slave_sg.patch
  patches.suse/tty-fix-tty_operations-types-in-documentation.patch
  patches.suse/tty-hvsi-remove-an-extra-variable-from-hvsi_write.patch
  patches.suse/tty-make-tty_operations-send_xchar-accept-u8-char.patch
  patches.suse/tty-make-tty_operations-write-s-count-size_t.patch
  patches.suse/tty-msm_serial-use-dmaengine_prep_slave_sg.patch
  patches.suse/tty-propagate-u8-data-to-tty_operations-put_char.patch
  patches.suse/tty-propagate-u8-data-to-tty_operations-write.patch
  patches.suse/tty-serial-Add-RS422-flag-to-struct-serial_rs485.patch
  patches.suse/tty-serial-amba-pl011-avoid-quoted-string-split-across-lines.patch
  patches.suse/tty-serial-amba-pl011-factor-QDF2400-SoC-erratum-44-out-of-probe.patch
  patches.suse/tty-serial-amba-pl011-fix-formatting-of-conditions.patch
  patches.suse/tty-serial-amba-pl011-fix-miscellaneous-checkpatch-warnings.patch
  patches.suse/tty-serial-amba-pl011-fix-whitespace-formatting.patch
  patches.suse/tty-serial-amba-pl011-replace-TIOCMBIT-macros-by-static-functions.patch
  patches.suse/tty-serial-amba-pl011-unindent-pl011_console_get_options-function-body.patch
  patches.suse/tty-serial-Cleanup-the-bit-shift-with-macro.patch
  patches.suse/tty-serial-kgdboc-Fix-8250_-kgdb-over-serial.patch
  patches.suse/tty-serial-sc16is7xx-convert-to-use-maple-tree-register-cache.patch
  patches.suse/tty-serial-switch-from-circ_buf-to-kfifo.patch
  patches.suse/tty-serial-uartps-Add-rs485-support-to-uartps-driver.patch
  patches.suse/tty-serial-uartps-Relocate-cdns_uart_tx_empty-to-facilitate-rs485.patch
  patches.suse/rcu-Add-RCU-CPU-stall-notifier.patch
  patches.suse/rcu-Add-sysfs-to-provide-throttled-access-to-rcu_barrier.patch
  patches.suse/rcu-Assume-IRQS-disabled-from-rcu_report_dead.patch
  patches.suse/rcu-Assume-rcu_report_dead-is-always-called-locally.patch
  patches.suse/rcu-Break-rcu_node_0-rq-__lock-order.patch
  patches.suse/rcu-Bring-diagnostic-read-of-rcu_state.gp_flags-into-alignment.patch
  patches.suse/rcu-Check-callback-invocation-time-limit-for-rcuc-kthreads.patch
  patches.suse/rcu-Clarify-rcu_is_watching-kernel-doc-comment.patch
  patches.suse/rcu-Conditionally-build-CPU-hotplug-teardown-callbacks.patch
  patches.suse/rcu-Defer-RCU-kthreads-wakeup-when-CPU-is-dying.patch
  patches.suse/rcu-Delete-a-redundant-check-in-rcu_check_gp_kthread_starvation.patch
  patches.suse/rcu-Don-t-redump-the-stalled-CPU-where-RCU-GP-kthread-last-ran.patch
  patches.suse/rcu-Dump-memory-object-info-if-callback-function-is-invalid.patch
  patches.suse/rcu-Eliminate-check_cpu_stall-duplicate-code.patch
  patches.suse/rcu-Eliminate-rcu_gp_slow_unregister-false-positive.patch
  patches.suse/rcu-Employ-jiffies-based-backstop-to-callback-time-limit.patch
  patches.suse/rcu-Force-quiescent-states-only-for-ongoing-grace-period.patch
  patches.suse/rcu-Introduce-rcu_cpu_online.patch
  patches.suse/rcu-Mark-__rcu_irq_enter_check_tick-rcu_urgent_qs-load.patch
  patches.suse/rcu-Mark-loads-from-rcu_state.n_online_cpus.patch
  patches.suse/rcu-Mark-rcu_cpu_kthread-accesses-to-rcu_cpu_has_work.patch
  patches.suse/rcu-Reduce-synchronize_rcu-latency.patch
  patches.suse/rcu-Remove-full-memory-barrier-on-RCU-stall-printout.patch
  patches.suse/rcu-Restrict-access-to-RCU-CPU-stall-notifiers.patch
  patches.suse/rcu-Standardize-explicit-CPU-hotplug-calls.patch
  patches.suse/rcu-dynamically-allocate-the-rcu-kfree-shrinker.patch
  patches.suse/rcu-exp-Fix-RCU-expedited-parallel-grace-period-kworker-allocation-failure-recovery.patch
  patches.suse/rcu-exp-Handle-RCU-expedited-grace-period-kworker-allocation-failure.patch
  patches.suse/rcu-exp-Handle-parallel-exp-gp-kworkers-affinity.patch
  patches.suse/rcu-exp-Make-parallel-exp-gp-kworker-per-rcu-node.patch
  patches.suse/rcu-exp-Move-expedited-kthread-worker-creation-functions-above-rcutree_prepare_cpu.patch
  patches.suse/rcu-exp-Remove-full-barrier-upon-main-thread-wakeup.patch
  patches.suse/rcu-exp-Remove-rcu_par_gp_wq.patch
  patches.suse/rcu-exp-Remove-redundant-full-memory-barrier-at-the-end-of-GP.patch
  patches.suse/rcu-exp-Remove-superfluous-full-memory-barrier-upon-first-EQS-snapshot.patch
  patches.suse/rcu-kvfree-Add-debug-check-for-GP-complete-for-kfree_rcu_cpu-list.patch
  patches.suse/rcu-kvfree-Add-debug-to-check-grace-periods.patch
  patches.suse/rcu-kvfree-Do-not-run-a-page-work-if-a-cache-is-disabled.patch
  patches.suse/rcu-kvfree-Invoke-debug_rcu_bhead_unqueue-after-checking-bnode-gp_snap.patch
  patches.suse/rcu-kvfree-Make-drain_page_cache-take-early-return-if-cache-is-disabled.patch
  patches.suse/rcu-kvfree-Make-fill-page-cache-start-from-krcp-nr_bkv_objs.patch
  patches.suse/rcu-kvfree-Use-consistent-krcp-when-growing-kfree_rcu-page-cache.patch
  patches.suse/rcu-s-boost_kthread_mutex-kthread_mutex.patch
  patches.suse/rcu-tree-Defer-setting-of-jiffies-during-stall-reset.patch
  patches.suse/rcu-tree-Remove-superfluous-return-from-void-call_rcu-functions.patch
  patches.suse/rcutorture-Add-test-of-RCU-CPU-stall-notifiers.patch
  patches.suse/cap_syslog-remove-CAP_SYS_ADMIN-when-dmesg_restrict.patch
  patches.suse/consoles-use-if-instead-of-switch-case-in-consw-con_cursor.patch
  patches.suse/crash-split-vmcoreinfo-exporting-code-out-from-crash_core.c.patch
  patches.suse/don-t-pass-vc-vc_par-0-to-csi_-handlers.patch
  patches.suse/kexec-split-crashkernel-reservation-code-out-from-crash_core.c.patch
  patches.suse/printk-export-symbols-for-debug-modules.patch
  patches.suse/printk-Fail-pr_flush-if-before-SYSTEM_SCHEDULING.patch
  patches.suse/printk-Flush-console-on-unregister_console.patch
  patches.suse/printk-Implement-legacy-printer-kthread-for-PREEMPT_RT.patch
  patches.suse/printk-nbcon-Add-context-to-usable-and-emit.patch
  patches.suse/printk-nbcon-Add-function-for-printers-to-reacquire-ownership.patch
  patches.suse/printk-nbcon-Assign-nice-20-for-printing-threads.patch
  patches.suse/printk-nbcon-Init-nbcon_seq-to-highest-possible.patch
  patches.suse/printk-nbcon-Introduce-printer-kthreads.patch
  patches.suse/printk-nbcon-Relocate-nbcon_atomic_emit_one.patch
  patches.suse/printk-nbcon-Rely-on-kthreads-for-normal-operation.patch
  patches.suse/printk-nbcon-Use-thread-callback-if-in-task-context-for-legacy.patch
  patches.suse/proc-Add-nbcon-support-for-proc-consoles.patch
  patches.suse/proc-consoles-Add-notation-to-c_start-c_stop.patch
  patches.suse/Revert-printk-export-symbols-for-debug-modules.patch
  patches.suse/sysctl-treewide-constify-the-ctl_table-argument-of-proc_handlers.patch
  patches.suse/tty-Restrict-access-to-TIOCLINUX-copy-and-paste-subcommands.patch
  patches.suse/tty-stop-using-ndash-in-kernel-doc.patch
  patches.suse/tty-sysfs-Add-nbcon-support-for-active.patch
  patches.suse/tty-vt-add-con_putc-helper.patch
  patches.suse/tty-vt-change-consw-con_set_origin-return-type.patch
  patches.suse/tty-vt-define-a-common-enum-for-VESA-blanking-constants.patch
  patches.suse/tty-vt-define-an-enum-for-ascii-characters.patch
  patches.suse/tty-vt-define-an-enum-for-CSI-J-codes.patch
  patches.suse/tty-vt-define-an-enum-for-CSI-K-codes.patch
  patches.suse/tty-vt-define-an-enum-for-CSI-m-codes.patch
  patches.suse/tty-vt-document-the-rest-of-struct-consw.patch
  patches.suse/tty-vt-eliminate-unneeded-consw-con_putc-implementations.patch
  patches.suse/tty-vt-expect-valid-vc-when-in-tty-ops.patch
  patches.suse/tty-vt-fix-up-kernel-doc.patch
  patches.suse/tty-vt-make-consw-con_debug_-return-void.patch
  patches.suse/tty-vt-make-consw-con_font_default-s-name-const.patch
  patches.suse/tty-vt-make-consw-con_switch-return-a-bool.patch
  patches.suse/tty-vt-make-font-of-consw-con_font_set-const.patch
  patches.suse/tty-vt-make-init-parameter-of-consw-con_init-a-bool.patch
  patches.suse/tty-vt-make-types-around-consw-con_blank-bool.patch
  patches.suse/tty-vt-make-vtconsole_class-constant.patch
  patches.suse/tty-vt-pass-proper-pointers-from-tioclinux.patch
  patches.suse/tty-vt-pass-vc_resize_user-as-a-parameter.patch
  patches.suse/tty-vt-push-console-lock-from-tioclinux-down-to-2-functions.patch
  patches.suse/tty-vt-reflow-csi_J.patch
  patches.suse/tty-vt-reflow-csi_K.patch
  patches.suse/tty-vt-remove-checks-for-count-in-consw-con_clear-implementations.patch
  patches.suse/tty-vt-remove-CM_-constants.patch
  patches.suse/tty-vt-remove-consw-con_getxy.patch
  patches.suse/tty-vt-remove-consw-con_screen_pos.patch
  patches.suse/tty-vt-Remove-some-repetitive-initialization.patch
  patches.suse/tty-vt-remove-unused-consw-con_flush_scrollback.patch
  patches.suse/tty-vt-sanitize-arguments-of-consw-con_clear.patch
  patches.suse/tty-vt-sanitize-consw-con_putc-parameters.patch
  patches.suse/tty-vt-sanitize-consw-con_putcs-parameters.patch
  patches.suse/tty-vt-stop-using-1-for-blank-mode-in-consw-con_blank.patch
  patches.suse/tty-vt-use-case-ranges-for-CSI-m-fg-bg-colors.patch
  patches.suse/tty-vt-use-enum-constants-for-VESA-blanking-modes.patch
  patches.suse/tty-vt-use-VESA-blanking-constants.patch
  patches.suse/use-clamp-for-counts-in-csi_-handlers.patch
  patches.suse/vt-remove-superfluous-CONFIG_HW_CONSOLE.patch
  patches.suse/kfifo-drop-__kfifo_dma_out_finish_r.patch
  patches.suse/kfifo-introduce-and-use-kfifo_skip_count.patch
  patches.suse/kernel.h-Move-ARRAY_SIZE-to-a-separate-header.patch
  patches.suse/kfifo-add-kfifo_dma_out_prepare_mapped.patch
  patches.suse/kfifo-add-kfifo_out_linear-_ptr.patch
  patches.suse/kfifo-fix-typos-in-kernel-doc.patch
  patches.suse/kfifo-pass-offset-to-setup_sgl_buf-instead-of-a-pointer.patch
  patches.suse/kfifo-remove-support-for-physically-non-contiguous-memory.patch
  patches.suse/kfifo-rename-l-to-len_to_end-in-setup_sgl.patch
  patches.suse/compiler_types-Introduce-the-Clang-__preserve_most-function-attribute.patch
  patches.suse/extract-and-use-FILE_LINE-macro.patch
  patches.suse/fortify-Use-const-variables-for-__member_size-tracking.patch
  patches.suse/fortify-strcat-Move-definition-to-use-fortified-strlcat.patch
  patches.suse/fortify-strscpy-Fix-flipped-q-and-p-docstring-typo.patch
  patches.suse/string-Remove-strlcpy.patch
  patches.suse/string-use-__builtin_memcpy-in-strlcpy-strlcat.patch
  patches.suse/um-Remove-strlcpy-declaration.patch
  patches.suse/uml-Replace-strlcpy-with-strscpy.patch
  patches.suse/rcu-Add-data-structures-for-synchronize_rcu.patch
  patches.suse/rcu-Remove-full-memory-barrier-on-boot-time-eqs-sanity-check.patch
  patches.suse/rcu-Remove-full-ordering-on-second-EQS-snapshot.patch
  patches.suse/rcu-Remove-superfluous-full-memory-barrier-upon-first-EQS-snapshot.patch
  patches.suse/overflow-Change-DEFINE_FLEX-to-take-__counted_by-member.patch
  patches.suse/ice-make-ice_vsi_cfg_rxq-static.patch
  patches.suse/ice-make-ice_vsi_cfg_txq-static.patch
- Replace with mainline patch
  patches.suse/printk-nbcon-Clarify-rules-of-the-owner-waiter-matching.patch
  patches.suse/printk-Properly-deal-with-nbcon-consoles-on-seq-init.patch.
  patches.suse/printk-Check-printk_deferred_enter-_exit-usage.patch
  patches.suse/printk-nbcon-Remove-return-value-for-write_atomic.patch
  patches.suse/printk-nbcon-Add-detailed-doc-for-write_atomic.patch
  patches.suse/printk-nbcon-Add-callbacks-to-synchronize-with-driver.patch
  patches.suse/printk-nbcon-Use-driver-synchronization-while-un-registering.patch
  patches.suse/serial-core-Provide-low-level-functions-to-lock-port.patch
  patches.suse/serial-core-Introduce-wrapper-to-set-uart_port-cons.patch
  patches.suse/console-Improve-console_srcu_read_flags-comments.patch
  patches.suse/printk-nbcon-Do-not-rely-on-proxy-headers.patch
  patches.suse/printk-Make-console_is_usable-available-to-nbcon.patch
  patches.suse/panic-Mark-emergency-section-in-oops.patch
  patches.suse/panic-Mark-emergency-section-in-warn.patch
  patches.suse/printk-Add-flags-argument-for-console_is_usable.patch
  patches.suse/printk-Avoid-console_lock-dance-if-no-legacy-or-boot-consoles.patch
  patches.suse/printk-Coordinate-direct-printing-in-panic.patch
  patches.suse/printk-nbcon-Add-helper-to-assign-priority-based-on-CPU-state.patch
  patches.suse/printk-nbcon-Add-unsafe-flushing-on-panic.patch
  patches.suse/printk-nbcon-Clarify-rules-of-the-owner-waiter-matching.patch
  patches.suse/printk-nbcon-Do-not-rely-on-proxy-headers.patch
  patches.suse/printk-nbcon-Implement-emergency-sections.patch
  patches.suse/printk-nbcon-Provide-function-to-flush-using-write_atomic.patch
  patches.suse/printk-nbcon-Use-nbcon-consoles-in-console_flush_all.patch
  patches.suse/printk-Track-nbcon-consoles.patch
  patches.suse/printk-Track-registered-boot-consoles.patch
  patches.suse/serial-8250_omap-Implementation-of-Errata-i2310.patch
  patches.suse/serial-core-Use-port-lock-wrappers.patch
  patches.suse/serial-sc16is7xx-change-EFR-lock-to-operate-on-each-.patch
  patches.suse/serial-sc16is7xx-fix-bug-in-sc16is7xx_set_baud-when-.patch
  patches.suse/serial-sc16is7xx-fix-invalid-FIFO-access-with-specia.patch
  patches.suse/serial-sc16is7xx-fix-invalid-sc16is7xx_lines-bitfiel.patch
  patches.suse/serial-sc16is7xx-fix-TX-fifo-corruption.patch
  patches.suse/serial-sc16is7xx-improve-regmap-debugfs-by-using-one.patch
  patches.suse/serial-sc16is7xx-remove-global-regmap-from-struct-sc.patch
  patches.suse/tty-add-the-option-to-have-a-tty-reject-a-new-ldisc.patch
  patches.suse/serial-8250-omap-Cleanup-on-error-in-request_irq.patch
  patches.suse/rcu-Reduce-synchronize_rcu-latency.patch
  patches.suse/rcu-Standardize-explicit-CPU-hotplug-calls.patch
  patches.suse/printk-Avoid-false-positive-lockdep-report-for-legacy-printing.patch
  patches.suse/printk-nbcon-Show-replay-message-on-takeover.patch
  patches.suse/printk-Provide-helper-for-message-prepending.patch
  patches.suse/overflow-add-DEFINE_FLEX-for-on-stack-allocs.patch
- commit c63b672
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 46 (Chromaticity For Narrow Gamut (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cacf3c4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 45 (eDP BFI) contents (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a4e3ee6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 28 (EFP DTD) contents (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e1d9695
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 26 (TV Options) contents (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4d9caae
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 25 (SDVO LVDS PPS) contents (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3e0a74e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 24 (SDVO LVDS PnP ID) contents (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3e1c36
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 21 (EFP List) contents (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 847e522
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 20 (OEM Customizable Modes) contents (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d34351b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT blocks 19,30,32 (Display Configuration (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f14747d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT blocks 16,29,31 (Toggle List) contents (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 523f88c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 18 (Driver Rotation) contents (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b31fbe8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 17 (SV Test Functions) contents (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 73f39b1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define ALM only VBT block 9 contents (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b585826
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 15 (Dot Clock Override Table) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ca30867
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 12 (Driver Persistent Algorithm) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4705898
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 10 (Mode Removal Table) contents (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b06c196
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT blocks 6,7,8 (register tables) contents (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e7e28f2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 5 (Generic Mode Table) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 881155b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 4 (Mode Support List) contents (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9c29fe9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define VBT block 3 (Display Toggle Option) contents (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 646d7a6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Add version notes for some blocks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fca2a4f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Flag "VBIOS only" VBT data blocks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7c623a8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define "TV" child device handle (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2696cf0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Rename SDVO DTD blocks a bit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a110cbf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Get rid of "LVDS" from all LFP data stuff (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 696b9c9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Indicate which VBT structures are based on EDID (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 34e4266
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Remove version number comment from DEVICE_HANDLE_EFP4 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e62186d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bios: Define eDP DSC disable bit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5db765a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PORT_DFT2_G4X (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 710acb9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPE_CRC_* (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2b1f18b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPE_CRC_CTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5727b73
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PORT_ALPM_LFPS_CTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4c3c124
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PORT_ALPM_CTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4300a61
* Thu Oct 31 2024 pjakobsson@suse.de
- FIXME drm/i915: pass dev_priv explicitly to ALPM_CTL2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c4399fc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to ALPM_CTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2fed277
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPE_SRCSZ_ERLY_TPT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 57572a2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PSR2_MAN_TRK_CTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ca1fb60
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PSR2_SU_STATUS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit feba696
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to EDP_PSR2_STATUS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6745a65
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PSR_EVENT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7a2e37f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to EDP_PSR2_CTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit af4575a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to EDP_PSR_DEBUG (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 98df993
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to EDP_PSR_PERF_CNT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4299624
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to EDP_PSR_STATUS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dddaf95
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to EDP_PSR_AUX_DATA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 443ee8b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to EDP_PSR_AUX_CTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb8a9d8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_PSR_IIR (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8d6076e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_PSR_IMR (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 63c1555
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to EDP_PSR_CTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5a38536
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to TRANS_EXITLINE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cfdcf20
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/bmg: Enable the display support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a79add9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: perform transient flush (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8f96102
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/device: implement transient flush (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3213a8b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/gt_print: add xe_gt_err_once() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c13e44c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/xe2hpd: Set maximum DP rate to UHBR13.5 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 676b5fa
* Thu Oct 31 2024 pjakobsson@suse.de
- Revert "drm/i915/dgfx: DGFX uses direct VBT pin mapping" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3fcce77
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bmg: BMG should re-use MTL's south display logic (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 82161eb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/xe2hpd: Do not program MBUS_DBOX BW credits (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a30a5a7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/xe2hpd: Add max memory bandwidth algorithm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a998536
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/xe2hpd: Configure CHICKEN_MISC_2 before enabling planes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 203c5eb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/xe2hpd: Add display info (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1c11f13
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/xe2hpd: update pll values in sync with Bspec (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 478b7d1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/xe2hpd: Add support for eDP PLL configuration (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e33fcc9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/xe2hpd: Add new C20 PHY SRAM address (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 115ead1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/xe2hpd: Properly disable power in port A (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 35c1d94
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bmg: Extend DG2 tc check to future (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1572531
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/xe2hpd: Initial cdclk table (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5300aac
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bmg: Define IS_BATTLEMAGE macro (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 94119a2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/bmg: Lane reversal requires writes to both context lanes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f1155a1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: Calculate crtc clock rate based on PLL parameters (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4b3c46f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: s/need_async_flip_disable_wa/need_async_flip_toggle_wa/ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4c9c0a8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Eliminate extra frame from skl-glk sync->async flip change (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 67188ce
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Allow the initial async flip to change modifier (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e2ccdb5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Reject async flips if we need to change DDB/watermarks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 80839be
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Align PLANE_SURF to 16k on ADL for async flips (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5635045
* Thu Oct 31 2024 pjakobsson@suse.de
- dma-buf/heaps: Correct the types of fd_flags and heap_flags (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2d209ea
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panfrost: Add support for Mali on the MT8188 SoC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e1fc3c6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: bridge: simple-bridge: use devm_drm_bridge_add in probe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 99f54c1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panic: depends on !VT_CONSOLE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7fc97c0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: Add DRM_MODE_TV_MODE_MONOCHROME (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2ee8f20
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tidss: Add drm_panic support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9d3d323
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/nouveau: Constify struct nouveau_job_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6e7ecfd
* Thu Oct 31 2024 pjakobsson@suse.de
- nouveau: rip out busy fence waits (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e8fb6b2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ci: add tests on vkms (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8bc4335
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: zynqmp_dp: Don't delay work (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 296cec7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: zynqmp_dp: Rearrange zynqmp_dp for better padding (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1262e16
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: xlnx: zynqmp_dpsub: Enable plane in atomic update (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 20216cb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ci: mark kms_addfb_basic@addfb25-bad-modifier as passing on msm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 403713f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel-edp: drop several legacy panels (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ea6126d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel-edp: add fat warning against adding new panel compatibles (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 64f7d83
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Remove unused ivpu_rpm_get_if_active() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6782584
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Remove duplicated debug messages (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0274c42
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Increase autosuspend delay to 100ms on 40xx (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e6834c7
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Synchronize device unbind with recovery work (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 89bb29f
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Disable MMU before checking for idle (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4248d22
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Add test mode flag for disabling timeouts (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ebd8ab
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Make parts of FW image read-only (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 579ec8d
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Update FW BOOT API headers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 49e9477
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Make selected params read-only (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b7192b3
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Implement DCT handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 04ce0f6
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Disable clock relinquish for MMIO reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 53e924b
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Disable disable_clock_relinquish WA for LNL B0+ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e61bd0a
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Remove suspend_reschedule_counter (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f80157e
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Abort jobs of faulty context (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d3eed4c
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Add wp0_during_power_up WA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f11912
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: sii902x: Add pixel clock check in atomic_check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7963fc9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: sii902x: Support atomic bridge APIs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ccc176b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: sii902x: Fix mode_valid hook (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0f89770
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/connector: hdmi: Fix kerneldoc warnings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 865cbfd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mgag200: Set .detect_ctx() and enable connector polling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a935537
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mgag200: Add BMC output (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e385725
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mgag200: Consolidate VGA output (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa90f8e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: himax-hx83102: fix incorrect argument to mipi_dsi_msleep (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 95cfcfb
* Thu Oct 31 2024 mgorman@suse.de
- Delete
  patches.suse/sched-rt-Don-t-try-push-tasks-if-there-are-none.patch.
- commit c389ea4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mipi-dsi: fix handling of ctx in mipi_dsi_msleep (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a400b27
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge-connector: implement glue code for HDMI connector (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4a8def9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge-connector: switch to using drmm allocations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b18f94
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/connector: hdmi: allow disabling Audio Infoframe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ae221b3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: Update TODO list item for cleaning up prepared/enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f305a7d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: raydium-rm67191: Don't call unprepare+disable at shutdown (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d7fc24
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: raydium-rm67191: Stop tracking enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0a90426
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: sharp-ls043t1le01: Don't call disable at shutdown/remove (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aaf6e37
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: sharp-ls043t1le01: Stop tracking prepared (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0b4cf5a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: sharp-lq101r1sx01: Don't call disable at shutdown/remove (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 479a93b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: sharp-lq101r1sx01: Stop tracking prepared/enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fcb12f9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: seiko-43wvf1g: Don't call disable at shutdown/remove (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 94d6943
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: seiko-43wvf1g: Stop tracking prepared/enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 59c96a4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: panasonic-vvx10f034n00: Don't call disable at (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit baf5fa7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: panasonic-vvx10f034n00: Stop tracking prepared/enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 35d50a2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: jdi-lt070me05000: Don't call disable at shutdown/remove (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f642649
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: jdi-lt070me05000: Stop tracking prepared/enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f89450a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: tdo-tl070wsh30: Don't call unprepare+disable at (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7bf8808
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: tdo-tl070wsh30: Stop tracking prepared (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bfef126
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: osd-osd101t2587-53ts: Don't call unprepare+disable at (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 29f8866
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: osd-osd101t2587-53ts: Stop tracking prepared/enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 70cd8b7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: olimex-lcd-olinuxino: Don't call unprepare+disable at (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 05be547
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: olimex-lcd-olinuxino: Stop tracking prepared/enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6c94a67
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: khadas-ts050: Don't call unprepare+disable at (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1c780d2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: khadas-ts050: Stop tracking prepared/enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 737d905
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: boe-himax8279d: Don't call unprepare+disable at (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b94387a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: boe-himax8279d: Stop tracking prepared/enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4636952
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: it6505: update usleep_range for RC circuit charge time (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9b66e7b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: samsung-dsim: Fix porch calcalcuation rounding (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb6d83e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: tc358767: Fix comment in tc_edp_mode_valid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a04d054
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: Drop drm_bridge_chain_mode_fixup (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 98bd675
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mediatek: Drop chain_mode_fixup call in mode_valid() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 30cc656
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panic: Add a kmsg panic screen (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9de4e7f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panic: Add a set_pixel() callback to drm_scanout_buffer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4281170
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panic: only draw the foreground color in drm_panic_blit() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 94b4c80
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/sun4i: Fix layer zpos change/atomic modesetting (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 52603e0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/sun4i: Add more parameters to sunxi_engine commit callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cd1882c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/sun4i: Unify sun8i_*_layer structs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0f947ac
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: add missing MODULE_DESCRIPTION() macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e7354a6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: add missing MODULE_DESCRIPTION() macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 388f83a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tiny: add missing MODULE_DESCRIPTION() macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 82e5982
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: add missing MODULE_DESCRIPTION() macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 44fe48e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tests: add missing MODULE_DESCRIPTION() macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d39061f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tiny: panel-mipi-dbi: Support the pixel format property (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 956bcad
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mipi-dbi: Add support for DRM_FORMAT_RGB888 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 59f71ff
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mipi-dbi: Make bits per word configurable for pixel transfers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit caf0053
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mipi-dbi: Remove mipi_dbi_machine_little_endian() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 97bae96
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915: Don't use __func__ as prefix for drm_dbg_printer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9c6cd72
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/print: Improve drm_dbg_printer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cc53ed6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/print: Add generic drm dev printk function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6016d06
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/print: Kill ___drm_dbg() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d011e54
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/print: Add missing [drm] prefix to drm based WARN (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ee2aea2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: simple: Add PrimeView PM070WL4 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d56376b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ci: update xfails for the new testlist (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0d7d97e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ci: skip driver specific tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9e7c6b1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ci: uprev IGT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bea704d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ci: generate testlist from build (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f48b12
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ci: add farm variable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 803edfd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ci: uprev mesa version (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 19f18b4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mm: Remove unused drm_mm_replace_node (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2d21974
* Thu Oct 31 2024 pjakobsson@suse.de
- dma-buf: align fd_flags and heap_flags with dma_heap_allocation_data (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 23f59a5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/v3d: Fix perfmon build error/warning (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aa09af4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: analogix_dp: don't adjust further when clock recovery (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bdeecaa
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: analogix_dp: simplify (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 33ee44a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: panel: nv3052c: Add WL-355608-A8 panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 12c82fc
* Thu Oct 31 2024 pjakobsson@suse.de
- dma-buf: add a warning when drv try to reserve 0 fence slots (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 83a03af
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ci: validate drm/msm XML register files against schema (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c4ec5b0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: atmel-hlcdc: add LCD controller layer definition for sam9x75 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f853fed
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: atmel-hlcdc: add support for DSI output formats (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9f89c59
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: atmel-hlcdc: add vertical and horizontal scaling support for (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6aaf93c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: atmel-hlcdc: add DPI mode support for XLCDC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0ebdc2a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: atmel_hlcdc: Add support for XLCDC using IP specific driver ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 09e934f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: atmel_hlcdc: replace regmap_read with regmap_read_poll_timeout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d74b353
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: atmel-hlcdc: Define XLCDC specific registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8730e4e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: atmel-hlcdc: add driver ops to differentiate HLCDC and XLCDC IP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 83d8572
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/display: Fix HDMI state helper dependency (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1c1ee4b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/sun4i: Fix compilation error (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5ea9547
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel-edp: Add more panels with conservative timings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2a3f2a6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel-edp: Add support for several panels (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d3b1330
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: sony-acx565akm: Don't call disable at remove (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 27a7c5b
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/device: Remove optimization in ib_device_get_netdev() (jsc#PED-11232)
- commit 1805fe1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: sony-acx565akm: Don't double-check enabled state in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b8bf6af
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: sitronix-st7703: Don't call disable at shutdown/remove (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3efb077
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: sitronix-st7703: Stop tracking prepared (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe0c4c2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: xinpeng-xpp055c272: Don't call unprepare+disable at (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2f2c3ad
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: xinpeng-xpp055c272: Stop tracking prepared (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c5914e4
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/mad: Simplify an alloc_ordered_workqueue() invocation (jsc#PED-11232)
- commit 8ecd593
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: simple: Add a comment about unprepare+disable at (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9aed59e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: simple: Stop tracking prepared/enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0715e1e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: samsung-atna33xc20: Don't call unprepare+disable at (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 114f6d6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: samsung-atna33xc20: Stop tracking prepared/enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0c20dcd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: novatek-nt36672a: Don't call unprepare+disable at (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9313eb4
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/umem: Introduce an option to revoke DMABUF umem (jsc#PED-11232)
- commit 1fd80cd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: novatek-nt36672a: Stop tracking prepared (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 20b9d7f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: ltk500hd1829: Don't call unprepare+disable at (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d212ed0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: ltk500hd1829: Stop tracking prepared (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6d2a87a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: ltk050h3146w: Don't call unprepare+disable at (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 81fc068
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: ltk050h3146w: Stop tracking prepared (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2a8fbb9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: kingdisplay-kd097d04: Don't call unprepare+disable at (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3e9cd23
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: kingdisplay-kd097d04: Stop tracking prepared/enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 67fdc4f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: innolux-p079zca: Don't call unprepare+disable at (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 117b4ad
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: innolux-p079zca: Stop tracking prepared/enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3c733b0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: edp: Add a comment about unprepare+disable at (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 37ad03c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: edp: Stop tracking prepared/enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 13032f1
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/umem: Add support for creating pinned DMABUF umem with a given dma device (jsc#PED-11232)
- commit 71e8066
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: boe-tv101wum-nl6: Don't call unprepare+disable at (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2c25158
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: boe-tv101wum-nl6: Stop tracking prepared (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ecfc599
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: raydium-rm692e5: Stop tracking prepared (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 604da4b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/sti: Allow build with COMPILE_TEST=y (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d2e2a73
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/sti: Include linux/io.h for devm_ioremap() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 762f247
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/dp: Fix documentation warning (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6196894
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/rockchip: dsi: Add support for RK3128 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7ab9600
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/sun4i: hdmi: Switch to HDMI connector (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e0838fd
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/nldev: Enhance netlink message parsing and validation (jsc#PED-11232)
- commit ced5b08
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Switch to HDMI connector (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ec717b0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/vc4: tests: Convert to plane creation helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dc1a43e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/vc4: tests: Remove vc4_dummy_plane structure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2e59288
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/connector: hdmi: Create Infoframe DebugFS entries (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c474528
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tests: Add infoframes test (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f89d9e2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/connector: hdmi: Add Infoframes generation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 68f47e5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tests: Add RGB Quantization tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cc48d26
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/connector: hdmi: Add RGB Quantization Range to the connector (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 88b3e32
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tests: Add tests for Broadcast RGB property (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4a6866a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/connector: hdmi: Add Broadcast RGB property (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit 66de86d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/doc: Remove unused Broadcast RGB Property (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7ef51b1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tests: Add HDMI connector bpc and format tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 47f3f8e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/connector: hdmi: Compute bpc and format automatically (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 872a307
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tests: Add HDMI connector rate filter hook tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5807fde
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/connector: hdmi: Add custom hook to filter TMDS character rate (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb31084
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tests: Add TDMS character rate connector state tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e986831
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/connector: hdmi: Calculate TMDS character rate (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 945d79c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tests: Add HDMI TDMS character rate tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d659614
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/display: hdmi: Add HDMI compute clock helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fd7f95b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tests: Add output formats tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0b3cdfe
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/connector: hdmi: Add support for output format (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit acf08ad
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tests: Add output bpc tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f0cf410
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mode_object: Export drm_mode_obj_find_prop_id for tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ed24a5e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/connector: hdmi: Add output BPC to the connector state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e135b5b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/connector: hdmi: Create an HDMI sub-state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1a844e2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tests: connector: Add tests for drmm_connector_hdmi_init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 68f3aca
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/connector: Introduce an HDMI connector initialization function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a2a1399
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/imx/ldb: convert to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 186b0e1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/imx/tve: convert to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a4120f9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/loongson/7a2000: convert to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ec84d35
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/loongson/7a1000: convert to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fec7887
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/hisilicon/hibmc: convert to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d758bab
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: analogix_dp: convert to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3fd26a7
* Thu Oct 31 2024 pjakobsson@suse.de
- dma-buf/fence-array: Add flex array to struct dma_fence_array (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 63e079c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/connector: update edid_blob_ptr documentation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f71c662
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/edid: add a helper for EDID sysfs property show (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7f7d1ee
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: remove amdgpu_connector_edid() and stop using (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b28e26a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/radeon: remove radeon_connector_edid() and stop using (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd40bf5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/radeon: convert to using is_hdmi and has_audio from display info (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c2adbc1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/nouveau: convert to using is_hdmi and has_audio from display info (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4aaf464
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel-edp: Add CMN N116BCJ-EAK (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a4e4c9e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: it6505: fix hibernate to resume no display issue (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0d27d68
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/probe-helper: Call drm_mode_validate_ycbcr420() before (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e5e169d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: tc358767: Enable FRMSYNC timing generator (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 50b95ad
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: himax-hx83102: use wrapped MIPI DCS functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 72c0408
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: himax-hx83102: Check for errors on the NOP in prepare() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7d3354c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: himax-hx83102: If prepare fails, disable GPIO before (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0c750b9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mgag200: Add an option to disable Write-Combine (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 17b4dc8
* Thu Oct 31 2024 pjakobsson@suse.de
- Revert "drm/mgag200: Add a workaround for low-latency" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 29236d9
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/nldev: Add support to dump device type and parent device if exists (jsc#PED-11232)
- commit a9b9f62
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/v3d: Deprecate the use of the Performance Counters enum (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0d5ffc2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/v3d: Use V3D_MAX_COUNTERS instead of V3D_PERFCNT_NUM (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aea8df1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/v3d: Create new IOCTL to expose performance counters information (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 02813e9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/v3d: Create a new V3D parameter for the maximum number of perfcnt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f09f306
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/v3d: Different V3D versions can have different number of perfcnt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5b23773
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/v3d: Add Performance Counters descriptions for V3D 4.2 and 7.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c86362e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: lg-sw43408: use new streamlined MIPI DSI API (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f33852
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: novatek-nt36672e: use wrapped MIPI DCS functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9c44859
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: innolux-p079zca: use mipi_dsi_dcs_nop_multi() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3ec715
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: ilitek-ili9882t: use wrapped MIPI DCS functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 09fc993
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: boe-tv101wum-nl6: use wrapped MIPI DCS functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b37dc2d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mipi-dsi: wrap more functions for streamline handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 739f42c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: lg-sw43408: add missing error handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f149cd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mgag200: Use drm_connector_helper_get_modes() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dcc0047
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mgag200: Acquire I/O-register lock in DDC code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 03c0a49
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mgag200: Rename struct i2c_algo_bit_data callbacks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 989d1ce
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mgag200: Rename mgag200_i2c.c to mgag200_ddc.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e20fe2f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mgag200: Replace struct mga_i2c_chan with struct mgag200_ddc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 38b1ed3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mgag200: Inline mgag200_i2c_init() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 51a5d13
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mgag200: Allocate instance of struct mga_i2c_chan dynamically (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 37125c6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mgag200: Store pointer to struct mga_device in struct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d2f94bb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: himax-hx83102: Support for IVO t109nw41 MIPI-DSI panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c40dbb7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: himax-hx83102: Support for BOE nv110wum-l60 MIPI-DSI panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 256dc90
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Replace wake_thread with kfifo (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5981f4e
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Split IP and buttress code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e106310
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Split IP and buttress headers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8c1f1ee
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: simple: Add Microtips Technology MF-103HIEB0GA0 panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5089757
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: simple: Add Microtips Technology 13-101HIEBCAF0-C panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1c356a1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: simple: Add Lincoln Tech Sol LCD185-101CT panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ad9f86a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: innolux-p079zca: Don't use a table for initting panels (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0106d20
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: ili9882t: Don't use a table for initting panels (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 15793d1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: boe-tv101wum-nl6: Don't use a table for initting panels (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2802f17
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: novatek-nt36672e: Switch to mipi_dsi_dcs_write_seq_multi() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dbd5893
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mipi-dsi: Introduce mipi_dsi_*_write_seq_multi() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a24b283
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mipi-dsi: Reduce driver bloat of mipi_dsi_*_write_seq() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 53cf322
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mipi-dsi: mipi_dsi_*_write functions don't need to ratelimit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b380be4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/fbdev-shmem: Clean up deferred I/O (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cbd92c4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/fbdev-dma: Clean up deferred I/O (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9240794
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Share NPU busy time in sysfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aa1f753
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Increase reset counter when warm boot fails (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 580b82b
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Configure fw logging using debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2ddb3eb
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Add force snoop module parameter (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c72f352
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Add NPU profiling support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ad947c0
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Add resume engine support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2f3b527
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Implement support for hardware scheduler (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 50b5a08
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Add HWS JSM messages (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7abce02
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Implement support for preemption buffers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8107ebd
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Create priority based command queues (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 33878d9
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Add sched_mode module param (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 37499fe
* Thu Oct 31 2024 pjakobsson@suse.de
- accel/ivpu: Update VPU FW API headers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b6f658d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/edid: remove drm_do_get_edid() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 39b12da
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/virtio: switch to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f4a564
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bochs: switch to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3a92fb1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i2c: tda998x: switch to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a7959f1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: anx7625: use struct drm_edid more (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f9dc798
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge/analogix/anx78xx: switch to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 350470f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge/analogix/anx6345: switch to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7310c8f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: analogix: Remove redundant checks on existence of (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6344f2a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: imx: Remove redundant checks on existence of (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 59989fe
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: lt9611uxc: Remove a redundant check on existence of (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b5a136a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: synopsys: dw-mipi-dsi: Remove a redundant check on (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5e9875b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: megachips-stdpxxxx-ge-b850v3-fw: Remove a redundant check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7100048
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: cdns-mhdp8546: Remove a redundant check on existence of (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b5bb73a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: adv7511: Remove a redundant check on existence of (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5c04b48
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: it6505: Remove a redundant check on existence of (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2fa31c7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: panel: Remove a redundant check on existence of (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 18146ba
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: nxp-ptn3460: Remove a redundant check on existence of (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 15a76d2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: tfp410: Remove a redundant check on existence of (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 613d6a4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: simple-bridge: Remove a redundant check on existence of (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5c3c7d1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/udl: Remove struct udl_connector (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 32fd534
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/udl: Untangle .get_modes() and .detect_ctx() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 880e3de
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/udl: Clean up Makefile (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0cb8863
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/udl: Move drm_dev_{enter, exit}() into udl_get_edid_block() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 69945e0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: use "0" instead of "" for deprecated driver date (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2b7c52c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/arm/komeda: update DMA mask to 40 bits (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ffc8ee5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/arm/komeda: Move pipeline prints to after the entire pipeline has (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 793a225
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/arm/komeda: don't use confusing 'timeout' variable name (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2e4258c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/stm: Allow build with COMPILE_TEST=y (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8a98a24
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/rcar-du: Allow build with COMPILE_TEST=y (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2ade557
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/atmel-hlcdc: Allow build with COMPILE_TEST=y (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f79380d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/omap: Allow build with COMPILE_TEST=y (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 156dee7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/omap: Open code phys_to_page() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a6f1510
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/hisilicon/kirin: Allow build with COMPILE_TEST=y (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a022c69
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/hisilicon/kirin: Fix MASK(32) on 32bit architectures (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ee9de95
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/hisilicon/kirin: Fix 64bit divisions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3c962db
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/hisilicon/kirin: Include linux/io.h for readl()/writel() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 03ddd0e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Use drm_crtc_vblank_crtc() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 30922fa
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: deprecate driver date (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c41756c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/uapi: Move drm_color_ctm_3x4 out from drm_mode.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8749c44
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel-edp: Add ID for KD KD116N09-30NH-A016 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 980ff1a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/gma500: Fix spelling mistake "patter" -> "pattern" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d361349
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/fbdev: Clean up fbdev documentation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b80b703
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/fbdev-generic: Convert to fbdev-ttm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 229b287
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tiny/st7735r: Use fbdev-dma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 032175c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tiny/st7586: Use fbdev-dma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1b99a65
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tiny/repaper: Use fbdev-dma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dcabfe1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tiny/panel-mipi-dbi: Use fbdev-dma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 723d620
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tiny/mi0283qt: Use fbdev-dma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ebbecf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tiny/ili9486: Use fbdev-dma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 64ef994
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tiny/ili9341: Use fbdev-dma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3136bc4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tiny/ili9225: Use fbdev-dma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a66125d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tiny/ili9163: Use fbdev-dma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0ed9279
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tiny/hx8357d: Use fbdev-dma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9548927
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/rockchip: Use fbdev-dma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3f645d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/renesas/shmobile: Use fbdev-dma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e6c28e5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/renesas/rz-du: Use fbdev-dma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 764ffb5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/renesas/rcar-du: Use fbdev-dma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4374ad1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel/panel-ilitek-9341: Use fbdev-dma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit df156d1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mediatek: Use fbdev-dma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 375733f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ingenic: Use fbdev-dma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5d78490
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/imx/lcdc: Use fbdev-dma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0279d75
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/hisilicon/kirin: Use fbdev-dma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4b2a785
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/arm/komeda: Use fbdev-dma (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 75c0689
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/fbdev-dma: Implement damage handling and deferred I/O (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d3eeb5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/vkms: Use fbdev-shmem (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c5d3a11
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/virtio: Use fbdev-shmem (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 178a298
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/udl: Use fbdev-shmem (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 10ffb96
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tiny/simpledrm: Use fbdev-shmem (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ab9760f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tiny/ofdrm: Use fbdev-shmem (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c439a74
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tiny/gm12u320: Use fbdev-shmem (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d2083a5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tiny/cirrus: Use fbdev-shmem (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3367e16
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/solomon: Use fbdev-shmem (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ddcc2fb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/mgag200: Use fbdev-shmem (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 31edb1b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/hyperv: Use fbdev-shmem (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5727581
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/gud: Use fbdev-shmem (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bbeeea7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/ast: Use fbdev-shmem (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0c006df
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/fbdev: Add fbdev-shmem (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aff9ebf
* Thu Oct 31 2024 pjakobsson@suse.de
- fbdev/deferred-io: Provide get_page hook in struct fb_deferred_io (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d2e1ebe
* Thu Oct 31 2024 pjakobsson@suse.de
- fbdev/deferred-io: Always call get_page() for framebuffer pages (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bd2aaca
* Thu Oct 31 2024 pjakobsson@suse.de
- fbdev/deferred-io: Test smem_start for I/O memory (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4811995
* Thu Oct 31 2024 pjakobsson@suse.de
- fbdev/deferred-io: Test screen_buffer for vmalloc'ed memory (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 20e8ada
* Thu Oct 31 2024 pjakobsson@suse.de
- fbdev/deferred-io: Clean up pageref on lastclose (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d96ecef
* Thu Oct 31 2024 pjakobsson@suse.de
- fbdev/deferred-io: Move pageref setup into separate helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5e6156b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/panel: ili9341: Remove a superfluous else after return (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 323ce20
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/debugfs: Drop conditionals around of_node pointers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b902d0f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/vmwgfx: Remove duplicate vmwgfx_vkms.h header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 57e32f6
* Thu Oct 31 2024 pjakobsson@suse.de
- nouveau: Add missing break statement (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e2d7c45
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: ci: fix the xfails for apq8016 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9ac0867
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: zynqmp_dp: Adjust training values per-lane (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b95d284
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: zynqmp_dp: Downgrade log level for aux retries message (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 256e78f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: xlnx: Fix kerneldoc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5695a51
* Thu Oct 31 2024 pjakobsson@suse.de
- drm: xlnx: Store base pointers in zynqmp_disp directly (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b86eaa5
* Thu Oct 31 2024 pjakobsson@suse.de
- nouveau: add command-line GSP-RM registry support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 172af68
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tiny: st7586: drop driver owner assignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0648009
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tiny: panel-mipi-dbi: drop driver owner assignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b7985f1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tiny: mi0283qt: drop driver owner assignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 59d04b4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/tiny: ili9225: drop driver owner assignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 410bed4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add RAS is_rma flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ace573b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: remove dead code in si_convert_power_level_to_smc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 720c571
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Prevent IPX From Link Detect and Set Mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e146aa9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: remove logically dead code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5942ec0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix failure mapping legacy queue when FLR (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4149502
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fetch Mall caps from DC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b70ccd8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: fix YUV video color corruption in DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3541a69
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: add reset cause in gpu pre-reset smi event (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b8984ea
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Update soc24_enum.h and soc21_enum.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 49def3f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Set PTE_IS_PTE bit for gfx12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c59a40b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Updated optc401_set_drr to use dcn401 functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d4b179f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add reset sources in gpu reset context (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 97707ff
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add UCLK p-state support message to dcn401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9c6d4de
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Use current_state when checking old_pipe subvp type (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 331b7f6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: add missing error handling in function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d3f5215
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Update the impelmentation of AMDGPU_PTE_MTYPE_VG10 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a14737d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: remove dead code in kfd_create_vcrat_image_gpu (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3ad2004
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: fix the kdf debugger issue (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8b890f7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Comment out the unused variable use_static in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9b477f1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Move fpo_in_use to stream_status (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 288e9e3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Only program P-State force if pipe config changed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e7af3d3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add retires when read DPCD (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 652e932
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix DML2 logic to set clk state to min (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e0ff206
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Handle deallocated VPGRs in gfx11+ trap handler (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ccc24d8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Support new VA page table block size (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f13462a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: workaround for oled eDP not lighting up on DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 45932d2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add params of set_abm_event for VB Scaling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4d2ae38
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix swapped dimension calculations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8f60288
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Wait for hardmins to complete on dcn401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f768d80
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: turn on symclk for dio virtual stream in dpms (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d91961e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Keep VBios pixel rate div setting until next mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fffb418
* Thu Oct 31 2024 pjakobsson@suse.de
- Revert "drm/amdgpu/gfx11: enable gfx pipe1 hardware support" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 77ef33d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: update gc_12_0_0 headers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 77be269
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: define new gfx12 uapi flags (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 523933e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: remove dead code in the function svm_range_get_pte_flags (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e386541
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Update the impelmentation of AMDGPU_PTE_MTYPE_NV10 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 890b002
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: disable lane0 L1TLB and enable lane1 L1TLB (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3fd2e8a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: init SAW registers for mmhub v3.3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ad307c1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix a handful of spelling mistakes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 156e592
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix comments and error message for ipdump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5901d37
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: rename ip_dump_cp_queues to compute queues (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 50cf09a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add cp queue registers for gfx9 ipdump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5b89fe0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add print support for gfx9 ipdump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b357e24
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add gfx9 register support in ipdump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b713760
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Fix type mismatch in amdgpu_gfx_kiq_init_ring (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b887a12
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Update programming for boot error reporting (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d5f2d3e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/soc24: use common nbio callback to set remap offset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b69f138
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Convert some legacy DRM debug macros into (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a63459b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Estimate RAS reservation when report capacity v2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 913373f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: use u32 for buf size in __amdgpu_eeprom_xfer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7f29e83
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: gfx12 context save/restore trap handler fixes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d4ef825
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: drop some kernel messages in VCN code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 68813a2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Update the impelmentation of AMDGPU_PTE_MTYPE_GFX12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ae19a05
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: avoid large on-stack structures (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 008b263
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: fix graphics_object_id size (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e711fc1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: dynamically allocate dml2_configuration_options (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f01676
* Thu Oct 31 2024 pjakobsson@suse.de
- drivers/gpu: Fix misalignment in comment block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1a540d2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Replace deprecated gfx12 trap handler instructions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 04f4619
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Sync trap handler binary with source (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bf8c3be
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/gfx11: enable gfx pipe1 hardware support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 53386d0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/gfx11: handle priority setup for gfx pipe1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 86c09d8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/gfx11: select HDP ref/mask according to gfx ring pipe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6326cd0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Enable copying of bounding box data from VBIOS DMUB (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 50ed8a0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add new GPINT command definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8f9d81c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Move some init routines to dm_sw_init() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d130122
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add missing registers for DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a73f360
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix null pointer dereference for dcn401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 086c134
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove incorrect FP context start (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe190b5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Use DCN 410 includes for DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9db7d43
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove unnecessary HPD entry for DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2e6c49f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Update DML2.1 generated code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2d9d6c6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Refactor HUBP into component folder. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 15884e7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove unused code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7843825
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Enable ISHARP support for DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0f94b74
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix incorrect cursor position for dcn401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 789a851
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix typo in amdgpu_ras_aca_sysfs_read() function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9b58a63
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: add AMD_PG_SUPPORT_VCN_DPG flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 43eb041
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: drop MES 10.1 support v3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4fe63ff
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: clean up some inconsistent indenting (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4a0dab3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/display: Fix null pointer dereference in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7b19b87
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add gfx queue support for gfx11 ipdump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 55fdf56
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add cp queue registers for gfx11 ipdump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 268133e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Pass errors from amdgpu_dm_init() up (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d5454b7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add print support for gfx11 ipdump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 49c1e96
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add gfx11 registers support in ipdump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe12102
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add missing offsets in gc_11_0_0_offset.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit be82b05
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add more device info to the devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 53c6120
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add prints in IP State dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8512563
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add gfx queue support of gfx10 in ipdump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8fa833a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add cp queues support fro gfx10 in ipdump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b0eea16
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: rename the ip_dump to ip_dump_core (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 82eab95
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add CRC16 selection in config (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 59d6f28
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: workaround to pass jpeg unit test (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 66d9268
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: fix the inst passed to amdgpu_virt_rlcg_reg_rw (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d058de3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu - optimize rlc spm cntl (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eaa85d2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Refactor construct_phy function in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f9c745
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: program device_cntl2 through pci cfg space (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 648aaaf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Fix snprintf usage in amdgpu_gfx_kiq_init_ring (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c0cb7a3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix invadate operation for pg_flags (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e407235
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: mes hw_fini fix for mode1 reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cdcd833
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix invadate operation for umsch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8c9a5c6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: fix unsigned value asic_type compared against (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8da074f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: skip to create ras xxx_err_count node when ACA is enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 526a8d3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Fix amdgpu_vm_is_bo_always_valid kerneldoc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ae92a3b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: remove unused struct 'dc_reg_sequence' (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c9cc24e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: remove unused struct 'aux_payloads' (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 28421db
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: remove unused struct 'hqd_registers' (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d7c94a8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: enable thermal alert on smu 14.0.2/3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit af5c911
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: add thm 14.0.2 header file (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2c986cc
* Thu Oct 31 2024 pjakobsson@suse.de
- Revert "drm/amd/pm: Add gpu_metrics_v1_6" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 23eaf73
* Thu Oct 31 2024 pjakobsson@suse.de
- Documentation/amdgpu: Add PM policy documentation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c393f0f
* Thu Oct 31 2024 pjakobsson@suse.de
- Revert "drm/amd/pm: Use gpu_metrics_v1_6 for SMUv13.0.6" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d5d2641
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: Remove unused interface to set plpd (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5663abd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/swsmu: update Dpmclocks_t for smu v14.0.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4e4fb88
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Queue KFD reset workitem in VF FED (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 45bc5e7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Extend KIQ reg polling wait for VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6a60a03
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.286 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1ffb244
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix POWERPC_64 compilation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 080b3e5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Not fallback if link BW is smaller than req BW (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7de4c7f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Correct display clocks update block sequence (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b06e9c3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Disable DCN401 idle optimizations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ebeca1a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix ODM + underscan case with cursor (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3f3ebf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: fix a typo which causes an incorrect ODM combine (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4441165
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add ips status info to debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b01a5fd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Clear shared dmub firmware state on init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b2776cb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add 3DLUT DMA load trigger (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5716e4f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Deallocate DML 2.1 Memory Allocation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2574e71
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add NULL check within get_target_mpc_factor (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1c1d786
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: update driver-if interface (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3f7185e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add missing DML2 var helpers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f34711f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Modify HPO pixel clock programming to support DPM (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 81a243d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Refactor HUBBUB into component folder for DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 472f8dc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: enable EASF support for DCN40 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b7bc102
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Adjust incorrect indentations and spaces (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e1d6187
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Use the correct TMDS function to avoid DVI issues (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3a36342
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix incorrect DCN401 comparison (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 46c69f7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add missing enable and disable symclk_se functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe641ff
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove duplicate configuration (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8bd90d4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Move DSC functions from dc.c to dc_dsc.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0fb147b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix ACA no query result after gpu reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d8f0d79
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: Remove legacy interface for xgmi plpd (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 11c321f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: Add xgmi plpd to arcturus pm_policy (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d7e6792
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: change bank cache lock type to spinlock (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fafb390
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: Add xgmi plpd to aldebaran pm_policy (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7112463
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: Add xgmi plpd to SMU v13.0.6 pm_policy (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 45ac57a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: Add xgmi plpd policy to pm_policy (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1647641
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: Add support to select pstate policy (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 94ccd23
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: Update PMFW messages for SMUv13.0.6 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 79fd0f2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: Add support for DPM policies (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e60c057
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: change aca bank error lock type to spinlock (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 56d66c5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Describe all object placements in debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f7b512
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Reduce mem_type to domain double indirection (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bbad283
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add amdgpu_bo_is_vm_bo helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c2427e4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Remove duplicate check for *is_queue_unmap in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 02c41b4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/vcn: update vcn5 enc/dec capabilities (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 45426b8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: support mode1 reset on smu v14.0.3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d27224c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Remove duplicate amdgpu_umsch_mm.h header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 27f3203
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/display: Update kdoc for 'optc35_set_odm_combine' (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c545f78
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/radeon: initialize backlight for iMac12,2 with Radeon 6750M (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e70c814
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: support pp_dpm_pcie on smu v14.0.2/3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5c0724d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: add module parameter for jpeg (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c713616
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Add GFX1201 to svm_range_get_pte_flags function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2d500a7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix documentation errors in gmc v12.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 953fbfe
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Check correct memory types for is_system variable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 48c4d6a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix documentation errors in sdma v7.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 441a96d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Ensure gpu_id is unique (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fd4edfe
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix compiler 'side-effect' check issue for (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ca95c4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: disable gpo temporarily (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7127a47
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix getting vram info for gfx12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2ea8b1f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/mes: use mc address for wptr in add queue packet (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a5429d0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: add pp_dpm_dcefclk for smu 14.0.2/3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 412cb3a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: enable gfxoff for gc v12.0.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2d9bace
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: enable mmhub and athub cg on gc 12.0.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9099970
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: switch default mes to uni mes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c1f8cd8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add debug flag to enable RAS ACA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ff0826f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: enable some cg feature for gc 12.0.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0e99014
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/pm: Drop hard-code value of usTMax (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ce7cef8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Use NPS ranges from discovery table (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c0e274d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add nps info table to IP discovery (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a1c9346
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: enable gfx cgcg&cgls for gfx v12_0_0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9498833
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/jpeg5: enable power gating (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6a9385b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Drop pixel_clock_mhz (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b54f7f2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: support imu for gc 12_0_0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dfc0d0f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: Use gpu_metrics_v1_6 for SMUv13.0.6 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 526a3e8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: Add gpu_metrics_v1_6 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a8c0386
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Remove dead code in amdgpu_ras_add_mca_err_addr (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 41fe329
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Fix null pointer dereference to bo (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 04a0cec
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: fix documentation warnings for mpc.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4b930ec
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: enable unmapped doorbell handling basic mode on mes 12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 734bbdd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Use dev_error intead of pr_error (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 42dfea7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix mqd corruption for gfx12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 06f2d35
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add initial value for gfx12 AGP aperture (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8b5419e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Don't register panel_power_savings on OLED panels (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5878d05
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix the warning bad bit shift operation for (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 471ac0e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: remove logically dead code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fd99b50
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: remove structurally dead code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dba091f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: fix enum feature compared against 0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ddc4cc8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: fix enum type compared against 0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c8fd60f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgu: remove unused code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 46345c3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: remove structurally dead code for amd_gmc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3992bc0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: check the return of send smc msg for smu_v13 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1a434ca
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: check the return of send smc msg for navi10 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 62d8961
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: check the return of send smc msg for sienna_cichild (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 912b88a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd: fix the warning unchecking return vaule for sdma_v7 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8c5c502
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: clear the warning unsigned compared against 0 for xcp_id (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 96d986a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: fix get dpm level count for yello carp (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3005f5b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/pm: Drop redundant setting code for pcie lanes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0c98f09
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/pm: Fix code alignment issue (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ee23f2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: fix get dpm level count for smu13 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2659b1d
* Thu Oct 31 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Enable SYMCLK gating in DCCG" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e7aeb23
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.285 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a743bc0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Read default boot options (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 43bd0b9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Find max flickerless instant vtotal delta (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 93e7c0c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Refactor dcn401_update_clocks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4ae03e4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Reduce I2C speed to 95kHz in DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 60dfb2b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Allow higher DSC slice support for small timings on (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7905754
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Don't offload flip if not only address update (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fb69a5e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Check UHBR13.5 cap when determining max link cap (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bd9b660
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Enable SYMCLK gating in DCCG (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ce115af
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Expand to higher link rates (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eae513a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add left edge pixel for YCbCr422/420 + ODM pipe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7b99024
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add resource interfaces for get ODM slice rect (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8dfc5df
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add COEF filter types for DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aa32adb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Refactor DCN401 DCCG into component directory (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 30fb8e2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix 3dlut size for Fastloading on DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d54ef49
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix write to non-existent reg on DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3e021dd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove USBC check for DCN32 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ed3f7c6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove unused code for some dc files (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ab08729
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Disable AC/DC codepath when unnecessary (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 81f36ed
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Create dcn401_clk_mgr struct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d3c1768
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/umsch: add support to capture fw debug log (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5dded18
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: update jpeg 5 capability (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f388fc2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/vcn: set VCN5 power gating state to GATE on suspend (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 515660d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/vcn: remove irq disabling in vcn 5 suspend (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 964962e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/pm: Check input value for power profile setting on smu11, (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 94affb9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/radeon: Delay Connector detecting when HPD singals is unstable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b47eb46
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdkfd: Fix a resource leak in svm_range_validate_and_map() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 91003c0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/mes: fix mes12 to map legacy queue (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fc6ac30
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Remove arbitrary timeout for hmm_range_fault (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2fe50e0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Fix buffer size to prevent truncation in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c62412e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Fix truncation by resizing ucode_prefix in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 42c6d66
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/soc21: use common nbio callback to set remap offset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b6ecb5d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/nv: use common nbio callback to set remap offset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8658f63
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/soc15: use common nbio callback to set remap offset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ffd81e3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add set_reg_remap callback for NBIF 6.3.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit baac285
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add set_reg_remap callback for NBIO 7.7 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6fe82bd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add set_reg_remap callback for NBIO 4.3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1297d0f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add set_reg_remap callback for NBIO 2.3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 20e5c4d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add set_reg_remap callback for NBIO 7.2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2381205
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add set_reg_remap callback for NBIO 7.11 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c99a966
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add set_reg_remap callback for NBIO 7.9 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6578786
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add set_reg_remap callback for NBIO 7.4 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 41cd722
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add set_reg_remap callback for NBIO 7.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7f90687
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add set_reg_remap callback for NBIO 6.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f28d12
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add nbio set_reg_remap helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c48abe7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: change log level (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8f50388
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: enable UMD Pstate profile level for renoir (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f86bc2d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix spl component for psp v14 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bc7c9b4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix uninitialized variable warning for jpeg_v4 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0c51f0a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix RAS unload driver issue in SRIOV (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6b43d73
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: ignoring unsupported ras blocks when MCA bank dispatches (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 46ecb5f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix uninitialized variable warning for amdgpu_xgmi (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 54e6e1f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix uninitialized variable warning for sdma_v7 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 943f81e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdxcp: Fix warnings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b962dae
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/mes11: fix kiq ring ready flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 88777e1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add se registers to ip dump for gfx10 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ed2a249
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add CP headers registers to gfx10 dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1954eed
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.284 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 75ae2b3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.216.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 19c7c3c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: reset DSC clock in post unlock update (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a947a74
* Thu Oct 31 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Only program P-State force if pipe config (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 170878c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Reset input mode for DIG on encoder reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f4b2547
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Refactor HUBP into component folder. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f08128
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Clean-up recout calculation for visual confirm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7a50ccf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Enable urgent latency adjustments for DCN35 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dca036d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Refactor input mode programming for DIG FIFO (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7a0926a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Providing a mechanism to have a custom pwm frequency (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 62b81d8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add Replay capability and state in debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 83c57b2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: add support for force ODM override (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c7bbac4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: remove ip dump reg_count variable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f90fd2b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix uninitialized variables in dcn401 and dml21 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c2542f8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Assign disp_cfg_index_max when dml21 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2c4d64a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix writeback job lock evasion within (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 729c3cf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Skip plane when not found by stream id (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e1598f8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Avoid overflow dc_clk_table->entries by limit to (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 03ff2fe
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Limit array index according to architecture (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4f33906
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Limit clock assignments by size of clk tables (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e9004ad
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Release clck_src memory if clk_src_construct fails (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0434a5d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix wrong array size dummy_boolean of (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8c4cdd7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add NULL pointer check for kzalloc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fbd3cd0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add otg_master NULL check within resource_log_pipe_topology_update (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- blacklist.conf: Now applicable
- commit 7ea6550
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Release state memory if (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1dd485d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Skip updating link encoder for unknown eng_id (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3fca949
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add missing NULL pointer check within (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a21f0de
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix incorrect size calculation for loop (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022 bsc#1230704 CVE-2024-46729)
- commit ba69aa3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Stop amdgpu_dm initialize when link nums greater (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 94e6126
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add NULL pointer and OVERRUN check within amdgpu_dm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 50e88ed
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Skip accessing array for unknown eng_id (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3e04878
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Refactor DCCG into component folder (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 31e6822
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix invalid Copyright notice (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 077e775
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: add pstate support for SMU_14_0_2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dfc706c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: add tool log support on smu v14.0.2/3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 457a95b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: enable mode1 reset on smu v14.0.2/v14.0.3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2ce9a9a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: support mode1 reset on smu_v14_0_3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f40b147
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: Use a separate fence per transaction (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 576728d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: increase mes submission timeout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e56b5ba
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: print MES opcodes rather than numbers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dbd0efd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: enable mmhub and athub cg on gc 12.0.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dc8f24e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: enable gfxoff on gc 12.0.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9c1cf8a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: support cg state get for gfx v12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 60c9164
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: enable sram fgcg on gc 12.0.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 58825bd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: enable perfcounter mgcg and repeater fgcg (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 682b8b5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: enable 3D cgcg and 3D cgls (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3f1ab10
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: enable mgcg on gfx 12.0.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7326fd1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: enable cgcg and cgls (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5276d6f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/vcn5: Add VCN5 capabilities (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 90967c0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/vcn5: enable DPG mode support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2061750
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/jpeg5: enable power gating (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 88dcab3
* Thu Oct 31 2024 pjakobsson@suse.de
- amdgpu/vcn: enable AMD_PG_SUPPORT_VCN (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7c118be
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Fix physical address mask (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 659963b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/discovery: add mes v12_0 ip block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4a530eb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/discovery: add gfx v12_0 ip block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6984a08
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: disable logging output (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4a63883
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add module parameter 'amdgpu_uni_mes' (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 23f0a92
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: add legacy setting hw resource interface (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 73145ee
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Disable unmapped doorbell handling basic mode on mes 12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ee5c46
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/gfx: enable mes to map legacy queue support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 73a9cf8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: add mes mapping legacy queue support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b79613e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: enable uni_mes fw on mes pipe0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dc08864
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: add uni_mes fw loading support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3898fbf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/mes: add uni_mes fw loading support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0182587
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: mark GFX12 system and peer GPU memory mappings as (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 78f02a1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdkfd: Add GFX12 PTE flag to SVM get PTE function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0e3a15d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Enable atomic support for GFX12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 43d898e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: fix NULL ptr for debugfs mqds on GFX v12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f77e617
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: enable single alu ops for gfx12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b43b799
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: fix support for trap on wave start and end for gfx12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e676819
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: always enable ttmp setup for gfx12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a8d3609
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Enable GFX12 trap handler (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 83c8f3f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: enable missed single-step workaround for gfx12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6b3a95d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: save and restore barrier state for gfx12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9989469
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Add gfx12 trap handler support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6366434
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Move trap handler coherence flags to preprocessor (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f8d5ce
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Added gfx_v12_kfd2kgd interface for GFX12. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 820b359
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Added device queue manager files for GFX12. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit af3b88f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Added MQD manager files for GFX12. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c944745
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Added temporary changes for GFX12. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b5c10fc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Basic SDMA and cache info changes for GFX12. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7f6784b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Enable event log on MES 12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd4b79c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Enable unmapped doorbell handling basic mode on mes 12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c4cdb55
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Switch to smuio func to get gpu clk counter (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f9fa169
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: init gfxhub setting to align with mmhub (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6db3c30
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: skip dpm check to init imu fw (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 82be3fc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix active rb and cu number for gfx12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ac4f732
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: use new method to program rlc ram (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e81e83a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: add cgcg&cgls interface for gfx 12.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f3784f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: update GFX12 wave data registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7b0e8bf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: set different fw data addr for mec pipe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 95ad7b7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: workaround for the imu fw loading (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 08a787d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd: Move fw init from sw_init to early_init for imu v12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1fe9f77
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: support S&R fw load for gfx v12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 27fa1b0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/gfx12: recalculate available compute rings to use (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ff7126
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: skip imu related function if dpm=0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 78bc9e5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdgpu: imu fw loading support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8de741c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: set cp fw address set for gfx v12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ed677ff
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add gfx v12_0 ip block support (v6) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d3bca69
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/mes12: update data cache boundary (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb742ca
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: fix trap enablement for gfx12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 299ea26
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Enable MES to handle doorbell ring on unmapped queue (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9e4df04
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: enable mes v12 self test (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 78f69ac
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: set mes fw address for mes v12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d53b0e9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add mes v12_0 ip block support (v4) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1c41489
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: init mes ucode name for gfx v12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 74043ae
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add mes_v12_api_def.h for gfx12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1f18802
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add rlc TOC header file for soc24 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 33716ae
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add new TOC structure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9904d75
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add gfx12 clearstate header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0b14dae
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/discovery: Set GC family for GC 12.0 IP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 405b539
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add gfx v12_0_0 family id (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit caf82ba
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: IB test encode test package change for VCN5 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7c98621
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add gfx v9_4_4 ip block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5ee14a8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add smu v13_0_14 ip block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a84024c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add psp v13_0_14 ip block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6002cf3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add sdma v4_4_5 ip block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e1394f5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd: Override DCN410 IP version (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 49963a6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Move ras resume into SRIOV function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 61fbc52
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/amdxcp: Use unique name for partition dev (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8b55c87
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/vpe: fix vpe dpm clk ratio setup failed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8d7b9a4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove redundant NULL check in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cb849ad
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove redundant NULL check in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bf5ddd3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Fix amdgpu_device_reset_sriov retry logic (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 94344ec
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd: Enable DCN410 init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 62708bb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add reset_context flag for host FLR (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 16d8fbc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Fix two reset triggered in a row (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 47fc045
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: update vf to pf message retry from 2 to 5 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit df0a1ff
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: re-indent dc_power_down_on_boot() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 79d3715
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix spelling various spelling mistakes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a0296b5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Avoid -Wenum-float-conversion in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 98cbc73
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: fix uninitialized variable warning for smu_v13 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b359cb7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/discovery: add sdma v7_0 ip block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 313e596
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: provide more ucode name shown via id (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e4f7a0c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: support SDMA v3 struct fw front door load (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6104668
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/sdma7: set sdma hang watchdog (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b5c8ad2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add sdma v7_0 ip block support (v7) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 24e9d88
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add MSF panel to DPCD 0x317 patch list (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 434acbe
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove duplicate dcn401/dcn401_clk_mgr.h header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1b14b78
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add sdma fw v3 structure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8044d44
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove duplicate spl/dc_spl_types.h header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 35496a2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add new members for sdma v7_0 fw (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a68049e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add gfx12 mqd structures (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e668861
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/discovery: Add gmc v12_0 ip block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 53f5f18
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: support gfx v12 specific pte/pde fields (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c475863
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Set pte_is_pte flag in gmc v12 gart (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8839d62
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Bump kfd version for contiguous VRAM allocation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 50df4cf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add gmc v12_0 ip block support (v7) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f57f843
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add gfx v12 pte/pde format change (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ee7009e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add gfxhub v12_0 ip block support (v3) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1468dad
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/mes11: increase waiting time for engine ready (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 96c07b2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/gfx: enable mes to map legacy queue support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 71dda1e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdkfd: Evict BO itself for contiguous allocation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3a68e7c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: re-indent dpp401_dscl_program_isharp() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 956ae95
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/pm: fix uninitialized variable warning (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7a9d8a1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Remove redundant function call (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3a22660
* Thu Oct 31 2024 pjakobsson@suse.de
- rm/amdgpu: Remove unused code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a5be77a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: avoid dump mca bank log muti times during ras ISR (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eefbcf5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add MCA smu cache support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa82785
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add amdgpu MCA bank dispatch function support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0706feb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add mmhub v4_1_0 ip block support (v4) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d02e47e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Evict BOs from same process for contiguous allocation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f034ce0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: add function descripion of new functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 54cb529
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.283 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e526c91
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Change ASSR disable sequence (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c3d2fe0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add periodic detection for IPS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 03825c7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Notify idle link detection through shared state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 318cfb4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Enable Replay for DCN315 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 99308f9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: use even ODM slice width for two pixels per (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe50f2d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: For FPO + Vactive check that all pipes support VA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit de1abc4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: gpuvm handling in DML21 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 25fed05
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Refactor HUBBUB into component folder (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 59a2ba3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Only program P-State force if pipe config changed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 80f6b23
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Revert "dc: Keep VBios pixel rate div setting util (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit daedabb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Enable RCO for PHYSYMCLK in DCN35 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 201cc63
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add trigger FIFO resync path for DCN35 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8afbab9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Re-enable IPS2 for static screen (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 329adce
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: take ODM slice count into account when deciding DSC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fc15118
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Restrict multi-disp support for in-game FAMS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bba56ee
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Refactor for Replay Link off frame count (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ba6f890
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add log_color_state callback to multiple DCNs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eeb457d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove legacy code in DC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2717364
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Update some of the dcn303 parameters (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5ac710e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Enable legacy fast update for dcn301 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8bf9229
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Adjust functions prefix for some of the dcn301 fpu (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1727fa3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Remove unnecessary files (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0712e9a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Adjust codestyle for dcn31 and hdcp_msg (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d4a8a73
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add missing SMU version (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 410eb62
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Improve registers write (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c927638
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Always use legacy way of setting cursor on DCE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6d88803
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: remove unused MCA driver codes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 10ba1b1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Do cursor programming with rest of pipe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ae8757
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add mmhub v4_1_0 ip headers (v4) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dff3f9d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.282 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6974895
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.214.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d5c6363
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/discovery: Add common soc24 ip block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ee72fc2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Replace uint8_t with u8 for (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d311fef
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/mes11: adjust mes initialization sequence (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5c60198
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu/mes11: add mes mapping legacy queue support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a53ea30
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Update dcn351 debug flags and function pointers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 33446a3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Keep VBios pixel rate div setting util next mode set (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a27bfc6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix recout calculation for stereo side-by-side (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4e8fe8e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Set cursor attributes before position (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b611eeb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Separate setting and programming of cursor (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bcd50ff
* Thu Oct 31 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Fix incorrect pointer assignment" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4b79ad6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add condition for dp_set_dsc_config call (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bf060ab
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add soc24 common ip block (v2) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9b53fcf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Force flush after write to IPS driver signals (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b89f457
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Block FPO According to Luminance Delta (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6b2247a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add soc24 chip enum definitions (v4) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7efad22
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Add gc v12_0_0 ip headers (v4) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0c70079
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Skip SST ACT polling when sink_count is 0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 12b8d8f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Handle HPD_IRQ for internal link (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fcf6be4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Reuse the modified power sequence (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 813640c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add null check in resource_log_pipe_topology_update (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- blacklist.conf: Functionality now exists
- commit 4579707
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix Replay Desync Error Test (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e34e0a4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Drop unnecessary semicolon (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 81f51bb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add missing IRQ types (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 814c8b3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Update comments in DC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4cc79bb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amdgpu: Support contiguous VRAM allocation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3e5902f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix CFLAGS for dml2_core_dcn4_calcs.o (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f70473e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add frame_warn_flag to dml2_core_shared.o (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0dcf259
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Address kdoc for 'Enable CRTC' in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 045fd7b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add misc DC changes for DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit 774164f
* Thu Oct 31 2024 krisman@suse.de
- io_uring: check if we need to reschedule during overflow flush
  (bsc#1232417 CVE-2024-50060).
- commit 695bc5f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add some DCN401 reg name to macro definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a2f05a4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add DCN401 dependant changes for DMCUB (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6be3806
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add gfx12 modifiers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9f43c3b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Fix SPL related enum definition used in DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cccb1a0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd/display: Add new DCN401 sources (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 68097a5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd: Add DCN401 related register definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 89362cf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd: GFX12 changes for converting tiling flags to modifiers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 65cc5f5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/amd: define new gfx12 uapi flags (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5408ac3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/xe_gt_debugfs: Add synchronous gt reset debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 908ad4d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Do not dereference NULL job->fence in trace points (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b0cc3c3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Custom GT restart (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0e40f06
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Custom GuC reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4dfb49e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Custom uC initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 708fded
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Support only GuC/HuC firmwares (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 47a4b4a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Don't overmap identity VRAM mapping (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cebfbf4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vm: Simplify if condition (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 60746d8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: drop redundant W=1 warnings from Makefile (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f928fb7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Use missing lock in relay_needs_worker (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 36d7a2b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/xe2lpg: Add permanent wa_14020756599 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4168787
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/xe2lpm: Add permanent Wa_14020756599 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 505d78a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add kernel-doc to some xe_lrc interfaces (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5643de4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Fix NULL ptr dereference in devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a1016ba
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Split MCR initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3700e0f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Setup VRAM based on received config data (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dad4946
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Promote VRAM initialization function to own file (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b8c768a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Drop xe_ prefix from static functions in xe_mmio.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3fc33b2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Move BAR definitions to dedicated file (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f9be27a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Move XEHP_MTCFG_ADDR register definition to xe_regs.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e249cbb
* Thu Oct 31 2024 pjakobsson@suse.de
- Revert "drm/xe: make gt_remove use devm" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3419acb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: replace format-less snprintf() with strscpy() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c908c99
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Decouple xe_exec_queue and xe_lrc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 372d739
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Remove unwanted mutex locking (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f2f84aa
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Drop undesired prefix from the platform name (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5c726ee
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/hwmon: Expose card power and energy attributes of BMG (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3fca9fb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/hwmon: Add HWMON support for BMG (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 388c6ee
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add engine name to the engine reset and cat-err log (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b7d31fd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Check empty pinned BO list with lock held. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit da48f3d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Fix uninitialised count in GuC load debug prints (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 91ec7f3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Enable Coarse Power Gating (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8fd755f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Standardize power gate registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4a86d94
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Don't refer to general LRC initialization as a "wa" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 532b59f
* Thu Oct 31 2024 vkarasulli@suse.de
- iommu/vt-d: Fix potential lockup if qi_submit_sync called
  with 0 count (bsc#1232316 CVE-2024-49993).
- commit f1e5ce7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Use platform name in xe_assert() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 61c8112
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Store platform name in xe_device.info (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 073795b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: allow unaligned start and size xe_res_cursor parameters (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b6c20e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Do not access xe file when updating exec queue run_ticks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e4983ed
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Use run_ticks instead of runtime for client stats (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 08b399a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Move job creation out of the struct xe_migrate::job_mutex (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6051e8b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Remove xe_lrc_create_seqno_fence() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ff7e92a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Don't initialize fences at xe_sched_job_create() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1618661
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Split lrc seqno fence creation up (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b5570e6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Decouple job seqno and lrc seqno (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0e9d730
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Use only assigned GGTT region (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b19c816
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Read VF configuration prior to GGTT initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 59c6775
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Treat GMDID as another runtime register (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7ac7fbe
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Cache value of the GMDID register (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d8f5b49
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Provide early access to GMDID register (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 97676c5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Obtain value of GMDID register from GuC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ddf5ba4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Add GLOBAL_CFG_GMD_ID KLV definition (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f6de2c6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Use register values obtained from the PF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 047d30f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Port over the slow GuC loading support from i915 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7658fba
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Make read_perf_limit_reasons globally accessible (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a5a25d7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add process name to devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 20a979c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: remove unused struct 'xe_gt_desc' (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ea1de1b
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/nldev: Add support to add/delete a sub IB device through netlink (jsc#PED-11232)
- commit 6b51a2b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Enable D3Cold on 'low' VRAM utilization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 133f54b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Stop checking for power_lost on D3Cold (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5241734
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Prepare display for D3Cold (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 76e18d3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Relax runtime pm protection around VM (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f028b8c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Relax runtime pm protection during execution (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 405ec1c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Fix xe_pm_runtime_get_if_in_use documentation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ba921d0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Fix xe_pm_runtime_get_if_active return (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6b24352
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/uc: Don't emit false error if running in execlist mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 705a591
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/display: move device_remove over to drmm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9dc9fdb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/display: stop calling domains_driver_remove twice (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 97e0917
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/display: move display fini stuff to devm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 77acaf6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: reset mmio mappings with devm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 39ed1ad
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/mmio: move mmio_fini over to devm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3240b1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: make gt_remove use devm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1e8f2dd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/gt: break out gt_fini into sw vs hw state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4cc8952
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/coredump: move over to devm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit be639ce
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/device: move xe_device_sanitize over to devm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e905bd3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/device: move flr to devm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 100463f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/irq: move irq_uninstall over to devm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5c372f8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc_pc: s/pc_fini/pc_fini_hw/ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 45d9b13
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc_pc: move pc_fini to devm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cf2db05
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: s/guc_fini/guc_fini_hw/ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e478415
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: move guc_fini over to devm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit 459651d
* Thu Oct 31 2024 dsterba@suse.com
- blacklist.conf: CVE-2024-50057 bsc#1232393: not applicable, code does not exist
  Fixed code added in 7e7a3c815d2217 ("USB: typec: tps6598x: Add TPS25750
  support") which is not present.
- commit 037802e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/ggtt: use drm_dev_enter to mark device section (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit 43e8c60
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: covert sysfs over to devm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7a12b98
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/pci: remove broken driver_release (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b8577c0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Custom GuC initialization if VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8094046
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Allow to initialize submission with limited set of IDs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7cedd92
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Cleanup xe_mmio.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2090c63
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Don't rely on indirect includes from xe_mmio.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2eff080
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/i915/display: Add missing include to intel_vga.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 18f635c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Fix xe_guc_pc.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 711f132
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Fix xe_huc.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6d64389
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/core: Create GSI QP only when CM is supported (jsc#PED-11232)
- commit 24ddc4c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Fix xe_gsc.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d9bf754
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Fix xe_uc.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 58b965c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/tests: Use uninterruptible VM lock (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c00d23e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add warn when level can not be zero. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b18f011
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/core: Support IB sub device with type "SMI" (jsc#PED-11232)
- commit a470e97
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/uapi: Expose the L3 bank mask (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aecf143
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/client: Print runtime to fdinfo (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit 663dd33
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/core: Create "issm*" device nodes only when SMI is supported (jsc#PED-11232)
- commit 36ee0db
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add helper to return any available hw engine (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9ec3e9b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Cache data about user-visible engines (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b7ce384
* Thu Oct 31 2024 nmorey@suse.com
- IB/core: add support for draining Shared receive queues (jsc#PED-11232)
- commit 0ea84c6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add helper to accumulate exec queue runtime (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6148330
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add helper to capture engine timestamp (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b5c66ff
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/lrc: Add helper to capture context timestamp (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 93e53a0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add XE_ENGINE_CLASS_OTHER to str conversion (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cd4f95c
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/iwcm: Simplify cm_work_handler() (jsc#PED-11232)
- commit 922abe9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Promote xe_hw_engine_class_to_str() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb47b29
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Replace RING_START_UDW by u64 RING_START (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 974dc64
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Expose SR-IOV VF attributes to GT debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9eca5ca
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Custom hardware config load step if VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bfaba01
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vf: Add support for VF to query its configuration (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0d5b787
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Add VF2GUC_QUERY_SINGLE_KLV to ABI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c9494fa
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Add VF2GUC_VF_RESET to ABI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 45fdd12
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Add VF2GUC_MATCH_VERSION to ABI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8f9223c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/pf: Expose PF monitor details via debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b309a80
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/pf: Track adverse events notifications from GuC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe5305d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Add GUC2PF_ADVERSE_EVENT to ABI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6952111
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/pf: Allow configuration of VF thresholds over debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 361ed34
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/pf: Introduce functions to configure VF thresholds (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bbf0f90
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Add support for threshold KLVs in to_string() helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9f19e81
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Introduce GuC KLV thresholds set (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4dcae8e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Add more KLV helper macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit af457b2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/pf: Implement pci_driver.sriov_configure callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b61662e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/pf: Don't advertise support to enable VFs if not ready (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e745730
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Only zap PTEs as needed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 425aab3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/xe_guc_submit: Declare reset if banned or killed or wedged (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2cbf901
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/iwcm: Simplify cm_event_handler() (jsc#PED-11232)
- commit c8218cc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/xe_guc_submit: Allow lr exec queues to be banned (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit afb58df
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/xe_guc_submit: Fix exec queue stop race condition (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dfb8a30
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/uc: Move GuC submission init to post hwconfig step (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ded6484
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/uc: Reorder post hwconfig uC initialization step (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8aa5ef8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Fix the warning conditions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 13af23b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Move sw-only pcode initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a6c0ca4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Move xe_force_wake_init_gt() inside gt initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a064f01
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/iwcm: Change the return type of iwcm_deref_id() (jsc#PED-11232)
- commit 972b7ed
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Move xe_gt_init_early() where it belongs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1b01304
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Drop useless forcewake get/put (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e7ecd26
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Drop __engine_mask (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a4c4e86
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Fix xe_reg_sr.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c3cccda
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Fix xe_lrc.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0dcea17
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Fix xe_guc_ads.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d4bc620
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Fix xe_gt_throttle_sysfs.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 85031f1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Rename few xe_args.h macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 13e8ea8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Move xe_gpu_commands.h file to instructions/ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3a80ea1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/hwmon: Remove unwanted write permission for currN_label (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4ad3f1b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Fix UBSAN shift-out-of-bounds failure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1e0f0c5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/xe2: Enable Indirect Ring State support for Xe2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e74d8c3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Dump Indirect Ring State registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 24c72a3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add Indirect Ring State support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ab58b03
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Minor cleanup in LRC handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 14eb981
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/xe2: Add workaround 14021402888 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4a44161
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Fix xe_device.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f8763ee
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Don't rely on xe_force_wake.h to be included elsewhere (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7c548e3
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Don't rely on xe_assert.h to be included elsewhere (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb091eb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: skip error capture when exec queue is killed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 14a368f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vm_doc: Fix some typos (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eca70ee
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Fix xe_mocs.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c379855
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/mocs: Add debugfs node to dump mocs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bfe8afc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Relocate regs_are_mcr function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6990ab4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Refactor default device atomic settings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ac41672
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add function to check if BO has single placement (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a08e4e7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Introduce has_device_atomics_on_smem device info (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4cff5d2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Move vm bind bo validation to a helper function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ea929d6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Introduce has_atomic_enable_pte_bit device info (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 729a99e
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/iwcm: Use list_first_entry() where appropriate (jsc#PED-11232)
- commit 2ed989c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Demote CCS_MODE info to debug only (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 74f8924
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/debugfs: Get a runtime_pm reference when setting wedged mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 57025cb
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/rtp: Prefer helper macros from xe_args.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d3e660a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/kunit: Add simple tests for new xe_args macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bc73c84
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add helpers for manipulating macro arguments (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 32090c8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Perform dma_map when moving system buffer objects to TT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8d92432
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/gt: Fix assert in L3 bank mask generation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ce0846e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/gsc: define GSCCS for LNL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3e20ba4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/gsc: Turn off GSCCS interrupts when disabling the engine (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b6f54a1
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Remove uninitialized end var from (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 52f7a74
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/xe2hpg: Add Wa_14021490052 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1841ce7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Delete PT update selftest (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d7702b8
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add xe_gt_tlb_invalidation_range and convert PT layer to use (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0589420
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Move ufence add to vm_bind_ioctl_ops_fini (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 147e5ad
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Move ufence check to op_lock_and_prep (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3c169ca
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add vm_bind_ioctl_ops_fini helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0bee25d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add some members to xe_vma_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8e03170
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Use xe_vma_ops to implement page fault rebinds (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3f8d416
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Simplify VM bind IOCTL error handling and cleanup (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 528136e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Use xe_vma_ops to implement xe_vm_rebind (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4f97870
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add struct xe_vma_ops abstraction (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit caef8ab
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Move migrate to prefetch to op_lock_and_prep function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9a7f022
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add ops_execute function which returns a fence (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7b02c1e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Lock all gpuva ops during VM bind IOCTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c4f1a8b
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Fix spelling mistake "forcebly" -> "forcibly" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d2d96fd
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/pf: Initialize and update PF services on driver init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b341c4c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/pf: Re-initialize SR-IOV specific HW settings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 71847d0
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Change xe_guc_submit_stop return to void (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ad58e1f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Use xe_bo_lock()/xe_bo_unlock() helpers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d1f37c9
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/vm: Use xe_vm_lock()/xe_vm_unlock() helpers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d215f27
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Replace engine references with exec queue in xe_guc_submit.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 71842b6
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Fix alignment in GuC exec queue state defines (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4eaf06c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: s/ENGINE_STATE_KILLED/EXEC_QUEUE_STATE_KILLED (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e4b556f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: s/ENGINE_STATE_SUSPENDED/EXEC_QUEUE_STATE_SUSPENDED (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a510d3e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: s/ENGINE_STATE_ENABLED/EXEC_QUEUE_STATE_ENABLED (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4e90ec5
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Delete unused GuC submission_state.suspend (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 34589ce
* Thu Oct 31 2024 pjakobsson@suse.de
- Revert "drm/xe/vm: drop vm->destroy_work" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d1a6ecc
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/preempt_fence: enlarge the fence critical section (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 22efc04
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Fix typos in VF CFG KLVs descriptions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b524aaa
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/pf: Expose PF service details via debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 435113d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Check result of drmm_mutex_init() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2e6729f
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/xe2: Add workaround 14021567978 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d6c4796
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Improve GuC doorbell/context ID manager intro message (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d588470
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Introduce the wedged_mode debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b447f5c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Force wedged state and block GT reset upon any GPU hang (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5d2c29e
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: declare wedged upon GuC load failure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 44d79f4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Introduce a simple wedged state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c049a91
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add INSTDONE registers to devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 307448c
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/core: Remove NULL check before dev_{put, hold} (jsc#PED-11232)
  Refresh patches.suse/RDMA-Fix-netdev-tracker-in-ib_device_set_netdev.patch
- commit 68d01e7
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add helpers to loop over geometry and compute DSS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 83a9b06
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Store xe_hw_engine in xe_hw_engine_snapshot (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ea56a5c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/pf: Clamp maximum execution quantum to 100s (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b504c8a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Update VF configuration KLVs definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d29b13d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/pf: Expose SR-IOV policy settings over debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b4c7bca
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/pf: Expose SR-IOV VF control commands over debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7005e1c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/pf: Expose SR-IOV VFs configuration over debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d590b28
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/kunit: Add PF service tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 500bb7a
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/pf: Add SR-IOV GuC Relay PF services (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit beb2cc3
* Thu Oct 31 2024 dsterba@suse.com
- ext4: dax: fix overflowing extents beyond inode size when partially writing (CVE-2024-50015 bsc#1232079)
- commit 9768b7c
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add few more GT register definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 69e303d
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Add helper to calculate adjusted register offset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 52eefd2
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/guc: Add GuC Relay ABI version 1.0 definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a366bdf
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: make xe_pm_runtime_lockdep_map a static struct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eedd8d0
* Thu Oct 31 2024 pjakobsson@suse.de
- backlight: sky81452-backlight: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e67d960
* Thu Oct 31 2024 pjakobsson@suse.de
- backlight: rave-sp-backlight: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 88037fb
* Thu Oct 31 2024 pjakobsson@suse.de
- backlight: pwm-backlight: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 72e2505
* Thu Oct 31 2024 pjakobsson@suse.de
- backlight: pcf50633-backlight: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 031206c
* Thu Oct 31 2024 pjakobsson@suse.de
- backlight: pandora-backlight: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4b8534e
* Thu Oct 31 2024 pjakobsson@suse.de
- backlight: mp3309c: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 10cd033
* Thu Oct 31 2024 pjakobsson@suse.de
- backlight: lm3533-backlight: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 847d2b4
* Thu Oct 31 2024 pjakobsson@suse.de
- backlight: led-backlight: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e0972d8
* Thu Oct 31 2024 pjakobsson@suse.de
- backlight: ktd253-backlight: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6384ebd
* Thu Oct 31 2024 pjakobsson@suse.de
- backlight: kb3886-bl: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7db10de
* Thu Oct 31 2024 pjakobsson@suse.de
- backlight: journada_bl: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0907031
* Thu Oct 31 2024 pjakobsson@suse.de
- backlight: ipaq-micro-backlight: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 60daab4
* Thu Oct 31 2024 pjakobsson@suse.de
- backlight: gpio-backlight: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4e454f5
* Thu Oct 31 2024 pjakobsson@suse.de
- backlight: corgi-lcd: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 492807f
* Thu Oct 31 2024 pjakobsson@suse.de
- backlight: ams369fb06: Use backlight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 16f2562
* Thu Oct 31 2024 pjakobsson@suse.de
- backlight: aat2870-backlight: Use blacklight power constants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 059b315
* Thu Oct 31 2024 pjakobsson@suse.de
- backlight: Add BACKLIGHT_POWER_ constants for power states (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e4c87f1
* Thu Oct 31 2024 pjakobsson@suse.de
- backlight: lm3509_bl: Fix early returns in for_each_child_of_node() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 03d1781
* Thu Oct 31 2024 pjakobsson@suse.de
- backlight: Drop explicit initialization of struct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0a40331
* Thu Oct 31 2024 pjakobsson@suse.de
- backlight: Add missing MODULE_DESCRIPTION() macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 838addc
* Thu Oct 31 2024 pjakobsson@suse.de
- backlight: lm3509_bl: Fix NULL vs IS_ERR() check in register() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e23c236
* Thu Oct 31 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Reset freesync config before update new (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d2f5fbf
* Thu Oct 31 2024 pjakobsson@suse.de
- Rename to patches.suse/0010-drm-amdgpu-reject-gang-submit-on-reserved-VMIDs.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f9fe2e4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe/display/xe_hdcp_gsc: Free arbiter on driver removal (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2d5bd44
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/xe: Use write-back caching mode for system memory on DGFX (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f5414f4
* Thu Oct 31 2024 pjakobsson@suse.de
- drm/bridge: adv7511: Fix Intermittent EDID failures (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit baf1ac4
* Thu Oct 31 2024 pjakobsson@suse.de
- devcoredump: Add dev_coredumpm_timeout() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit 3dcd2f6
* Thu Oct 31 2024 dsterba@suse.com
- jbd2: stop waiting for space when jbd2_cleanup_journal_tail() returns error (CVE-2024-49959 bsc#1232149)
- commit 8307a3a
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/core: Add an option to display driver-specific QPs in the rdmatool (jsc#PED-11232)
- commit 5d6073b
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/uverbs: Avoid -Wflex-array-member-not-at-end warnings (jsc#PED-11232)
- commit 56c3835
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/uverbs: Remove flexible arrays from struct *_filter (jsc#PED-11232)
- commit 1158971
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-syncobj-Fix-syncobj-leak-in-drm_syncobj_eventfd_.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c1933f1
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-fb-restore-init-for-ramgp102.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 92d3664
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/dma-buf-heaps-Fix-off-by-one-in-CMA-heap-fault-handl.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fbfdee2
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-guc-prevent-a-possible-int-overflow-in-wq-o.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1e862e5
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-atomfirmware-Silence-UBSAN-warning.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0dc4ae5
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Avoid-race-between-dcn10_set_drr-and.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 35bd829
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amdgpu-align-pp_power_profile_mode-with-k.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 726386c
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-fix-the-fwsec-sb-verification-register.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e6d8922
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-komeda-Fix-an-issue-related-to-normalized-zpos.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4e46994
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-fence-Mark-debug_fence_free-with-__maybe_un.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b298bc1
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-fence-Mark-debug_fence_init_onstack-with-__.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ea151ea
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Do-not-attempt-to-load-the-GSC-multiple-tim.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bad3548
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-vmwgfx-Fix-prime-with-external-buffers.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 19c9bb8
* Thu Oct 31 2024 pjakobsson@suse.de
- Delete patches.suse/0001-drm-vmwgfx-Prevent-unmapping-active-read-buffers.patch.
- commit 1646571
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dsi-Make-Lenovo-Yoga-Tab-3-X90F-DMI-match-l.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 28623de
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-swsmu-always-force-a-state-reprogram-on-i.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 16d6f80
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-align-pp_power_profile_mode-with-kernel-d.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1487267
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-firmware-use-dma-non-coherent-allocator.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 15e1225
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-sdma5.2-limit-wptr-workaround-to-sdma-5.2.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bd34e6c
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-adreno-Fix-error-return-if-missing-firmware-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8e34238
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-take-plane-rotation-into-account-for-wid.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3bb00b4
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-cleanup-FB-if-dpu_format_populate_layout.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7e09fe2
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dp-reset-the-link-phy-params-before-link-tra.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3bdec16
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-move-dpu_encoder-s-connector-assignment-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3754944
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dp-fix-the-max-supported-bpp-logic.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit 384ed6a
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-don-t-play-tricks-with-debug-macros.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 29a76fb
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Set-sensible-cursor-width-height-values.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7618d5e
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-orientation-quirks-Add-quirk-for-Ayn-Loki--2c71c84.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6444573
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-orientation-quirks-Add-quirk-for-Ayn-Loki-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8cbe2e2
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Actually-check-flags-for-all-context-ops.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d615be7
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-jpeg4-properly-set-atomics-vmid-field.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1e1afd2
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-jpeg2-properly-set-atomics-vmid-field.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c36508c
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Adjust-cursor-position.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3da5229
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-cursor-offset-on-rotation-180.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ff997fa
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-s2idle-entry-for-DCN3.5.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c1cf949
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gem-Fix-Virtual-Memory-mapping-boundaries-c.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 77f7c95
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gem-Adjust-vma-offset-for-framebuffer-mmap-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd0b66a
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Skip-Recompute-DSC-Params-if-no-Stre.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 98b7f1c
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Forward-soft-recovery-errors-to-userspace.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e6d1b88
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Replace-dm_execute_dmub_cmd-with-dc_.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f372b92
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-vmwgfx-Fix-overlay-when-using-Screen-Targets.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5721162
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-virtio-Fix-type-of-dma-fence-context-variable.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 20840d4
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-prime-fix-refcount-underflow.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5b08924
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-gpuvm-fix-missing-dependency-to-DRM_EXEC.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 813a218
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-orientation-quirks-Add-quirk-for-OrangePi-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3650489
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-fb-helper-Don-t-schedule_work-to-flush-frame-buf.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 345d5a6
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Fix-possible-int-overflow-in-skl_ddi_calcul.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9dd5a37
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-hdcp-Fix-HDCP2_STREAM_STATUS-macro.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3e013ce
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/i915-perf-Remove-code-to-update-PWR_CLK_STATE-for-ge.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 16fb929
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-contiguous-handling-for-IB-parsing-v2.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2bb5037
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-reset-vm-state-machine-after-gpu-reset-vr.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1fea250
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Check-for-NULL-pointer.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ab38f86
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-amdgpu-Fix-uninitialized-variable-warnings.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 39976b1
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-sdma5.2-Update-wptr-registers-as-well-as-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa22341
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Do-not-consider-preemption-during-execli.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7553b4b
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dp-Don-t-switch-the-LTTPR-mode-on-an-active.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit cca78f9
* Thu Oct 31 2024 pjakobsson@suse.de
- Delete patches.suse/drm-amd-display-Solve-mst-monitors-blank-out-problem.patch.
- commit 18b77ce
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Set-no_hw_access-when-VF-request-full-GPU.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e93e98d
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-fbdev-dma-Fix-framebuffer-mode-for-big-endian-de.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0b71bf3
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-mdp5-Remove-MDP_CAP_SRC_SPLIT-from-msm8x53_c.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2926e64
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-drop-validity-checks-for-clear_pending_f.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0cdb755
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dsi-set-VIDEO_COMPRESSION_MODE_CTRL_WC.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cc7155c
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-fix-encoder-irq-wait-skip.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 83e794a
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-dp_mst-Skip-CSN-if-topology-probing-is-not-done-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1e1fb0b
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-dp_mst-Fix-all-mstb-marked-as-not-probed-after-s.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8eaf73f
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-panfrost-Mark-simple_ondemand-governor-as-softde.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e45eb3e
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-lima-Mark-simple_ondemand-governor-as-softdep.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7691596
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-display-handle-gfx12-in-amdgpu_dm_plane_f.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd242db
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-handle-gfx12-in-amdgpu_display_verify_siz.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e2dd3dc
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-check-for-LINEAR_ALIGNED-correctly-in-che.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6ed733d
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Check-denominator-crb_pipes-before-u.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b924615
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-null-pointer-deref-in-dcn20_reso.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 334a7a6
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-clear-RB_OVERFLOW-bit-when-enabling-inter.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2c54a57
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-add-missing-error-handling-in-function-am.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7fec9a3
* Thu Oct 31 2024 pjakobsson@suse.de
- Delete patches.suse/0001-drm-amd-display-Validate-function-returns.patch.
- commit ae27a32
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Remove-a-redundant-check-in-authenti.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 991b41f
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Check-HDCP-returned-status.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 70a2419
* Thu Oct 31 2024 pjakobsson@suse.de
- Delete patches.suse/drm-mediatek-Fix-bit-depth-overwritten-for-mtk_ovl_s.patch.
- commit ef35272
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Support-DRM-plane-alpha-in-Mixer.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 026f9f2
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Support-DRM-plane-alpha-in-OVL.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e6552f7
* Thu Oct 31 2024 pjakobsson@suse.de
- Delete patches.suse/drm-mediatek-Support-RGBA8888-and-RGBX8888-in-OVL-on.patch.
- commit b9c7be8
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Set-DRM-mode-configs-accordingly.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 63b49ea
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Add-OVL-compatible-name-for-MT8195.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 67b88e0
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Turn-off-the-layers-with-zero-width-or-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 792b54b
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-destination-alpha-error-in-OVL.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0534cda
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-XRGB-setting-error-in-Mixer.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a71a661
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-XRGB-setting-error-in-OVL.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a19d3a8
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Use-8-bit-alpha-in-ETHDR.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c7c769a
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-etnaviv-don-t-block-scheduler-when-GPU-is-still-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 79c8ff8
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-etnaviv-fix-DMA-direction-handling-for-cached-RW.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 886fa22
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-bridge-tc358767-Set-default-CLRSIPO-count.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 43e0cbf
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-null-checker-before-passing-vari.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 98958bb
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-use-preferred-link-settings-for-dp-s.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fd683ed
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-added-NULL-check-at-start-of-dc_vali.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa859f6
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Wake-DMCUB-before-sending-a-command-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b9e1a6b
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Don-t-use-fsleep-for-PSR-exit-waits-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 74d2015
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-overflowed-constant-warning-in-mmhub_.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6acd408
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-add-lock-in-kfd_process_dequeue_from_devi.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 00b3581
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amd-display-Add-NULL-check-for-afb-before.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 93f94fe
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-add-lock-in-amdgpu_gart_invalidate_tlb.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 30dd5ce
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-add-skip_hw_access-checks-for-sriov.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit caeb3e6
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-NULL-check-for-afb-before-derefe.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 644ef70
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-zynqmp_kms-Fix-AUX-bus-not-getting-unregistered.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4924614
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-zynqmp_dpsub-Fix-an-error-handling-path-in-zynqm.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2b2301a
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-samsung-dsim-Set-P-divider-based-on-min-m.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 373ed5d
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-meson-plane-Add-error-handling.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e9d744d
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-analogix_dp-properly-handle-zero-sized-AU.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8006bdd
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-ilitek-ili9882t-Check-for-errors-on-the-NO.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f2d06e7
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-ilitek-ili9882t-If-prepare-fails-disable-G.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 425b146
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-boe-tv101wum-nl6-Check-for-errors-on-the-N.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 361eb9f
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-boe-tv101wum-nl6-If-prepare-fails-disable-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 504ec83
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-himax-hx8394-Handle-errors-from-mipi_dsi_d.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1bdd6ea
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-mgag200-Set-DDC-timeout-in-milliseconds.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7ccf6e4
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-mipi-dsi-Fix-theoretical-int-overflow-in-mipi_ds-24acbcc.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9dc8d08
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-mipi-dsi-Fix-theoretical-int-overflow-in-mipi_ds.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fb14c46
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-udl-Remove-DRM_CONNECTOR_POLL_HPD.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d9fa1a2
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-arm-komeda-Fix-komeda-probe-failing-if-there-are.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b4dbe44
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-drm-bridge-Drop-conditionals-around-of_node-poin.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7e72c59
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-vop2-Fix-the-port-mux-of-VP2.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6176d89
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-null-checks-for-stream-and-plane.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d470a05
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-Fix-the-null-pointer-dereference-for-vega.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ca0c0a6
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgu-fix-Unintentional-integer-overflow-for-mal.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b538032
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-Remove-__counted_by-from-StateArray.state.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 43bb332
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Move-struct-scaler_data-off-stack.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b1e6e9f
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Add-lock-around-VF-RLCG-interface.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 90133d8
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-update-type-of-buf-size-to-u32-for-eeprom.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c540112
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-pipe-addition-logic-in-calc_bloc.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1786d4f
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Remove-GC-HW-IP-9.3.0-from-noretry-1.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 28891d3
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-pm-Fix-the-null-pointer-dereference-in-ap.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 52cbd83
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-kfd-Correct-pinned-buffer-handling-at-kfd-restor.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a4d004b
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Check-if-NBIO-funcs-are-NULL-in-amdgpu_de.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 309b7a2
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-memory-range-calculation.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d3f0cbc
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-Fix-aldebaran-pcie-speed-reporting.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7306b5f
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-pm-Fix-the-null-pointer-dereference-for-s.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 487ae63
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-check-negtive-return-for-table-entries.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7f808f9
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-remove-logically-dead-code-for-renoir.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7f448b9
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-check-specific-index-for-smu13.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e4ea581
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-check-specific-index-for-aldebaran.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 98b181f
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Fix-CU-Masking-for-GFX-9.4.3.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6526179
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-pm-Check-input-value-for-CUSTOM-profile-m.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0c268b5
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Reconcile-the-definition-and-use-of-oem_i.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c8c72db
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-pm-Fix-the-param-type-of-set_power_profil.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7734e52
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-uninitialized-variable-warning-in-amd-0991e49.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ee0a4bf
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-the-uninitialized-variable-warning.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cf6e469
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-pm-Fix-uninitialized-variable-agc_btc_res.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 71a9288
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-pm-Fix-uninitialized-variable-warning-for.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5918f46
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-fix-uninitialized-variable-warnings-for-v-b2871de.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bea09a8
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-Coverity-INTEGER_OVERFLOW-within-83c0c83.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d957819
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Spinlock-before-reading-event.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e651c2a
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-Coverity-INTEGER_OVERFLOW-within.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5ebd066
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-Coverity-INTERGER_OVERFLOW-withi.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0e7fc0b
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Check-link_index-before-accessing-dc.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5789329
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-array-index-check-for-hdcp-ddc-a.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c0177b4
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Check-index-for-aux_rd_interval-befo.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3462c48
* Thu Oct 31 2024 pjakobsson@suse.de
- Delete patches.suse/0001-drm-amd-display-Fix-incorrect-size-calculation-for-l.patch.
- commit 3f9121e
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Ensure-array-index-tg_inst-won-t-be-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0b583f8
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-avoid-reading-vf2pf-info-size-from-FB.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4f7086e
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-fix-uninitialized-variable-warnings-for-v.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2ee26a1
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-uninitialized-scalar-variable-warning-0fa4c25.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit db41a11
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-Fix-negative-array-index-read.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2123e73
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-fix-warning-using-uninitialized-value-of-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9dbca9b
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-fix-uninitialized-variable-warning-for-sm.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b80eb66
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-fix-uninitialized-variable-warning.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 707e502
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-pm-Check-the-return-value-of-smum_send_ms.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0757d56
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-overflowed-array-index-read-warning.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bdb936a
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-potential-resource-leak-warning.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e1b12c5
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Handle-sg-size-limit-for-contiguous-alloc.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1326c08
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-FEC_READY-write-on-DP-LT.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c5f17b3
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Defer-handling-mst-up-request-in-res.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 91bfa93
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Handle-the-case-which-quad_part-is-e.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7c1134a
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Disable-error-correction-if-it-s-not.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3c00b8
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-delay-to-improve-LTTPR-UHBR-inte.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2aeedc7
* Thu Oct 31 2024 pjakobsson@suse.de
- Update patches.suse/drm-meson-fix-canvas-release-in-bind-function.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 29ebfc6
* Thu Oct 31 2024 pjakobsson@suse.de
- blacklist.conf: Unblacklist patches for DRM v6.11 backport
- commit 832efd4
* Thu Oct 31 2024 mfranc@suse.cz
- s390/pai_crypto: Add support for MSA 10 and 11 pai counters
  (jsc#PED-9587).
- commit 52f2515
* Thu Oct 31 2024 pjakobsson@suse.de
- Update
  patches.suse/0327-drm-amdgpu-update-kernel-vcn-ring-test.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0327-drm-i915-Split-g4x-DP-audio-presence-detect-from-por.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0327-drm-i915-hdcp-Use-intel_connector-argument-in-intel_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0327-drm-tegra-Use-regular-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0328-drm-amdgpu-update-kernel-vcn-ring-test.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0328-drm-fb-helper-Export-helpers-for-marking-damage-area.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0328-drm-i915-Split-g4x-HDMI-audio-presence-detect-from-p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0328-drm-i915-hdcp-Propagate-aux-info-in-DP-HDCP-function.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0329-drm-amdkfd-report-dispatch-id-always-saved-in-ttmps-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0329-drm-i915-Convert-audio-enable-disable-into-encoder-v.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0329-drm-i915-hdcp-Send-the-correct-aux-for-DPMST-HDCP-sc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0329-drm-msm-Use-regular-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0330-drm-amdkfd-Fix-stack-size-in-amdgpu_amdkfd_unmap_hiq.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0330-drm-fbdev-generic-Implement-dedicated-fbdev-I-O-help.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0330-drm-i915-Hoist-the-encoder-audio_-enable-disable-cal.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0330-drm-i915-hdcp-Adjust-timeout-for-read-in-DPMST-Scena.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0331-drm-amdgpu-Rename-to-amdgpu_vm_tlb_seq_struct.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0331-drm-i915-Implement-dedicated-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0331-drm-i915-Push-audio_-enable-disable-to-the-pre-post-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0331-drm-i915-sdvo-Nuke-attached_output-tracking.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0332-drm-i915-Implement-audio-fastset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0332-drm-i915-sdvo-Initialize-the-encoder-earlier.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0333-drm-Place-Renesas-drivers-in-a-separate-dir.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0333-drm-amdgpu-Fix-error-warnings-in-gmc_v8_0.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0333-drm-i915-display-Separate-xe-and-i915-common-dpt-cod.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0333-drm-i915-sdvo-Nuke-the-duplicate-sdvo-port.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0334-Revert-drm-amdgpu-update-kernel-vcn-ring-test.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0334-accel-habanalabs-add-description-to-several-info-ioc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0334-drm-i915-display-in-skl_surf_address-check-for-dpt-v.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0334-drm-i915-sdvo-Get-rid-of-the-per-connector-i2c-symli.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0335-Revert-drm-amdgpu-update-kernel-vcn-ring-test.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0335-drm-bridge-tc358762-Add-reset-GPIO-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0335-drm-i915-display-In-intel_framebuffer_init-switch-to.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0335-drm-i915-sdvo-Rework-DDC-bus-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0336-drm-Fix-color-LUT-rounding.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0336-drm-amd-display-Expose-more-formats-for-overlay-plan.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0336-drm-i915-sdvo-Print-out-the-i2c-pin-and-slave-addres.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0336-drm-meson-fix-unbind-path-if-HDMI-fails-to-bind.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0337-drm-amd-display-Enable-3-plane-for-DCN-3.01.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0337-drm-i915-Adjust-LUT-rounding-rules.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0337-drm-i915-psr-Apply-Wa_14015648006-for-all-display-14.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0337-drm-meson-only-use-components-with-dw-hdmi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0338-drm-amd-display-Implement-zpos-property.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0338-drm-display-dp-Assume-8-bpc-support-when-DSC-is-supp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0338-drm-i915-s-clamp-min-in-i965_lut_11p6_max_pack.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0338-drm-meson-venc-add-ENCL-encoder-setup-for-MIPI-DSI-o.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0339-drivers-drm-i915-Honor-limits-max_bpp-while-computin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0339-drm-amd-display-Clean-up-style-problems-in-amdgpu_dm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0339-drm-i915-Fix-glk-degamma-LUT-conversions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0339-drm-meson-add-DSI-encoder.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0340-drm-amd-display-Eliminate-warnings-in-amdgpu_dm_help.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0340-drm-amdgpu-Implement-a-new-64bit-sequence-memory-dri.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0340-drm-i915-dg2-Add-support-for-new-DG2-G12-revid-0x1.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0340-drm-meson-add-support-for-MIPI-DSI-transceiver.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0341-drm-amdgpu-Avoid-possiblity-of-kernel-crash-in-gmc_v.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0341-drm-amdgpu-update-mappings-not-managed-by-KFD.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0341-drm-i915-dp-Drop-redundant-AUX-power-get-put-in-inte.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0341-drm-panel-khadas-ts050-update-timings-to-achieve-60H.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0342-drm-amdgpu-Enable-aqua-vanjaram-RAS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0342-drm-amdkfd-Move-TLB-flushing-logic-into-amdgpu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0342-drm-i915-mtl-Add-TC-port-lockdep-assert-to-AUX-power.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0342-drm-panel-Support-for-Starry-himax83102-j02-TDDI-MIP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0343-drm-amd-pm-Fix-return-value-and-drop-redundant-param.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0343-drm-amdgpu-Disable-RAS-by-default-on-APU-flatform.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0343-drm-i915-add-minimal-i915_gem_object_frontbuffer.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0343-drm-panel-Support-for-Starry-ili9882t-TDDI-MIPI-DSI-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0344-amdgpu-Adjust-kmalloc_array-calls-for-new-Walloc-siz.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0344-drm-amdgpu-Add-dcdebugmask-option-to-enable-DPIA-tra.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0344-drm-i915-hdcp-Use-intel_connector-as-argument-for-hd.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0344-drm-meson-Remove-unneeded-semicolon.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0345-drm-amdgpu-create-a-new-file-for-doorbell-manager.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0345-drm-i915-hdcp-Use-correct-aux-for-capability-check-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0345-drm-meson-venc-include-linux-bitfield.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0345-drm-radeon-Fix-warning-using-plain-integer-as-NULL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0346-drm-amd-display-Setup-stream-encoder-before-link-ena.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0346-drm-amd-pm-Move-some-functions-to-smu_v13_0.c-as-gen.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0346-drm-edid-add-drm_edid_is_digital.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0346-drm-virtio-Refactor-and-optimize-job-submission-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0347-drm-amd-display-Use-is_dig_enable-function-instead-o.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0347-drm-amd-pm-Make-smu_v13_0_baco_set_armd3_sequence-st.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0347-drm-i915-display-use-drm_edid_is_digital.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0347-drm-virtio-Wait-for-each-dma-fence-of-in-fence-array.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0348-drm-amd-display-Re-add-aux-intercept-disable-delay-g.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0348-drm-amdgpu-Refactor-amdgpu_connector_dvi_detect-in-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0348-drm-bridge-imx-fix-mixed-module-builtin-object.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0348-drm-edid-parse-source-physical-address.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0349-drm-amd-display-Improve-the-include-of-header-file.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0349-drm-amdkfd-Clear-the-VALU-exception-state-in-the-tra.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0349-drm-bridge-imx-turn-imx8-qm-qxp-ldb-into-single-obje.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0349-drm-cec-add-drm_dp_cec_attach-as-the-non-edid-versio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0350-drm-amd-display-Remove-unused-function.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0350-drm-i915-cec-switch-to-setting-physical-address-dire.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0350-drm-panel-simple-add-support-for-Rocktech-RK043FN48H.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0351-drm-amd-display-Add-missing-static.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0351-drm-amdgpu-correct-mca-ipid-die-socket-addr-decode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0351-drm-i915-fbc-Clear-frontbuffer-busy-bits-on-flip.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0352-accel-habanalabs-remove-variable-gaudi_irq_name.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0352-drm-amd-display-Enable-CM-low-mem-power-optimization.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0352-drm-amd-display-Hardcode-vco_freq-for-dcn316.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0352-drm-i915-Introduce-intel_csc_matrix-struct.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0352-drm-i915-psr-Clear-frontbuffer-busy-bits-on-flip.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0353-accel-habanalabs-ignore-false-positive-razwi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0353-drm-amd-display-Reduce-stack-size.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0353-drm-amd-display-add-a-debugfs-interface-for-the-DMUB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0353-drm-i915-Add-new-frontbuffer-tracking-interface-to-q.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0353-drm-i915-Split-chv_load_cgm_csc-into-pieces.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0354-accel-habanalabs-allow-user-to-modify-EDMA-RL-regist.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0354-drm-amd-display-Refactor-resource-into-component-dir.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0354-drm-amd-display-Skip-enabling-DMCUB-when-using-emula.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0354-drm-i915-Handle-dma-fences-in-dirtyfb-callback.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0354-drm-i915-Start-using-struct-intel_csc_matrix-for-chv.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0355-accel-habanalabs-remove-commented-code-that-won-t-be.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0355-drm-amd-display-Try-to-acquire-a-free-OTG-master-not.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0355-drm-amd-display-Update-scaler-recout-data-for-visual.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0355-drm-i915-Store-ilk-csc-matrices-in-the-crtc-state.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0355-drm-i915-vdsc-Refactor-dsc-register-field-macro.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0356-accel-habanalabs-fix-bug-in-free-scratchpad-memory.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0356-drm-amd-display-Prefer-currently-used-OTG-master-whe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0356-drm-amd-display-Skip-querying-caps-when-DMCUB-emulat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0356-drm-i915-Utilize-crtc_state-csc-on-chv.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0356-drm-i915-vdsc-Add-a-check-for-dsc-split-cases.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0357-accel-habanalabs-add-helper-to-extract-the-FW-major-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0357-drm-amd-display-Enable-DCN-clock-gating-for-DCN35.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0357-drm-amd-display-Update-SW-cursor-fallback-for-subvp-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0357-drm-i915-Sprinke-a-few-sanity-check-WARNS-during-csc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0357-drm-i915-vdsc-Add-func-to-get-no.-of-vdsc-instances-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0358-accel-habanalabs-rename-fw_-major-minor-_version-to-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0358-drm-amd-display-Add-disable-timeout-option.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0358-drm-amd-display-Reenable-all-root-clock-gating-optio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0358-drm-i915-Add-hardware-csc-readout-for-ilk.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0358-drm-i915-vdsc-Add-function-to-read-any-PPS-register.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0359-accel-habanalabs-extract-and-save-the-FW-s-SW-major-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0359-drm-amd-display-Cache-backlight_millinits-in-link-st.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0359-drm-amd-display-Send-PQ-bit-in-AMD-VSIF.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0359-drm-i915-Implement-chv-cgm-csc-readout.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0359-drm-i915-vdsc-Add-function-to-write-in-PPS-register.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0360-accel-habanalabs-check-fw-version-using-sw-version.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0360-drm-amd-display-Enable-DSC-Flag-in-MST-Mode-Validati.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0360-drm-amd-display-Fix-DP2-link-training-failure-with-R.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0360-drm-i915-Include-the-csc-matrices-in-the-crtc-state-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0360-drm-i915-vdsc-Remove-unused-dsc-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0361-accel-habanalabs-do-soft-reset-using-cpucp-packet.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0361-drm-amd-display-Add-new-command-to-disable-replay-ti.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0361-drm-amd-display-refine-to-decide-the-verified-link-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0361-drm-i915-Hook-up-csc-into-state-checker.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0361-drm-i915-vdsc-Fill-the-intel_dsc_get_pps_config-func.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0362-accel-habanalabs-unsecure-TPC-bias-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0362-drm-amd-display-Add-missing-chips-for-HDCP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0362-drm-amd-display-add-additional-refresh-rate-conditio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0362-drm-i915-display-Compare-the-readout-dsc-pps-params.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0362-drm-i915-display-remove-unnecessary-i915_debugfs.h-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0363-accel-habanalabs-call-to-HW-FW-err-returns-0-when-no.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0363-drm-amd-Use-the-first-non-dGPU-PCI-device-for-BW-lim.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0363-drm-amd-display-Fix-race-condition-when-turning-off-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0363-drm-i915-Generalize-planes_-enabling-disabling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0363-drm-i915-tc-rename-mtl_tc_port_get_pin_assignment_ma.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0364-accel-habanalabs-minimize-encapsulation-signal-mutex.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0364-drm-amd-Exclude-dGPUs-in-eGPU-enclosures-from-DPM-qu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0364-drm-amd-display-Update-128b-132b-downspread-factor-t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0364-drm-i915-tc-make-intel_tc_port_get_lane_mask-static.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0364-drm-i915-vrr-Eliminate-redundant-function-arguments.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0365-accel-habanalabs-refactor-abort-of-completions-and-w.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0365-drm-amd-display-Promote-DAL-to-3.2.242.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0365-drm-amd-display-Promote-DC-to-3.2.260.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0365-drm-i915-tc-move-legacy-code-out-of-the-main-_max_la.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0365-drm-i915-vrr-Make-delayed-vblank-operational-in-VRR-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0366-accel-habanalabs-add-missing-tpc-interrupt-info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0366-drm-amd-display-Add-helpers-to-get-DMUB-FW-boot-opti.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0366-drm-amdgpu-expose-the-connected-port-num-info-throug.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0366-drm-i915-tc-remove-fia-from-intel_tc_port_fia_max_la.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0366-drm-i915-vrr-Tell-intel_crtc_update_active_timings-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0367-drm-amd-display-Initialize-necessary-uninitialized-v.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0367-drm-amdgpu-add-pm-metrics-structure-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0367-drm-i915-psr-Add-psr-sink-error-status-into-sink-sta.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0367-drm-i915-vrr-Relocate-VRR-enable-disable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0368-accel-habanalabs-expose-debugfs-files-later.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0368-drm-amd-display-Add-stream-overhead-in-BW-calculatio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0368-drm-amdgpu-add-amdgpu-runpm-usage-trace-for-separate.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0368-drm-i915-add-trailing-newlines-to-msgs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0368-drm-i915-vrr-Allow-VRR-to-be-toggled-during-fastsets.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0369-accel-habanalabs-poll-for-device-status-update-follo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0369-drm-amd-display-Add-link-encoding-to-timing-BW-calcu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0369-drm-amdgpu-Add-function-parameter-xcc_mask-not-descr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0369-drm-i915-Flag-purely-internal-commits-to-not-clear-c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0369-drm-i915-cx0-Check-and-increase-msgbus-timeout-thres.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0370-accel-habanalabs-fix-a-static-warning-dubious-x-y.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0370-drm-amd-Document-device-reset-methods.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0370-drm-amd-display-Fix-ASIC-check-in-aux-timeout-workar.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0370-drm-i915-Allow-arbitrary-refresh-rates-with-VRR-eDP-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0370-drm-i915-Constify-LUT-entries-in-checker.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0371-accel-habanalabs-always-fetch-pci-addr_dec-error-inf.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0371-drm-amd-display-ABM-pause-toggle.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0371-drm-amd-display-Remove-redundant-DRM-device-struct-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0371-drm-i915-Evade-transcoder-s-vblank-when-doing-seamle.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0371-drm-i915-dsb-Dump-the-DSB-command-buffer-when-DSB-fa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0372-accel-habanalabs-Fix-some-kernel-doc-comments.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0372-drm-amd-display-Add-missing-triggers-for-full-update.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0372-drm-amd-pm-Add-support-to-fetch-pm-metrics-sample.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0372-drm-i915-Use-min-instead-of-hand-rolling-it.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0372-drm-i915-dsb-Avoid-corrupting-the-first-register-wri.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0373-drm-amd-display-Promote-DAL-to-3.2.243.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0373-drm-amd-pm-Add-pm-metrics-support-to-SMU-v13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0373-drm-i915-debugfs-New-debugfs-for-display-clock-frequ.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0373-drm-i915-dsb-Don-t-use-indexed-writes-when-byte-enab.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0374-accel-habanalabs-rename-security-functions-related-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0374-drm-amd-pm-Add-sysfs-attribute-to-get-pm-metrics.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0374-drm-amdgpu-Add-RLCG-interface-driver-implementation-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0374-drm-i915-Stop-forcing-clock-gating-init-for-future-p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0375-accel-habanalabs-set-unused-bit-as-reserved.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0375-drm-amd-Avoid-reading-the-VBIOS-part-number-twice.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0375-drm-amd-display-Add-new-Replay-command-and-Disabled-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0375-drm-i915-adlp-Stop-calling-gen12lp_init_clock_gating.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0375-drm-i915-mtl-Add-DP-rates.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0376-drm-amdgpu-allow-secure-submission-on-VCN4-ring.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0376-drm-amdkfd-Copy-HW-exception-data-to-user-event.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0376-drm-i915-display-Extract-display-workarounds-from-cl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0376-drm-i915-mtl-Create-separate-reg-file-for-PICA-regis.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0377-accel-habanalabs-align-to-latest-firmware-specs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0377-drm-amd-display-add-skip_implict_edp_power_control-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0377-drm-i915-display-Apply-workarounds-during-display-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0377-drm-i915-mtl-Add-Support-for-C10-PHY-message-bus-and.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0377-drm-radeon-Prefer-pr_err-_info-over-printk.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0378-accel-habanalabs-print-max-timeout-value-on-CS-stuck.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0378-drm-amd-display-remove-an-unused-file.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0378-drm-amdgpu-Retire-query-reset_ras_err_status-from-gf.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0378-drm-i915-dsc-improve-clarity-of-the-pps-reg-read-wri.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0378-drm-i915-mtl-Add-vswing-programming-for-C10-phys.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0379-accel-habanalabs-upon-DMA-errors-use-FW-extracted-er.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0379-drm-amd-display-Allow-building-DC-with-clang-on-RISC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0379-drm-amd-display-update-pixel-clock-params-after-stre.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0379-drm-i915-dsc-have-intel_dsc_pps_read_and_verify-retu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0379-drm-i915-mtl-MTL-PICA-hotplug-detection.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0380-accel-habanalabs-remove-support-for-mmu-disable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0380-drm-amd-display-always-use-mpc-factor-of-2-for-stere.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0380-drm-amdgpu-Program-xcp_ctl-registers-as-needed.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0380-drm-i915-dsc-have-intel_dsc_pps_read-return-the-valu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0380-drm-i915-mtl-display-Implement-DisplayPort-sequences.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0381-accel-habanalabs-use-binning-info-when-handling-razw.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0381-drm-amd-display-Refactor-DSC-into-component-folder.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0381-drm-amdgpu-Fix-one-kernel-doc-comment.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0381-drm-i915-dsc-rename-pps-write-to-intel_dsc_pps_write.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0381-drm-i915-mtl-Add-C10-phy-programming-for-HDMI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0382-accel-habanalabs-use-lower-QM-in-QM-errors-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0382-drm-amd-display-replay-generalize-the-send-command-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0382-drm-amdgpu-set-sw-state-to-gfxoff-after-SR-IOV-reset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0382-drm-i915-display-mtl-Fill-port-width-in-DDI_BUF_-TRA.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0382-drm-i915-dsc-drop-redundant-0-assignments.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0383-accel-habanalabs-print-qman-data-on-error-only-for-l.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0383-drm-amd-display-replay-Augment-Frameupdate-Command.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0383-drm-amdkfd-enable-cooperative-groups-for-gfx11.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0383-drm-i915-dsc-clean-up-pps-comments.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0383-drm-i915-mtl-Initial-DDI-port-setup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0384-accel-habanalabs-update-state-when-loading-boot-fit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0384-drm-amd-display-Simplify-brightness-initialization.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0384-drm-amdgpu-Prefer-if-IS_ENABLED-over-if-defined-in-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0384-drm-i915-Make-intel_-mpllb-c10pll-_state_verify-safe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0384-drm-i915-dsc-add-the-PPS-number-to-the-register-cont.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0385-accel-habanalabs-mask-part-of-hmmu-page-fault-captur.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0385-drm-amd-display-adjust-flow-for-deallocation-mst-pay.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0385-drm-amdgpu-Fix-do-not-add-new-typedefs-in-amdgpu_fw_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0385-drm-i915-display-remove-intel_display_commit_duplica.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0385-drm-i915-dsc-use-REG_BIT-REG_GENMASK-and-friends-for.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0386-accel-habanalabs-remove-sim-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0386-drm-amd-display-Disable-Timing-sync-check-in-Full-Sc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0386-drm-amdgpu-Return-ENOMEM-when-there-is-no-memory-in-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0386-drm-i915-display-start-high-level-display-driver-fil.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0386-drm-i915-gt-rename-DBG-to-GTT_TRACE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0387-drm-amd-display-Correct-grammar-mistakes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0387-drm-amd-display-Enable-SubVP-on-1080p60-displays.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0387-drm-i915-display-move-intel_modeset_probe_defer-to-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0387-drm-i915-mst-Read-out-FEC-state.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0388-accel-habanalabs-fix-bug-of-not-fetching-addr_dec-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0388-drm-i915-Fix-FEC-pipe-A-vs.-DDI-A-mixup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0388-drm-i915-display-rename-intel_modeset_probe_defer-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0388-drm-radeon-Avoid-externs-do-not-initialize-globals-t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0389-Revert-drm-amd-display-Enable-CM-low-mem-power-optim.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0389-accel-habanalabs-move-ioctl-error-print-to-debug-lev.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0389-drm-amd-amdgpu-Fix-warnings-in-amdgpu-amdgpu_display.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0389-drm-i915-display-move-modeset-probe-remove-functions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0390-accel-habanalabs-unsecure-TSB_CFG_MTRR-regs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0390-drm-amd-display-If-P-State-is-supported-try-SubVP-fo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0390-drm-i915-Split-some-long-lines-in-hsw_fdi_link_train.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0390-drm-i915-display-rename-intel_display_driver_-functi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0390-drm-radeon-Fix-style-issues-in-radeon-_encoders.c-_g.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0391-accel-habanalabs-add-event-queue-extra-validation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0391-drm-amd-display-Refactor-OPTC-into-component-folder.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0391-drm-i915-Stop-spamming-the-logs-with-PLL-state.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0391-drm-i915-display-add-intel_display_reset.-ch.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0391-drm-radeon-Prefer-dev_-variant-over-printk.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0392-accel-habanalabs-refactor-error-info-reset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0392-drm-amd-display-Add-VESA-SCR-case-for-default-aux-ba.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0392-drm-i915-Reduce-combo-PHY-log-spam.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0392-drm-i915-display-move-display-suspend-resume-to-inte.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0393-drm-amd-display-FW-Promotion-Release-0.0.193.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0393-drm-amdgpu-Enabling-FW-workaround-through-shared-mem.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0393-drm-i915-display-rename-intel_display_driver_suspend.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0394-drm-amd-display-3.2.261.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0394-drm-amdgpu-Update-ring-scheduler-info-as-needed.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0394-drm-i915-display-add-intel_display_driver_early_prob.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0394-drm-i915-dsc-Fix-pic_width-readout.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0395-drm-Reorder-drm_sysfs_connector_remove-vs.-drm_debug.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0395-drm-amd-display-Prevent-invalid-pipe-connections.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0395-drm-amdgpu-Move-mca-debug-mode-decision-to-ras.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0395-drm-i915-pps-use-intel_de_rmw-for-panel-unlock.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0396-drm-amd-display-Read-down-spread-percentage-from-lut.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0396-drm-amd-display-remove-unnecessary-braces-to-fix-cod.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0396-drm-i915-Introduce-platform-_hotplug_mask.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0396-drm-sysfs-Register-ddc-symlink-later.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0397-drm-amd-display-Refactor-recout-calculation-with-a-m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0397-drm-amd-display-block-dcn315-dynamic-crb-allocation-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0397-drm-i915-Call-the-DDC-bus-i2c-adapter-ddc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0397-drm-i915-Introduce-intel_hpd_enable_detection.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0398-drm-amd-display-Correct-unit-conversion-for-vstartup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0398-drm-amd-display-Update-Fixed-VS-PE-Retimer-Sequence.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0398-drm-i915-Check-HPD-live-state-during-eDP-probe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0398-drm-i915-lvds-Populate-connector-ddc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0399-drm-amd-display-Update-DPG-test-pattern-programming.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0399-drm-amdkfd-Run-restore_workers-on-freezable-WQs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0399-drm-i915-Reuse-platform-_hotplug_mask-in-.hpd_detect.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0399-drm-i915-crt-Populate-connector-ddc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0400-drm-amd-display-Add-new-sequence-for-4-lane-HBR3-on-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0400-drm-amd-display-FW-Promotion-Release-0.0.194.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0400-drm-i915-dvo-Populate-connector-ddc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0400-drm-i915-use-explicit-includes-for-i915_reg.h-and-i9.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0401-drm-amd-display-Add-DSC-granular-throughput-adjustme.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0401-drm-amdgpu-Fix-style-issues-in-amdgpu_gem.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0401-drm-i915-Use-separate-DC-off-power-well-for-ADL-P-an.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0401-drm-i915-dp-Populate-connector-ddc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0402-drm-amd-display-Promote-DAL-to-3.2.262.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0402-drm-amd-display-Remove-check-for-default-eDP-panel_m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0402-drm-i915-mst-Populate-connector-ddc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0402-drm-i915-mtl-Re-use-ADL-P-s-DC-off-power-well.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0403-drm-amd-display-Rearrange-dmub_cmd-defs-order.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0403-drm-amdgpu-add-amdgpu_reg_state.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0403-drm-i915-hdmi-Use-connector-ddc-everwhere.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0403-drm-i915-wm-remove-stale-and-unused-ilk_wm_max_level.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0404-drm-amd-display-Add-interface-to-modify-DMUB-panel-p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0404-drm-amdgpu-Add-reg_state-sysfs-attribute.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0404-drm-i915-display-split-out-load-detect-to-a-separate.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0404-drm-i915-hdmi-Nuke-hdmi-ddc_bus.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0405-drm-amd-display-Fix-underflow-issue-on-175hz-timing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0405-drm-amdgpu-Read-aquavanjaram-PCIE-register-state.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0405-drm-i915-display-throw-out-struct-intel_load_detect_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0405-drm-i915-hdmi-Remove-old-i2c-symlink.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0406-drm-amd-display-3.2.244.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0406-drm-amdgpu-Read-aquavanjaram-XGMI-register-state.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0406-drm-i915-Relocate-VBLANK_EVASION_TIME_US.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0406-drm-i915-sdvo-Constify-mapping-structs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0407-drm-amd-open-brace-following-struct-go-on-the-same-l.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0407-drm-amdgpu-Skip-access-gfx11-golden-registers-under-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0407-drm-i915-Relocate-intel_atomic_setup_scalers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0407-drm-i915-fbc-replace-GEM_BUG_ON-to-drm_WARN_ON.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0408-drm-amd-pm-open-brace-following-struct-go-on-the-sam.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0408-drm-amdgpu-Fix-missing-mca-debugfs-node.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0408-drm-i915-Relocate-skl_get_pfit_config.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0408-drm-i915-fb-replace-GEM_WARN_ON-with-drm_WARN_ON.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0409-drm-amdgpu-distinguish-rlc-fw-for-different-SKU.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0409-drm-amdgpu-open-brace-following-struct-go-on-the-sam.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0409-drm-i915-Use-REG_BIT-co-for-the-pre-ilk-pfit-registe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0409-drm-i915-dpt-replace-GEM_BUG_ON-with-drm_WARN_ON.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0410-drm-amdgpu-enable-mca-debug-mode-on-APU-by-default.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0410-drm-i915-Namespace-pfit-registers-properly.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0410-drm-i915-move-more-of-the-display-probe-to-display-c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0410-drm-radeon-ERROR-foo-bar-should-be-foo-bar.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0411-drm-amdkfd-avoid-svm-dump-when-dynamic-debug-disable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0411-drm-i915-Use-REG_BIT-co.-for-ilk-pfit-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0411-drm-i915-display-call-gmdid-display-probe-at-a-highe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0412-drm-amdgpu-add-VISIBLE-info-in-amdgpu_bo_print_info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0412-drm-i915-Drop-a-useless-forward-declararion.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0412-drm-i915-move-intel_display_device_probe-one-level-h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0413-drm-amdgpu-fix-the-indexing-issue-during-rlcg-access.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0413-drm-i915-Fix-up-whitespace-in-some-display-chicken-r.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0413-drm-i915-Remove-runtime-suspended-boolean-from-intel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0414-drm-amdgpu-Check-APU-flag-to-disable-RAS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0414-drm-i915-Clean-up-various-display-chicken-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0414-drm-i915-dp_mst-Tune-down-error-message-during-paylo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0415-drm-amdgpu-Add-ENOMEM-error-handling-when-there-is-n.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0415-drm-i915-cx0-Add-step-for-programming-msgbus-timer.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0415-drm-i915-psr-Clean-up-PSR-register-defininitions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0416-drm-amd-display-Remove-else-after-return-in-dm_vblan.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0416-drm-i915-Move-the-SDP-split-debug-spew-to-the-correc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0416-drm-i915-dsi-let-HW-maintain-CLK_POST.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0416-drm-i915-psr-Use-intel_de_rmw.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0417-drm-amdgpu-Remove-else-after-return-in-is_fru_eeprom.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0417-drm-i915-Move-psr-unlock-out-from-the-pipe-update-cr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0417-drm-i915-psr-Define-more-PSR-mask-bits.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0417-drm-i915-psr-Move-plane-sel-fetch-configuration-into.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0418-drm-i915-Change-intel_pipe_update_-start-end-calling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0418-drm-i915-psr-Add-a-FIXME-for-the-PSR-vs.-AUX-usage-c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0418-drm-i915-psr-Add-proper-handling-for-disabling-sel-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0419-drm-amdgpu-Use-seq_puts-instead-of-seq_printf.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0419-drm-i915-Extract-intel_crtc_vblank_evade_scanlines.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0419-drm-i915-psr-Include-PSR_PERF_CNT-in-debugfs-output-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0419-drm-i915-xe2lpd-remove-the-FBC-restriction-if-PSR2-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0420-drm-amdgpu-load-sdma-ucode-in-the-guest-machine.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0420-drm-i915-Enable-VRR-later-during-fastsets.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0420-drm-i915-psr-Include-some-basic-PSR-information-in-t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0420-drm-i915-psr-Sprinkle-cpu_transcoder-variables-aroun.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0421-drm-amd-pm-Vangogh-Add-new-gpu_metrics_v2_4-to-acqui.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0421-drm-i915-Adjust-seamless_m_n-flag-behaviour.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0421-drm-i915-Clean-up-some-DISPLAY_VER-checks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0421-drm-i915-Initialize-dkl_phy-spin-lock-from-display-c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0422-drm-i915-Optimize-out-redundant-M-N-updates.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0422-drm-i915-irq-Improve-error-logging-for-unexpected-DE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0422-drm-i915-mtl-Skip-pcode-qgv-restrictions-for-MTL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0422-drm-radeon-si_dpm-open-brace-following-struct-go-on-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0423-drm-i915-Relocate-is_in_vrr_range.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0423-drm-i915-adlp-Disable-DC5-6-states-for-TC-port-DDI-A.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0423-drm-i915-display-Fix-IP-version-of-the-WAs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0423-drm-radeon-add-missing-spaces-before.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0424-drm-i915-Validate-that-the-timings-are-within-the-VR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0424-drm-i915-dgfx-DGFX-uses-direct-VBT-pin-mapping.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0424-drm-i915-display-Increase-AUX-timeout-for-Type-C.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0424-drm-radeon-add-missing-spaces-after-and-else-should-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0425-drm-i915-Disable-VRR-during-seamless-M-N-changes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0425-drm-i915-mtl-C20-PLL-programming.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0425-drm-i915-use-PIPE_CONF_CHECK_BOOL-for-bool-members.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0425-drm-radeon-that-open-brace-should-be-on-the-previous.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0426-drm-i915-Update-VRR-parameters-in-fastset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0426-drm-i915-add-bool-type-checks-in-PIPE_CONF_CHECK_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0426-drm-i915-mtl-C20-HW-readout.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0426-drm-radeon-that-open-brace-should-be-on-the-previous.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0427-drm-i915-Assert-that-VRR-is-off-during-vblank-evasio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0427-drm-i915-display-Skip-state-verification-with-TBT-AL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0427-drm-i915-mtl-Dump-C20-pll-hw-state.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0427-drm-radeon-Move-assignment-outside-if-condition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0428-drm-amd-pm-add-missing-spaces-before.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0428-drm-i915-Implement-transcoder-LRR-for-TGL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0428-drm-i915-display-split-i915-specific-code-from-intel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0428-drm-i915-mtl-C20-port-clock-calculation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0429-drm-amd-pm-Clean-up-errors-in-navi10_ppt.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0429-drm-i915-add-a-note-about-fec_enable-with-128b-132b.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0429-drm-i915-display-use-intel_bo_to_drm_bo-in-intel_fbd.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0429-drm-i915-mtl-Add-voltage-swing-sequence-for-C20.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0430-Revert-drm-i915-mst-Populate-connector-ddc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0430-drm-amd-pm-Clean-up-errors-in-arcturus_ppt.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0430-drm-i915-display-use-intel_bo_to_drm_bo-in-intel_fb..patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0430-drm-i915-mtl-For-DP2.0-10G-and-20G-rates-use-MPLLA.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0431-drm-amd-pm-Clean-up-errors-in-arcturus_ppt.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0431-drm-i915-display-Convert-intel_fb_modifier_to_tiling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0431-drm-i915-mtl-Enabling-disabling-sequence-Thunderbolt.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0431-drm-i915-xelpdp-Add-XE_LPDP_FEATURES.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0432-drm-amd-pm-that-open-brace-should-be-on-the-previous.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0432-drm-i915-display-Handle-invalid-fb_modifier-in-intel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0432-drm-i915-lnl-Add-display-definitions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0432-drm-i915-mtl-Readout-Thunderbolt-HW-state.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0433-drm-amd-pm-open-brace-following-function-definitions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0433-drm-i915-display-Split-i915-specific-code-away-from-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0433-drm-i915-mtl-Define-mask-for-DDI-AUX-interrupts.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0433-drm-i915-xe2lpd-FBC-is-now-supported-on-all-pipes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0434-drm-amd-pm-open-brace-following-struct-go-on-the-sam.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0434-drm-i915-display-Remove-FBC-capability-from-fused-of.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0434-drm-i915-mtl-Power-up-TCSS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0434-drm-i915-syncmap-squelch-a-sparse-warning.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0435-drm-amdgpu-enable-trap-of-each-kfd-vmid-for-gfx-v9.4.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0435-drm-i915-Re-order-if-else-ladder-in-intel_detect_pch.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0435-drm-i915-display-Don-t-use-proxy-headers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0435-drm-i915-mtl-TypeC-HPD-live-status-query.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0436-drm-amdgpu-Checkpoint-and-Restore-VRAM-BOs-without-V.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0436-drm-i915-dsi-Use-devm_gpiod_get-for-all-GPIOs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0436-drm-i915-mtl-Pin-assignment-for-TypeC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0436-drm-i915-xe2lpd-Add-fake-PCH.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0437-drm-amdgpu-remove-repeat-code-for-mes_add_queue_pkt.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0437-drm-i915-handle-uncore-spinlock-when-not-available.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0437-drm-i915-mtl-Enable-TC-ports.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0437-drm-i915-xe2lpd-Treat-cursor-plane-as-regular-plane-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0438-drm-amdgpu-Fix-ENOSYS-means-invalid-syscall-nr-in-am.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0438-drm-i915-display-dp-128-132b-LT-requirement.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0438-drm-i915-rpm-add-rpm_to_i915-helper-around-container.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0438-drm-i915-xe2lpd-Don-t-try-to-program-PLANE_AUX_DIST.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0439-drm-amdgpu-Fix-no-new-typedefs-for-enum-_AMDGPU_DOOR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0439-drm-i915-Define-bitmasks-for-ilk-pfit-window-pos-siz.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0439-drm-i915-use-intel_connector-in-intel_connector_debu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0439-drm-i915-xe2lpd-Register-DE_RRMR-has-been-removed.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0440-drm-amdgpu-Prefer-dev_-variant-over-printk-in-amdgpu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0440-drm-i915-Remove-dead-scaler-register-defines.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0440-drm-i915-display-Fix-style-and-conventions-for-DP-AU.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0440-drm-i915-pass-struct-intel_connector-to-connector-de.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0441-drm-amdgpu-Move-externs-to-amdgpu.h-file-from-amdgpu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0441-drm-i915-Rename-skl-scaler-binding-bits.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0441-drm-i915-display-Use-_PICK_EVEN_2RANGES-in-DP-AUX-re.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0441-drm-i915-use-octal-permissions-in-display-debugfs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0442-drm-amdkfd-fix-and-enable-ttmp-setup-for-gfx11.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0442-drm-i915-s-PS_COEE_INDEX_AUTO_INC-PS_COEF_INDEX_AUTO.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0442-drm-i915-xe2lpd-Re-order-DP-AUX-regs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0443-drm-i915-Define-bitmasks-for-skl-scaler-window-pos-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0443-drm-i915-display-Add-intel_fb_bo_framebuffer_fini.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0443-drm-i915-xe2lpd-Handle-port-AUX-interrupts.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0443-drm-radeon-Fix-format-error.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0444-drm-Refuse-to-async-flip-with-atomic-prop-changes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0444-drm-amdgpu-add-PSP-14.0.0-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0444-drm-i915-Use-REG_BIT-co.-for-pipe-scaler-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0444-drm-i915-xe2lpd-Read-pin-assignment-from-IOM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0445-drm-allow-DRM_MODE_PAGE_FLIP_ASYNC-for-atomic-commit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0445-drm-amdgpu-discovery-enable-PSP-14.0.0-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0445-drm-i915-Communicate-display-power-demands-to-pcode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0445-drm-i915-xe2lpd-Enable-odd-size-and-panning-for-plan.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0446-drm-amdgpu-Fix-unnecessary-else-after-return-in-amdg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0446-drm-i915-display-Add-new-member-to-configure-PCON-co.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0446-drm-i915-xe2lpd-Add-support-for-HPD.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0446-drm-introduce-DRM_CAP_ATOMIC_ASYNC_PAGE_FLIP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0447-drm-amdgpu-Use-parentheses-for-sizeof-numa_info-in-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0447-drm-i915-dp-Replace-intel_dp.dfp-members-with-the-ne.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0447-drm-i915-xe2lpd-Extend-Wa_15010685871.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0448-drm-atomic-Add-support-for-mouse-hotspots.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0448-drm-i915-dp-Configure-PCON-for-conversion-of-output_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0448-drm-i915-lnl-Add-gmbus-ddc-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0448-drm-radeon-Remove-unnecessary-NULL-test-before-kfree.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0449-drm-i915-display-Use-sink_format-instead-of-ycbcr420.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0449-drm-i915-lnl-Add-CDCLK-table.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0449-drm-radeon-Fix-ENOSYS-with-better-fitting-error-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0449-drm-vmwgfx-Use-the-hotspot-properties-from-cursor-pl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0450-drm-amdgpu-set-completion-status-as-preempted-for-th.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0450-drm-i915-dp-Add-helper-to-get-sink_format.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0450-drm-i915-xe2lpd-Add-display-power-well.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0450-drm-qxl-Use-the-hotspot-properties-from-cursor-plane.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0451-drm-amdgpu-Fix-non-standard-format-specifiers-in-amd.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0451-drm-i915-dp-Rearrange-check-for-illegal-mode-and-com.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0451-drm-i915-xe2lpd-Add-DC-state-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0451-drm-vboxvideo-Use-the-hotspot-properties-from-cursor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0452-drm-amdgpu-correct-vmhub-index-in-GMC-v10-11.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0452-drm-i915-Move-has_hdmi_sink-out-from-intel_hdmi_comp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0452-drm-i915-lnl-Start-using-CDCLK-through-PLL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0452-drm-virtio-Use-the-hotspot-properties-from-cursor-pl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0453-drm-Remove-legacy-cursor-hotspot-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0453-drm-i915-Pick-one-HDMI-port-for-infoframe-audio-tran.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0453-drm-i915-bios-Fixup-h-vsync_end-instead-of-h-vtotal.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0453-drm-xlnx-zynqmp_dp-Fix-function-name-zynqmp_dp_link_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0454-drm-Introduce-DRM_CLIENT_CAP_CURSOR_PLANE_HOTSPOT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0454-drm-i915-Fix-wrong-condition-in-bxt_set_cdclk-for-DG.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0454-drm-i915-display-Print-display-info-inside-driver-di.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0455-drm-Introduce-documentation-for-hotspot-properties.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0455-drm-i915-hdcp-drop-display-prefix-from-include.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0455-drm-i915-irq-Clear-GFX_MSTR_IRQ-as-part-of-IRQ-reset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0455-drm-xlnx-zynqmp_dpsub-Use-dev_err_probe-instead-of-d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0456-drm-i915-Define-more-PS_CTRL-bits.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0456-drm-i915-dp-refactor-aux_ch_name.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0456-drm-xlnx-zynqmp_dpsub-Use-devm_platform_ioremap_reso.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0457-drm-i915-Use-REG_BIT-co.-for-AUX-CH-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0457-drm-i915-cx0-prefer-forward-declarations-over-includ.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0457-drm-ssd130x-Use-shadow-buffer-helpers-when-managing-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0458-drm-i915-Split-map_aux_ch-into-per-platform-arrays.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0458-drm-i915-dsb-Use-non-locked-register-access.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0458-drm-v3d-Avoid-Wconstant-logical-operand-in-nsecs_to_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0458-drm-vmwgfx-Disable-damage-clipping-if-FB-changed-sin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0459-drm-i915-Avoid-Wconstant-logical-operand-in-nsecs_to.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0459-drm-i915-Flip-VBT-DDC-pin-maps-around.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0459-drm-i915-dsb-Define-more-DSB-bits.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0459-drm-plane-Extend-damage-tracking-kernel-doc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0460-drm-i915-Nuke-intel_bios_is_port_dp_dual_mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0460-drm-i915-dsb-Define-the-contents-of-some-intstructio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0460-drm-tegra-Add-error-check-for-NVDEC-firmware-memory-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0460-drm-todo-Add-entry-about-implementing-buffer-age-for.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0461-drm-i915-dsb-Introduce-intel_dsb_noop.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0461-drm-i915-irq-relocate-gmbus-and-dp-aux-irq-handlers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0461-drm-nouveau-use-GPUVM-common-infrastructure.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0461-gpu-host1x-Return-error-when-context-device-not-atta.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0462-drm-i915-dsb-Introduce-intel_dsb_reg_write_masked.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0462-drm-i915-gt-drop-dependency-on-VLV_DISPLAY_BASE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0462-drm-nouveau-implement-1-1-scheduler-entity-relations.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0462-drm-tegra-dpaux-Use-devm_platform_ioremap_resource.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0463-drm-i915-bios-add-helper-for-reading-SPI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0463-drm-i915-dsb-Add-support-for-non-posted-DSB-register.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0463-drm-nouveau-enable-dynamic-job-flow-control.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0463-drm-tegra-Enable-runtime-PM-during-probe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0464-drm-fourcc-define-Intel-Meteorlake-related-ccs-modif.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0464-drm-i915-dsb-Don-t-use-DSB-to-load-the-LUTs-during-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0464-drm-tegra-output-hdmi-Support-bridge-connector.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0465-drm-i915-dsb-Load-LUTs-using-the-DSB-during-vblank.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0465-drm-i915-mtl-Add-handling-for-MTL-ccs-modifiers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0465-drm-sched-Rename-priority-MIN-to-LOW.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0466-drm-i915-dpll-drop-a-useless-I915_STATE_WARN_ON.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0466-drm-i915-dsb-Use-non-posted-register-writes-for-lega.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0466-drm-sched-Reverse-run-queue-priority-enumeration.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0466-drm-tegra-hdmi-Convert-to-devm_platform_ioremap_reso.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0467-drm-i915-crtc-replace-I915_STATE_WARN_ON-with-I915_S.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0467-drm-i915-dsb-Evade-transcoder-undelayed-vblank-when-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0467-drm-tegra-sor-Convert-to-devm_platform_ioremap_resou.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0467-drm-ttm-Schedule-delayed_delete-worker-closer.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0468-drm-i915-Introduce-skl_watermark_max_latency.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0468-drm-i915-display-remove-I915_STATE_WARN_ON.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0468-drm-sched-Fix-compilation-issues-with-DRM-priority-r.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0468-drm-vkms-Add-support-to-1D-gamma-LUT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0469-drm-Use-device_get_match_data.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0469-drm-i915-Introduce-intel_crtc_scanline_to_hw.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0469-drm-i915-display-add-i915-parameter-to-I915_STATE_WA.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0469-drm-vkms-Fix-race-condition-between-the-hrtimer-and-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0470-drm-i915-dsb-Use-DEwake-to-combat-PkgC-latency.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0470-drm-i915-irq-convert-gen8_de_irq_handler-to-void.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0470-drm-imagination-Fix-a-couple-of-spelling-mistakes-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0471-drm-i915-dp-Factor-out-helpers-to-compute-the-link-l.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0471-drm-i915-irq-split-out-hotplug-irq-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0471-drm-imagination-Remove-unneeded-semicolon.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0472-Revert-fbcon-Use-kzalloc-in-fbcon_prepare_logo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0472-drm-i915-dp-Track-the-pipe-and-link-bpp-limits-separ.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0472-drm-i915-irq-split-out-display-irq-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0472-drm-imagination-vm-prevent-duplicate-drm_gpuvm_bo-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0473-drm-i915-dp-Skip-computing-a-non-DSC-link-config-if-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0473-drm-i915-hdcp-add-intel_atomic_state-argument-to-hdc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0473-drm-imagination-vm-check-for-drm_gpuvm_range_valid.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0473-video-logo-LOGO-should-depend-on-FB_CORE-i.s.o.-FB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0474-drm-i915-dp-Update-the-link-bpp-limits-for-DSC-mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0474-drm-i915-hdcp-Remove-enforce_type0-check-outside-loo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0474-drm-imagination-vm-fix-drm_gpuvm-reference-count.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0474-drm-panel-simple-Simplify-matching-using-of_device_g.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0475-drm-ast-Turn-ioregs_lock-to-modeset_lock.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0475-drm-i915-Zap-some-empty-lines.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0475-drm-i915-dp-Limit-the-output-link-bpp-in-DSC-mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0475-drm-i915-hdcp-Fix-modeset-locking-issue-in-hdcp-mst.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0475-drm-imx-dcss-Use-dev_err_probe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0476-drm-ast-Rework-I-O-register-setup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0476-drm-i915-Add-helper-to-modeset-a-set-of-pipes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0476-drm-i915-hdcp-Fill-hdcp2_streamid_type-and-k-in-appr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0477-drm-ast-Retrieve-I-O-memory-ranges-without-ast-devic.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0477-drm-i915-Add-helpers-to-reference-unreference-a-DPLL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0477-drm-i915-Rename-intel_modeset_all_pipes-to-intel_mod.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0478-drm-ast-Add-I-O-helpers-without-ast-device.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0478-drm-i915-Factor-out-a-helper-to-check-compute-all-th.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0478-drm-i915-Make-the-CRTC-state-consistent-during-sanit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0478-drm-imx-ipuv3-ipuv3-plane-reuse-local-variable-heigh.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0479-drm-ast-Enable-VGA-without-ast-device-instance.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0479-drm-i915-Add-helpers-for-BW-management-on-shared-dis.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0479-drm-i915-Update-connector-atomic-state-before-crtc-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0479-gpu-ipu-v3-pre-Convert-to-devm_platform_ioremap_reso.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0480-drm-ast-Enable-MMIO-without-ast-device-instance.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0480-drm-i915-Separate-intel_crtc_disable_noatomic_begin-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0480-drm-i915-fdi-Improve-FDI-BW-sharing-between-pipe-B-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0480-gpu-ipu-v3-prg-Convert-to-devm_platform_ioremap_reso.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0481-drm-ast-Partially-implement-POST-without-ast-device-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0481-drm-bridge_connector-Handle-drm_connector_init_with_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0481-drm-i915-Factor-out-set_encoder_for_connector.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0481-drm-i915-fdi-Recompute-state-for-affected-CRTCs-on-F.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0482-drm-ast-Add-enum-ast_config_mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0482-drm-i915-Add-support-for-disabling-any-CRTCs-during-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0482-drm-i915-Warn-on-if-set-frontbuffer-return-value-is-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0482-drm-udl-Convert-to-drm_crtc_helper_atomic_check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0483-drm-Spelling-s-sempahore-semaphore.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0483-drm-ast-Detect-ast-device-type-and-config-mode-witho.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0483-drm-i915-Update-DRIVER_DATE-to-20230929.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0483-drm-i915-dp-Add-link-training-debug-and-error-printi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0484-drm-Spelling-s-randevouz-rendez-vous.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0484-drm-ast-Move-detection-code-into-PCI-probe-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0484-drm-i915-dp-Convert-link-training-error-to-debug-mes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0485-drm-bridge_connector-stop-filtering-events-in-drm_br.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0485-drm-i915-dp-Prevent-link-training-fallback-on-discon.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0486-drm-bridge_connector-implement-oob_hotplug_event.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0486-drm-i915-dp-Factor-out-intel_dp_get_active_pipes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0487-drm-i915-Factor-out-a-helper-for-handling-atomic-mod.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0487-drm-imagination-Numerous-documentation-fixes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0487-drm-tegra-Remove-surplus-else-after-return.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0487-drm-todo-Add-atomic-modesetting-references.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0488-drm-i915-tc-Call-TypeC-port-flush_work-cleanup-witho.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0488-drm-sched-Partial-revert-of-Qualify-drm_sched_wakeup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0488-drm-tegra-Remove-two-unused-function-declarations.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0488-drm-todo-Convert-list-of-fbconv-links-to-footnotes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0489-drm-i915-tc-Reset-TypeC-PHYs-left-enabled-in-DP-alt-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0489-drm-tegra-hub-Increase-buffer-size-to-ensure-all-pos.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0489-drm-tilcdc-Convert-to-platform-remove-callback-retur.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0490-drm-Fix-references-to-drm_plane_helper_check_state.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0490-drm-i915-fix-intel_display_irq.c-include-order.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0490-gpu-host1x-Add-locking-in-channel-allocation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0491-drm-i915-tweak-language-in-fastset-pipe-config-compa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0491-drm-panel-edp-Add-auo_b116xa3_mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0491-drm-ssd130x-clean-up-some-inconsistent-indenting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0491-gpu-host1x-Stop-CDMA-before-suspending.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0492-drm-i915-mtl-Fix-expected-reg-value-for-Thunderbolt-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0492-drm-panel-edp-Avoid-adding-multiple-preferred-modes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0492-gpu-host1x-Enable-system-suspend-callbacks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0493-drm-bridge-ti-sn65dsi86-Simplify-using-pm_runtime_re.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0493-drm-i915-Add-16bit-register-mask-operators.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0493-drm-tests-helpers-Switch-to-kunit-actions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0493-gpu-host1x-Syncpoint-interrupt-sharding.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0494-drm-i915-hdmi-C20-computed-PLL-frequencies.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0494-drm-loongson-Add-platform-dependency.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0494-drm-tests-client-modeset-Remove-call-to-drm_kunit_he.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0495-drm-i915-dsc-change-DSC-param-tables-to-follow-the-D.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0495-drm-tegra-Zero-initialize-iosys_map.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0495-drm-tests-modes-Remove-call-to-drm_kunit_helper_free.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0496-drm-i915-dsc-move-rc_buf_thresh-values-to-common-hel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0496-drm-tegra-gem-Do-not-return-NULL-in-tegra_bo_mmap.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0496-drm-tests-probe-helper-Remove-call-to-drm_kunit_help.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0497-drm-Remove-plane-hsub-vsub-alignment-requirement-for.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0497-drm-i915-dsc-move-DSC-tables-to-DRM-DSC-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0497-drm-tests-helpers-Create-a-helper-to-allocate-a-lock.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0498-drm-Replace-drm_framebuffer-plane-size-functions-wit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0498-drm-i915-dsc-stop-using-interim-structure-for-calcul.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0498-drm-tests-helpers-Create-a-helper-to-allocate-an-ato.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0499-drm-display-dsc-use-flat-array-for-rc_parameters-loo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0499-drm-simpledrm-Fix-power-domain-device-link-validity-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0499-drm-vc4-tests-pv-muxing-Remove-call-to-drm_kunit_hel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0499-fbdev-vfb-Set-FBINFO_VIRTFB-flag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0500-drm-display-dsc-split-DSC-1.2-and-DSC-1.1-pre-SCR-pa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0500-drm-i915-define-I915-during-i915-driver-build.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0500-drm-vc4-tests-mock-Use-a-kunit-action-to-unregister-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0500-fbdev-vfb-Initialize-fb_ops-with-fbdev-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0501-drm-display-dsc-include-the-rest-of-pre-SCR-paramete.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0501-drm-i915-display-add-I915-conditional-build-to-intel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0501-drm-vc4-tests-pv-muxing-Switch-to-managed-locking-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0501-fbdev-arcfb-Set-FBINFO_VIRTFB-flag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0502-drm-display-dsc-add-YCbCr-4-2-2-and-4-2-0-RC-paramet.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0502-drm-i915-display-add-I915-conditional-build-to-hsw_i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0502-drm-vc4-tests-Switch-to-atomic-state-allocation-help.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0502-fbdev-arcfb-Use-generator-macros-for-deferred-I-O.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0503-drm-i915-constify-pointers-to-hwmon_channel_info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0503-drm-i915-display-add-I915-conditional-build-to-i9xx_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0503-drm-vc4-tests-pv-muxing-Document-test-scenario.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0503-fbdev-sh_mobile_lcdcfb-Set-FBINFO_VIRTFB-flag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0504-drm-i915-Support-Async-Flip-on-Linear-buffers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0504-drm-i915-display-add-I915-conditional-build-to-intel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0504-drm-panel-r66451-select-CONFIG_DRM_DISPLAY_DP_HELPER.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0504-fbdev-sh_mobile_lcdcfb-Initialize-fb_ops-with-fbdev-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0505-drm-i915-Wait-for-active-retire-before-i915_active_f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0505-drm-i915-display-add-I915-conditional-build-to-intel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0505-drm-panel-simple-specify-bpc-for-powertip_ph800480t0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0505-fbdev-smscufx-Select-correct-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0506-drm-i915-Replace-all-non-returning-strlcpy-with-strs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0506-drm-i915-display-add-I915-conditional-build-to-intel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0506-drm-panel-ilitek-ili9881c-Add-TDO-TL050HDV35-LCD-pan.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0506-fbdev-udlfb-Select-correct-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0507-drm-i915-display-add-I915-conditional-build-to-intel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0507-drm-panel-Support-for-startek-kd070fhfid015-MIPI-DSI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0507-fbdev-au1200fb-Set-FBINFO_VIRTFB-flag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0508-drm-i915-Convert-INTEL_INFO-display-to-a-pointer.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0508-drm-i915-display-add-I915-conditional-build-to-intel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0508-fbdev-au1200fb-Initialize-fb_ops-with-fbdev-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0509-drm-i915-display-Move-display-runtime-info-to-displa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0509-drm-i915-display-add-I915-conditional-build-to-g4x_d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0509-fbdev-Use-_IOMEM_-infix-for-I-O-memory-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0509-fbdev-ps3fb-Set-FBINFO_VIRTFB-flag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0510-drm-i915-display-Make-display-responsible-for-probin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0510-drm-i915-display-add-I915-conditional-build-to-intel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0510-fbdev-Use-_SYSMEM_-infix-for-system-memory-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0510-fbdev-ps3fb-Initialize-fb_ops-with-fbdev-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0511-drm-i915-display-Handle-GMD_ID-identification-in-dis.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0511-drm-i915-display-add-I915-conditional-build-to-intel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0511-fbdev-Use-_DMAMEM_-infix-for-DMA-memory-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0511-fbdev-clps711x-fb-Initialize-fb_ops-with-fbdev-macro.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0512-drm-i915-display-Move-feature-test-macros-to-intel_d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0512-drm-i915-display-add-I915-conditional-build-to-vlv_d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0512-fbdev-Align-deferred-I-O-with-naming-of-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0512-fbdev-vt8500lcdfb-Initialize-fb_ops-with-fbdev-macro.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0513-drm-i915-Fix-clang-Wimplicit-fallthrough-in-intel_as.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0513-drm-i915-display-add-I915-conditional-build-to-i9xx_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0513-drm-virtio-Support-sync-objects.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0513-fbdev-wm8505fb-Initialize-fb_ops-to-fbdev-I-O-memory.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0514-drm-i915-Expose-crtc-CTM-property-on-ilk-snb.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0514-drm-i915-display-add-I915-conditional-build-to-g4x_h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0514-drm-tests-Alloc-drm_device-on-drm_exec-tests.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0514-fbdev-cyber2000fb-Initialize-fb_ops-with-fbdev-macro.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0515-drm-i915-Fix-CHV-CGM-CSC-coefficient-sign-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0515-drm-i915-display-add-I915-conditional-build-to-intel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0515-drm-panel-sitronix-st7789v-add-SPI-ID-table.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0515-fbdev-Rename-FB_SYS_FOPS-token-to-FB_SYSMEM_FOPS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0516-drm-i915-Always-enable-CGM-CSC-on-CHV.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0516-drm-i915-display-add-I915-conditional-build-to-intel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0516-drm-panel-sitronix-st7789v-remove-unused-constants.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0516-fbdev-Remove-trailing-whitespaces.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0517-drm-i915-Implement-CTM-property-support-for-VLV.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0517-drm-i915-display-add-I915-conditional-build-to-intel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0517-drm-panel-sitronix-st7789v-make-reset-GPIO-optional.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0517-fbdev-Push-pgprot_decrypted-into-mmap-implementation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0518-drm-i915-display-add-I915-conditional-build-to-vlv_d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0518-drm-i915-hdcp-Rename-dev_priv-to-i915.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0518-drm-panel-sitronix-st7789v-simplify-st7789v_spi_writ.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0518-fbdev-Avoid-file-argument-in-fb_pgprotect.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0518-fbdev-Move-default-fb_mmap-code-into-helper-function.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0519-arch-m68k-Merge-variants-of-fb_pgprotect-into-single.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0519-drm-i915-display-Include-i915_active-header-in-front.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0519-drm-i915-hdcp-Move-away-from-master-naming-to-arbite.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0519-drm-panel-sitronix-st7789v-improve-error-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0519-fbdev-Warn-on-incorrect-framebuffer-access.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0520-arch-m68k-Implement-asm-fb.h-with-generic-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0520-drm-i915-Abstract-display-info-away-during-probe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0520-drm-i915-hdcp-Rename-comp_mutex-to-hdcp_mutex.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0520-drm-panel-sitronix-st7789v-avoid-hardcoding-mode-inf.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0520-fbdev-Remove-default-file-I-O-implementations.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0521-Documentation-gpu-VM_BIND-locking-document.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0521-drm-i915-use-localized-__diag_ignore_all-instead-of-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0521-drm-panel-sitronix-st7789v-avoid-hardcoding-panel-si.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0521-fbdev-Replace-fb_pgprotect-with-pgprot_framebuffer.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0522-drm-edid-parse-display-info-has_audio-similar-to-is_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0522-drm-nouveau-Removes-unnecessary-args-check-in-nouvea.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0522-drm-panel-sitronix-st7789v-add-media-bus-format.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0523-drm-display-dp_mst-drop-has_audio-from-struct-drm_dp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0523-drm-i915-lnl-possibility-to-enable-FBC-on-first-thre.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0523-drm-imagination-Fix-error-codes-in-pvr_device_clk_in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0523-drm-panel-sitronix-st7789v-avoid-hardcoding-invert-m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0524-drm-i915-dp-stop-caching-has_audio-in-struct-intel_d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0524-drm-i915-lnl-update-the-supported-plane-formats-with.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0524-drm-imagination-Fix-IS_ERR-vs-NULL-bug-in-pvr_reques.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0524-drm-panel-sitronix-st7789v-avoid-hardcoding-polarity.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0525-drm-i915-convert-INTEL_DISPLAY_ENABLED-into-a-functi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0525-drm-i915-dp-stop-caching-has_hdmi_sink-in-struct-int.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0525-drm-imagination-fix-off-by-one-in-pvr_vm_mips_init-e.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0525-drm-panel-sitronix-st7789v-add-Inanbo-T28CP45TN89-su.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0526-dma-buf-Correct-the-documentation-of-name-and-exp_na.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0526-drm-i915-hdmi-stop-caching-has_audio-in-struct-intel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0526-drm-i915-move-display-info-related-macros-to-display.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0526-drm-panel-sitronix-st7789v-Use-9-bits-per-spi-word-b.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0527-drm-i915-hdmi-stop-caching-has_hdmi_sink-in-struct-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0527-drm-i915-separate-display-runtime-info-init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0527-drm-omapdrm-Improve-check-for-contiguous-buffers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0527-drm-panel-sitronix-st7789v-Clarify-a-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0528-drm-i915-sdvo-stop-caching-has_hdmi_monitor-in-struc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0528-drm-i915-separate-subplatform-init-and-runtime-featu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0528-drm-panel-sitronix-st7789v-Add-EDT-ET028013DMA-panel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0528-drm-tidss-Add-support-for-AM62A7-DSS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0529-accel-qaic-remove-redundant-pointer-pexec.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0529-drm-i915-Stop-requiring-PLL-index-PLL-ID.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0529-drm-i915-sdvo-stop-caching-has_hdmi_audio-in-struct-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0529-drm-panel-sitronix-st7789v-Check-display-ID.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0529-drm-tidss-Use-pm_runtime_resume_and_get.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0530-drm-edid-add-drm_edid_read_switcheroo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0530-drm-i915-Decouple-I915_NUM_PLLS-from-PLL-IDs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0530-drm-panel-edp-Add-enable-timings-for-N140HCA-EAC-pan.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0530-drm-tidss-Use-PM-autosuspend.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0531-drm-i915-Introduce-for_each_shared_dpll.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0531-drm-i915-lvds-switch-to-drm_edid_read_switcheroo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0531-drm-panel-Check-for-already-prepared-enabled-in-drm_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0531-drm-tidss-Drop-useless-variable-init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0532-drm-edid-make-drm_edid_duplicate-safe-to-call-with-N.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0532-drm-i915-s-dev_priv-i915-in-the-shared_dpll-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0532-drm-panel-Add-a-way-for-other-devices-to-follow-pane.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0533-drm-bridge-Add-debugfs-print-for-bridge-chains.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0533-drm-display-dp_mst-convert-to-struct-drm_edid.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0533-drm-i915-mocs-use-to_gt-instead-of-direct-i915-gt.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0534-drm-i915-allocate-i915-gt0-dynamically.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0534-drm-i915-display-switch-the-rest-of-the-connectors-t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0534-drm-mipi-dbi-Lock-SPI-bus-before-setting-D-C-GPIO.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0535-drm-i915-gt-remove-i915-gt0-in-favour-of-i915-gt-0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0535-drm-i915_drm.h-fix-a-typo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0535-drm-tidss-Add-simple-K2G-manual-reset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0535-drm-tiny-panel-mipi-dbi-Allow-sharing-the-D-C-GPIO.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0536-drm-i915-Remove-i915_drm_suspend_mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0536-drm-i915-display-lspcon-Increase-LSPCON-mode-settle-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0536-drm-panel-Fix-kernel-doc-typo-for-follower_lock.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0537-drm-i915-Flush-power-delayed-put-when-connector-init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0537-drm-i915-dp_mst-Make-sure-pbn_div-is-up-to-date-afte.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0537-drm-panel-Fix-todo-indentation-for-panel-prepared-en.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0537-drm-tidss-IRQ-code-cleanup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0538-drm-i915-display-Created-exclusive-version-of-vga-de.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0538-drm-i915-mtl-Reset-only-one-lane-in-case-of-MFD.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0538-drm-panel-simple-Add-Innolux-G156HCE-L01-panel-entry.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0539-drm-bridge-dw_hdmi-Add-cec-suspend-resume-functions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0539-drm-i915-gsc-use-system-include-style-for-drm-header.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0539-drm-i915-pmu-Use-local64_try_cmpxchg-in-i915_pmu_eve.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0539-drm-tidss-Use-DRM_PLANE_COMMIT_ACTIVE_ONLY.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0540-drm-drm_plane.h-fix-grammar-of-the-comment.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0540-drm-i915-fbc-Remove-ancient-16k-plane-stride-limit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0540-drm-i915-gem-Use-large-rings-for-compute-contexts.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0540-drm-v3d-Remove-unused-function-header.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0541-drm-i915-fbc-Split-plane-stride-checks-per-platform.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0541-drm-i915-guc-Use-FAST_REQUEST-for-non-blocking-H2G-c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0541-drm-v3d-Move-wait-BO-ioctl-to-the-v3d_bo-file.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0541-fbcon-Make-fbcon_registered_fb-and-fbcon_num_registe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0542-drm-doc-use-proper-cross-references-for-sections.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0542-drm-i915-fbc-Split-plane-tiling-checks-per-platform.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0542-drm-i915-guc-Update-log-for-unsolicited-CTB-response.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0542-drm-v3d-Detach-job-submissions-IOCTLs-to-a-new-speci.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0543-drm-doc-add-warning-about-connector_type_id-stabilit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0543-drm-i915-fbc-Split-plane-rotation-checks-per-platfor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0543-drm-i915-guc-Track-all-sent-actions-to-GuC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0543-drm-v3d-Simplify-job-refcount-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0544-drm-doc-document-drm_event-and-its-types.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0544-drm-i915-fbc-Split-plane-pixel-format-checks-per-pla.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0544-drm-i915-guc-Drop-legacy-CTB-definitions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0544-drm-v3d-Don-t-allow-two-multisync-extensions-in-the-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0545-drm-doc-document-that-PRIME-import-export-is-always-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0545-drm-i915-fbc-Remove-pointless-stride-is-multiple-of-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0545-drm-i915-pmu-Turn-off-the-timer-to-sample-frequencie.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0545-drm-v3d-Decouple-job-allocation-from-job-initiation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0546-drm-i915-pmu-Make-PMU-sample-array-two-dimensional.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0546-drm-i915-psr-Unify-PSR-pre-post-plane-update-hooks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0546-drm-v3d-Add-a-CPU-job-submission.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0546-fbdev-ps3fb-Build-without-kernel-device.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0547-drm-i915-Stop-clobbering-old-crtc-state-during-state.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0547-drm-i915-gmch-avoid-unused-variable-warning.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0547-drm-i915-gt-Fix-second-parameter-type-of-pre-gen8-pt.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0547-drm-v3d-Use-v3d_get_extensions-to-parse-CPU-job-data.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0548-drm-i915-Constify-the-crtc-states-in-the-DPLL-checke.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0548-drm-i915-dsi-Do-panel-power-on-reset-deassert-earlie.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0548-drm-i915-gt-Fix-parameter-in-gmch_ggtt_insert_-entri.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0548-drm-v3d-Create-tracepoints-to-track-the-CPU-job.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0549-drm-i915-Simplify-DPLL-state-checker-calling-convent.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0549-drm-i915-dsi-Do-display-on-sequence-later-on-icl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0549-drm-i915-gt-limit-lmem-allocation-size-to-succeed-on.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0549-drm-v3d-Detach-the-CSD-job-BO-setup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0550-drm-i915-Constify-watermark-state-checker.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0550-drm-i915-dsi-Print-the-VBT-MIPI-sequence-delay-durat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0550-drm-i915-pxp-Fix-size_t-format-specifier-in-gsccs_se.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0550-drm-v3d-Enable-BO-mapping.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0551-drm-i915-Simplify-watermark-state-checker-calling-co.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0551-drm-i915-dsi-Split-icl-D-PHY-vs.-DSI-timing-steps.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0551-drm-v3d-Create-a-CPU-job-extension-for-a-indirect-CS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0552-drm-i915-Constify-the-snps-c10x-PLL-state-checkers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0552-drm-i915-dsi-Gate-DSI-clocks-earlier.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0552-drm-i915-uc-perma-pin-firmwares.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0552-drm-v3d-Create-a-CPU-job-extension-for-the-timestamp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0553-drm-i915-Simplify-snps-c10x-DPLL-state-checker-calli.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0553-drm-i915-dsi-Respect-power-cycle-delay-on-icl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0553-drm-i915-huc-Parse-the-GSC-enabled-HuC-binary.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0553-drm-v3d-Create-a-CPU-job-extension-for-the-reset-tim.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0554-drm-i915-Constify-remainder-of-the-state-checker.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0554-drm-i915-dsi-Implement-encoder-shutdown-for-icl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0554-drm-i915-huc-Load-GSC-enabled-HuC-via-DMA-xfer-if-th.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0554-drm-v3d-Create-a-CPU-job-extension-to-copy-timestamp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0555-drm-i915-Simplify-the-state-checker-calling-convetio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0555-drm-i915-dsi-Move-most-things-from-.disable-into-.po.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0555-drm-i915-huc-differentiate-the-2-steps-of-the-MTL-Hu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0555-drm-v3d-Create-a-CPU-job-extension-for-the-reset-per.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0556-drm-i915-dsi-Do-DSC-scaler-disable-earlier-on-icl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0556-drm-i915-mtl-huc-auth-HuC-via-GSC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0556-drm-i915-s-pipe_config-crtc_state-in-the-state-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0556-drm-v3d-Create-a-CPU-job-extension-for-the-copy-perf.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0557-drm-i915-dsi-Respect-power_off_delay-on-icl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0557-drm-i915-mtl-huc-Use-the-media-gt-for-the-HuC-getpar.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0557-drm-i915-s-dev_priv-i915-in-the-state-checker.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0558-accel-qaic-Increase-number-of-in_reset-states.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0558-drm-i915-ddi-Remove-redundant-intel_connector-NULL-c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0558-drm-i915-dsi-Move-panel-reset-power-off-to-be-the-la.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0558-drm-i915-huc-define-HuC-FW-version-for-MTL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0559-accel-qaic-Expand-DRM-device-lifecycle.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0559-drm-i915-Use-the-fdinfo-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0559-drm-i915-dsi-Grab-the-crtc-from-the-customary-place.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0559-drm-i915-uapi-fix-doc-typos.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0560-drm-i915-Fix-VLV-color-state-readout.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0560-drm-i915-Reduce-I915_MAX_GT-to-2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0560-drm-i915-dsi-Remove-weird-has_pch_encoder-asserts.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0560-drm-syncobj-Add-deadline-support-for-syncobj-waits.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0561-dma-buf-sync_file-Add-SET_DEADLINE-ioctl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0561-drm-i915-display-Free-crtc_state-in-verify_crtc_stat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0561-drm-i915-hdcp-Modify-hdcp_gsc_message-msg-sending-me.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0561-drm-i915-rename-I915_PMU_MAX_GTS-to-I915_PMU_MAX_GT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0562-dma-buf-sw_sync-Add-fence-deadline-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0562-drm-i915-Add-wrapper-for-getting-display-step.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0562-drm-i915-guc-Remove-some-obsolete-definitions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0562-drm-i915-mtl-Cleanup-usage-of-phy-lane-reset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0563-drm-Introduce-pixel_source-DRM-plane-property.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0563-drm-i915-Allow-user-to-set-cache-at-BO-creation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0563-drm-i915-Re-init-clock-gating-on-coming-out-of-PC8.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0563-drm-i915-xe2lpd-display-capability-register-definiti.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0564-drm-Introduce-solid-fill-DRM-plane-property.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0564-drm-i915-psr-Wrap-PSR1-register-with-functions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0564-drm-i915-xe2lpd-update-the-dsc-feature-capability.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0564-i915-perf-Drop-the-aging_tail-logic-in-perf-OA.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0565-drm-Add-solid-fill-pixel-source.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0565-drm-i915-psr-Reintroduce-HSW-PSR1-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0565-drm-i915-xe2lpd-update-the-scaler-feature-capability.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0565-i915-perf-Do-not-add-ggtt-offset-to-hw_tail.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0566-drm-atomic-Add-pixel-source-to-plane-state-dump.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0566-drm-i915-gsc-Fix-error-code-in-intel_gsc_uc_heci_cmd.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0566-drm-i915-gvt-remove-unused-to_gvt-and-reduce-include.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0566-drm-i915-psr-Bring-back-HSW-BDW-PSR-AUX-CH-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0567-drm-amd-display-Refactor-ABM-feature.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0567-drm-atomic-Add-solid-fill-data-to-plane-state-dump.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0567-drm-i915-gvt-don-t-include-gvt.h-from-intel_gvt_mmio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0567-drm-i915-psr-HSW-BDW-have-no-PSR2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0568-drm-atomic-Move-framebuffer-checks-to-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0568-drm-i915-gvt-move-struct-engine_mmio-to-mmio_context.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0568-drm-i915-psr-Restore-PSR-interrupt-handler-for-HSW.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0569-drm-amd-display-Check-log-if-receiver-supports-MST-D.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0569-drm-atomic-Loosen-FB-atomic-checks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0569-drm-i915-gvt-move-structs-intel_gvt_irq_info-and-int.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0569-drm-i915-psr-Implement-WaPsrDPAMaskVBlankInSRD-hsw.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0570-drm-amd-display-Fix-ABM-pipe-backlight-issues-when-c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0570-drm-i915-drop-Wall-and-related-disables-from-cflags-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0570-drm-i915-psr-Implement-WaPsrDPRSUnmaskVBlankInSRD-hs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0570-drm-improve-the-documentation-of-connector-hpd-ops.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0571-drm-amd-display-Do-not-set-drr-on-pipe-commit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0571-drm-i915-enable-W-1-warnings-by-default.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0571-drm-i915-psr-Do-no-mask-display-register-writes-on-h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0571-drm-remove-drm_bridge_hpd_disable-from-drm_bridge_co.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0572-drm-amd-display-Block-optimize-on-consecutive-FAMS-e.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0572-drm-i915-display-Use-intel_crtc_destroy_state-instea.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0572-drm-i915-psr-Don-t-skip-both-TP1-and-TP2-3-on-hsw-bd.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0572-drm-test-add-a-test-suite-for-GEM-objects-backed-by-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0573-drm-amd-display-Fix-in-disabling-secure-display.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0573-drm-i915-display-Use-correct-method-to-free-crtc_sta.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0573-drm-i915-psr-Allow-PSR-with-sprite-enabled-on-hsw-bd.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0573-drm-imagination-Fixed-warning-due-to-implicit-cast-t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0574-drm-amd-display-update-max-streams-per-surface.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0574-drm-i915-hdcp-Move-checks-for-gsc-health-status.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0574-drm-i915-psr-Re-enable-PSR1-on-hsw-bdw.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0574-drm-imagination-Fixed-missing-header-in-pvr_fw_meta.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0575-drm-amd-display-Only-consider-DISPCLK-when-using-opt.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0575-drm-i915-Remove-bogus-DDI-F-from-hsw-bdw-output-init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0575-drm-i915-hdcp-Move-common-message-filling-function-t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0575-drm-imagination-pvr_device_process_active_queues-now.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0576-drm-amd-display-refactor-dmub-commands-into-single-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0576-drm-i915-Introduce-device-info-port_mask.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0576-drm-i915-Remove-the-module-parameter-fastboot.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0576-drm-imagination-pvr_gpuvm_free-now-static.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0577-drm-amd-display-drain-dmub-inbox-if-queue-is-full.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0577-drm-i915-Assert-that-device-info-bitmasks-have-enoug.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0577-drm-i915-vlv_dsi-Add-DMI-quirk-for-wrong-panel-model.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0577-drm-imagination-Removed-unused-function-to_pvr_vm_gp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0578-drm-i915-Assert-that-the-port-being-initialized-is-v.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0578-drm-i915-vlv_dsi-Add-DMI-quirk-for-wrong-I2C-bus-and.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0579-drm-amd-display-Adding-support-for-VESA-SCR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0579-drm-i915-Beef-up-SDVO-HDMI-port-checks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0579-drm-i915-vlv_dsi-Add-DMI-quirk-for-backlight-control.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0579-drm-qxl-remove-unused-declaration.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0580-drm-amd-display-DSC-policy-override-when-ODM-combine.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0580-drm-display-dp-Add-the-remaining-Square-PHY-patterns.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0580-drm-i915-Init-DDI-outputs-based-on-port_mask-on-skl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0580-drm-i915-dsi-Add-some-debug-logging-to-mipi_exec_i2c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0581-drm-amd-display-Correct-output-color-space-during-HW.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0581-drm-bridge-lt8912b-Add-suspend-resume-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0581-drm-i915-Convert-HSW-BDW-to-use-port_mask-for-DDI-pr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0581-drm-i915-Introduce-intel_gt_mcr_lock_sanitize.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0582-drm-amd-display-Set-watermarks-set-D-equal-to-A.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0582-drm-bridge-lt8912b-Add-power-supplies.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0582-drm-i915-Introduce-the-intel_gt_resume_early.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0582-drm-i915-mtl-update-DP-2.0-vswing-table-for-C20-phy.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0583-drm-amd-display-Enable-FPO-Vactive.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0583-drm-i915-Clean-steer-semaphore-on-resume.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0583-drm-i915-mtl-Add-new-vswing-table-for-C20-phy-to-sup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0584-drm-amd-display-FW-Promotion-Release-0.0.162.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0584-drm-bridge-add-transparent-bridge-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0584-drm-i915-mtl-Skip-MCR-ops-for-ring-fault-register.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0584-drm-i915-mtl-Skip-using-vbt-hdmi_level_shifter-selec.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0585-drm-amd-display-add-extra-dc-odm-debug-options.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0585-drm-bridge-implement-generic-DP-HPD-bridge.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0585-drm-i915-gem-Make-i915_gem_shrinker-multi-gt-aware.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0585-drm-i915-hdcp-Add-a-debug-statement-at-hdcp2-capabil.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0586-drm-amd-display-add-mechanism-to-skip-DCN-init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0586-drm-encoder-register-per-encoder-debugfs-dir.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0586-drm-i915-Lift-runtime-pm-acquire-callbacks-out-of-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0586-drm-i915-Remove-redundant-forward-declarations-from-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0587-drm-amd-display-Write-TEST_EDID_CHECKSUM_WRITE-for-E.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0587-drm-bridge-migrate-bridge_chains-to-per-encoder-file.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0587-drm-i915-Add-way-to-specify-the-power-off-delay-of-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0587-drm-i915-Create-a-kernel-context-for-GGTT-updates.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0588-Revert-drm-atomic-Loosen-FB-atomic-checks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0588-drm-i915-Implement-for_each_sgt_daddr_next.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0588-drm-i915-Prevent-needless-toggling-of-DC-states-duri.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0589-Revert-drm-atomic-Move-framebuffer-checks-to-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0589-drm-doc-fix-duplicate-declaration-warning.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0589-drm-i915-Parameterize-binder-context-creation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0590-Revert-drm-atomic-Add-solid-fill-data-to-plane-state.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0590-drm-i915-Implement-GGTT-update-method-with-MI_UPDATE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0590-drm-i915-Remove-prototype-for-intel_cx0_phy_ddi_vswi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0591-Revert-drm-atomic-Add-pixel-source-to-plane-state-du.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0591-drm-amdgpu-Increase-GFX6-graphics-ring-size.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0591-drm-i915-Toggle-binder-context-ready-status.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0591-drm-i915-move-platform_engine_mask-and-memory_region.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0592-Revert-drm-Add-solid-fill-pixel-source.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0592-drm-amdgpu-Add-a-max-ibs-per-submission-limit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0592-drm-i915-Enable-GGTT-updates-with-binder-in-MTL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0592-drm-i915-separate-display-info-printing-from-the-res.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0593-Revert-drm-Introduce-solid-fill-DRM-plane-property.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0593-drm-amdgpu-Add-support-for-querying-the-max-ibs-in-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0593-drm-i915-Clarify-type-evolution-of-uabi_node-uabi_en.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0593-drm-i915-fix-display-info-usage.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0594-Revert-drm-Introduce-pixel_source-DRM-plane-property.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0594-drm-amd-pm-Fix-spelling-mistake-aquire-acquire.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0594-drm-i915-guc-Suppress-ignoring-reset-notification-me.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0594-drm-i915-move-display-device-and-runtime-info-to-str.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0595-drm-amd-display-remove-unused-variable-oldest_index.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0595-drm-i915-guc-Update-recommended-version-to-70.12.1-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0595-drm-i915-make-device-info-a-const-pointer-to-rodata.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0595-drm-v3d-Fix-missing-error-code-in-v3d_submit_cpu_ioc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0596-drm-gpuvm-fall-back-to-drm_exec_lock_obj.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0596-drm-i915-guc-Annotate-struct-ct_incoming_msg-with-__.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0596-drm-i915-uncore-add-intel_uncore_regs-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0597-drm-amdgpu-convert-gfx.kiq-to-array-type-v3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0597-drm-i915-dram-replace-__raw_uncore_read32-with-intel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0597-drm-i915-guc-Enable-WA-14018913170.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0597-drm-imagination-vm-make-use-of-GPUVM-s-drm_exec-help.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0598-drm-amdgpu-move-queue_bitmap-to-an-independent-struc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0598-drm-i915-Fail-if-DSC-compression-requirement-is-less.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0598-drm-i915-gt-More-use-of-GT-specific-print-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0598-drm-panel-simple-Add-BOE-BP101WX1-100-panel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0599-drm-amdgpu-separate-the-mqd_backup-for-kiq-from-kcq.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0599-drm-i915-Initialize-dig_port-aux_ch-to-NONE-to-be-su.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0599-drm-i915-More-use-of-GT-specific-print-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0599-drm-panel-himax-hx8394-Drop-prepare-unprepare-tracki.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0600-accel-habanalabs-add-tsc-clock-sampling-to-clock-syn.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0600-drm-amdgpu-add-multi-xcc-support-to-amdgpu_gfx-inter.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0600-drm-i915-Only-populate-aux_ch-if-really-needed.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0600-drm-panel-himax-hx8394-Drop-shutdown-logic.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0601-accel-habanalabs-change-Greco-to-Gaudi2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0601-drm-amdgpu-split-gc-v9_4_3-functionality-from-gc-v9_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0601-drm-i915-Remove-DDC-pin-sanitation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0601-drm-panel-himax-hx8394-Add-Panel-Rotation-Support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0602-drm-amd-amdgpu-Use-kmemdup-to-simplify-kmalloc-and-m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0602-drm-amdgpu-add-xcc-index-argument-to-soc15_grbm_sele.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0602-drm-i915-Remove-AUX-CH-sanitation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0602-drm-panel-himax-hx8394-Add-Support-for-Powkiddy-X55-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0603-drm-amdgpu-Keep-reset-handlers-shared.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0603-drm-amdgpu-add-multi-XCC-initial-support-in-gfx_v9_4.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0603-drm-i915-bios-Extract-intel_bios_encoder_port.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0603-drm-panel-ilitek-ili9881c-make-use-of-prepare_prev_f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0604-drm-amd-display-Fix-unnecessary-conversion-to-bool-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0604-drm-amdgpu-add-xcc-index-argument-to-gfx-v9_4_3-func.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0604-drm-i915-Try-to-initialize-DDI-ICL-DSI-ports-for-eve.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0604-drm-panel-ilitek-ili9881c-Add-Ampire-AM8001280G-LCD-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0605-drm-amdgpu-add-xcc-index-argument-to-select_sh_se-fu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0605-drm-i915-Add-helper-function-for-getting-number-of-V.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0605-drm-panel-simple-add-Evervision-VGG644804-panel-entr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0605-drm-radeon-Cleanup-radeon-radeon_fence.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0606-drm-amd-display-Fix-useless-else-if-in-display_mode_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0606-drm-amdgpu-add-xcc-index-argument-to-rlc-safe_mode-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0606-drm-i915-Don-t-rely-that-2-VDSC-engines-are-always-e.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0607-drm-amd-display-Clear-GPINT1-before-taking-DMCUB-out.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0607-drm-amd-display-Expose-mall-capability.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0607-drm-panfrost-Add-gpu_irq-mmu_irq-to-struct-panfrost_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0607-i915-display-hotplug-use-drm_kms_helper_connector_ho.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0608-drm-amd-display-PQ-tail-accuracy.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0608-drm-amdgpu-add-master-slave-check-in-init-phase.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0608-drm-i915-dsc-Move-rc-param-calculation-for-native_42.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0608-drm-panfrost-Synchronize-and-disable-interrupts-befo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0609-drm-amd-display-PQ-regamma-end-point.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0609-drm-amdgpu-initialize-num_xcd-to-1-for-gfx-v9_0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0609-drm-gpuvm-Let-drm_gpuvm_bo_put-report-when-the-vm_bo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0609-drm-i915-drm-Fix-comment-for-YCbCr20-qp-table-declar.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0610-drm-atomic-add-private-obj-state-to-state-dump.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0610-drm-i915-dsc-Add-rc_range_parameter-calculation-for-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0611-drm-amd-display-Enable-runtime-register-offset-init-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0611-drm-amdgpu-Drop-pcie_bif-ras-check-from-fatal-error-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0611-drm-i915-vdsc-Remove-FIXME-in-intel_dsc_compute_conf.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0611-drm-panel-edp-Add-SDC-ATNA45AF01.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0612-drm-amd-amdgpu-Fix-spaces-in-array-indexing-and-inde.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0612-drm-amd-display-Write-flip-addr-to-scratch-reg-for-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0612-drm-edp-panel-Sort-the-panel-entries.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0612-drm-i915-display-Do-not-use-stolen-on-MTL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0613-drm-amd-amdgpu-Fix-style-errors-in-amdgpu_drv.c-amdg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0613-drm-i915-Start-using-plane-scale-factor-for-relative.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0614-drm-Include-drm-drm_auth.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0614-drm-amdgpu-allocate-doorbell-index-for-multi-die-cas.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0614-drm-amdgpu-use-6.1.0-register-offset-for-HDP-CLK_CNT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0614-drm-i915-Simplify-expression-to_i915-dev-drm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0615-drm-amd-display-Remove-unused-variables-in-dcn21_hws.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0615-drm-amdgpu-add-new-AMDGPU_FAMILY-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0615-drm-i915-Include-drm-drm_auth.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0615-drm-i915-hotplug-Reduce-SHPD_FILTER-to-250us.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0616-accel-Include-drm-drm_auth.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0616-drm-amd-amdgpu-Fix-style-issues-in-amdgpu_discovery..patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0616-drm-amdgpu-soc21-add-initial-GC-11.5.0-soc21-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0616-drm-i915-color-Upscale-degamma-values-for-MTL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0617-drm-Include-drm-drm_device.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0617-drm-amd-display-add-support-for-low-bpc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0617-drm-amdgpu-discovery-enable-soc21-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0617-drm-i915-color-Downscale-degamma-lut-values-read-fro.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0618-drm-amd-display-Set-DRAM-clock-if-retraining-is-requ.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0618-drm-amdgpu-add-nbio-7.11-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0618-drm-i915-Add-macros-to-get-i915-device-from-i915_gem.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0618-drm-radeon-Do-not-include-drm-drm_legacy.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0619-drm-Remove-entry-points-for-legacy-ioctls.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0619-drm-amd-display-Add-check-for-PState-change-in-DCN32.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0619-drm-amdgpu-add-nbio-7.11-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0619-drm-i915-Add-getter-setter-for-i915_gem_object-front.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0620-drm-Remove-the-legacy-DRM_IOCTL_MODESET_CTL-ioctl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0620-drm-amd-display-Limit-nv21-dst_y.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0620-drm-amdgpu-discovery-add-nbio-7.11.0-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0620-drm-i915-display-Remove-i915_gem_object_types.h-from.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0621-drm-Remove-support-for-legacy-drivers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0621-drm-amd-display-correct-DML-calc-error.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0621-drm-amdgpu-add-gc-headers-for-gc-11.5.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0621-drm-i915-Add-function-to-clear-scanout-flag-for-vmas.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0622-drm-Remove-locking-for-legacy-ioctls-and-DRM_UNLOCKE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0622-drm-amd-display-Add-extra-check-for-444-16-format.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0622-drm-amdgpu-gmc11-initialize-GMC-for-GC-11.5.0-memory.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0622-drm-i915-uncore-split-unclaimed_reg_debug-to-header-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0623-drm-Remove-source-code-for-non-KMS-drivers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0623-drm-amd-display-3-plane-MPO-enablement-for-DCN321.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0623-drm-amdgpu-gfx11-initialize-gfx11.5.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0623-drm-i915-uncore-fix-race-around-i915-params.mmio_deb.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0624-drm-Remove-Kconfig-option-for-legacy-support-CONFIG_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0624-drm-amd-display-Adjust-dmub-outbox-notification-enab.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0624-drm-amdgpu-add-golden-setting-for-gc_11_5_0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0624-drm-i915-Fix-a-VMA-UAF-for-multi-gt-platform.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0625-accel-habanalabs-prevent-immediate-hard-reset-due-to.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0625-drm-amd-display-update-GSP1-generic-info-packet-for-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0625-drm-amdkfd-add-KFD-support-for-GC-11.5.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0625-drm-i915-gsc-fixes-and-updates-for-GSC-memory-alloca.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0625-drm-plane-helper-Move-drm_plane_helper_atomic_check-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0626-accel-habanalabs-update-pending-reset-flags-with-new.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0626-drm-amd-display-fix-dpms_off-issue-when-disabling-bi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0626-drm-amdgpu-Do-not-include-drm-drm_plane_helper.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0626-drm-amdgpu-add-imu-firmware-support-for-gc_11_5_0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0626-drm-i915-mtl-gsc-extract-release-and-security-versio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0627-accel-habanalabs-notify-user-about-undefined-opcode-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0627-drm-amdgpu-add-mes-firmware-support-for-gc_11_5_0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0627-drm-i915-mtl-gsc-query-the-GSC-FW-for-its-compatibil.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0627-drm-loongson-Do-not-include-drm-drm_plane_helper.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0628-accel-habanalabs-print-task-name-and-request-code-up.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0628-drm-amd-display-Add-FAMS-capability-to-DCN31.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0628-drm-amdgpu-discovery-enable-mes-block-for-gc-11.5.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0628-drm-i915-mtl-gsc-Add-a-gsc_info-debugfs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0628-drm-shmobile-Do-not-include-drm-drm_plane_helper.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0629-accel-habanalabs-print-task-name-upon-creation-of-a-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0629-drm-amdgpu-discovery-enable-gfx11-for-GC-11.5.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0629-drm-i915-gsc-Fix-intel_gsc_uc_fw_proxy_init_done-wit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0629-drm-solomon-Do-not-include-drm-drm_plane_helper.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0630-accel-habanalabs-set-device-status-malfunction-while.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0630-drm-amdgpu-add-mmhub-3.3.0-headers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0630-drm-i915-mtl-Update-workaround-14018778641.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0630-drm-ofdrm-Do-not-include-drm-drm_plane_helper.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0631-accel-habanalabs-stop-fetching-MME-SBTE-error-cause.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0631-drm-amd-display-Add-FAMS-related-definitions-and-doc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0631-drm-amdgpu-add-mmhub-3.3.0-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0631-drm-i915-Extend-Wa_14015795083-platforms.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0631-drm-simpledrm-Do-not-include-drm-drm_plane_helper.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0632-accel-habanalabs-handle-arc-farm-razwi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0632-drm-amd-display-3.2.231.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0632-drm-amdgpu-enable-gmc11-for-GC-11.5.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0632-drm-i915-Replace-kmap-with-kmap_local_page.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0632-drm-xlnx-Do-not-include-drm-drm_plane_helper.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0633-accel-habanalabs-fix-standalone-preboot-descriptor-r.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0633-drm-amd-display-dumb_abm_lcd-avoid-missing-prototype.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0633-drm-amdgpu-add-gfxhub-11.5.0-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0633-drm-i915-gt-Move-wal_get_fw_for_rmw.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0633-drm-imagination-Removed-unused-functions-in-pvr_fw_t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0634-accel-habanalabs-print-return-code-when-process-term.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0634-drm-amd-display-Save-addr-update-in-scratch-before-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0634-drm-amdgpu-gfx11-add-FW-version-check-for-new-CP-GFX.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0634-drm-i915-gt-Clear-all-bits-from-GEN12_FF_MODE2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0634-drm-imagination-move-update_logtype-into-ifdef-secti.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0635-accel-habanalabs-call-put_pid-after-hpriv-list-is-up.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0635-drm-amd-display-add-check-for-PMFW-hard-min-request-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0635-drm-i915-gt-Fix-context-workarounds-with-non-masked-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0636-accel-habanalabs-rename-fd_list-to-hpriv_list.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0636-drm-amd-display-ensure-FS-is-enabled-before-sending-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0636-drm-amdgpu-gfx11-check-the-CP-FW-version-CP-GFX-shad.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0636-drm-i915-gt-Drop-read-from-GEN8_L3CNTLREG-in-ICL-wor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0637-accel-habanalabs-Allow-single-timestamp-registration.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0637-drm-amd-display-FW-Promotion-Release-0.0.180.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0637-drm-amdgpu-UAPI-add-new-CS-chunk-for-GFX-shadow-buff.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0637-drm-i915-gt-Enable-read-back-on-XEHP_FF_MODE2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0638-accel-habanalabs-fix-wait_for_interrupt-abortion-flo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0638-drm-amd-display-3.2.248.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0638-drm-amdgpu-add-gfx-shadow-CS-IOCTL-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0638-drm-i915-gt-Remove-bogus-comment-on-IVB_FBC_RT_BASE_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0639-accel-habanalabs-remove-pdev-check-on-idle-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0639-drm-amdgpu-add-gfx11-emit-shadow-callback.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0639-drm-amdkfd-Share-the-original-BO-for-GTT-mapping.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0639-drm-i915-gt-Also-check-set-bits-in-clr_set.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0640-accel-habanalabs-reset-device-if-scrubbing-failed.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0640-drm-amdgpu-Fix-kcalloc-over-kzalloc-in-gmc_v9_0_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0640-drm-amdgpu-don-t-require-a-job-for-cond_exec-and-sha.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0640-drm-i915-Remove-some-dead-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0641-accel-habanalabs-dump-temperature-threshold-boot-err.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0641-drm-amd-pm-fix-error-flow-in-sensor-fetching.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0641-drm-amdgpu-add-UAPI-to-query-GFX-shadow-sizes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0641-drm-i915-guc-Dump-perf_limit_reasons-for-debug.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0642-accel-make-accel_class-a-static-const-structure.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0642-drm-amd-pm-Fixes-incorrect-type-in-amdgpu_hwmon_show.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0642-drm-amdgpu-add-gfx-shadow-callback.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0642-drm-exynos-Convert-to-platform-remove-callback-retur.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0642-drm-i915-mtl-Update-cache-coherency-setting-for-cont.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0643-accel-habanalabs-gaudi-Add-MODULE_FIRMWARE-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0643-drm-amd-pm-Vangogh-Get-average_-from-average-field-o.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0643-drm-amdgpu-add-get_gfx_shadow_info-callback-for-gfx1.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0643-drm-exynos-dpi-Change-connector-type-to-DPI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0643-drm-i915-gt-Do-not-use-stolen-on-MTL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0644-accel-habanalabs-gaudi2-un-secure-register-for-engin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0644-drm-amdgpu-add-support-for-new-GFX-shadow-size-query.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0644-drm-amdgpu-pm-Remove-the-duplicate-dpm-status-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0644-drm-i915-Move-setting-of-rps-thresholds-to-init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0644-drm-i915-gt-Use-proper-priority-enum-instead-of-0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0645-accel-habanalabs-gaudi2-unsecure-tpc-count-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0645-drm-amd-display-assign-edid_blob_ptr-with-edid-from-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0645-drm-amd-pm-correct-SMU13-gfx-voltage-related-OD-sett.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0645-drm-i915-Record-default-rps-threshold-values.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0645-drm-i915-gt-Remove-from-if-else.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0646-accel-habanalabs-gaudi2-prepare-to-remove-soft_rst_i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0646-drm-amd-pm-fulfill-the-support-for-SMU13-pp_dpm_dcef.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0646-drm-i915-Add-helpers-for-managing-rps-thresholds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0646-drm-i915-gt-Remove-unncessary-from-if-else.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0647-accel-habanalabs-gaudi2-fix-missing-check-of-kernel-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0647-amdgpu-pm-Replace-print_clock_levels-with-emit_clock.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0647-drm-amdkfd-Fix-an-issue-at-userptr-buffer-validation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0647-drm-i915-Expose-RPS-thresholds-in-sysfs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0647-drm-i915-pmu-add-pmu_to_i915-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0648-accel-habanalabs-handle-f-w-reserved-dram-space-requ.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0648-drm-amdgpu-Allow-issue-disable-gfx-ras-cmd-to-firmwa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0648-drm-amdgpu-bump-driver-version-number-for-CP-GFX-sha.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0648-drm-i915-huc-check-HuC-and-GuC-version-compatibility.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0648-drm-i915-pmu-add-event_to_pmu-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0649-accel-habanalabs-set-default-device-release-watchdog.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0649-drm-amdgpu-Explicitly-add-a-flexible-array-at-the-en.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0649-drm-amdgpu-track-MQD-size-for-gfx-and-compute.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0649-drm-i915-pmu-rearrange-hrtimer-pointer-chasing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0649-drm-i915-use-direct-alias-for-i915-in-requests.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0650-accel-habanalabs-add-info-ioctl-for-engine-error-rep.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0650-drm-amdgpu-Remove-a-redundant-sanity-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0650-drm-amdgpu-add-debugfs-interface-for-reading-MQDs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0650-drm-i915-Replace-i915-gt0-with-to_gt-i915.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0650-drm-i915-mtl-Add-Wa_22016670082.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0651-accel-habanalabs-register-compute-device-as-an-accel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0651-drm-amd-display-FW-Promotion-Release-0.0.163.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0651-drm-amdgpu-Remove-amdgpu_bo_list_array_entry.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0651-drm-i915-Reserve-some-kernel-space-per-vm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0651-drm-i915-Use-the-i915_vma_flush_writes-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0652-accel-habanalabs-Move-ioctls-to-the-device-specific-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0652-drm-amd-display-3.2.232.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0652-drm-amdgpu-Use-kvzalloc-to-simplify-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0652-drm-i915-Add-WABB-blit-for-Wa_16018031267-Wa_1601806.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0652-drm-i915-selftest-gsc-Ensure-GSC-Proxy-init-complete.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0653-accel-habanalabs-gaudi2-prepare-to-remove-cpu_rst_st.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0653-drm-amd-Fix-spelling-mistake-throtting-throttling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0653-drm-amd-display-implement-force-function-in-amdgpu_d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0653-drm-i915-gt-Move-TLB-invalidation-to-its-own-file.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0653-drm-i915-gt-add-selftest-to-exercise-WABB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0654-accel-habanalabs-gaudi2-remove-psoc_arc-access.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0654-drm-amd-display-Update-FW-feature-caps-struct.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0654-drm-i915-Set-copy-engine-arbitration-for-Wa_16018031.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0654-drm-radeon-radeon_ttm-Remove-unused-variable-rbo-fro.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0654-i915-drm-gt-Move-the-gt-defines-in-the-gt-directory.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0655-accel-habanalabs-fix-ETR-ETF-flush-logic.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0655-drm-amd-amdgpu-amdgpu_device-Provide-suitable-descri.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0655-drm-amd-display-Restore-rptr-wptr-for-DMCUB-as-worka.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0655-drm-i915-Invalidate-the-TLBs-on-each-GT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0655-drm-i915-mtl-Add-Wa_14019821291.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0656-accel-habanalabs-refactor-deprecated-strncpy-to-strs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0656-drm-amd-amdgpu-amdgpu_ras-Increase-buffer-size-to-ac.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0656-drm-i915-Remove-unnecessary-include.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0656-drm-i915-make-some-error-capture-functions-static.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0657-drm-amd-amdgpu-amdgpu_sdma-Increase-buffer-size-to-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0657-drm-exynos-fix-a-possible-null-pointer-dereference-d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0657-drm-i915-move-gpu-error-debugfs-to-i915_gpu_error.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0658-accel-habanalabs-refactor-deprecated-strncpy.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0658-drm-amd-amdgpu-imu_v11_0-Increase-buffer-size-to-ens.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0658-drm-amd-display-Enable-SubVP-on-PSR-panels-if-single.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0658-drm-exynos-remove-redundant-of_match_ptr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0658-drm-i915-move-gpu-error-sysfs-to-i915_gpu_error.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0659-accel-habanalabs-improve-etf-configuration.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0659-drm-amd-display-add-option-to-use-custom-backlight-c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0659-drm-doc-fix-underline-for-section-DRM-Sync-Objects.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0659-drm-i915-gt-Remove-prohibited-space-after-opening-pa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0660-accel-habanalabs-gaudi2-include-block-id-in-ECC-erro.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0660-drm-amd-display-Program-OTG-vtotal-min-max-selectors.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0660-drm-amdgpu-add-header-files-for-MP-14.0.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0660-drm-i915-gt-Temporarily-disable-CPU-caching-into-DMA.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0660-drm-loongson-Add-a-check-for-lsdc_bo_create-errors.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0661-accel-habanalabs-move-cpucp-interface-to-linux-haban.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0661-drm-amd-display-Add-support-for-1080p-SubVP-to-reduc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0661-drm-amd-display-Update-scaler-recout-data-for-visual.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0661-drm-bridge-dw_hdmi-Fix-ELD-is-not-updated-issue.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0661-drm-i915-xelpmp-Add-Wa_16021867713.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0662-accel-habanalabs-disable-events-ioctls-on-control-de.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0662-drm-amd-display-add-comments-to-add-plane-functions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0662-drm-i915-Adapt-to-Walloc-size.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0662-drm-panel-sitronix-st7789v-fix-indentation-in-drm_pa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0663-accel-habanalabs-fix-inline-doc-typos.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0663-drm-amd-display-rename-function-to-add-otg-master-fo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0663-drm-i915-Add-ability-for-tracking-buffer-objects-per.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0663-drm-panel-sitronix-st7789v-add-panel-orientation-sup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0664-drm-amd-display-Add-p-state-debugging.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0664-drm-amd-display-add-new-resource-interface-for-acqui.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0664-drm-i915-Record-which-client-owns-a-VM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0664-drm-panel-sitronix-st7789v-add-support-for-partial-m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0665-accel-habanalabs-gaudi2-print-power-mode-changes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0665-drm-amd-display-For-no-plane-case-set-pstate-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0665-drm-amd-display-add-new-resource-interfaces-to-updat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0665-drm-i915-Track-page-table-backing-store-usage.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0665-drm-panel-sitronix-st7789v-add-jasonic-jt240mhqs-hwt.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0666-accel-habanalabs-gaudi2-handle-eq-health-heartbeat-c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0666-drm-amd-display-Enable-SubVP-for-high-refresh-rate-d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0666-drm-amd-display-add-more-pipe-resource-interfaces.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0666-drm-i915-Account-ring-buffer-and-context-state-stora.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0666-fbdev-acornfb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0667-accel-habanalabs-gaudi2-add-eq-health-check-using-ir.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0667-drm-amd-display-Query-GECC-enable-for-SubVP-disable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0667-drm-amd-display-use-new-pipe-allocation-interface-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0667-drm-i915-Add-stable-memory-region-names.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0667-fbdev-asiliantfb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0668-accel-habanalabs-prevent-sending-heartbeat-before-ev.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0668-drm-amd-display-switch-to-new-ODM-policy-for-windowe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0668-drm-i915-Implement-fdinfo-memory-stats-printing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0668-fbdev-atmel_lcdfb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0669-accel-habanalabs-always-pass-exported-size-to-alloc_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0669-drm-amd-display-3.2.233.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0669-drm-amd-display-add-pipe-topology-update-log.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0669-drm-i915-Read-a-shadowed-mmio-register-for-ggtt-flus.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0669-fbdev-aty128fb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0670-accel-habanalabs-use-exported-size-from-dma_buf-and-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0670-drm-amd-display-Skip-dmub-memory-flush-when-not-need.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0670-drm-i915-gt-add-missing-new-line-to-GT_TRACE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0670-fbdev-carminefb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0671-accel-habanalabs-export-dma-buf-only-if-size-offset-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0671-drm-amd-display-Fix-incorrect-comment.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0671-drm-amdgpu-support-psp-vbflash-sysfs-for-MP0-13_0_10.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0671-drm-i915-huc-Stop-printing-about-unsupported-HuC-on-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0671-fbdev-chipsfb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0672-accel-habanalabs-tiny-refactor-of-hl_map_dmabuf.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0672-drm-amd-display-correct-z8_watermark-16bit-to-20bit-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0672-drm-amd-display-remove-unused-variables-dispclk_dela.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0672-drm-i915-dg2-Wa_18028616096-now-applies-to-all-DG2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0672-fbdev-da8xx-fb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0673-accel-habanalabs-fix-bug-in-timestamp-interrupt-hand.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0673-drm-amd-amdgpu-Fix-missing-bo-unlock-in-failure-path.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0673-drm-amd-display-Add-debugfs-interface-for-ODM-combin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0673-drm-i915-mtl-Update-Wa_22018931422.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0673-fbdev-efifb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0674-accel-habanalabs-optimize-timestamp-registration-han.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0674-drm-amd-display-fix-pipe-topology-logging-error.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0674-drm-i915-Remove-return-type-from-i915_drm_client_rem.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0674-fbdev-fm2fb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0675-accel-habanalabs-split-user-interrupts-pending-list.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0675-drm-amd-display-3.2.249.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0675-fbdev-fsl-diu-fb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0676-accel-habanalabs-fix-SG-table-creation-for-dma-buf-m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0676-drm-amd-display-Fix-up-kdoc-format-for-dc_set_edp_po.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0676-drm-amdgpu-add-new-flag-to-AMDGPU_CTX_QUERY2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0676-fbdev-g364fb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0677-accel-habanalabs-set-hl_dmabuf_priv.device_address-o.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0677-drm-amd-display-DSC-passthrough-is-for-DP-HDMI-pcon-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0677-fbdev-geode-gx1fb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0678-accel-habanalabs-add-missing-offset-handling-for-dma.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0678-drm-amd-amdgpu-Fix-style-errors-in-amdgpu_display.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0678-drm-amd-display-Add-dcn35-register-header-files.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0678-fbdev-geode-gxfb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0679-accel-habanalabs-add-debug-prints-to-dump-content-of.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0679-drm-amd-display-Add-DCN35-family-information.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0679-drm-amd-display-set-variable-custom_backlight_curve0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0679-drm-i915-Add-__rcu-annotation-to-cursor-when-iterati.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0679-fbdev-geode-lxfb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0680-accel-habanalabs-add-fw-status-SHUTDOWN_PREP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0680-drm-amd-display-Update-DCE-for-DCN35-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0680-drm-amd-display-return-status-of-dmub_srv_get_fw_boo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0680-drm-i915-Replace-custom-intel-runtime_pm-tracker-wit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0680-fbdev-goldfishfb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0681-accel-habanalabs-extend-preboot-timeout-when-preboot.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0681-drm-amd-display-Update-DCN10-for-DCN35-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0681-drm-amdgpu-fix-a-build-warning-by-a-typo-in-amdgpu_g.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0681-drm-i915-Track-gt-pm-wakerefs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0681-fbdev-grvga-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0682-accel-habanalabs-update-boot-status-print.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0682-drm-amd-display-Update-DCN20-for-DCN35-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0682-drm-amdgpu-check-correct-allocated-mqd_backup-object.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0682-drm-i915-ATS-M-device-ID-update.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0682-fbdev-gxt4500-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0683-accel-habanalabs-remove-unused-asic-functions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0683-drm-amd-display-Update-DCN30-for-DCN35-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0683-drm-amdgpu-mark-gfx_v9_4_3_disable_gpa_mode-static.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0683-drm-i915-dg2-Drop-Wa_22014600077.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0683-fbdev-i740fb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0684-accel-habanalabs-add-traces-for-dma-mappings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0684-drm-amd-display-Update-DCN31-for-DCN35-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0684-drm-i915-pxp-Add-drm_dbgs-for-critical-PXP-events.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0684-drm-ttm-Helper-function-to-get-TTM-mem-limit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0684-fbdev-imxfb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0685-accel-habanalabs-trace-dma-map-sgtable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0685-drm-amd-display-Update-DCN314-for-DCN35-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0685-drm-amdgpu-Set-GTT-size-equal-to-TTM-mem-limit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0685-drm-i915-Skip-pxp-init-if-gt-is-wedged.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0685-fbdev-kyro-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0686-accel-habanalabs-minor-cosmetics-update-to-cpucp_if..patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0686-drm-amd-display-Update-DCN32-for-DCN35-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0686-drm-amdkfd-Update-KFD-TTM-mem-limit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0686-drm-i915-guc-Fix-for-potential-false-positives-in-Gu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0686-fbdev-macfb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0687-accel-habanalabs-minor-cosmetics-update-to-trace-fil.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0687-drm-amd-display-Update-dc.h-for-DCN35-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0687-drm-amdgpu-Add-SDMA_UTCL1_WR_FIFO_SED-field-for-sdma.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0687-drm-i915-guc-Add-a-selftest-for-FAST_REQUEST-errors.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0687-fbdev-maxinefb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0688-drm-amd-amdgpu-Simplify-switch-case-statements-in-am.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0688-drm-amd-display-Add-DCN35-BIOS-command-table-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0688-drm-i915-selftests-wait-for-active-idle-event-in-i91.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0688-fbdev-mb862xxfb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0689-accel-habanalabs-gaudi-remove-unused-structure-defin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0689-drm-amd-display-Add-DCN35-GPIO.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0689-drm-amdgpu-remove-pasid_src-field-from-IV-entry.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0689-drm-i915-guc-Create-the-guc_to_i915-wrapper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0689-fbdev-mmpfb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0690-accel-habanalabs-remove-unused-field.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0690-drm-amd-amdgpu-Move-vcn4-fw_shared-init-to-a-single-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0690-drm-amd-display-Add-DCN35-DCCG.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0690-drm-amdgpu-Enable-mcbp-under-sriov-by-default.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0690-fbdev-mx3fb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0691-accel-habanalabs-print-device-name-when-it-is-remove.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0691-drm-amd-amdgpu-Fix-style-problems-in-amdgpu_debugfs..patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0691-drm-amd-display-Add-DCN35-DIO.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0691-drm-amd-display-Optimize-fast-validation-cases.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0691-fbdev-ocfb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0692-accel-habanalabs-remove-leftover-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0692-drm-amd-display-Add-DCN35-PG_CNTL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0692-drm-amd-display-Fix-possible-NULL-dereference-in-dc_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0692-drm-amd-display-initialize-all-the-dpm-level-s-stutt.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0692-fbdev-offb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0693-accel-habanalabs-gaudi-remove-define-used-for-simula.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0693-drm-amd-display-Add-DCN35-OPTC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0693-drm-amd-display-Add-ODM-check-during-pipe-split-merg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0693-drm-amd-display-Add-logging-for-eDP-v1.4-supported-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0693-fbdev-omapfb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0694-accel-habanalabs-minor-cosmetic-update-to-habanalabs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0694-drm-amd-display-Add-DCN35-OPP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0694-drm-amd-display-Only-enumerate-top-local-sink-as-DP2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0694-drm-amdkfd-Optimize-svm-range-map-to-GPU-with-XNACK-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0694-fbdev-platinumfb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0695-accel-habanalabs-add-missing-debugfs-function-stubs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0695-drm-amd-display-Add-DCN35-DPP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0695-drm-amdgpu-gfx11-drop-old-bring-up-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0695-drm-amdkfd-Use-partial-migrations-mapping-for-GPU-CP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0695-fbdev-pmag-aa-fb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0696-accel-habanalabs-remove-wrong-doc-for-init_phys_pg_p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0696-drm-amd-display-Add-DCN35-DWB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0696-drm-amd-display-Add-missing-dcn35-RCO-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0696-drm-amdgpu-gfx10-drop-old-bring-up-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0696-fbdev-pmag-ba-fb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0697-accel-habanalabs-fix-bug-in-decoder-wait-for-cs-comp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0697-drm-amd-amdgpu-Fix-style-problems-in-amdgpu_psp.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0697-drm-amd-display-Add-DCN35-HUBP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0697-fbdev-pmagb-b-fb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0698-accel-habanalabs-gaudi2-perform-hard-reset-upon-PCIe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0698-drm-amd-display-Add-DCN35-HUBBUB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0698-drm-amd-display-Add-logging-when-DP-link-training-Ch.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0698-drm-amd-display-Change-dither-policy-for-10bpc-to-ro.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0698-fbdev-pxa168fb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0699-accel-habanalabs-gaudi2-fix-spmu-mask-creation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0699-drm-amd-display-Add-DCN35-MMHUBBUB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0699-drm-amd-display-Increase-scratch-buffer-size.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0699-drm-amd-display-Workaround-wrong-HDR-colorimetry-wit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0699-fbdev-pxafb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0700-drm-amd-display-Add-DCN35-DSC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0700-drm-amd-display-Adding-debug-option-to-override-Z8-w.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0700-drm-amd-display-insert-drv-pmfw-log-rollback-to-new-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0700-fbdev-q40fb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0701-drm-amd-display-Add-DCN35-HWSEQ.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0701-drm-amd-display-revert-Update-scaler-recout-data-for.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0701-fbdev-s3cfb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0702-drm-amd-display-Add-DCN35-CLK_MGR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0702-drm-amd-display-Add-w-a-to-disable-DP-dual-mode-on-c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0702-drm-amd-display-Use-channel_width-2-for-vram-table-3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0702-fbdev-sh7760fb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0703-drm-amd-display-Add-DCN35-IRQ.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0703-drm-amd-display-FW-Promotion-Release-0.0.165.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0703-drm-amd-display-Fix-null-pointer.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0703-fbdev-simplefb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0704-drm-amd-display-3.2.234.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0704-drm-amd-display-Add-DCN35-DMUB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0704-drm-amd-display-Skip-DPIA-specific-DP-LL-automation-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0704-fbdev-sstfb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0705-drm-amd-display-Add-DCN35-init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0705-drm-amd-display-Update-BIOS-FW-info-table-revision.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0705-drm-amdgpu-add-en-dis-able_kgq-functions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0705-fbdev-sunxvr1000-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0706-drm-amd-display-Add-DCN35-Resource.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0706-drm-amd-display-revert-removing-otg-toggle-w-a-back-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0706-drm-amdgpu-gfx10-use-generic-en-dis-able_kgq-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0706-fbdev-sunxvr2500-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0707-drm-amd-display-Add-DCN35-DML.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0707-drm-amd-display-Pass-debug-watermarks-through-to-DCN.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0707-drm-amdgpu-gfx11-use-generic-en-dis-able_kgq-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0707-fbdev-uvesafb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0708-drm-amd-Downgrade-message-about-watermarks-table-aft.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0708-drm-amd-display-Add-DCN35-blocks-to-Makefile.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0708-drm-amd-display-Added-delay-to-DPM-log.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0708-fbdev-valkyriefb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0709-drm-amd-display-Add-DCN35-CORE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0709-drm-amd-display-keep-domain24-power-on-if-eDP-not-ex.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0709-drm-amdgpu-gfx10-drop-unused-variable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0709-fbdev-vesafb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0710-drm-amd-display-Add-DCN35-DM-Support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0710-drm-amdgpu-gfx11-drop-unused-variable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0710-fbdev-xilinxfb-Use-fbdev-I-O-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0711-drm-Drop-select-FRAMEBUFFER_CONSOLE-for-DRM_FBDEV_EM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0711-drm-amd-amdgpu-sdma_v6_0-Demote-a-bunch-of-half-comp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0711-drm-amd-display-add-MPC-MCM-1D-LUT-clock-gating-prog.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0711-drm-amdgpu-gfx8-always-restore-kcq-MQDs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0712-drm-amdgpu-access-RLC_SPM_MC_CNTL-through-MMIO-in-SR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0712-drm-amdgpu-gfx9-always-restore-kcq-MQDs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0712-drm-gem-fix-lockdep-check-for-dma-resv-lock.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0713-drm-amdgpu-gfx10-always-restore-kcq-kgq-MQDs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0713-drm-nouveau-fixup-the-uapi-header-file.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0714-drm-amd-Simplify-the-bo-size-check-funciton.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0714-drm-amd-display-mark-amdgpu_dm_connector_funcs_force.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0714-drm-nouveau-new-VM_BIND-uAPI-interfaces.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0715-drm-amd-display-Adjust-kdoc-for-optc35_set_odm_combi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0715-drm-amd-display-Avoid-virtual-stream-encoder-if-not-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0715-drm-amdgpu-gfx11-always-restore-kcq-kgq-MQDs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0715-drm-nouveau-get-vmm-via-nouveau_cli_vmm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0716-amdgpu-pm-Optimize-emit_clock_levels-for-arcturus-pa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0716-drm-amd-amdgpu-Fix-errors-warnings-in-amdgpu-_bios-_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0716-drm-amd-display-Skip-entire-amdgpu_dm-build-if-CONFI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0716-drm-nouveau-bo-initialize-GEM-GPU-VA-interface.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0717-amdgpu-pm-Optimize-emit_clock_levels-for-arcturus-pa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0717-drm-amd-display-Create-one-virtual-connector-in-DC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0717-drm-amdgpu-put-MQDs-in-VRAM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0717-drm-nouveau-move-usercopy-helpers-to-nouveau_drv.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0718-drm-amd-display-Initialize-writeback-connector.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0718-drm-amdgpu-drop-invalid-IP-revision.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0718-drm-amdkfd-Replace-pr_err-with-dev_err.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0718-drm-nouveau-fence-separate-fence-alloc-and-emit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0719-drm-amd-display-Skip-writeback-connector-when-we-get.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0719-drm-amdgpu-drop-unused-function.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0719-drm-amdgpu-remove-unused-parameter-in-amdgpu_vmid_gr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0719-drm-nouveau-fence-fail-to-emit-when-fence-context-is.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0720-drm-amdgpu-Use-READ_ONCE-when-reading-the-values-in-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0720-drm-amdgpu-unlock-the-correct-lock-in-amdgpu_gfx_ena.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0720-drm-nouveau-chan-provide-nouveau_channel_kill.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0721-drm-amdgpu-Fix-printk_ratelimit-with-DRM_ERROR_RATEL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0721-drm-amdgpu-unlock-on-error-in-gfx_v9_4_3_kiq_resume.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0721-drm-nouveau-nvkm-vmm-implement-raw-ops-to-manage-uvm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0722-drm-amdgpu-add-VPE-6.1.0-header-files.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0722-drm-amdgpu-do-gfxhub-init-for-all-XCDs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0722-drm-nouveau-implement-new-VM_BIND-uAPI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0723-drm-amd-display-Create-amdgpu_dm_wb_connector.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0723-drm-amdgpu-add-VPE-HW-IP-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0723-drm-amdgpu-remove-unneeded-semicolon.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0723-drm-nouveau-debugfs-implement-DRM-GPU-VA-debugfs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0724-drm-amd-display-Add-additional-pstate-registers-to-H.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0724-drm-amd-display-Create-fake-sink-and-stream-for-writ.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0724-drm-amdgpu-add-VPE-RING-TYPE-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0724-drm-tve200-remove-redundant-of_match_ptr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0725-drm-amd-display-Hande-writeback-request-from-userspa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0725-drm-amdgpu-add-VPE-IP-BLOCK-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0725-drm-amdkfd-Don-t-trigger-evictions-unmapping-dmabuf-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0725-drm-mcde-remove-redundant-of_match_ptr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0726-accel-ivpu-Rename-sources-to-use-generation-based-na.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0726-drm-amd-display-Add-writeback-enable-disable-in-dc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0726-drm-amdgpu-Remove-the-unused-variable-golden_setting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0726-drm-amdgpu-add-VPE-HW-IP-BLOCK-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0726-nouveau-dmem-fix-copy-paste-error-in-nouveau_dmem_mi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0727-accel-ivpu-Use-generation-based-function-and-registe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0727-drm-amd-display-Fix-writeback_info-never-got-updated.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0727-drm-amd-display-Show-the-DCN-DCE-version-in-the-log.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0727-drm-amdgpu-add-VPE-firmware-header-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0727-drm-nouveau-nvkm-vmm-silence-warning-from-cast.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0728-accel-ivpu-Switch-to-generation-based-FW-names.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0728-drm-amd-display-Validate-hw_points_num-before-using-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0728-drm-amdgpu-add-VPE-firmware-interface.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0728-drm-nouveau-remove-incorrect-__user-annotations.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0729-drm-amd-display-Fix-writeback_info-is-not-removed.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0729-drm-amdgpu-add-HWID-for-VPE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0729-drm-amdgpu-set-default-num_kcq-to-2-under-sriov.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0729-drm-nouveau-uvmm-remove-incorrect-calls-to-mas_unloc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0730-accel-ivpu-Refactor-memory-ranges-logic.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0730-drm-amd-display-Add-writeback-enable-field-wb_enable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0730-drm-amd-display-Check-Vactive-for-VRR-active-for-FPO.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0730-drm-amdgpu-add-IH-CLIENT-ID-for-VPE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0730-drm-nouveau-uvmm-remove-dedicated-VM-pointer-from-VM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0731-accel-ivpu-Add-initial-support-for-VPU-4.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0731-drm-amd-display-Block-SubVP-high-refresh-when-VRR-ac.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0731-drm-amd-display-Setup-for-mmhubbub3_warmup_mcif-with.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0731-drm-amdgpu-add-irq-src-id-definitions-for-VPE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0731-drm-nouveau-sched-Don-t-pass-user-flags-to-drm_synco.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0732-accel-ivpu-Extend-get_param-ioctl-to-identify-capabi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0732-drm-amd-display-Add-new-set_fc_enable-to-struct-dwbc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0732-drm-amd-display-Block-SubVP-on-displays-that-have-pi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0732-drm-amdgpu-add-doorbell-index-for-VPE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0733-drm-amd-display-Disable-DWB-frame-capture-to-emulate.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0733-drm-amd-display-Promote-DAL-to-3.2.235.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0733-drm-amdgpu-add-support-for-VPE-firmware-name-decodin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0734-drm-amd-display-Adjust-code-style.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0734-drm-amdgpu-add-UCODE-ID-for-VPE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0734-drm-amdgpu-display-Enable-DC_FP-for-LoongArch.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0734-drm-ttm-Introduce-KUnit-test.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0735-drm-amd-display-Update-code-comment-to-be-more-accur.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0735-drm-amdgpu-add-PSP-FW-TYPE-for-VPE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0735-drm-amdgpu-release-correct-lock-in-amdgpu_gfx_enable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0735-drm-ttm-tests-Add-tests-for-ttm_device.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0736-drm-amd-amdgpu-Fix-warnings-in-amdgpu-_object-_ring..patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0736-drm-amd-display-3.2.263.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0736-drm-amdgpu-add-nbio-callback-for-VPE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0736-drm-ttm-tests-Add-tests-for-ttm_pool.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0737-drm-amdgpu-add-nbio-7.11-callback-for-VPE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0737-drm-exec-use-unique-instead-of-local-label.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0738-drm-amd-display-Simplify-the-calculation-of-variable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0738-drm-amdgpu-Read-aquavanjaram-WAFL-register-state.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0738-drm-amdgpu-add-VPE-6.1.0-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0738-drm-exec-add-test-case-for-using-a-drm_exec-multiple.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0739-drm-amdgpu-Read-aquavanjaram-USR-register-state.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0739-drm-amdgpu-add-PSP-loading-support-for-VPE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0739-drm-amdgpu-improve-wait-logic-at-fence-polling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0739-drm-panfrost-Sync-IRQ-by-job-s-timeout-handler.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0740-drm-amd-Add-a-DC-debug-mask-for-DML2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0740-drm-amd-display-Only-skip-update-for-DCFCLK-UCLK-FCL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0740-drm-amdgpu-add-user-space-CS-support-for-VPE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0740-drm-atmel-hlcdc-Support-inverting-the-pixel-clock-po.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0741-drm-amd-display-Update-vactive-margin-and-max-vblank.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0741-drm-amdgpu-enable-VPE-for-VPE-6.1.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0741-drm-test-drm_exec-fix-memory-leak-on-object-prepare.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0742-drm-amd-display-Convert-connector-signal-id-to-strin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0742-drm-amdgpu-add-VPE-FW-version-query-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0742-drm-ttm-Remove-two-unused-function-declarations.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0743-drm-amd-amdgpu-Add-SMUIO-headers-for-10.0.2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0743-drm-amdgpu-fix-VPE-front-door-loading-issue.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0743-drm-i915-sdvo-ignore-returned-broken-edid-on-intel_s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0744-drm-amd-amdgpu-SRIOV-full-reset-issue-with-VCN.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0744-drm-amd-display-Add-visual-confirm-color-support-for.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0744-drm-amdgpu-add-vcn-4_0_5-header-files.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0744-drm-i915-Move-stolen-memory-handling-into-i915_gem_s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0745-drm-amd-display-Make-unbounded-req-update-separate-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0745-drm-amd-display-Restore-guard-against-default-backli.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0745-drm-amdgpu-add-VCN4-ip-block-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0745-drm-i915-fbc-Make-FBC-check-stolen-at-use-time.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0746-drm-amd-display-Remove-unnecessary-variable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0746-drm-amdgpu-SW-part-of-MES-event-log-enablement.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0746-drm-amdgpu-jpeg-add-jpeg-support-for-VCN4_0_5.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0746-drm-i915-fbc-Moved-fence-related-code-away-from-inte.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0747-drm-amdgpu-Enable-event-log-on-MES-11.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0747-drm-amdgpu-add-VCN_4_0_5-firmware-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0747-drm-i915-hsw-s-HSW-HASWELL-for-platform-subplatform-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0748-drm-amd-display-3.2.236.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0748-drm-amdgpu-enable-CG-and-PG-flags-for-VCN.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0748-drm-bridge-Return-NULL-instead-of-plain-0-in-drm_dp_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0748-drm-i915-bdw-s-BDW-BROADWELL-for-platform-subplatfor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0749-drm-amdgpu-introduce-vmhub-definition-for-multi-part.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0749-drm-amdgpu-soc21-Add-video-cap-query-support-for-VCN.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0749-drm-debugfs-fix-potential-NULL-pointer-dereference.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0749-drm-i915-skl-s-SKL-SKYLAKE-for-platform-subplatform-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0750-drm-amdgpu-assign-register-address-for-vmhub-object-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0750-drm-amdgpu-discovery-add-VCN-4.0.5-Support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0750-drm-doc-rfc-Mark-long-running-workload-as-complete.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0750-drm-i915-kbl-s-KBL-KABYLAKE-for-platform-subplatform.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0751-drm-amdgpu-add-bitmask-to-iterate-vmhubs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0751-drm-amdgpu-enable-PG-flags-for-VCN.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0751-drm-doc-rfc-Mark-drm_scheduler-as-completed.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0751-drm-i915-cfl-s-CFL-COFFEELAKE-for-platform-subplatfo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0752-drm-amdgpu-add-UMSCH-4.0-register-headers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0752-drm-amdgpu-init-vmhubs-bitmask-for-GC-9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0752-drm-doc-rfc-Move-Xe-ASYNC-VM_BIND-to-the-completed-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0752-drm-i915-cml-s-CML-COMETLAKE-for-platform-subplatfor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0753-amdgpu-pm-Optimize-emit_clock_levels-for-arcturus-pa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0753-drm-amdgpu-assign-different-AMDGPU_GFXHUB-for-rings-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0753-drm-doc-rfc-Move-userptr-integration-and-vm_bind-to-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0753-drm-i915-rkl-s-RKL-ROCKETLAKE-for-platform-subplatfo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0754-drm-amdgpu-add-UMSCH-IP-BLOCK-TYPE-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0754-drm-amdgpu-add-sysfs-node-for-compute-partition-mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0754-drm-doc-rfc-Xe-is-using-drm_exec-so-mark-as-complete.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0754-drm-i915-jsl-s-JSL-JASPERLAKE-for-platform-subplatfo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0755-drm-amd-pm-introduce-a-new-set-of-OD-interfaces.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0755-drm-amdgpu-make-the-WREG32_SOC15_xx-macro-to-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0755-drm-bridge-aux-hpd-Replace-of_device.h-with-explicit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0755-drm-i915-tgl-s-TGL-TIGERLAKE-for-platform-subplatfor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0756-drm-amdgpu-override-partition-mode-through-module-pa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0756-drm-amdgpu-revise-the-device-initialization-sequence.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0756-drm-edp-panel-Move-the-KDC-panel-to-a-separate-group.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0756-drm-i915-adlp-s-ADLP-ALDERLAKE_P-for-display-and-gra.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0757-drm-amdgpu-alloc-vm-inv-engines-for-every-vmhub.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0757-drm-amdgpu-jpeg-initialize-number-of-jpeg-ring.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0757-drm-atomic-helper-rename-drm_atomic_helper_check_wb_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0757-drm-i915-rplp-s-ADLP_RPLP-RAPTORLAKE_P-for-RPLP-defi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0758-drm-amd-pm-add-fan-temperature-pwm-curve-OD-setting-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0758-drm-amdgpu-Add-kgd2kfd-for-GC-9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0758-drm-i915-rplu-s-ADLP_RPLU-RAPTORLAKE_U-in-RPLU-defin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0758-drm-vkms-move-wb-s-atomic_check-from-encoder-to-conn.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0759-drm-amd-pm-add-fan-acoustic-limit-OD-setting-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0759-drm-amdgpu-Use-the-correct-API-to-read-register.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0759-drm-i915-adln-s-ADLP-ALDERLAKE_P-in-ADLN-defines.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0759-drm-imagination-Remove-unneeded-semicolon.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0760-drm-amdgpu-add-UMSCH-RING-TYPE-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0760-drm-amdgpu-add-more-macro-to-support-offset-variant.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0760-drm-i915-adls-s-ADLS_RPLS-RAPTORLAKE_S-in-platform-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0760-drm-imagination-Move-dereference-after-NULL-check-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0761-drm-amdgpu-add-UMSCH-firmware-header-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0761-drm-amdgpu-add-vcn-v4_0_3-ip-headers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0761-drm-i915-display-pre-initialize-some-values-in-probe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0761-drm-panel-nv3052c-Document-known-register-names.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0762-drm-amdgpu-add-UMSCH-4.0-api-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0762-drm-amdgpu-add-VCN4_0_3-firmware.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0762-drm-i915-debug-log-when-GMD-ID-indicates-there-s-no-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0762-drm-panel-nv3052c-Add-SPI-device-IDs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0763-drm-amdgpu-add-initial-support-for-UMSCH.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0763-drm-amdgpu-jpeg-add-jpeg-support-for-VCN4_0_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0763-drm-i915-irq-add-dedicated-intel_display_irq_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0763-drm-panel-nv3052c-Allow-specifying-registers-per-pan.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0764-drm-amdgpu-enable-UMSCH-scheduling-for-VPE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0764-drm-amdgpu-vcn-add-vcn-support-for-VCN4_0_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0764-drm-i915-irq-add-dg1_de_irq_postinstall.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0764-drm-panel-nv3052c-Add-Fascontek-FS035VG158-LCD-displ.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0765-drm-amdgpu-add-selftest-framework-for-UMSCH.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0765-drm-amdgpu-jpeg-enable-jpeg-cg-for-VCN4_0_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0765-drm-i915-irq-add-ilk_de_irq_postinstall.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0766-drm-amdgpu-add-VPE-queue-submission-test.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0766-drm-amdgpu-jpeg-enable-jpeg-pg-for-VCN4_0_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0766-drm-i915-irq-move-all-PCH-irq-postinstall-calls-to-d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0766-drm-panel-st7701-Add-Anbernic-RG-ARC-Panel-Support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0767-drm-amdgpu-reserve-mmhub-engine-3-for-UMSCH-FW.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0767-drm-amdgpu-vcn-enable-vcn-cg-for-VCN4_0_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0767-drm-i915-gt-Simplify-shmem_create_from_object-map_ty.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0767-drm-panel-Add-Synaptics-R63353-panel-driver.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0768-drm-amdgpu-add-PSP-loading-support-for-UMSCH.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0768-drm-amdgpu-vcn-enable-vcn-pg-for-VCN4_0_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0768-drm-i915-Make-i915_coherent_map_type-GT-centric.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0768-drm-panel-Add-Ilitek-ILI9805-panel-driver.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0769-drm-amdgpu-discovery-enable-UMSCH-4.0-in-IP-discover.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0769-drm-amdgpu-vcn-enable-vcn-DPG-mode-for-VCN4_0_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0769-drm-i915-gt-Apply-workaround-22016122933-correctly.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0769-drm-panel-ilitek-ili9805-add-support-for-Tianma-TM04.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0770-drm-amdgpu-add-amdgpu_umsch_mm-module-parameter.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0770-drm-amdgpu-jpeg-add-multiple-jpeg-rings-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0770-drm-i915-guc-Fix-potential-null-pointer-deref-in-GuC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0770-drm-panel-simple-Add-AUO-G156HAN04.0-LVDS-display-su.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0771-drm-amdgpu-jpeg-add-multiple-jpeg-rings-support-for-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0771-drm-amdgpu-update-SET_HW_RESOURCES-definition-for-UM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0771-drm-bridge-ti-sn65dsi86-Associate-PWM-device-to-auxi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0772-drm-amd-pm-add-fan-acoustic-target-OD-setting-suppor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0772-drm-amdkfd-Set-F8_MODE-for-gc_v9_4_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0772-drm-mediatek-mtk_dpi-Simplify-with-devm_drm_bridge_a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0772-drm-rockchip-move-output-interface-related-definitio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0773-drm-amd-pm-add-fan-target-temperature-OD-setting-sup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0773-drm-amdgpu-nbio-update-vcn-doorbell-range.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0773-drm-mediatek-mtk_dpi-Simplify-with-dev_err_probe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0774-drm-amd-pm-add-fan-minimum-pwm-OD-setting-support-fo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0774-drm-amdgpu-vcn-enable-vcn-doorbell-for-vcn4.0.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0774-drm-mediatek-mtk_dpi-Switch-to-devm_drm_of_get_bridg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0774-drm-rockchip-vop2-set-half_block_en-bit-in-all-mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0775-Revert-drm-amd-pm-disable-the-SMU13-OD-feature-suppo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0775-drm-amdgpu-jpeg-enable-jpeg-doorbell-for-jpeg4.0.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0775-drm-mediatek-mtk_dpi-Switch-to-.remove_new-void-call.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0776-drm-amdgpu-fix-vcn-doorbell-range-setting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0776-drm-mediatek-mtk_dpi-Use-devm_platform_ioremap_resou.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0776-drm-rockchip-vop2-Add-write-mask-for-VP-config-done.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0777-drm-amd-pm-only-poweron-off-vcn-jpeg-when-they-are-v.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0777-drm-amdgpu-support-gc-v9_4_3-ring_test-running-on-al.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0777-drm-mediatek-mtk_dpi-Compress-struct-of_device_id-en.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0777-drm-rockchip-vop2-Set-YUV-RGB-overlay-mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0778-drm-amdgpu-calling-address-translation-functions-to-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0778-drm-amdgpu-enable-the-ring-and-IB-test-for-slave-kcq.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0778-drm-rockchip-vop2-set-bg-dly-and-prescan-dly-at-vop2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0779-drm-amdgpu-add-node_id-to-physical-id-conversion-in-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0779-drm-amdgpu-clean-up-some-inconsistent-indenting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0779-drm-mediatek-dp-Move-AUX-and-panel-poweron-off-seque.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0779-drm-rockchip-vop2-rename-grf-to-sys_grf.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0780-drm-amd-display-Remove-duplicated-include-in-dcn35_r.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0780-drm-amdgpu-Add-some-XCC-programming.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0780-drm-mediatek-dp-Change-logging-to-dev-for-mtk_dp_aux.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0780-dt-bindings-rockchip-vop2-Add-more-endpoint-definiti.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0781-drm-amd-display-Remove-duplicated-include-in-dcn35_o.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0781-drm-amdgpu-Add-mode2-reset-logic-for-v13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0781-drm-mediatek-dp-Use-devm-variant-of-drm_bridge_add.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0781-drm-rockchip-vop2-Add-support-for-rk3588.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0782-drm-amd-display-Remove-duplicated-include-in-dcn35_h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0782-drm-amdkfd-Introduce-kfd_node-struct-v5.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0782-drm-mediatek-dp-Move-AUX_P0-setting-to-mtk_dp_initia.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0782-drm-rockchip-vop2-rename-VOP_FEATURE_OUTPUT_10BIT-to.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0783-drm-amd-display-Remove-duplicated-include-in-dcn35_c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0783-drm-amdkfd-Add-spatial-partitioning-support-in-KFD.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0783-drm-fourcc-fix-spelling-typos.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0783-drm-mediatek-dp-Enable-event-interrupt-only-when-bri.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0784-drm-amd-display-clean-up-one-inconsistent-indenting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0784-drm-amdkfd-Update-MQD-management-on-multi-XCC-setup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0784-drm-drm_modeset_helper_vtables.h-fix-typos-spellos.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0784-drm-mediatek-dp-Avoid-mutex-locks-if-audio-is-not-su.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0785-drm-amd-display-clean-up-one-inconsistent-indenting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0785-drm-amdkfd-Add-PM4-target-XCC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0785-drm-mediatek-dp-Move-PHY-registration-to-new-functio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0785-drm-uapi-drm_mode.h-fix-spellos-and-grammar.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0786-drm-amd-display-clean-up-some-inconsistent-indenting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0786-drm-amdkfd-Add-XCC-instance-to-kgd2kfd-interface-v3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0786-drm-mediatek-dp-Add-support-for-embedded-DisplayPort.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0786-drm-panel-synaptics-r63353-adjust-the-includes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0787-drm-amd-display-clean-up-some-inconsistent-indenting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0787-drm-amdgpu-Add-XCC-inst-to-PASID-TLB-flushing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0787-drm-mediatek-dp-Add-.wait_hpd_asserted-for-AUX-bus.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0787-drm-panel-ilitek-ili9805-adjust-the-includes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0788-amdgpu-pm-Replace-print_clock_levels-with-emit_clock.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0788-drm-amdkfd-Update-context-save-handling-for-multi-XC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0788-drm-mediatek-dp-Don-t-register-HPD-interrupt-handler.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0788-drm-vc4-hdmi-Create-destroy-state-implementation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0789-amdgpu-pm-Optimize-emit_clock_levels-for-aldebaran-p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0789-drm-amdgpu-Fix-VM-fault-reporting-on-XCC1.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0789-drm-imagination-vm-Fix-heap-lookup-condition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0789-drm-mediatek-Do-not-check-for-0-return-after-calling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0790-amdgpu-pm-Optimize-emit_clock_levels-for-aldebaran-p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0790-drm-amdkfd-Call-DQM-stop-during-DQM-uninitialize.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0790-drm-ci-igt_runner-Remove-todo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0790-drm-mediatek-Convert-to-platform-remove-callback-ret.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0791-amdgpu-pm-Optimize-emit_clock_levels-for-aldebaran-p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0791-drm-amdkfd-Update-sysfs-node-properties-for-multi-XC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0791-drm-ci-Force-db410c-to-host-mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0792-drm-amdgpu-Declare-array-with-strings-as-pointers-co.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0792-drm-amdkfd-Update-SDMA-queue-management-for-GFX9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0792-drm-ci-arm64.config-Enable-DA9211-regulator.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0793-drm-amdgpu-Add-RREG64_PCIE_EXT-WREG64_PCIE_EXT-funct.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0793-drm-amdgpu-Fix-CP_HYP_XCP_CTL-register-programming-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0793-drm-ci-Enable-new-jobs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0794-drm-amdgpu-Update-amdgpu_device_indirect_r-wreg_ext.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0794-drm-amdkfd-Update-coherence-settings-for-svm-ranges.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0794-drm-ci-Use-scripts-config-to-enable-disable-configs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0795-drm-amd-Add-umc-v12_0_0-ip-headers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0795-drm-amdgpu-Use-new-atomfirmware-init-for-GC-9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0795-drm-ci-mt8173-Do-not-set-IGT_FORCE_DRIVER-to-panfros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0796-drm-amdgpu-Set-XNACK-per-process-on-GC-9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0796-drm-amdgpu-Use-min_t-to-replace-min.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0796-drm-ci-virtio-Make-artifacts-available.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0796-drm-mediatek-mtk_disp_aal-Remove-half-completed-inco.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0797-drm-amdgpu-assign-the-doorbell-index-in-1st-page-to-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0797-drm-amdgpu-fix-incompatible-types-in-conditional-exp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0797-drm-ci-uprev-IGT.patch (jsc#PED-9898
  jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237
  jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0797-drm-mediatek-mtk_disp_ccorr-Remove-half-completed-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0798-drm-amdgpu-Add-only-valid-firmware-version-nodes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0798-drm-amdgpu-adjust-some-basic-elements-for-multiple-A.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0798-drm-doc-ci-Add-IGT-version-details-for-flaky-tests.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0798-drm-rcar-du-Replace-DRM_INFO-with-drm_info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0799-drm-amdgpu-Correct-se_num-and-reg_inst-for-gfx-v9_4_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0799-drm-amdgpu-add-support-for-SDMA-on-multiple-AIDs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0799-drm-ci-Update-xfails.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0799-drm-rcar-du-Use-dev_err_probe-to-record-cause-of-KMS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0800-drm-amd-display-Fix-spelling-mistake-SMC_MSG_AllowZs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0800-drm-amdgpu-assign-the-doorbell-index-for-sdma-on-non.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0800-drm-renesas-Convert-to-devm_platform_ioremap_resourc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0801-drm-amdgpu-Add-umc-v12_0-ras-functions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0801-drm-amdgpu-do-mmhub-init-for-multiple-AIDs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0801-drm-drm_mode_object-increase-max-objects-to-accommod.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0801-drm-rcar-du-Add-more-formats-to-DRM_MODE_BLEND_PIXEL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0802-drm-amd-display-clean-up-one-inconsistent-indenting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0802-drm-amdgpu-correct-the-vmhub-reference-for-each-XCD-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0802-drm-drm_property-make-replace_property_blob_from_id-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0802-drm-rcar-du-Enable-ABGR-and-XBGR-formats.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0803-drm-amdgpu-complement-the-IH-node_id-table-for-multi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0803-drm-amdgpu-fix-unsigned-error-codes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0803-drm-amdgpu-sdma6-initialize-sdma-6.1.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0803-drm-drm_plane-track-color-mgmt-changes-per-plane.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0804-drm-amd-Fix-the-flag-setting-code-for-interrupt-requ.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0804-drm-amd-display-add-driver-specific-property-for-pla.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0804-drm-amdgpu-discovery-enable-sdma6-for-SDMA-6.1.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0804-drm-amdgpu-set-mmhub-bitmask-for-multiple-AIDs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0805-drm-amdgpu-Use-default-reset-method-handler.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0805-drm-amdgpu-Use-the-right-method-to-get-IP-version.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0805-drm-amdgpu-convert-the-doorbell_index-to-2-dwords-of.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0805-drm-amdgpu-discovery-add-hdp-6.1.0-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0806-drm-amd-pm-Remove-redundant-function-members-of-ppta.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0806-drm-amdgpu-add-address-conversion-for-UMC-v12.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0806-drm-amdgpu-discovery-add-smuio-14.0.0-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0806-drm-amdgpu-program-GRBM_MCM_ADDR-for-non-AID0-GRBM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0807-drm-amd-display-Remove-minor-revision-5-until-proper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0807-drm-amd-pm-update-smu_v13_0_6-smu-header.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0807-drm-amdgpu-add-ih-6.1-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0807-drm-amdgpu-introduce-new-doorbell-assignment-table-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0808-drm-amd-display-Use-explicit-size-for-types-in-DCCG-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0808-drm-amd-pm-enable-smu_v13_0_6-mca-debug-mode-when-UM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0808-drm-amdgpu-add-ih-6.1-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0808-drm-amdkfd-add-gpu-compute-cores-io-links-for-gfx9.4.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0809-drm-amd-display-allow-DP40-cables-to-do-UHBR13.5.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0809-drm-amdgpu-add-channel-index-table-for-UMC-v12.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0809-drm-amdgpu-discovery-add-ih-6.1.0-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0809-drm-amdkfd-Fix-SDMA-in-CPX-mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0810-drm-amd-display-Add-symclk-enable-disable-during-str.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0810-drm-amd-display-Revert-Fix-conversions-between-bytes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0810-drm-amdkfd-Add-SDMA-info-for-SDMA-4.4.2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0811-drm-amd-display-Fix-typo-in-enable-and-disable-symcl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0811-drm-amd-display-trivial-comment-change.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0811-drm-amdkfd-Populate-memory-info-before-adding-GPU-no.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0812-drm-amd-display-Revert-DP2-MST-hub-triple-display-fi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0812-drm-amd-display-set-default-return-value-for-ODM-Com.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0812-drm-amdgpu-add-new-vram-type-for-dgpu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0812-drm-amdkfd-avoid-unmap-dma-address-when-svm_ranges-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0813-drm-amd-display-Disable-OPTC-pg-to-match-DC-Hubp-dpp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0813-drm-amd-display-FW-Promotion-Release-0.0.181.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0813-drm-amd-pm-fix-pp_dpm_sclk-node-not-displaying-corre.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0813-drm-amdgpu-add-the-support-of-XGMI-link-for-GC-9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0814-drm-amd-display-Exit-from-idle-state-before-accessin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0814-drm-amdgpu-Change-num_xcd-to-xcc_mask.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0814-drm-amdgpu-Fix-style-issues-in-amdgpu_debugfs.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0814-drm-amdgpu-print-more-address-info-of-UMC-bad-page.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0815-drm-amd-display-Fix-DML-calculation-errors.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0815-drm-amdgpu-Fix-style-issues-in-amdgpu_psp.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0815-drm-amdgpu-vcn-use-vcn4-irqsrc-header-for-VCN-4.0.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0816-drm-amd-display-do-not-block-ODM-OPM-on-one-side-of-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0816-drm-amdgpu-Cleanup-amdgpu-amdgpu_cgs.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0816-drm-amdgpu-vcn-update-vcn-header-to-support-multiple.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0817-drm-amd-display-fix-HW-block-PG-sequence.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0817-drm-amdgpu-Rename-KGD_MAX_QUEUES-to-AMDGPU_MAX_QUEUE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0817-drm-amdgpu-Sort-the-includes-in-amdgpu-amdgpu_drv.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0817-drm-amdgpu-jpeg-update-jpeg-header-to-support-multip.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0818-drm-amd-display-3.2.264.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0818-drm-amd-display-Add-structs-for-Freesync-Panel-Repla.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0818-drm-amd-display-support-main-link-off-before-specifi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0818-drm-amdgpu-vcn-update-new-doorbell-map.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0819-drm-amd-display-Add-new-logs-for-AutoDPMTest.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0819-drm-amd-display-add-plane-degamma-TF-driver-specific.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0819-drm-amdgpu-Only-create-err_count-sysfs-when-hw_op-is.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0819-drm-amdgpu-vcn-update-ucode-setup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0820-drm-amd-display-Add-DCHUBBUB-callback-to-report-MALL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0820-drm-amd-display-explicitly-define-EOTF-and-inverse-E.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0820-drm-amdgpu-Apply-poison-mode-check-to-GFX-IP-only.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0820-drm-amdgpu-vcn-remove-unused-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0821-Revert-drm-radeon-Prefer-dev_-variant-over-printk.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0821-drm-amd-display-document-AMDGPU-pre-defined-transfer.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0821-drm-amd-display-remove-a-function-that-does-complex-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0821-drm-amdgpu-vcn-update-amdgpu_fw_shared-to-amdgpu_vcn.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0822-drm-amd-display-add-plane-HDR-multiplier-driver-spec.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0822-drm-amd-display-do-not-attempt-ODM-power-optimizatio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0822-drm-amdgpu-Move-vram-gtt-flash-defines-to-amdgpu_-tt.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0822-drm-amdgpu-reflect-psp-xgmi-topology-info-for-gfx9.4.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0823-drm-amd-display-Fix-memory-leak-in-dm_set_writeback.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0823-drm-amd-display-only-allow-ODM-power-optimization-if.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0823-drm-amdgpu-Clean-up-style-problems-in-mmhub_v2_3.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0823-drm-amdkfd-EOP-Removal-Handle-size-0-correctly.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0824-drm-amd-display-add-dp-dto-programming-function-to-d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0824-drm-amdgpu-Remove-gfx-v11_0_3-ras_late_init-call.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0824-drm-amdgpu-add-indirect-r-w-interface-for-smn-addres.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0824-drm-amdgpu-xgmi_fill_topology_info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0825-drm-amd-display-Drop-unused-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0825-drm-amdgpu-Issue-ras-enable_feature-for-gfx-ip-only.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0825-drm-amdgpu-configure-the-doorbell-settings-for-sdma-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0825-drm-amdkfd-Export-DMABufs-from-KFD-using-GEM-handles.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0826-drm-amdgpu-add-type-conversion-for-gc-info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0826-drm-amdgpu-enable-SDMA-MGCG-for-SDMA-5.2.x.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0826-drm-amdkfd-Import-DMABufs-for-interop-through-DRM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0826-drm-amdkfd-Rework-kfd_locked-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0827-Documentation-driver-api-Add-document-about-WBRF-mec.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0827-drm-amd-display-Add-Functions-to-enable-Freesync-Pan.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0827-drm-amd-display-dc-cleanup-for-tests.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0827-drm-amdkfd-Add-device-repartition-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0828-drm-amd-display-Add-check-for-vrr_active_fixed.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0828-drm-amdgpu-Add-map-of-logical-to-physical-inst.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0828-drm-amdgpu-remove-SRIOV-VF-FB-location-programming.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0829-drm-amd-display-fix-some-non-initialized-register-ma.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0829-drm-amd-pm-update-driver_if-and-ppsmc-headers-for-co.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0829-drm-amdgpu-Use-instance-lookup-table-for-GC-9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0829-drm-amdgpu-init-TA-microcode-for-SRIOV-VF-when-MP0-I.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0830-drm-amd-display-3.2.250.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0830-drm-amd-display-Clean-up-flip-pending-timeout-handli.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0830-drm-amd-pm-setup-the-framework-to-support-Wifi-RFI-m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0830-drm-amdgpu-Add-mask-for-SDMA-instances.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0831-Revert-drm-amdgpu-Prefer-dev_-variant-over-printk-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0831-drm-amd-pm-add-flood-detection-for-wbrf-events.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0831-drm-amdgpu-Use-instance-table-for-sdma-4.4.2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0832-drm-amd-display-Temporary-Disable-MST-DP-Colorspace-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0832-drm-amd-display-move-odm-power-optimization-decision.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0832-drm-amd-pm-enable-Wifi-RFI-mitigation-feature-suppor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0832-drm-amdgpu-Fix-GRBM-programming-sequence.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0833-drm-amd-display-do-not-skip-ODM-minimal-transition-b.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0833-drm-amd-pm-enable-Wifi-RFI-mitigation-feature-suppor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0833-drm-amdgpu-Prefer-pr_err-_warn-_notice-over-printk-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0833-drm-amdgpu-nbio-add-vcn-doorbell-multiple-AIDs-suppo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0834-drm-amd-display-Implement-interface-for-notify-curso.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0834-drm-amd-display-minior-logging-improvements.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0834-drm-amdgpu-jpeg-add-JPEG-multiple-AIDs-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0835-Revert-drm-amd-display-Implement-zpos-property.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0835-drm-amd-display-add-skip_implict_edp_power_control-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0835-drm-amdgpu-vcn-update-clock-gate-setting-for-VCN-4.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0835-drm-radeon-include-drm-drm_edid.h-only-where-needed.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0836-drm-amd-display-Promote-DC-to-2.3.245.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0836-drm-amd-display-add-plane-3D-LUT-driver-specific-pro.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0836-drm-amd-display-clean-up-some-inconsistent-indenting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0836-drm-amdgpu-vcn-add-vcn-multiple-AIDs-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0837-drm-amdgpu-Add-pcie-replay-count-callback-to-nbio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0837-drm-amdgpu-Conform-to-SET_UCONFIG_REG-spec.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0837-drm-amdgpu-Merge-debug-module-parameters.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0837-drm-amdgpu-Switch-to-aca-bank-for-xgmi-pcs-err-cnt.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0838-drm-amdgpu-Create-an-option-to-disable-soft-recovery.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0838-drm-amdgpu-don-t-modify-num_doorbells-for-mes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0838-drm-amdkfd-pass-kfd_node-ref-to-svm-migration-api.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0839-drm-amd-display-add-plane-shaper-LUT-and-TF-driver-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0839-drm-amdgpu-Use-status-register-for-partition-mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0839-drm-amdgpu-add-UAPI-for-allocating-doorbell-memory.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0839-drm-amdgpu-add-vcn_doorbell_range-callback-for-nbio-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0840-drm-amd-display-add-plane-blend-LUT-and-TF-driver-sp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0840-drm-amdgpu-add-remap_hdp_registers-callback-for-nbio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0840-drm-amdkfd-Sync-trap-handler-binaries-with-source.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0840-drm-amdkfd-Update-SMI-events-for-GFX9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0841-drm-amd-display-add-CRTC-gamma-TF-driver-specific-pr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0841-drm-amdgpu-Use-function-for-IP-version-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0841-drm-amdgpu-adjust-s2a-entry-register-for-sdma-doorbe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0841-drm-amdkfd-Relocate-TBA-TMA-to-opposite-side-of-VM-h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0842-drm-amd-display-add-comments-to-describe-DM-crtc-col.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0842-drm-amd-pm-Fix-clock-reporting-for-SMUv13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0842-drm-amdgpu-drop-redundant-csb-init-for-gfx943.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0842-drm-amdkfd-Sign-extend-TMA-address-in-trap-handler.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0843-drm-amd-display-encapsulate-atomic-regamma-operation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0843-drm-amd-pm-Fix-GFX-deep-sleep-clock-reporting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0843-drm-amdgpu-Fix-SWS-on-multi-XCD-GPU.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0843-drm-amdgpu-accommodate-DOMAIN-PL_DOORBELL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0844-drm-amd-Drop-special-case-for-yellow-carp-without-di.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0844-drm-amd-display-add-CRTC-gamma-TF-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0844-drm-amdgpu-initialize-ttm-for-doorbells.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0844-drm-amdkfd-Use-instance-table-for-GFX-9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0845-drm-amd-Move-seamless-boot-check-out-of-display.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0845-drm-amd-include-drm-drm_edid.h-only-where-needed.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0845-drm-amdgpu-Add-pci-replay-count-to-nbio-v7.9.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0845-drm-amdgpu-Fix-failure-when-switching-to-DPX-mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0846-drm-amd-Add-HDP-flush-during-jpeg-init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0846-drm-amd-display-set-sdr_ref_white_level-to-80-for-ou.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0846-drm-amdkfd-Update-interrupt-handling-for-GFX9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0847-drm-amd-Add-a-module-parameter-for-seamless-boot.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0847-drm-amd-display-mark-plane-as-needing-reset-if-color.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0847-drm-amdgpu-Fix-programming-of-initial-XCP-mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0847-drm-amdgpu-Use-nbio-callback-for-nv-and-soc21.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0848-drm-amd-Enable-seamless-boot-by-default-on-newer-ASI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0848-drm-amd-display-decouple-steps-for-mapping-CRTC-dega.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0848-drm-amdgpu-Fix-register-access-on-GC-v9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0848-drm-amdgpu-create-kernel-doorbell-pages.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0849-Documentation-amdgpu-Modify-pp_dpm_-clk-details.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0849-drm-amd-display-add-plane-degamma-TF-and-LUT-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0849-drm-amdgpu-add-new-doorbell-assignment-table-for-aqu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0849-drm-amdgpu-get-absolute-offset-from-doorbell-index.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0850-drm-amd-display-reject-atomic-commit-if-setting-both.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0850-drm-amdgpu-Add-IP-instance-map-for-aqua-vanjaram.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0850-drm-amdgpu-Report-Missing-MES-Firmware-Versions-with.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0850-drm-amdgpu-add-amdgpu-smu-mca-dump-feature-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0851-drm-amd-display-add-dc_fixpt_from_s3132-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0851-drm-amd-pm-update-smu_v13_0_6-message-vf-flag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0851-drm-amdgpu-Add-mask-for-SDMA-instances.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0851-drm-amdgpu-add-VPE-IP-discovery-info-to-HW-IP-info-q.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0852-drm-amd-display-Add-Freesync-Panel-DM-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0852-drm-amd-display-add-HDR-multiplier-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0852-drm-amdgpu-Use-SDMA-instance-table-for-aqua-vanjaram.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0852-drm-amdgpu-add-amdgpu-mca-debug-sysfs-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0853-drm-amd-display-Read-replay-data-from-sink.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0853-drm-amd-display-add-plane-shaper-LUT-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0853-drm-amdgpu-switch-to-aqua_vanjaram_doorbell_index_in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0853-drm-amdkfd-fix-add-queue-process-context-clear-witho.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0854-drm-amd-display-add-plane-shaper-TF-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0854-drm-amdgpu-Add-EXT_COHERENT-memory-allocation-flags.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0854-drm-amdgpu-update-ip-discovery-header-to-v4.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0854-drm-amdgpu-use-doorbell-mgr-for-kfd-kernel-doorbells.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0855-drm-amd-pm-update-smu_v13_0_6-ppsmc-header.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0855-drm-amdgpu-increase-DISCOVERY_TMR_SIZE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0855-drm-amdgpu-use-doorbell-mgr-for-kfd-process-doorbell.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0855-drm-radeon-Prevent-multiple-debug-error-lines-on-sus.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0856-drm-amd-display-add-plane-3D-LUT-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0856-drm-amd-pm-add-smu_13_0_6-mca-dump-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0856-drm-amdgpu-extend-max-instances.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0857-drm-amd-display-handle-empty-LUTs-in-__set_input_tf.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0857-drm-amdgpu-Fix-vbios-version-string-search.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0857-drm-amdgpu-do-some-register-access-cleanup-in-nbio-v.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0857-drm-amdgpu-remove-unused-functions-and-variables.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0858-drm-amd-display-Hook-up-content-type-property-for-HD.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0858-drm-amd-display-add-plane-blend-LUT-and-TF-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0858-drm-amdgpu-upgrade-amdgpu_discovery-struct-ip-to-ip_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0858-drm-amdgpu-use-doorbell-mgr-for-MES-kernel-doorbells.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0859-drm-amd-display-Remove-unused-display_content_suppor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0859-drm-amd-display-allow-newer-DC-hardware-to-use-degam.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0859-drm-amdgpu-cleanup-MES-process-level-doorbells.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0859-drm-amdgpu-parse-base-address-from-new-ip-discovery-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0860-drm-amd-display-fix-a-regression-in-blank-pixel-data.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0860-drm-amdgpu-Rework-coredump-to-use-memory-dynamically.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0860-drm-amdgpu-add-helpers-to-access-registers-on-differ.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0861-drm-amd-display-Add-interface-to-enable-DPIA-trace.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0861-drm-amd-display-Add-reset-for-SYMCLKC_FE_SRC_SEL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0861-drm-amd-pm-support-return-vpe-clock-table.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0861-drm-amdgpu-consolidate-the-access-helpers-in-nbio-v7.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0862-drm-amd-display-Enable-DPIA-trace-with-DC-debug-mask.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0862-drm-amd-display-copy-3D-LUT-settings-from-crtc-state.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0862-drm-amd-display-disable-clock-gating-logic.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0862-drm-amdgpu-Fix-interrupt-handling-in-GFX-v9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0863-drm-amd-display-Fix-a-bug-when-searching-for-insert_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0863-drm-amd-display-Temporarily-disable-clock-gating.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0863-drm-amd-display-add-plane-CTM-driver-specific-proper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0863-drm-amdgpu-init-gfx_v9_4_3-external_rev_id.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0864-drm-amd-display-Fix-dig-register-undefined.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0864-drm-amd-display-Make-mpc32-functions-available-to-fu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0864-drm-amdgpu-Add-SDMA-v4.4.2-golden-settings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0864-drm-amdgpu-vpe-enable-vpe-dpm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0865-drm-amd-amdgpu-Update-debugfs-for-XCC-support-v3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0865-drm-amd-display-Add-z8_marks-related-in-dml-for-DCN3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0865-drm-amd-display-Set-Stream-Update-Flags-in-commit_st.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0865-drm-amd-pm-add-power-save-mode-workload-for-smu-13.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0866-drm-amd-display-Add-DCN35-case-for-dc_clk_mgr_create.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0866-drm-amd-display-Use-DTBCLK-as-refclk-instead-of-DPRE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0866-drm-amd-display-add-plane-CTM-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0866-drm-amdgpu-retire-render-backend-setup-from-gfx_v9_4.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0867-drm-amd-display-Add-3x4-CTM-support-for-plane-CTM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0867-drm-amd-display-Enable-DCLK_DS-from-driver-by-defaul.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0867-drm-amd-display-support-plane-clip-with-zero-recout-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0867-drm-amdgpu-add-smuio-v13_0_3-ip-headers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0868-drm-amd-display-Add-pointer-check-before-function-ca.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0868-drm-amd-display-always-acquire-MPO-pipe-for-every-bl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0868-drm-amdgpu-implement-smuio-v13_0_3-callbacks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0869-drm-amd-display-fix-static-screen-detection-setting-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0869-drm-amd-display-update-add-plane-to-context-logic-wi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0869-drm-amd-pm-Remove-unneeded-semicolon.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0869-drm-amdgpu-init-smuio-funcs-for-smuio-v13_0_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0870-drm-amd-display-Add-DPIA-Link-Encoder-Assignment-Fix.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0870-drm-amd-display-adjust-visual-confirm-dpp-height-off.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0870-drm-amdgpu-detect-current-GPU-memory-partition-mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0871-drm-amd-display-Update-pipe-resource-interfaces-for-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0871-drm-amd-display-do-not-treat-clip_rect-size-change-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0871-drm-amdgpu-Revert-programming-of-CP_PSP_XCP_CTL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0872-drm-amd-display-Revert-drm-amd-display-Read-down-spr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0872-drm-amd-display-STREAM_MAPPER_CONTROL-register-offse.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0872-drm-amdgpu-fix-vm-context-register-assignment-in-mmh.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0873-drm-amd-display-Blocking-invalid-420-modes-on-HDMI-T.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0873-drm-amd-display-Correct-z8-watermark-mask.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0873-drm-amdgpu-Skip-runtime-db-read-for-PSP-13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0874-drm-amd-display-Blocking-invalid-420-modes-on-HDMI-T.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0874-drm-amd-display-Update-driver-and-IPS-interop.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0874-drm-amd-display-fix-documentation-for-amdgpu_dm_veri.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0874-drm-amdgpu-fix-kcq-mqd_backup-buffer-double-free-for.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0875-drm-amd-display-Add-IPS-control-flag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0875-drm-amd-display-Add-vendor-Id-for-reference.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0875-drm-amd-display-fix-documentation-for-dm_crtc_additi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0875-drm-amdgpu-remove-partition-attributes-sys-file-for-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0876-drm-amd-display-Use-max-memclk-variable-when-setting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0876-drm-amd-display-disable-IPS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0876-drm-amdgpu-more-GPU-page-fault-info-for-GC-v9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0877-drm-amd-display-Add-option-to-flip-ODM-optimization.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0877-drm-amd-display-move-idle-pipe-allocation-logic-into.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0877-drm-amdgpu-Check-APU-supports-true-APP-mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0877-drm-amdgpu-increase-hmm-range-get-pages-timeout.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0878-drm-amd-display-Enable-replay-for-dcn35.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0878-drm-amd-display-rename-acquire_idle_pipe_for_layer-t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0878-drm-amdgpu-Rename-xcc-specific-functions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0878-drm-amdgpu-make-an-improvement-on-amdgpu_hmm_range_g.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0879-drm-amd-display-Change-HDCP-update-sequence-for-DM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0879-drm-amd-display-fix-some-non-initialized-register-ma.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0879-drm-amd-swsmu-remove-duplicate-definition-of-smu-v14.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0879-drm-amdgpu-Add-xcc-specific-functions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0880-drm-amd-display-Fix-MST-recognizes-connected-display.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0880-drm-amd-display-Promote-DAL-to-3.2.246.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0880-drm-amdgpu-Add-xcc-specific-functions-for-gfxhub.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0881-drm-amd-display-FW-Promotion-Release-0.0.183.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0881-drm-amd-display-remove-HPO-PG-in-driver-side.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0881-drm-amdgpu-Add-sdma-instance-specific-functions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0881-drm-amdgpu-Report-vbios-version-instead-of-PN.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0882-drm-amd-display-3.2.251.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0882-drm-amd-display-Return-value-of-function.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0882-drm-amd-display-Revert-drm-amd-display-Use-channel_w.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0882-drm-amdgpu-Add-initial-version-of-XCP-routines.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0883-drm-amdgpu-Add-SOC-partition-funcs-for-GC-v9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0883-drm-amdgpu-Remove-a-lot-of-unnecessary-ternary-opera.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0883-drm-amdgpu-jpeg-skip-set-pg-for-sriov.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0883-drm-msm-gpu-Move-gpu-devcore-s-to-gpu-device.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0884-drm-amd-pm-Clean-up-errors-in-smu_v11_0.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0884-drm-amdgpu-Add-soc-config-init-for-GC9.4.3-ASICs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0884-drm-amdgpu-Fix-false-positive-error-log.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0885-drm-amd-pm-Clean-up-errors-in-smu_v13_0_7_ppt.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0885-drm-amdgpu-Switch-to-SOC-partition-funcs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0885-drm-amdgpu-update-IP-count-INFO-query.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0885-drm-msm-gpu-Skip-retired-submits-in-recover-worker.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0886-drm-amd-pm-Clean-up-errors-in-smu_v13_0.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0886-drm-amd-pm-Round-Q10-format-values-in-SMU-v13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0886-drm-amdgpu-Add-GFXHUB-v1.2-XCP-funcs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0886-drm-msm-don-t-create-GPU-related-debugfs-files-with-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0887-drm-amd-pm-Clean-up-errors-in-aldebaran_ppt.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0887-drm-amd-pm-Remove-SMUv13.0.6-unsupported-feature.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0887-drm-amdgpu-Add-SDMA-v4.4.2-XCP-funcs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0887-drm-msm-Small-uabi-fixes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0888-drm-amd-pm-Clean-up-errors-in-smu_v13_0_6_ppt.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0888-drm-amdgpu-Add-XCP-functions-for-GFX-v9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0888-drm-amdkfd-Separate-dma-unmap-and-free-of-dma-addres.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0888-drm-msm-gem-Add-metadata.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0889-drm-amd-pm-Clean-up-errors-in-smu_v13_0_5_ppt.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0889-drm-amdgpu-Add-XCP-IP-callback-funcs-for-each-IP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0889-drm-amdgpu-print-channel-index-for-UMC-bad-page.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0889-drm-msm-gem-Demote-userspace-errors-to-DRM_UT_DRIVER.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0890-drm-amd-Clean-up-errors-in-smu_v13_0_5_ppt.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0890-drm-amdgpu-Add-more-fields-to-IP-version.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0890-drm-amdgpu-Skip-TMR-allocation-if-not-required.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0890-drm-msm-gem-Demote-allocations-to-__GFP_NOWARN.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0891-drm-amd-pm-Clean-up-errors-in-amdgpu_smu.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0891-drm-amdgpu-Fix-the-KCQ-hang-when-binding-back.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0891-drm-msm-a6xx-Add-missing-BIT-7-to-REG_A6XX_UCHE_CLIE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0892-drm-amd-display-Optimize-OLED-T7-delay.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0892-drm-amd-pm-Clean-up-errors-in-amd_powerplay.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0892-drm-amdgpu-Move-generic-logic-to-soc-config.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0893-drm-amd-display-Use-optc32-instead-of-optc30-in-DC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0893-drm-amd-pm-Clean-up-errors-in-vega10_baco.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0893-drm-amdgpu-Derive-active-clusters-from-SDMA.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0894-drm-amd-display-Expand-DML-to-better-support-replay.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0894-drm-amd-pm-Clean-up-errors-in-vega12_hwmgr.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0894-drm-amdgpu-Use-mask-for-active-clusters.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0895-drm-amd-display-Enable-DCN-low-mem-power-by-default.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0895-drm-amd-pm-powerplay-hwmgr-ppevvmath-Clean-up-errors.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0895-drm-amdgpu-set-MTYPE-in-PTE-for-GFXIP-9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0895-drm-msm-dpu-enable-smartdma-on-sm8350.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0896-drm-amd-display-Drop-unused-link-FPGA-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0896-drm-amd-pm-Clean-up-errors-in-smu10_hwmgr.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0896-drm-amdkfd-Update-packet-manager-for-GFX9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0897-drm-amd-display-3.2.252.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0897-drm-amd-pm-Clean-up-errors-in-fiji_baco.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0897-drm-amdgpu-correct-the-vmhub-index-when-page-fault-o.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0897-drm-msm-dp-cleanup-debugfs-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0898-drm-amd-pm-Clean-up-errors-in-vega10_powertune.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0898-drm-amdgpu-Remove-unnecessary-return-value-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0898-drm-amdgpu-Restore-partition-mode-after-reset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0898-drm-msm-mdp5-use-devres-managed-allocation-for-confi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0899-drm-amd-pm-Clean-up-errors-in-vega12_pptable.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0899-drm-amdkfd-Setup-current_logical_xcc_id-in-MQD.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0899-drm-msm-mdp5-use-devres-managed-allocation-for-CTL-m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0900-drm-amd-pm-Clean-up-errors-in-vega12_baco.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0900-drm-amdgpu-Fix-semaphore-release.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0900-drm-msm-mdp5-use-devres-managed-allocation-for-mixer.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0900-gpu-drm-amd-display-fix-kernel-doc-warnings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0901-drm-amdgpu-Clean-up-errors-in-smu7_powertune.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0901-drm-amdgpu-Fix-GFX-9.4.3-dma-address-capability.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0901-drm-amdgpu-fix-and-cleanup-gmc_v9_0_flush_gpu_tlb.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0901-drm-msm-mdp5-use-devres-managed-allocation-for-pipe-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0902-drm-amdgpu-Clean-up-errors-in-common_baco.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0902-drm-amdgpu-Fix-GFX-v9.4.3-EOP-buffer-allocation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0902-drm-amdkfd-Don-t-use-sw-fault-filter-if-retry-cam-en.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0902-drm-msm-mdp5-use-devres-managed-allocation-for-SMP-d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0903-amd-amdgpu-Set-MTYPE_UC-for-access-over-PCIe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0903-drm-amd-display-fix-some-style-issues.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0903-drm-amdgpu-Clean-up-errors-in-smu_helper.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0903-drm-msm-mdp5-use-devres-managed-allocation-for-INTF-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0904-drm-amdgpu-Clean-up-errors-in-ci_baco.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0904-drm-amdgpu-Make-UTCL2-snoop-CPU-caches.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0904-drm-amdgpu-fix-value-of-some-UMC-parameters-for-UMC-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0904-drm-msm-mdp5-use-drmm-managed-allocation-for-mdp5_cr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0905-drm-amdgpu-Add-FGCG-logic-for-GFX-v9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0905-drm-amdgpu-Clean-up-errors-in-ppatomctrl.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0905-drm-amdgpu-change-if-condition-for-bad-channel-bitma.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0905-drm-msm-mdp5-use-drmm-managed-allocation-for-mdp5_en.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0906-drm-amd-pm-Clean-up-errors-in-vega10_pptable.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0906-drm-amdgpu-Allocate-GART-table-in-RAM-for-AMD-APU.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0906-drm-amdgpu-rework-gmc_v10_0_flush_gpu_tlb-v2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0906-drm-msm-mdp4-use-bulk-regulators-API-for-LCDC-encode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0907-drm-amd-Clean-up-errors-in-smu7_hwmgr.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0907-drm-amdgpu-Make-VRAM-discovery-read-optional.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0907-drm-amdgpu-cleanup-gmc_v11_0_flush_gpu_tlb.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0907-drm-msm-mdp4-use-drmm-managed-allocation-for-mdp4_cr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0908-drm-amd-Clean-up-errors-in-pptable_v1_0.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0908-drm-amdgpu-Use-discovery-to-get-XCC-SDMA-mask.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0908-drm-amdgpu-fix-and-cleanup-gmc_v7_0_flush_gpu_tlb_pa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0908-drm-msm-mdp4-use-drmm-managed-allocation-for-mdp4_ds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0909-drm-amd-Clean-up-errors-in-vega10_processpptables.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0909-drm-amdgpu-fix-and-cleanup-gmc_v8_0_flush_gpu_tlb_pa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0909-drm-amdgpu-increase-MAX-setting-to-hold-more-jpeg-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0909-drm-msm-mdp4-use-drmm-managed-allocation-for-mdp4_dt.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0910-drm-amdgpu-add-fwlog-support-on-vcn_v4_0_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0910-drm-amdgpu-fix-and-cleanup-gmc_v9_0_flush_gpu_tlb_pa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0910-drm-amdgpu-powerplay-Clean-up-errors-in-smu_helper.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0910-drm-msm-mdp4-use-drmm-managed-allocation-for-mdp4_lc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0911-drm-amd-pm-Clean-up-errors-in-vega20_hwmgr.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0911-drm-amdgpu-add-unified-queue-support-on-vcn_v4_0_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0911-drm-amdgpu-cleanup-gmc_v10_0_flush_gpu_tlb_pasid.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0912-drm-amdgpu-Clean-up-errors-in-vega20_baco.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0912-drm-amdgpu-enable-indirect_sram-mode-on-vcn_v4_0_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0912-drm-amdgpu-fix-and-cleanup-gmc_v11_0_flush_gpu_tlb_p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0912-drm-msm-dp-tie-dp_display_irq_handler-with-dp-driver.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0913-drm-amdgpu-drop-error-return-from-flush_gpu_tlb_pasi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0913-drm-amdgpu-enable-vcn-jpeg-on-vcn_v4_0_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0913-drm-amdgpu-powerplay-Clean-up-errors-in-vega20_hwmgr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0913-drm-msm-dp-rename-is_connected-with-link_ready.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0914-drm-amdgpu-Remove-SMU-powergate-message-call-for-SDM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0914-drm-amdgpu-rework-lock-handling-for-flush_tlb-v2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0914-drm-msm-dp-use-drm_bridge_hpd_notify-to-report-HPD-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0914-gpu-amd-Clean-up-errors-in-ppatomfwctrl.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0915-drm-amd-pm-Clean-up-errors-in-tonga_baco.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0915-drm-amdgpu-Correct-dGPU-MTYPE-settings-for-gfx943.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0915-drm-amdgpu-further-move-TLB-hw-workarounds-a-layer-u.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0915-drm-msm-dp-move-parser-parse-and-dp_power_client_ini.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0916-drm-amd-pm-powerplay-hwmgr-hwmgr-Clean-up-errors-in-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0916-drm-amdgpu-Populate-VCN-JPEG-harvest-information.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0916-drm-amdkfd-Move-dma-unmapping-after-TLB-flush.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0916-drm-msm-dp-incorporate-pm_runtime-framework-into-DP-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0917-drm-amd-pm-Clean-up-errors-in-vega12_hwmgr.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0917-drm-amdgpu-vcn_v4_0_3-load-vcn-fw-once-for-all-AIDs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0917-drm-msm-dp-delete-EV_HPD_INIT_SETUP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0918-drm-amd-display-remove-unused-mmhub_reg_offsets.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0918-drm-amd-pm-Clean-up-errors-in-vega20_pptable.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0918-drm-amdgpu-increase-AMDGPU_MAX_HWIP_RINGS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0918-drm-msm-dp-move-of_dp_aux_populate_bus-to-eDP-probe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0919-drm-amd-display-determine-fast-update-only-before-co.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0919-drm-amd-pm-Clean-up-errors-in-polaris_baco.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0919-drm-amdgpu-add-num_xcps-return.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0920-drm-amd-display-reset-stream-slice-count-for-new-ODM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0920-drm-amd-pm-Clean-up-errors-in-smu9_driver_if.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0920-drm-amdkfd-Report-XGMI-IOLINKs-for-GFXIP9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0920-drm-msm-dpu-Capture-dpu-snapshot-when-frame_done_tim.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0921-drm-amd-display-add-new-windowed-mpo-odm-minimal-tra.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0921-drm-amd-pm-Remove-many-unnecessary-NULL-values.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0921-drm-amdgpu-Keep-SDMAv4.4.2-active-during-reset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0922-drm-amd-display-remove-guaranteed-viewports-limitati.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0922-drm-amd-pm-Clean-up-errors-in-smu71.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0922-drm-amdgpu-Use-unique-doorbell-range-per-xcc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0923-drm-amd-display-Improve-x86-and-dmub-ips-handshake.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0923-drm-amd-pm-Clean-up-errors-in-smu7_fusion.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0923-drm-amdgpu-Enable-CGCG-LS-for-GC-9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0924-drm-amd-display-Fix-DP2.0-timing-sync.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0924-drm-amd-fix-compiler-error-to-support-older-compiler.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0924-drm-amd-pm-Clean-up-errors-in-smu7.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0924-drm-msm-dp-add-a-missing-unlock-in-dp_hpd_plug_handl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0925-drm-amd-display-block-MPO-if-it-prevents-pstate-supp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0925-drm-amd-pm-Clean-up-errors-in-pp_thermal.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0925-drm-amdgpu-Fix-mqd-init-on-GFX-v9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0926-drm-amd-pm-Add-reset-option-for-fan_curve-on-smu13_0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0926-drm-amd-pm-Clean-up-errors-in-hardwaremanager.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0926-drm-msm-dpu-Drop-unused-get_scaler_ver-callback-from.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0926-drm-ttm-add-NUMA-node-id-to-the-pool.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0927-drm-amd-display-skip-audio-config-for-virtual-signal.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0927-drm-amd-pm-Clean-up-errors-in-hwmgr.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0927-drm-amdkfd-Cleanup-KFD-nodes-creation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0927-drm-msm-dpu-Drop-unused-qseed_type-from-catalog-dpu_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0928-drm-amd-display-switch-DC-over-to-the-new-DRM-loggin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0928-drm-amd-pm-Clean-up-errors-in-smu73.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0928-drm-amdkfd-bind-cpu-and-hiveless-gpu-to-a-hive-if-xg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0928-drm-msm-dpu-drop-the-id-field-from-DPU_HW_SUBBLK_INF.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0929-drm-amd-display-Remove-unwanted-drm-edid-references.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0929-drm-amd-pm-Clean-up-errors-in-smu75.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0929-drm-amdgpu-add-vcn_4_0_3-codec-query.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0929-drm-msm-dpu-drop-the-smart_dma_priority-field-from-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0930-drivers-amd-pm-Clean-up-errors-in-smu8_smumgr.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0930-drm-amd-display-Improve-code-style-on-bios_parser2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0930-drm-amdgpu-enable-context-empty-interrupt-on-sdma-v4.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0930-drm-msm-dpu-deduplicate-some-most-of-SSPP-sub-blocks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0931-drm-amd-pm-Clean-up-errors-in-r600_dpm.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0931-drm-amdgpu-Enable-MGCG-on-SDMAv4.4.2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0931-drm-amdgpu-vpe-fix-truncation-warnings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0931-drm-msm-dpu-drop-DPU_HW_SUBBLK_INFO-macro.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0932-drm-amd-display-Rename-DisableMinDispClkODM-in-dc_co.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0932-drm-amd-pm-Clean-up-errors-in-sislands_smc.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0932-drm-amdgpu-Add-common-helper-to-query-ras-error-v2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0932-drm-msm-dpu-rewrite-scaler-and-CSC-presense-checks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0933-drm-amd-display-add-missing-function-pointer-for-DCN.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0933-drm-amd-pm-Clean-up-errors-in-amdgpu_pm.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0933-drm-amdgpu-Add-common-helper-to-reset-ras-error.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0933-drm-msm-dpu-merge-DPU_SSPP_SCALER_QSEED3-QSEED3LITE-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0934-drm-amd-display-Clean-up-errors-in-color_gamma.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0934-drm-amd-display-add-get-primary-dpp-pipe-resource-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0934-drm-amdgpu-Add-sdma-v4_4_2-ras-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0934-drm-msm-gpu-drop-duplicating-VIG-feature-masks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0935-drm-amd-display-Clean-up-errors-in-ddc_regs.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0935-drm-amd-display-add-primary-pipe-check-when-building.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0935-drm-amdgpu-Add-query_ras_error_count-for-sdma-v4_4_2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0935-drm-msm-mdss-add-support-for-SDM670.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0936-drm-amd-dc-Clean-up-errors-in-hpd_regs.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0936-drm-amd-display-fix-incorrect-odm-change-detection-l.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0936-drm-amdgpu-Add-reset_ras_error_count-for-sdma-v4_4_2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0936-drm-msm-dpu-Add-hw-revision-4.1-SDM670.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0937-drm-amd-display-3.2.253.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0937-drm-amd-display-Clean-up-errors-in-dce110_timing_gen.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0937-drm-amdgpu-Initialize-sdma-v4_4_2-ras-function.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0937-drm-msm-dpu-add-support-for-SM8650-DPU.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0938-drm-amd-display-Clean-up-errors-in-dce110_hw_sequenc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0938-drm-amd-display-augment-display-clock-in-dc_cap-stru.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0938-drm-amdgpu-Add-mmhub-v1_8_0-ras-err-status-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0938-drm-msm-mdss-add-support-for-SM8650.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0939-drm-amd-display-Clean-up-errors-in-dce112_hw_sequenc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0939-drm-amd-display-Update-OPP-counter-from-new-interfac.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0939-drm-amdgpu-Add-query_ras_error_count-for-mmhub-v1_8.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0939-drm-msm-dsi-add-support-for-DSI-PHY-on-SM8650.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0940-drm-amd-display-Break-after-finding-supported-vlevel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0940-drm-amd-display-Clean-up-errors-in-dcn315_smu.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0940-drm-amdgpu-Add-reset_ras_error_count-for-mmhub-v1_8.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0940-drm-msm-dsi-add-support-for-DSI-2.8.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0941-drm-amd-display-Clean-up-errors-in-dcn316_clk_mgr.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0941-drm-amdgpu-Add-query_ras_error_status-for-mmhub-v1_8.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0941-drm-amdgpu-Expose-physical-id-of-device-in-XGMI-hive.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0942-drm-amd-display-Clean-up-errors-in-dcn316_smu.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0942-drm-amdgpu-Add-reset_ras_error_status-for-mmhub-v1_8.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0942-drm-amdgpu-gmc6-8-properly-disable-the-AGP-aperture.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0943-drm-amd-display-Clean-up-errors-in-bios_parser2.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0943-drm-amdgpu-Initialize-mmhub-v1_8-ras-function.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0943-drm-amdgpu-gmc-set-a-default-disable-value-for-AGP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0943-drm-msm-mdss-inline-msm_mdss_icc_request_bw.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0944-drm-amd-display-Clean-up-errors-in-dc_stream.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0944-drm-amd-display-set-stream-gamut-remap-matrix-to-MPC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0944-drm-amdgpu-Enable-persistent-edc-harvesting-in-APP-A.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0944-drm-msm-mdss-Handle-the-reg-bus-ICC-path.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0945-drm-amd-Propagate-failures-in-dc_set_power_state.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0945-drm-amd-display-Clean-up-errors-in-dcn10_dpp_dscl.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0945-drm-amdgpu-Enable-CG-for-IH-v4.4.2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0945-drm-msm-dpu-cleanup-dpu_kms_hw_init-error-path.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0946-drm-amd-display-Clean-up-errors-in-display_mode_vba_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0946-drm-amdgpu-Handle-VRAM-dependencies-on-GFXIP9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0946-drm-msm-dpu-remove-IS_ERR_OR_NULL-for-dpu_hw_intr_in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0947-drm-amd-display-Clean-up-errors-in-dce_clk_mgr.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0947-drm-amdgpu-Implement-new-dummy-vram-manager.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0947-drm-amdgpu-gmc11-disable-AGP-on-GC-11.5.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0947-drm-msm-dpu-use-devres-managed-allocation-for-interr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0948-drm-amd-display-Change-dc_set_power_state-to-bool-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0948-drm-amdgpu-Clean-up-errors-in-cik_ih.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0948-drm-amdgpu-Create-VRAM-BOs-on-GTT-for-GFXIP9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0948-drm-msm-dpu-use-devres-managed-allocation-for-VBIF-d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0949-drm-amdgpu-Add-description-for-AMD_IP_BLOCK_TYPE_VPE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0949-drm-amdgpu-Clean-up-errors-in-vce_v3_0.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0949-drm-amdgpu-increase-AMDGPU_MAX_RINGS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0950-drm-amd-pm-update-pmfw-headers-for-version-85.73.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0950-drm-amdgpu-Clean-up-errors-in-amdgpu_psp.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0950-drm-amdgpu-Increase-Max-GPU-instance-to-64.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0950-drm-msm-dpu-use-devres-managed-allocation-for-HW-blo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0951-drm-amd-pm-add-plpd_mode-in-smu_context-to-indicate-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0951-drm-amdgpu-Clean-up-errors-in-ih_v6_0.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0951-drm-amdgpu-change-the-print-level-to-warn-for-ip-blo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0951-drm-msm-dpu-drop-unused-dpu_plane-lock.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0952-drm-amd-pm-add-xgmi-plpd-mode-selecting-interface-fo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0952-drm-amdgpu-Clean-up-errors-in-vega20_ih.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0952-drm-amdgpu-fix-sdma-instance.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0952-drm-msm-dpu-remove-QoS-teardown-on-plane-destruction.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0953-drm-amd-pm-Update-pmfw-header-files-for-SMU-v13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0953-drm-amd-pm-add-xgmi_plpd_policy-sysfs-node-for-user-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0953-drm-amdgpu-Clean-up-errors-in-mmhub_v9_4.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0953-drm-msm-dpu-use-drmm-managed-allocation-for-dpu_plan.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0954-drm-amd-pm-Update-gfx-clock-frequency-for-SMU-v13.0..patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0954-drm-amdgpu-atomfirmware-Clean-up-errors-in-amdgpu_at.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0954-drm-msm-dpu-use-drmm-managed-allocation-for-dpu_crtc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0955-drm-amd-Drop-error-message-about-failing-to-load-DMU.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0955-drm-amd-pm-Update-pmfw-header-files-for-SMU-v13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0955-drm-amdgpu-Clean-up-errors-in-uvd_v7_0.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0956-drm-amd-Limit-seamless-boot-by-default-to-APUs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0956-drm-amd-pm-Add-ih-for-SMU-v13.0.6-thermal-throttling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0956-drm-jpeg-Clean-up-errors-in-jpeg_v2_0.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0956-drm-msm-dpu-drop-dpu_encoder_phys_ops-destroy.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0957-drm-amd-display-Skip-entire-amdgpu_dm-build-if-CONFI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0957-drm-amd-pm-Keep-interface-version-in-PMFW-header.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0957-drm-amdgpu-Clean-up-errors-in-dce_v10_0.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0957-drm-msm-dpu-use-drmm-managed-allocation-for-dpu_enco.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0958-drm-amd-display-Remove-unused-DPCD-declarations.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0958-drm-amd-pm-Initialize-power-limit-for-SMU-v13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0958-drm-amdgpu-Clean-up-errors-in-mxgpu_nv.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0959-drm-amd-pm-Update-hw-mon-attributes-for-GC-version-9.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0959-drm-amd-pm-init-plpd_mode-properly-for-different-asi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0959-drm-amdgpu-jpeg-Clean-up-errors-in-vcn_v1_0.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0960-drm-amd-pm-Expose-mem-temperature-for-GC-version-9.4.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0960-drm-amd-pm-integrate-plpd-allow-disallow-into-select.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0960-drm-amdgpu-Clean-up-errors-in-dce_v8_0.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0960-drm-msm-dp-Fix-platform_get_irq-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0961-drm-amd-pm-Update-PMFW-headers-for-version-85.54.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0961-drm-amd-pm-deprecate-allow_xgmi_power_down-interface.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0961-drm-amdgpu-Clean-up-errors-in-soc21.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0962-drm-amd-pm-Notify-PMFW-about-driver-unload-cases.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0962-drm-amd-pm-fix-the-print_clk_levels-issue-for-SMU-v1.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0962-drm-amdgpu-Clean-up-errors-in-amdgpu_atombios.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0962-drm-msm-Refactor-UBWC-config-setting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0963-drm-amd-Drop-error-message-about-failing-to-load-SDM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0963-drm-amdgpu-Add-mode-2-reset-in-SMU-v13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0963-drm-amdgpu-Clean-up-errors-in-mes_v11_0.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0963-drm-msm-Add-param-for-the-highest-bank-bit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0964-drm-amd-display-Create-one-virtual-connector-in-DC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0964-drm-amd-pm-fix-wrong-smu-socclk-value.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0964-drm-amdgpu-Clean-up-errors-in-amdgpu_trace.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0965-drm-amdgpu-Add-flags-for-partition-mode-query.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0965-drm-amdgpu-Clean-up-errors-in-amdgpu_ring.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0965-drm-msm-gem-Remove-valid-tracking.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0966-drm-amd-Move-microcode-init-from-sw_init-to-early_in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0966-drm-amdgpu-Clean-up-errors-in-amdgpu_virt.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0966-drm-amdgpu-Use-transient-mode-during-xcp-switch.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0966-drm-msm-gem-Remove-submit_unlock_unpin_bo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0967-drm-amd-Move-microcode-init-from-sw_init-to-early_in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0967-drm-amdgpu-Add-FGCG-for-GFX-v9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0967-drm-amdgpu-Clean-up-errors-in-nv.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0967-drm-msm-gem-Don-t-queue-job-to-sched-in-error-cases.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0968-drm-amd-Move-microcode-init-from-sw_init-to-early_in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0968-drm-amdgpu-Clean-up-errors-in-mxgpu_vi.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0968-drm-amdkfd-Enable-SVM-on-Native-mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0968-drm-msm-gem-Split-out-submit_unpin_objects-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0969-drm-amd-Move-microcode-init-from-sw_init-to-early_in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0969-drm-amdgpu-Add-parsing-of-acpi-xcc-objects.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0969-drm-amdgpu-Clean-up-errors-in-uvd_v3_1.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0969-drm-msm-gem-Cleanup-submit_cleanup_bo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0970-drm-amd-Move-microcode-init-from-sw_init-to-early_in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0970-drm-amdgpu-Add-API-to-get-tmr-info-from-acpi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0970-drm-amdgpu-Clean-up-errors-in-vcn_v4_0.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0970-drm-exec-Pass-in-initial-of-objects.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0971-drm-amd-Move-microcode-init-from-sw_init-to-early_in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0971-drm-amdgpu-Clean-up-errors-in-gfx_v7_0.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0971-drm-amdgpu-Read-discovery-info-from-system-memory.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0971-drm-msm-gem-Convert-to-drm_exec.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0972-drm-amd-display-Initialize-writeback-connector.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0972-drm-amdgpu-Add-fallback-path-for-discovery-info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0972-drm-amdgpu-Clean-up-errors-in-tonga_ih.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0972-drm-ci-remove-rebase-merge-directory.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0973-drm-amdgpu-Clean-up-errors-in-vcn_v3_0.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0973-drm-amdkfd-Flush-TLB-after-unmapping-for-GFX-v9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0973-drm-msm-dpu-move-encoder-status-to-standard-encoder-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0974-drm-amd-pm-Clean-up-errors-in-smu73_discrete.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0974-drm-amdgpu-Fix-discovery-sys-node-harvest-info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0975-drm-amd-pm-Disallow-managing-power-profiles-on-SRIOV.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0975-drm-amdgpu-Add-FRU-sysfs-nodes-only-if-needed.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0975-drm-amdgpu-preserve-the-num_links-in-case-of-reflect.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0976-drm-amd-display-Get-replay-info-from-VSDB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0976-drm-amdgpu-Load-vcn_v4_0_3-ucode-during-early_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0976-drm-amdgpu-exit-directly-if-gpu-reset-fails.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0977-drm-amd-display-Skip-writeback-connector-when-we-get.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0977-drm-amdgpu-Add-instance-mask-for-VCN-and-JPEG.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0977-drm-amdgpu-Fix-identation-issues-in-kgd_gfx_v9_progr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0977-drm-msm-dpu-remove-extra-drm_encoder_cleanup-from-th.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0978-drm-amdgpu-Add-VCN-logical-to-physical-id-mapping.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0978-drm-amdgpu-add-RAS-fatal-error-handler-for-NBIO-v7.9.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0978-drm-msm-dpu-add-formats-check-for-writeback-encoder.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0979-drm-amdgpu-Use-logical-ids-for-VCN-JPEG-v4.0.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0979-drm-amdgpu-irq-Move-irq-resume-to-the-beginning.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0979-drm-amdkfd-reduce-stack-size-in-kfd_topology_add_dev.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0980-drm-amd-display-Return-drm_connector-from-find_first.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0980-drm-amdgpu-Fix-harvest-reporting-of-VCN.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0980-drm-buddy-Fix-drm-buddy-info-output-format.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0980-drm-msm-dpu-fix-writeback-programming-for-YUV-cases.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0981-drm-amdgpu-Extend-poison-mode-check-to-SDMA-VCN-JPEG.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0981-drm-amdgpu-vcn-use-dummy-register-selects-AID-for-VC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0981-drm-amdkfd-drop-struct-kfd_cu_info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0981-drm-msm-dpu-move-csc-matrices-to-dpu_hw_util.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0982-drm-amd-display-Use-drm_connector-in-create_stream_f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0982-drm-amdgpu-Add-pcie-usage-callback-to-nbio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0982-drm-amdgpu-use-physical-AID-index-for-ring-name.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0982-drm-msm-dpu-add-cdm-blocks-to-sc7280-dpu_hw_catalog.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/0983-drm-amd-pm-delete-dead-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0983-drm-amdgpu-A-workaround-for-JPEG_v4_0_3-ring-test-fa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0983-drm-amdgpu-Add-pci-usage-to-nbio-v7.9.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0983-drm-msm-dpu-add-cdm-blocks-to-sm8250-dpu_hw_catalog.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0984-drm-amd-display-Address-srf_updates-not-described-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0984-drm-amdgpu-Use-local64_try_cmpxchg-in-amdgpu_perf_re.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0984-drm-amdgpu-fixes-a-JPEG-get-write-read-pointer-bug.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0984-drm-msm-dpu-add-dpu_hw_cdm-abstraction-for-CDM-block.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0985-drm-amd-display-Use-drm_connector-in-create_validate.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0985-drm-amdgpu-Add-a-read-after-write-DB_CTRL-for-vcn_v4.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0985-drm-amdkfd-drop-IOMMUv2-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/0985-drm-msm-dpu-add-cdm-blocks-to-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0986-drm-amd-display-Create-amdgpu_dm_wb_connector.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0986-drm-amdgpu-Use-a-different-value-than-0xDEADBEEF-for.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0986-drm-amdkfd-rename-device_queue_manager_init_v10_navi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0986-drm-msm-dpu-add-support-to-allocate-CDM-from-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0987-drm-amd-display-Create-fake-sink-and-stream-for-writ.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0987-drm-amdgpu-don-t-allow-userspace-to-create-a-doorbel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0987-drm-amdgpu-vcn-Use-buffer-object-s-deletion-logic.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0987-drm-msm-dpu-add-CDM-related-logic-to-dpu_hw_ctl-laye.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0988-drm-amd-display-Hande-writeback-request-from-userspa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0988-drm-amdgpu-Simplify-aquavanjram-instance-mapping.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0988-drm-etnaviv-Replace-of_platform.h-with-explicit-incl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0988-drm-msm-dpu-add-an-API-to-setup-the-CDM-block-for-wr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0989-drm-amd-display-Add-writeback-enable-disable-in-dc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0989-drm-amdgpu-Use-GPU-VA-space-for-IH-v4.4.2-in-APU.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0989-drm-etnaviv-slow-down-FE-idle-polling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0989-drm-msm-dpu-plug-in-the-cdm-related-bits-to-writebac.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0990-drm-amd-display-Fix-writeback_info-never-got-updated.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0990-drm-amdgpu-Use-apt-name-for-FW-reserved-region.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0990-drm-msm-dpu-reserve-cdm-blocks-for-writeback-in-case.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0991-drm-amd-display-Validate-hw_points_num-before-using-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0991-drm-amdgpu-Add-utility-functions-for-xcp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0991-drm-etnaviv-add-HWDB-entry-for-VIP8000-Nano-r8002.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0991-drm-msm-dpu-introduce-separate-wb2_format-arrays-for.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0992-drm-amd-display-Fix-writeback_info-is-not-removed.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0992-drm-amdgpu-Move-memory-partition-query-to-gmc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0992-drm-etnaviv-add-HWDB-entry-for-GC520-r5341-c204.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0992-drm-msm-dpu-add-cdm-blocks-to-dpu-snapshot.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0993-drm-amd-display-Add-writeback-enable-field-wb_enable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0993-drm-amdgpu-Get-supported-memory-partition-modes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0993-drm-etnaviv-move-down-etnaviv_gpu_recover_hang-in-fi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0994-drm-amd-display-Setup-for-mmhubbub3_warmup_mcif-with.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0994-drm-amdgpu-Store-additional-numa-node-information.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0994-drm-etnaviv-free-events-the-usual-way-in-recover-wor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0994-drm-msm-dpu-move-CSC-tables-to-dpu_hw_util.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0995-drm-amd-display-Add-new-set_fc_enable-to-struct-dwbc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0995-drm-amdgpu-Add-API-to-get-numa-information-of-XCC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0995-drm-etnaviv-move-runtime-PM-handling-to-events.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0996-drm-amd-display-Disable-DWB-frame-capture-to-emulate.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0996-drm-amdgpu-Add-memory-partitions-to-gmc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0996-drm-etnaviv-make-clock-handling-symetric-between-run.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0997-drm-amdgpu-Initialize-memory-ranges-for-GC-9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0997-drm-amdgpu-correct-gpu-clock-counter-query-on-cyan-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0997-drm-etnaviv-avoid-runtime-PM-usage-in-etnaviv_gpu_bi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0997-drm-msm-dp-call-dp_display_get_next_bridge-during-pr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0998-drm-amd-display-fix-problems-in-power_helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0998-drm-amdgpu-Add-callback-to-fill-xcp-memory-id.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0998-drm-etnaviv-better-track-GPU-state.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0998-drm-mediatek-Use-devm_platform_ioremap_resource.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/0999-drm-amdgpu-Fill-xcp-mem-node-in-aquavanjaram.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0999-drm-amdgpu-gmc-add-a-way-to-force-a-particular-place.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0999-drm-etnaviv-drop-GPU-initialized-property.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/0999-drm-mediatek-Stop-using-iommu_present.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1000-drm-amdgpu-Move-initialization-of-xcp-before-kfd.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1000-drm-amdgpu-gmc11-set-gart-placement-GC11.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1000-drm-etnaviv-expedited-MMU-fault-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1000-drm-mediatek-Rename-OVL_ADAPTOR_TYPE_RDMA.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1001-drm-amdgpu-Rework-KFD-memory-max-limits.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1001-drm-amdkfd-Add-xcp-reference-to-kfd-node.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1001-drm-etnaviv-fix-error-code-in-event_alloc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1001-drm-mediatek-Add-component-ID-to-component-match-str.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1002-drm-amdgpu-Use-ttm_pages_limit-to-override-vram-repo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1002-drm-amdkfd-Use-xcc-mask-for-identifying-xcc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1002-drm-mediatek-Manage-component-s-clock-with-function-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1002-drm-panel-simple-Fix-Innolux-G156HCE-L01-LVDS-clock.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1003-drm-amdgpu-Check-memory-ranges-for-valid-xcp-mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1003-drm-mediatek-Power-on-off-devices-with-function-poin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1003-drm-ttm-tests-Require-MMU-when-testing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1004-drm-amd-display-Add-Replay-supported-enabled-checks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1004-drm-amdgpu-Add-auto-mode-for-compute-partition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1004-drm-amdgpu-add-cached-GPU-fault-structure-to-vm-stru.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1004-drm-mediatek-Start-Stop-components-with-function-poi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1005-drm-amdgpu-Fix-missing-comment-for-mb-in-amdgpu_devi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1005-drm-amdgpu-cache-gpuvm-fault-information-for-gmc7.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1005-drm-mediatek-Sort-OVL-adaptor-components.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1005-drm-ttm-export-ttm_pool_fini-for-cleanup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1006-drm-amdgpu-Set-TTM-pools-for-memory-partitions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1006-drm-amdkfd-Add-missing-tba_hi-programming-on-aldebar.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1006-drm-mediatek-Refine-device-table-of-OVL-adaptor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1007-drm-amd-pm-Add-vclk-and-dclk-sysnode-for-GC-9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1007-drm-amdkfd-Native-mode-memory-partition-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1007-drm-mediatek-Support-MT8188-Padding-in-display-drive.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1008-drm-amdgpu-Fix-xGMI-access-P2P-mapping-failure-on-GF.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1008-drm-radeon-Fix-multiple-line-dereference-in-atom_iio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1009-drm-amd-Drop-all-hand-built-MIN-and-MAX-macros-in-th.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1009-drm-amdgpu-Fix-unmapping-of-aperture.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1009-drm-amdkfd-fix-build-failure-without-CONFIG_DYNAMIC_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1010-drm-amdgpu-Add-compute-mode-descriptor-function.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1010-drm-amdgpu-Remove-unnecessary-ras-cap-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1011-drm-amdgpu-Return-error-on-invalid-compute-mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1011-drm-amdgpu-ratelimited-override-pte-flags-messages.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1011-drm-amdkfd-Use-memdup_user-rather-than-duplicating-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1012-drm-amd-pm-avoid-driver-getting-empty-metrics-table-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1012-drm-amdgpu-Add-PSP-spatial-parition-interface.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1012-drm-amdkfd-Fix-EXT_COHERENT-memory-allocation-crash.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1012-drm-i915-Streamline-intel_dsc_pps_read.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1013-drm-amd-display-enable-dsc_clk-even-if-dsc_pg-disabl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1013-drm-amdgpu-Add-PSP-supporting-PSP-13.0.6-SRIOV-ucode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1013-drm-amdgpu-mode1-reset-needs-to-recover-mp1-for-mp0-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1013-drm-i915-Drop-redundant-NULL-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1014-drm-amd-display-remove-duplicated-edp-relink-to-fast.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1014-drm-amdgpu-Fix-identifier-names-to-function-definiti.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1014-drm-amdgpu-Skip-using-MC-FB-Offset-when-APU-flag-is-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1014-drm-i915-Drop-crtc-NULL-check-from-intel_crtc_active.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1015-drm-amd-display-Update-replay-for-clk_mgr-optimizati.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1015-drm-amdgpu-Set-memory-partitions-to-1-for-SRIOV.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1015-drm-i915-Drop-NULL-fb-check-from-intel_fb_uses_dpt.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1016-drm-amd-display-Make-driver-backwards-compatible-wit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1016-drm-amdgpu-Checked-if-the-pointer-NULL-before-use-it.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1016-drm-amdkfd-fix-double-assign-skip-process-context-cl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1016-drm-i915-Drop-redunant-null-check-from-intel_get_fra.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1017-drm-amd-Use-pci_dev_id-to-simplify-the-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1017-drm-amd-display-Clean-up-code-warnings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1017-drm-amdgpu-Add-vcn-jpeg-ras-err-status-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1017-drm-i915-s-cstate-crtc_state-in-intel_get_frame_time.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1018-drm-amd-pm-correct-the-way-for-checking-custom-OD-se.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1018-drm-amdgpu-Add-query_ras_error_count-for-vcn-v4_0_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1018-drm-i915-tv-Drop-redundant-null-checks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1019-drm-amd-display-Add-a-check-for-idle-power-optimizat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1019-drm-amd-pm-correct-the-logics-for-retreiving-SMU13-O.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1019-drm-amdgpu-Add-reset_ras_error_count-for-vcn-v4_0_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1019-drm-i915-mtl-Use-port-clock-compatible-numbers-for-C.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1020-drm-amd-display-Update-DMUB-cmd-header.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1020-drm-amd-pm-bump-SMU-v13.0.5-driver_if-header-version.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1020-drm-amdgpu-Initialize-vcn-v4_0_3-ras-function.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1020-drm-i915-mtl-Remove-misleading-clock-field-from-C20-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1021-drm-amd-display-Adjust-code-style-for-dmub_cmd.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1021-drm-amdgpu-Add-I2C-EEPROM-support-on-smu-v13_0_6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1021-drm-amdgpu-Re-enable-VCN-RAS-if-DPG-is-enabled.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1021-drm-i915-mtl-Rename-the-link_bit_rate-to-clock-in-C2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1022-drm-amd-display-Adjust-code-style-for-hw_sequencer.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1022-drm-amdgpu-Add-query_ras_error_count-for-jpeg-v4_0_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1022-drm-amdgpu-vcn-Add-MMSCH-v4_0_3-support-for-sriov.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1022-drm-i915-Stop-accessing-crtc-state-from-the-flip-don.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1023-drm-amd-Add-amdgpu_hwmon_get_sensor_generic.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1023-drm-amd-display-3.2.254.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1023-drm-amdgpu-Add-reset_ras_error_count-for-jpeg-v4_0_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1023-drm-i915-Drop-irqsave-restore-for-flip_done_handler.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1024-drm-amd-display-dmub_replay-don-t-use-kernel-doc-mar.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1024-drm-amd-pm-Add-throttle-limit-for-SMU-v13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1024-drm-amdgpu-Initialize-jpeg-v4_0_3-ras-function.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1024-drm-i915-display-do-not-use-cursor-size-reduction-on.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1025-drm-amd-pm-Add-GC-v9.4.3-thermal-limits-to-hwmon.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1025-drm-amdgpu-Adjust-the-sequence-to-query-ras-error-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1025-drm-amdkfd-Remove-unnecessary-NULL-values.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1025-drm-i915-display-Wait-for-PHY-readiness-not-needed-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1026-drm-amdgpu-add-new-INFO-ioctl-query-for-the-last-GPU.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1026-drm-amdgpu-vcn-mmsch_v4_0_3-requires-doorbell-on-32-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1026-drm-amdkfd-Increase-queue-number-per-process-to-255-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1026-drm-i915-cdclk-s-1-0-when-dealing-with-unsigned-valu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1027-drm-amd-display-Remove-unnecessary-NULL-values.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1027-drm-amdgpu-Fix-register-accesses-in-GFX-v9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1027-drm-amdgpu-refine-fault-cache-updates.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1027-drm-i915-cdclk-Give-the-squash-waveform-length-a-nam.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1028-drm-amdgpu-Skip-halting-RLC-on-GFX-v9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1028-drm-amdgpu-amdgpu_drm.h-fix-comment-typos.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1028-drm-i915-cdclk-Remove-the-assumption-that-cdclk-divi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1028-drm-radeon-Remove-unnecessary-NULL-values.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1029-drm-amd-display-Remove-migrate_en-dis-from-dc_fpu_be.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1029-drm-amdgpu-jpeg-mmsch_v4_0_3-requires-doorbell-on-32.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1029-drm-amdkfd-Move-pgmap-to-amdgpu_kfd_dev-structure.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1029-drm-i915-cdclk-Rewrite-cdclk-voltage_level-selection.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1030-drm-amd-display-Simplify-the-per-CPU-usage.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1030-drm-amd-display-Support-Compliance-Test-Pattern-Gene.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1030-drm-amdgpu-Enable-NPS4-CPX-mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1030-drm-i915-mtl-Fix-voltage_level-for-cdclk-480MHz.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1031-drm-amd-display-disable-clock-gating-logic-reversed-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1031-drm-amdgpu-For-GFX-9.4.3-APU-fix-vram_usage-value.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1031-drm-amdkfd-Use-partial-migrations-in-GPU-page-faults.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1031-drm-i915-Split-intel_ddi_compute_min_voltage_level-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1032-drm-amdgpu-Fix-complex-macros-error.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1032-drm-amdgpu-Use-legacy-TLB-flush-for-gfx943.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1032-drm-amdkfd-workaround-address-watch-clearing-bug-for.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1032-drm-i915-mtl-Calculate-the-correct-voltage-level-fro.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1033-drm-amdgpu-Move-package-type-enum-to-amdgpu_smuio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1033-drm-amdgpu-bu-Add-use_mtype_cc_wa-module-param.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1033-drm-amdgpu-vcn-change-end-doorbell-index-for-vcn_v4_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1033-drm-i915-Simplify-intel_ddi_compute_min_voltage_leve.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1034-drm-amd-display-Enable-subvp-high-refresh-up-to-175h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1034-drm-amd-pm-Remove-set-df-cstate-for-SMUv13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1034-drm-amdgpu-Fix-per-BO-MTYPE-selection-for-GFXv9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1034-drm-i915-dmc-Also-disable-the-flip-queue-event-on-TG.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1035-drm-amd-display-PMFW-to-wait-for-DMCUB-ack-for-FPO-c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1035-drm-amdgpu-Override-MTYPE-per-page-on-GFXv9.4.3-APUs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1035-drm-amdgpu-fix-ip-count-query-for-xcp-partitions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1035-drm-i915-dmc-Also-disable-HRR-event-on-TGL-ADLS-main.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1036-drm-amd-display-Gamut-remap-only-changes-missed.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1036-drm-amdgpu-Add-more-smuio-v13.0.3-package-types.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1036-drm-amdgpu-bu-add-mtype_local-as-a-module-parameter.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1036-drm-i915-dmc-Print-out-the-DMC-mmio-register-list-at.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1037-drm-amd-display-fix-incorrect-stream_res-allocation-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1037-drm-amdgpu-Get-package-types-for-smuio-v13.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1037-drm-amdgpu-bu-update-mtype_local-parameter-settings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1037-drm-i915-display-Remove-dead-code-around-intel_atomi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1038-drm-amd-display-Enable-8k60hz-mode-on-single-display.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1038-drm-amdgpu-Add-sysfs-attribute-to-get-board-info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1038-drm-amdgpu-support-partition-drm-devices.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1038-drm-xe-Introduce-a-new-DRM-driver-for-Intel-GPUs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1039-Documentation-amdgpu-Add-board-info-details.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1039-drm-amd-display-implement-pipe-type-definition-and-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1039-drm-amdgpu-find-partition-ID-when-open-device.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1039-drm-xe-Implement-a-local-xe_mmio_wait32.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1040-drm-amd-display-avoid-crash-and-add-z8_marks-related.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1040-drm-amdgpu-Drop-unnecessary-return-statements.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1040-drm-amdgpu-add-partition-ID-track-in-ring.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1040-drm-xe-Stop-using-i915-s-range_overflows_t-macro.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1041-drm-amd-display-Add-some-missing-register-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1041-drm-amdgpu-Annotate-struct-amdgpu_bo_list-with-__cou.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1041-drm-amdgpu-update-header-to-support-partition-schedu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1041-drm-xe-Let-s-return-last-value-read-on-xe_mmio_wait3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1042-drm-amdgpu-Replace-ternary-operator-with-min-in-amdg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1042-drm-amdgpu-add-partition-scheduler-list-update.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1042-drm-xe-Convert-guc_ready-to-regular-xe_mmio_wait32.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1043-drm-amdgpu-keep-amdgpu_ctx_mgr-in-ctx-structure.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1043-drm-amdgpu-vcn-sriov-support-for-vcn_v4_0_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1043-drm-radeon-Fix-UBSAN-array-index-out-of-bounds-for-R.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1043-drm-xe-Wait-for-success-on-guc-done.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1044-drm-amd-Add-a-new-hwmon-attribute-for-instantaneous-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1044-drm-amdgpu-add-partition-schedule-for-GC-9-4-3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1044-drm-xe-Remove-i915_utils-dependency-from-xe_guc_pc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1045-drm-amd-Remove-freesync-video-mode-amdgpu-parameter.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1045-drm-amd-display-Add-a-warning-if-the-FPU-is-used-out.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1045-drm-amdgpu-run-partition-schedule-if-it-is-supported.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1045-drm-xe-Stop-using-i915_utils-in-xe_wopcm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1046-drm-amd-Introduce-AMDGPU_PP_SENSOR_GPU_INPUT_POWER.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1046-drm-amd-display-Move-the-memory-allocation-out-of-dc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1046-drm-amdgpu-update-ref_cnt-before-ctx-free.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1046-drm-xe-Let-s-avoid-i915_utils-in-the-xe_force_wake.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1047-drm-amd-display-Move-the-memory-allocation-out-of-dc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1047-drm-amdgpu-Add-xcp-manager-num_xcp_per_mem_partition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1047-drm-amdgpu-expand-runpm-parameter.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1047-drm-xe-Convert-xe_mmio_wait32-to-us-so-we-can-stop-u.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1048-drm-amd-pm-Clean-up-errors-in-smu_v11_0_pptable.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1048-drm-amdgpu-Enable-SMU-13.0.0-optimizations-when-ROCm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1048-drm-amdkfd-Store-drm-node-minor-number-for-kfd-nodes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1048-drm-xe-Remove-i915_utils-dependency-from-xe_pcode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1049-drm-amd-display-Move-dce_calcs-from-DML-folder.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1049-drm-amd-display-enable-low-power-mode-for-VGA-memory.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1049-drm-amdgpu-Add-memory-partition-id-to-amdgpu_vm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1049-drm-xe-migrate-Add-kerneldoc-for-the-migrate-subsyst.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1050-drm-amd-display-Move-custom_float-from-DML-folder.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1050-drm-amd-pm-Clean-up-errors-in-amdgpu_smu.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1050-drm-amdkfd-Show-KFD-node-memory-partition-info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1050-drm-xe-Take-memory-ref-on-kernel-job-creation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1051-drm-amd-display-Move-bw_fixed-from-DML-folder.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1051-drm-amdgpu-Add-memory-partition-mem_id-to-amdgpu_bo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1051-drm-amdgpu-Remove-duplicated-includes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1051-drm-xe-Implement-stolen-memory.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1052-drm-amd-display-Move-dml-code-under-CONFIG_DRM_AMD_D.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1052-drm-amdkfd-Alloc-memory-of-GPU-support-memory-partit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1052-drm-radeon-Use-pci_dev_id-to-simplify-the-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1052-drm-xe-Ensure-VMA-not-userptr-before-calling-xe_bo_i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1053-drm-amd-Fix-SMU-13.0.4-13.0.11-GPU-metrics-average-p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1053-drm-amd-display-Introduce-DML2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1053-drm-amdkfd-SVM-range-allocation-support-memory-parti.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1053-drm-xe-Fake-pulling-gt-info.engine_mask-from-hwconfi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1054-drm-amd-Drop-unnecessary-helper-for-aldebaran.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1054-drm-amd-display-Add-DCN35-DML2-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1054-drm-amdgpu-dGPU-mode-placement-support-memory-partit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1054-drm-xe-guc-Report-submission-version-of-GuC-firmware.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1055-drm-amd-Fix-the-return-for-average-power-on-aldebara.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1055-drm-amd-display-Add-z8_marks-in-dml.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1055-drm-amdkfd-Update-MTYPE-for-far-memory-partition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1055-drm-xe-guc-s-xe_guc_send_mmio-xe_guc_mmio_send.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1056-drm-amd-Show-both-power-attributes-for-vega20.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1056-drm-amd-display-Handle-multiple-streams-sourcing-sam.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1056-drm-amdgpu-Alloc-page-table-on-correct-memory-partit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1056-drm-xe-guc-Add-support-GuC-MMIO-send-recv.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1057-drm-amd-Rename-AMDGPU_PP_SENSOR_GPU_POWER.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1057-drm-amd-display-Use-fixed-DET-Buffer-Size.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1057-drm-amdgpu-dGPU-mode-set-VRAM-range-lpfn-as-exclusiv.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1057-drm-xe-Fix-hidden-gotcha-regression-with-bo-create.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1058-drm-amd-Hide-unsupported-power-attributes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1058-drm-amd-display-Split-pipe-for-stereo-timings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1058-drm-amdkfd-Store-xcp-partition-id-to-amdgpu-bo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1058-drm-xe-enforce-GSMBASE-for-DG1-instead-of-BAR2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1059-drm-amd-display-Move-stereo-timing-check-to-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1059-drm-amd-display-Replace-ternary-operator-with-min-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1059-drm-amdgpu-KFD-graphics-interop-support-compute-part.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1059-drm-xe-pcode-fix-pcode-error-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1060-drm-amd-display-Fix-Chroma-Surface-height-width-init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1060-drm-amdgpu-Replace-ternary-operator-with-min-in-amdg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1060-drm-amdgpu-use-xcp-partition-ID-for-amdgpu_gem.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1060-drm-xe-fix-xe_mmio_total_vram_size.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1061-drm-amd-display-FW-Promotion-Release-0.0.179.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1061-drm-amd-display-correct-dml2-input-and-dlg_refclk.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1061-drm-amdkfd-Move-local_mem_info-to-kfd_node.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1061-drm-xe-ggtt-Use-BIT_ULL-for-64bit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1062-drm-amd-display-Modify-Pipe-Selection-for-Policy-for.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1062-drm-amd-display-Promote-DAL-to-3.2.247.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1062-drm-amdkfd-Fix-memory-reporting-on-GFX-9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1062-drm-xe-Fix-some-log-messages-on-32b.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1063-drm-amd-display-Port-replay-vblank-logic-to-DML2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1063-drm-amd-display-Update-adaptive-sync-infopackets-for.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1063-drm-amdkfd-APU-mode-set-max-svm-range-pages.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1063-drm-xe-mmio-Use-non-atomic-writeq-readq-variant-for-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1064-drm-amd-display-add-check-in-validate_only-in-dml2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1064-drm-amdgpu-jpeg-sriov-support-for-jpeg_v4_0_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1064-drm-amdgpu-route-ioctls-on-primary-node-of-XCPs-to-p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1064-drm-xe-Fix-tracepoints-on-32b.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1065-drm-amd-display-Handle-Replay-related-hpd-irq.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1065-drm-amdgpu-update-ib-start-and-size-alignment.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1065-drm-amdkfd-Refactor-migrate-init-to-support-partitio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1065-drm-xe-gt-Fix-min-with-u32-and-u64.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1066-drm-amdgpu-Correct-get_xcp_mem_id-calculation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1066-drm-amdgpu-enable-FRU-device-for-SMU-v13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1066-drm-amdgpu-vcn-Skip-vcn-power-gating-change-for-srio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1066-drm-xe-Add-documentation-for-mem_type.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1067-drm-amd-pm-allow-the-user-to-force-BACO-on-smu-v13.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1067-drm-amdgpu-Enable-IH-CAM-on-GFX9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1067-drm-amdgpu-Refactor-FRU-product-information.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1067-drm-xe-Add-min-config-for-kunit-integration-ARCH-um.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1068-drm-amd-pm-Update-pci-link-speed-for-smu-v13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1068-drm-amdgpu-Add-more-FRU-field-information.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1068-drm-amdgpu-convert-logical-instance-mask-to-physical.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1068-drm-xe-Kconfig.debug-select-DEBUG_FS-for-KUnit-runs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1069-Documentation-amdgpu-Add-FRU-attribute-details.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1069-drm-amdgpu-Remove-gfxoff-check-in-GFX-v9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1069-drm-amdgpu-add-instance-mask-for-RAS-inject.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1069-drm-xe-KUnit-tests-depend-on-CONFIG_DRM_FBDEV_EMULAT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1070-drm-amd-display-enable-S-G-display-for-for-recent-AP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1070-drm-amdgpu-Add-memory-vendor-information.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1070-drm-amdgpu-reorganize-RAS-injection-flow.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1070-drm-xe-gt-Enable-interrupt-while-initializing-root-g.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1071-drm-amdgpu-remove-RAS-GFX-injection-for-gfx_v9_4-gfx.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1071-drm-msm-dpu1-Rename-sm8150_dspp_blk-to-sdm845_dspp_b.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1071-drm-xe-Fix-Meteor-Lake-rsa-issue-on-guc-loading.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1072-drm-amd-display-Modify-SMU-message-logs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1072-drm-amdgpu-add-check-for-RAS-instance-mask.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1072-drm-msm-stop-storing-the-array-of-CRTCs-in-struct-ms.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1072-drm-xe-guc_pc-Fix-Meteor-Lake-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1073-drm-amd-display-VSIF-v3-set-Max-Refresh-Rate.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1073-drm-amdkfd-Fix-null-ptr-access.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1073-drm-msm-dpu-retrieve-DSI-DSC-struct-through-priv-dsi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1073-drm-xe-skip-Kunit-tests-requiring-real-hardware-when.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1074-drm-amd-display-Update-pmfw_driver_if-new-structure.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1074-drm-amdgpu-Do-not-access-members-of-xcp-w-o-check-v2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1074-drm-msm-dpu-remove-struct-drm_dsc_config-from-struct.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1074-drm-xe-Use-global-macros-to-set-PM-functions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1075-drm-amd-display-Modify-Vmin-default-value.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1075-drm-amdgpu-add-GFX-RAS-common-function.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1075-drm-msm-dsi-Hook-up-refgen-regulator.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1075-drm-xe-uapi-Rename-XE_ENGINE_PROPERTY_X-to-XE_ENGINE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1076-drm-amd-display-Revert-drm-amd-display-remove-duplic.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1076-drm-amdgpu-add-RAS-status-query-for-gfx_v9_4_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1076-drm-msm-enumerate-DSI-interfaces.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1076-drm-xe-uapi-Add-XE_ENGINE_GET_PROPERTY-uAPI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1077-drm-amd-display-Update-stream-mask.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1077-drm-amdgpu-add-RAS-status-reset-for-gfx_v9_4_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1077-drm-msm-dpu-always-use-MSM_DP-DSI_CONTROLLER_n.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1077-drm-xe-Convert-memory-device-refcount-to-s32.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1078-drm-amd-display-Update-dml-ssb-from-pmfw-clock-table.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1078-drm-amdgpu-Add-gc-v9_4_3-ras-error-status-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1078-drm-msm-dpu-simplify-peer-LM-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1078-drm-xe-Map-initial-FB-at-the-same-place-in-GGTT-too.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1079-drm-amd-display-Update-cursor-limits-based-on-SW-cur.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1079-drm-amdgpu-add-RAS-definitions-for-GFX.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1079-drm-msm-dpu-drop-dpu_mdss_cfg-mdp_count-field.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1079-drm-xe-bo-reduce-xe_bo_create_pin_map-restrictions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1080-drm-amdgpu-add-RAS-error-count-definitions-for-gfx_v.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1080-drm-msm-dpu-drop-enum-dpu_mdp-and-MDP_TOP-value.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1080-drm-xe-ppgtt-clear-the-scratch-page.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1081-drm-amdgpu-add-RAS-error-count-query-for-gfx_v9_4_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1081-drm-amdgpu-add-hub-ctx_distance-in-setup_vmid_config.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1081-drm-msm-dpu-expand-.clk_ctrls-definitions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1081-drm-xe-ppgtt-fix-scratch-page-usage-on-DG2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1082-drm-amd-display-Revert-drm-amd-display-Add-a-check-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1082-drm-amdgpu-add-RAS-error-count-reset-for-gfx_v9_4_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1082-drm-msm-dpu-drop-zero-features-from-dpu_mdp_cfg-data.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1082-drm-xe-ggtt-fix-alignment-usage-for-DG2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1083-drm-amd-display-Refactor-HWSS-into-component-folder.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1083-drm-amdgpu-add-sq-timeout-status-functions-for-gfx_v.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1083-drm-msm-dpu-drop-zero-features-from-dpu_ctl_cfg-data.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1083-drm-xe-ggtt-fix-GGTT-scratch-usage-for-DG2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1084-drm-amd-display-Don-t-set-dpms_off-for-seamless-boot.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1084-drm-amdgpu-initialize-RAS-for-gfx_v9_4_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1084-drm-msm-dpu-correct-indentation-for-CTL-definitions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1084-drm-xe-migrate-Update-emit_pte-to-cope-with-a-size-l.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1085-drm-amd-display-Refactor-DPG-test-pattern-logic-for-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1085-drm-amdgpu-gmc9-fix-64-bit-division-in-partition-cod.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1085-drm-msm-dpu-inline-SSPP_BLK-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1085-drm-xe-Don-t-process-TLB-invalidation-done-in-CT-fas.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1086-drm-amd-display-Disable-SubVP-if-test-pattern-is-ena.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1086-drm-amdgpu-vcn4-fix-endian-conversion.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1086-drm-msm-dpu-inline-DSPP_BLK-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1086-drm-xe-Break-of-TLB-invalidation-into-its-own-file.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1087-drm-amd-amdgpu-Fix-errors-warnings-in-amdgpu_ttm.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1087-drm-amd-display-Disable-virtual-links.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1087-drm-msm-dpu-inline-LM_BLK-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1087-drm-xe-Move-TLB-invalidation-variable-to-own-sub-str.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1088-drm-amd-display-3.2.255.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1088-drm-amdkfd-fix-stack-size-in-svm_range_validate_and_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1088-drm-msm-dpu-inline-DSC_BLK-and-DSC_BLK_1_2-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1088-drm-xe-Add-TLB-invalidation-fence.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1089-drm-amd-amdgpu-Fix-warnings-in-amdgpu_encoders.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1089-drm-msm-dpu-inline-MERGE_3D_BLK-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1089-drm-xe-Invalidate-TLB-after-unbind-is-complete.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1090-drm-amd-amdgpu-Fix-errors-warnings-in-amdgpu_vcn.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1090-drm-amdgpu-discovery-enable-DCN-3.5.0-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1090-drm-msm-dpu-inline-various-PP_BLK_-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1090-drm-xe-Kernel-doc-GT-TLB-invalidations.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1091-drm-amdgpu-Improve-MES-responsiveness-during-oversub.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1091-drm-amdgpu-perform-mode2-reset-for-sdma-fed-error-on.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1091-drm-msm-dpu-inline-WB_BLK-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1091-drm-xe-Add-TLB-invalidation-fence-ftrace.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1092-drm-amd-amdgpu-Fix-errors-warnings-in-amdgpu-_uvd-_v.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1092-drm-amdgpu-vpe-remove-IB-end-boundary-requirement.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1092-drm-msm-dpu-inline-INTF_BLK-and-INTF_BLK_DSI_TE-macr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1092-drm-xe-Add-TDR-for-invalidation-fence-timeout-cleanu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1093-drm-amdgpu-Fix-warnings-in-amdgpu-_sdma-_ucode.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1093-drm-amdgpu-vpe-align-with-mcbp-changes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1093-drm-msm-dpu-drop-empty-features-mask-MERGE_3D_SM8150.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1093-drm-xe-Only-set-VM-asid-for-platforms-that-support-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1094-drm-amdgpu-Address-member-gart_placement-not-describ.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1094-drm-amdgpu-fix-S3-issue-if-MQD-in-VRAM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1094-drm-msm-dpu-drop-empty-features-mask-INTF_SDM845_MAS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1094-drm-xe-Delete-debugfs-entry-to-issue-TLB-invalidatio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1095-drm-amdgpu-vpe-fix-insert_nop-ops.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1095-drm-xe-Add-has_range_tlb_invalidation-device-attribu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1096-drm-amd-display-drop-unused-function-set_abm_event.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1096-drm-amd-pm-wait-for-completion-of-the-EnableGfxImu-c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1096-drm-msm-dpu-Drop-unused-num-argument-from-relevant-m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1096-drm-xe-Add-range-based-TLB-invalidations.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1097-drm-amd-display-drop-unused-count-variable-in-create.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1097-drm-amdgpu-Return-EINVAL-when-MMSCH-init-status-inco.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1097-drm-msm-dpu-Define-names-for-unnamed-sblks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1097-drm-xe-Propagate-error-from-bind-operations-to-async.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1098-drm-amd-pm-Update-metric-table-for-smu-v13_0_6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1098-drm-amdgpu-fix-incorrect-pcie_gen_mask-in-passthroug.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1098-drm-msm-dpu-Remove-redundant-prefix-suffix-in-name-o.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1098-drm-xe-Use-GuC-to-do-GGTT-invalidations-for-the-GuC-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1099-drm-amd-Update-driver-misc.html-for-Phoenix.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1099-drm-amd-pm-Add-gpu_metrics_v1_4.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1099-drm-msm-dpu-Refactor-printing-of-main-blocks-in-devi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1099-drm-xe-Lock-GGTT-on-when-restoring-kernel-BOs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1100-drm-amd-Update-driver-misc.html-for-Dragon-Range.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1100-drm-amd-pm-Use-gpu_metrics_v1_4-for-SMUv13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1100-drm-msm-dpu-Update-dev-core-dump-to-dump-registers-o.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1100-drm-xe-Propagate-VM-unbind-error-to-invalidation-fen.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1101-drm-amdgpu-Increase-IP-discovery-region-size.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1101-drm-amdgpu-remove-unnecessary-void-conversions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1101-drm-msm-dsi-Enable-BURST_MODE-for-command-mode-for-D.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1101-drm-xe-Signal-invalidation-fence-immediately-if-CT-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1102-drm-amd-Update-driver-misc.html-for-Rembrandt-R.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1102-drm-amdgpu-umsch-fix-psp-frontdoor-loading.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1102-drm-msm-dpu-re-introduce-dpu-core-revision-to-the-ca.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1102-drm-xe-Add-has_asid-to-device-info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1103-drm-amdgpu-umsch-power-on-off-UMSCH-by-DLDO.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1103-drm-msm-dpu-use-dpu-core-s-major-version-to-enable-d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1103-drm-xe-Add-TLB-invalidation-fence-after-rebinds-issu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1104-drm-amdgpu-swsmu-add-smu-v14_0_0-driver-if-file.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1104-drm-msm-dpu-rename-all-hw_intf-structs-to-have-dpu_h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1104-drm-xe-Drop-TLB-invalidation-from-ring-operations.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1105-drm-amd-swsmu-add-smu-v14_0_0-ppsmc-file.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1105-drm-msm-dpu-rename-enable_compression-to-program_int.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1105-drm-radeon-Remove-unnecessary-void-conversions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1105-drm-xe-Add-debugfs-for-dumping-GGTT-mappings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1106-drm-amd-swsmu-add-smu-v14_0_0-pmfw-if-file.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1106-drm-amdgpu-add-the-smu_v13_0_6-and-gfx_v9_4_3-ip-blo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1106-drm-msm-dpu-drop-DPU_INTF_DATA_COMPRESS-from-dpu-cat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1106-drm-xe-Fix-typo-in-MCR-documentation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1107-drm-amd-swsmu-add-smu14-ip-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1107-drm-amdgpu-fix-the-memory-override-in-kiq-ring-struc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1107-drm-msm-dpu-Add-SM6125-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1107-drm-xe-Fix-xe_tuning-include.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1108-drm-amdgpu-Remove-IMU-ucode-in-vf2pf.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1108-drm-amdgpu-discovery-add-SMU-14-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1108-drm-msm-mdss-Add-SM6125-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1108-drm-xe-Remove-TODO-from-rtp-infra.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1109-drm-amdgpu-Fix-uninitialized-variable-in-gfx_v9_4_3_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1109-drm-amdgpu-add-support-to-powerup-VPE-by-SMU.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1109-drm-msm-dsi-Reuse-QCM2290-14nm-DSI-PHY-configuration.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1109-drm-xe-Remove-TODO-from-workaround-documentation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1110-drm-amdgpu-add-power-up-down-UMSCH-ppt-callback.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1110-drm-amdgpu-fix-vga_set_state-NULL-pointer-issue.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1110-drm-msm-Remove-redundant-DRM_DEV_ERROR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1110-drm-xe-mcr-Use-designated-init-for-xe_steering_types.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1111-drm-amd-display-improve-the-message-printed-when-loa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1111-drm-amdgpu-add-support-to-power-up-down-UMSCH-by-SMU.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1111-drm-msm-dpu-inline-__intr_offset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1111-drm-xe-mcr-Add-SQIDI-steering-for-DG2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1112-drm-amdgpu-enable-GFX-IP-v11.5.0-CG-and-PG-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1112-drm-amdgpu-retire-set_vga_state-for-some-ASIC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1112-drm-msm-dpu-split-interrupt-address-arrays.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1112-drm-xe-Rename-xe_rtp_regval-to-xe_rtp_action.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1113-drm-amd-Evict-resources-during-PM-ops-prepare-callba.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1113-drm-amd-amdgpu-Fix-errors-warnings-in-mmhub_v1_8.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1113-drm-msm-dpu-autodetect-supported-interrupts.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1113-drm-xe-rtp-Split-action-and-entry-flags.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1114-drm-amd-Add-concept-of-running-prepare_suspend-seque.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1114-drm-amdgpu-Fix-uninitalized-variable-in-jpeg_v4_0_3_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1114-drm-msm-dpu-drop-now-unused-mdss_irqs-field-from-hw-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1114-drm-xe-rtp-Support-multiple-actions-per-entry.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1115-drm-amd-Split-up-UVD-suspend-into-prepare-and-suspen.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1115-drm-amdgpu-Fix-uninitalized-variable-in-kgd2kfd_devi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1115-drm-msm-dpu-drop-compatibility-INTR-defines.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1115-drm-xe-Initialize-ret-in-mcr_lock.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1116-drm-amd-display-Catch-errors-from-drm_atomic_helper_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1116-drm-amdgpu-stop-including-swiotlb.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1116-drm-msm-mdss-rename-ubwc_version-to-ubwc_enc_version.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1116-drm-xe-Update-the-list-of-devices-to-add-even-more-T.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1117-drm-amd-display-Destroy-DC-context-while-keeping-DML.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1117-drm-amd-display-Fix-DMUB-debugging-print-issue.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1117-drm-msm-mdss-export-UBWC-data.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1117-drm-xe-Remove-unseless-xe_force_wake_prune.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1118-drm-amd-display-disable-dcn315-pixel-rate-crb-when-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1118-drm-amd-display-make-dc_set_power_state-return-type-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1118-drm-msm-mdss-populate-missing-data.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1118-drm-xe-mmio-fix-forcewake-ref-leak-in-xe_mmio_ioctl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1119-drm-amd-display-Update-SR-watermarks-for-DCN314.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1119-drm-amdgpu-umsch-enable-doorbell-for-umsch.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1119-drm-msm-dpu-use-MDSS-data-for-programming-SSPP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1119-drm-xe-stolen-don-t-map-stolen-on-small-bar.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1120-drm-amd-display-add-missing-NULL-check-for-DML2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1120-drm-amd-display-lower-dp-link-training-message-level.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1120-drm-msm-dpu-drop-UBWC-configuration.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1120-drm-xe-query-zero-the-region-info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1121-drm-amd-display-fix-dcn315-pixel-rate-crb-scaling-ch.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1121-drm-amdgpu-Read-PSPv13-OS-version-from-register.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1121-drm-msm-dpu-drop-BWC-features-from-DPU_MDP_foo-names.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1121-drm-xe-Make-local-functions-static.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1122-drm-amd-display-Trigger-DIO-FIFO-resync-on-commit-st.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1122-drm-amdgpu-Expose-ras-version-schema-info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1122-drm-msm-dpu-bail-from-_dpu_core_perf_crtc_update_bus.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1122-drm-xe-Fix-application-of-LRC-tunings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1123-drm-amd-display-Revert-drm-amd-display-Use-drm_conne.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1123-drm-amd-display-Revert-vblank-change-that-causes-nul.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1123-drm-msm-dpu-drop-separate-dpu_core_perf_tune-overrid.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1123-drm-xe-Remove-unused-functions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1124-Revert-drm-amd-display-Disable-DWB-frame-capture-to-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1124-drm-amd-display-Fix-possible-underflow-for-displays-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1124-drm-msm-dpu-rework-indentation-in-dpu_core_perf.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1124-drm-xe-Add-missing-doc-for-xe-parameter.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1125-Revert-drm-amd-display-Add-new-set_fc_enable-to-stru.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1125-drm-msm-dpu-drop-the-dpu_core_perf_crtc_update-s-sto.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1125-drm-xe-Add-missing-include-xe_wait_user_fence.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1126-Revert-drm-amd-display-Setup-for-mmhubbub3_warmup_mc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1126-drm-amd-display-Clean-FPGA-code-in-dc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1126-drm-msm-dpu-use-dpu_perf_cfg-in-DPU-core_perf-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1126-drm-xe-Remove-duplicate-media_ver.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1127-Revert-drm-amd-display-Add-writeback-enable-field-wb.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1127-drm-msm-dpu-remove-unused-fields-from-struct-dpu_cor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1127-drm-xe-Remove-outdated-build-workaround.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1128-Revert-drm-amd-display-Fix-writeback_info-is-not-rem.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1128-drm-amd-display-Trigger-DIO-FIFO-resync-on-commit-st.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1128-drm-msm-dpu-remove-extra-clk_round_rate-call.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1128-drm-xe-guc-Remove-i915_regs.h-include.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1129-Revert-drm-amd-display-Validate-hw_points_num-before.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1129-drm-amd-display-Reorganize-DCN30-Makefile.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1129-drm-msm-dpu-move-max-clock-decision-to-dpu_kms.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1129-drm-xe-pm-fix-unbalanced-ref-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1130-Revert-drm-amd-display-Fix-writeback_info-never-got-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1130-drm-amd-display-cache-trace-buffer-size.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1130-drm-msm-dpu-drop-dpu_core_perf_destroy.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1130-drm-xe-Fix-kunit-integration-due-to-missing-prototyp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1131-Revert-drm-amd-display-Add-writeback-enable-disable-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1131-drm-amd-display-3.2.237.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1131-drm-xe-Remove-gen-based-mmio-offsets-from-hw-engine-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1132-Revert-drm-amd-display-Hande-writeback-request-from-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1132-drm-amdgpu-Fix-unused-amdgpu_acpi_get_numa_info-func.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1132-drm-msm-dpu-fix-DSC-1.2-block-lengths.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1132-drm-xe-Assume-MTL-s-forcewake-register-continues-to-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1133-Revert-drm-amd-display-Create-fake-sink-and-stream-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1133-drm-amdgpu-Fix-uninitialized-variable-in-gfxhub_v1_2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1133-drm-msm-dpu-fix-DSC-1.2-enc-subblock-length.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1133-drm-xe-Sort-includes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1134-Revert-drm-amd-display-Create-amdgpu_dm_wb_connector.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1134-drm-amdgpu-remove-unused-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1134-drm-msm-dpu-Drop-encoder-vsync_event.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1134-drm-xe-Remove-dependency-on-intel_engine_regs.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1135-drm-amd-pm-Add-reset-option-for-fan_ctrl-interfaces.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1135-drm-amdgpu-init-the-XCC_DOORBELL_FENCE-regs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1135-drm-xe-Remove-dependency-on-intel_gt_regs.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1136-drm-amd-pm-Add-reset-option-for-fan_ctrl-on-smu-13.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1136-drm-msm-dpu-clean-up-some-inconsistent-indenting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1136-drm-radeon-stop-including-swiotlb.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1136-drm-xe-Remove-dependency-on-intel_lrc_reg.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1137-drm-amd-pm-drop-most-smu_cmn_get_smc_version-in-smu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1137-drm-msm-dpu-initialise-clk_rate-to-0-in-_dpu_core_pe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1137-drm-xe-Remove-dependency-on-intel_gpu_commands.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1138-Revert-drm-amd-display-Use-drm_connector-in-create_s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1138-drm-amdgpu-Disable-interrupt-tracker-on-NBIOv7.9.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1138-drm-xe-Remove-dependency-on-i915_reg.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1139-Revert-drm-amd-display-Return-drm_connector-from-fin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1139-drm-amdgpu-Fix-a-couple-of-spelling-mistakes-in-info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1139-drm-msm-adreno-Remove-GPU-name.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1139-drm-xe-guc_pc-Move-gt-register-to-the-proper-place.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1140-Revert-drm-amd-display-Skip-writeback-connector-when.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1140-drm-amdgpu-Fix-unsigned-comparison-with-zero-in-gmc_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1140-drm-msm-adreno-Remove-redundant-gmem-size-param.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1140-drm-xe-Remove-dependency-on-intel_mchbar_regs.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1141-Revert-drm-amd-display-Initialize-writeback-connecto.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1141-drm-amd-pm-mark-irq-functions-as-static.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1141-drm-msm-adreno-Remove-redundant-revn-param.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1141-drm-xe-Prefer-single-underscore-for-header-guards.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1142-Revert-drm-amd-display-Disable-virtual-links.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1142-drm-amdkfd-mark-local-functions-as-static.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1142-drm-msm-adreno-Use-quirk-identify-hw_apriv.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1142-drm-xe-Do-not-spread-i915_reg_defs.h-include.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1143-Revert-drm-amd-display-Create-one-virtual-connector-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1143-drm-amdgpu-mark-aqua_vanjaram_reg_init.c-function-as.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1143-drm-msm-adreno-Use-quirk-to-identify-cached-coherent.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1143-drm-xe-mocs-Drop-unwanted-TGL-table.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1144-Revert-drm-amd-display-Skip-entire-amdgpu_dm-build-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1144-drm-amdgpu-use-pad-format-string-for-dma_addr_t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1144-drm-msm-adreno-Allow-SoC-specific-gpu-device-table-e.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1144-drm-xe-mocs-Add-missing-RKL-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1145-drm-amdgpu-fix-acpi-build-warnings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1145-drm-amdgpu-save-VCN-instances-init-info-before-jpeg-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1145-drm-msm-adreno-Move-speedbin-mapping-to-device-table.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1145-drm-xe-mocs-Drop-xe_mocs_info_index.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1146-drm-amdgpu-Avoid-FRU-EEPROM-access-on-APU.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1146-drm-amdgpu-remove-unused-variable-num_xcc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1146-drm-msm-adreno-Bring-the-a630-family-together.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1146-drm-xe-mocs-Drop-duplicate-assignment-of-uc_index.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1147-drm-amdgpu-Update-PSP-interface-header.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1147-drm-amdkfd-Align-partition-memory-size-to-page-size.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1147-drm-msm-adreno-Add-adreno-family.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1147-drm-xe-mocs-add-MTL-mocs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1148-drm-amd-display-avoid-calling-missing-.resync_fifo_d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1148-drm-amdgpu-Add-support-to-load-P2S-tables.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1148-drm-msm-adreno-Add-helper-for-formating-chip-id.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1148-drm-xe-mocs-LNCF-MOCS-settings-only-need-to-be-resto.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1149-drm-amd-display-remove-unused-variables-res_create_m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1149-drm-amd-pm-Add-P2S-tables-for-SMU-v13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1149-drm-msm-adreno-Move-adreno-info-to-config.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1149-drm-xe-mocs-Drop-HAS_RENDER_L3CC-flag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1150-drm-amdgpu-Correctly-use-bo_va-ref_count-in-compute-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1150-drm-amdgpu-Remove-duplicate-include.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1150-drm-msm-adreno-Switch-to-chip-id-for-identifying-GPU.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1150-drm-xe-prefer-xe_bo_create_pin_map.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1151-drm-amdgpu-Modify-mismatched-function-name.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1151-drm-msm-a6xx-Fix-misleading-comment.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1151-drm-xe-bo-explicitly-reject-zero-sized-BO.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1152-drm-amdgpu-correct-NBIO-v7.11-programing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1152-drm-amdgpu-vcn-Modify-mismatched-function-name.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1152-drm-msm-a6xx-Add-some-missing-header-definitions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1152-drm-xe-device-Prefer-the-drm-managed-mutex_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1153-drm-amdgpu-Add-a-low-priority-scheduler-for-VRAM-cle.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1153-drm-amdgpu-don-t-use-legacy-invalidation-on-MMHUB-v3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1153-drm-msm-a6xx-Use-descriptive-bitfield-names-for-CP_P.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1153-drm-xe-Fix-typo-persitent-persistent.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1154-Revert-drm-amd-display-Block-optimize-on-consecutive.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1154-drm-amdgpu-umsch-correct-IP-version-format.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1154-drm-msm-a6xx-Skip-empty-protection-ranges-entries.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1154-drm-xe-Fix-size-of-xe_eu_mask_t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1155-drm-amd-amdgpu-Fix-warnings-in-amdgpu_irq.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1155-drm-amdgpu-umsch-fix-missing-stuff-during-rebase.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1155-drm-msm-a6xx-Ensure-clean-GMU-state-in-a6xx_gmu_fw_s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1155-drm-xe-Fix-duplicated-setting-for-register-0x6604.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1156-Revert-drm-amd-display-Do-not-set-drr-on-pipe-commit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1156-drm-amdgpu-disable-GFXOFF-and-PG-during-compute-for-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1156-drm-msm-a6xx-Improve-GMU-force-shutdown-sequence.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1156-drm-xe-Fix-ROW_CHICKEN2-define.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1157-drm-amdgpu-make-err_data-structure-built-in-for-ras_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1157-drm-amdkfd-Set-event-interrupt-class-for-GFX-9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1157-drm-msm-a6xx-Fix-up-GMU-region-reservations.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1157-drm-xe-tests-Remove-CONFIG_FB-dependency.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1158-drm-amdgpu-Fix-warnings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1158-drm-amdgpu-flush-the-correct-vmid-tlb-for-specific-p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1158-drm-xe-tests-Grab-a-memory-access-reference-around-t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1159-drm-amdgpu-add-ras_err_info-to-identify-RAS-error-so.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1159-drm-amdgpu-sdma-set-sched.ready-status-after-ring-IB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1159-drm-xe-migrate-Fix-number-of-PT-structs-in-docbook.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1160-drm-amdgpu-add-RAS-error-info-support-for-sdma_v4_4_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1160-drm-amdgpu-gfx-set-sched.ready-status-after-ring-IB-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1160-drm-msm-Disallow-relocs-on-a6xx.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1160-drm-xe-stolen-Exclude-reserved-lmem-portion.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1161-drm-amdgpu-add-RAS-error-info-support-for-gfx_v9_4_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1161-drm-amdgpu-switch-to-unified-amdgpu_ring_test_helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1161-drm-msm-adreno-adreno_gpu-Switch-to-memdup_user_nul-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1161-drm-xe-guc-Handle-regset-overflow-check-for-entire-G.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1162-drm-amdgpu-Use-single-copy-per-SDMA-instance-type-v2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1162-drm-amdgpu-add-RAS-error-info-support-for-mmhub_v1_8.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1162-drm-msm-Take-lru-lock-once-per-job_run.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1162-drm-xe-s-lmem-vram.patch (jsc#PED-9898
  jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237
  jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1163-drm-amd-display-remove-unused-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1163-drm-amdgpu-add-RAS-error-info-support-for-umc_v12_0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1163-drm-msm-Use-drm_gem_object-in-submit-bos-table.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1163-drm-xe-Separate-engine-fuse-handling-into-dedicated-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1164-drm-amd-display-remove-unused-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1164-drm-amd-swsmu-update-smu-v14_0_0-header-files-and-me.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1164-drm-msm-Take-lru-lock-once-per-submit_pin_objects.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1164-drm-xe-Add-support-for-CCS-engine-fusing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1165-drm-amd-display-remove-unused-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1165-drm-msm-Remove-vma-use-tracking.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1165-drm-xe-vm-Use-the-correct-vma-destroy-sequence-on-us.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1166-drm-amd-Drop-debugfs-access-to-the-DPCD.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1166-drm-i915-Add-new-DG2-PCI-IDs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1166-drm-xe-mcr-Add-L3BANK-steering-for-DG2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1167-drm-amd-display-remove-unused-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1167-drm-i915-lnl-Remove-watchdog-timers-for-PSR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1167-drm-msm-gpu-Push-gpu-lock-down-past-runpm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1167-drm-xe-mcr-Document-how-to-initialize-group-instance.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1168-drm-amdgpu-Fix-return-types-of-certain-NBIOv7.9-call.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1168-drm-i915-dsb-Allocate-command-buffer-from-local-memo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1168-drm-msm-adreno-Add-missing-MODULE_FIRMWARE-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1168-drm-xe-Allow-const-propagation-in-gt_to_xe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1169-drm-amdgpu-Fix-defined-but-not-used-gfx9_cs_data-in-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1169-drm-i915-dsb-Correct-DSB-command-buffer-cache-cohere.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1169-drm-msm-a6xx-Introduce-a6xx_llc_read.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1169-drm-xe-Constify-xe_dss_mask_group_ffs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1170-drm-amdgpu-Fix-unused-variable-in-amdgpu_gfx.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1170-drm-i915-dsb-Re-instate-DSB-for-LUT-updates.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1170-drm-msm-a6xx-Move-LLC-accessors-to-the-common-header.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1170-drm-xe-rtp-Move-match-function-from-wa-to-rtp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1171-drm-amd-display-remove-unused-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1171-drm-i915-dp-Sanitize-DPCD-revision-check-in-intel_dp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1171-drm-msm-a6xx-Bail-out-early-if-setting-GPU-OOB-fails.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1171-drm-xe-rtp-Add-match-for-render-reset-domain.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1172-drm-amd-display-remove-unused-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1172-drm-i915-dp-Store-DSC-DPCD-capabilities-in-the-conne.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1172-drm-ttm-tests-Fix-type-conversion-in-ttm_pool_test.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1172-drm-xe-Remove-dump-function-from-reg_sr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1173-drm-amdgpu-bypass-bios-dependent-operations.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1173-drm-i915-dp_mst-Set-connector-DSC-capabilities-and-d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1173-drm-nouveau-sched-avoid-job-races-between-entities.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1173-drm-xe-Name-LRC-wa-after-the-engine-it-belongs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1174-drm-amdgpu-golden-settings-for-ASIC-rev_id-0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1174-drm-i915-dp-Use-i915-intel-connector-local-variables.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1174-drm-nouveau-uvmm-fix-unset-region-pointer-on-remap.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1174-drm-xe-pvc-Remove-A-steppings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1175-drm-amdgpu-complement-the-4-6-and-8-XCC-cases.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1175-drm-i915-dp-Use-connector-DSC-DPCD-in-i915_dsc_fec_s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1175-drm-nouveau-uapi-don-t-pass-NO_PREFETCH-flag-implici.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1175-drm-xe-make-compound-literal-initialization-const.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1176-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_dsc_c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1176-drm-jpeg-add-init-value-for-num_jpeg_rings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1176-drm-tests-drm_kunit_helpers-Place-correct-function-n.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1176-drm-xe-Fix-overflow-in-vram-manager.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1177-drm-amdgpu-set-the-APU-flag-based-on-package-type.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1177-drm-gpuva_mgr-remove-unused-prev-pointer-in-__drm_gp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1177-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_suppo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1177-drm-xe-one-more-s-lmem-vram.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1178-clk-Annotate-struct-clk_hw_onecell_data-with-__count.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1178-drm-amdgpu-save-restore-part-of-xcp-drm_device-field.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1178-drm-i915-Fix-TLB-Invalidation-seqno-store.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1178-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_suppo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1178-drm-xe-add-xe_ttm_stolen_cpu_access_needs_ggtt.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1179-drm-amdgpu-add-the-accelerator-pcie-class.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1179-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_dsc_m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1179-drm-xe-rtp-Add-match-helper-for-gslice-fused-off.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1180-drm-amd-display-remove-unused-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1180-drm-i915-dp-Pass-connector-DSC-DPCD-to-drm_dp_dsc_si.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1180-drm-xe-reg_sr-Tweak-verbosity-for-register-printing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1181-PCI-VGA-Replace-full-MIT-license-text-with-SPDX-iden.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1181-drm-amd-display-remove-unused-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1181-drm-i915-dp-Pass-only-the-required-i915-to-intel_dp_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1181-drm-xe-Print-whitelist-while-applying.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1182-drm-amd-display-remove-unused-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1182-drm-i915-dp-Pass-only-the-required-DSC-DPCD-to-intel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1182-drm-xe-debugfs-Dump-register-save-restore-tables.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1183-drm-amd-display-clean-up-some-inconsistent-indenting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1183-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_dsc_c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1183-drm-xe-Reorder-WAs-to-consider-the-platform.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1184-drm-amd-display-remove-unused-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1184-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_dsc_s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1184-drm-xe-Add-PVC-gt-workarounds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1185-drm-amd-display-clean-up-some-inconsistent-indenting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1185-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_dsc_g.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1185-drm-xe-Add-PVC-engine-workarounds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1186-PCI-VGA-Fix-typos.patch (jsc#PED-9898
  jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237
  jsc#PED-10340 jsc#PED-10852 jsc#PED-11022 jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Update
  patches.suse/1186-drm-amd-display-remove-unused-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1186-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_mode_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1186-drm-xe-Add-missing-DG2-gt-workarounds-and-tunings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1187-drm-amdgpu-Mark-mmhub_v1_8_mmea_err_status_reg-as-__.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1187-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_dsc_c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1187-drm-xe-Add-missing-DG2-engine-workarounds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1187-tty-sysrq-switch-sysrq-handlers-from-int-to-u8.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1188-drm-amdxcp-add-platform-device-driver-for-amdxcp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1188-drm-i915-dp_mst-Use-connector-DSC-DPCD-in-intel_dp_m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1188-drm-xe-Add-missing-DG2-lrc-tunings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1188-mei-log-firmware-status-on-hw_start-failure.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1189-drm-amd-display-remove-unused-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1189-drm-i915-dp-Remove-unused-DSC-caps-from-intel_dp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1189-drm-xe-Add-missing-DG2-lrc-workarounds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1189-mei-bus-enable-asynchronous-suspend.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1190-drm-amdgpu-use-amdxcp-platform-device-as-spatial-par.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1190-drm-i915-display-Clean-up-zero-initializers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1190-drm-xe-Add-missing-ADL-P-engine-workaround.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1190-mei-obtain-firmware-version-only-on-gsc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1191-drm-amd-display-remove-unused-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1191-drm-i915-hdcp-Clean-up-zero-initializers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1191-drm-xe-Add-missing-LRC-workarounds-for-graphics-1200.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1191-mei-pxp-Keep-a-const-qualifier-when-calling-mei_clde.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1192-drm-amd-amdgpu-Fix-up-locking-etc-in-amdgpu_debugfs_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1192-drm-i915-pci-Clean-up-zero-initializers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1192-drm-xe-Replace-i915-with-xe-in-uapi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1192-mei-gsc-add-module-description.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1193-drm-i915-mtl-Remove-the-force_probe-requirement-for-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1193-drm-xe-irq-the-irq-handler-local-variable-need-not-b.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1193-mei-make-mei_class-a-static-const-structure.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1194-drm-amdkfd-fix-gfx_target_version-for-certain-11.0.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1194-drm-i915-guc-Clean-up-zero-initializers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1194-drm-xe-xe_uc_fw-Use-firmware-files-from-standard-loc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1194-fbdev-core-Use-list_for_each_entry-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1195-drm-amdgpu-Fix-up-kdoc-in-sdma_v4_4_2.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1195-drm-i915-pxp-Clean-up-zero-initializers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1195-drm-xe-Use-a-define-to-set-initial-seqno-for-fences.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1195-fbdev-mx3fb-Remove-the-driver.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1196-drm-amdgpu-Fix-up-kdoc-in-amdgpu_acpi.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1196-drm-i915-Add-GuC-TLB-Invalidation-device-info-flags.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1196-drm-xe-migrate-Update-cpu-page-table-updates.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1196-fbdev-neofb-Shorten-Neomagic-product-name-in-info-st.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1197-drm-amdgpu-Fix-up-missing-kdoc-in-sdma_v6_0.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1197-drm-i915-guc-Add-CT-size-delay-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1197-drm-xe-tests-Support-CPU-page-table-updates-in-the-m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1197-fbdev-ssd1307fb-Use-bool-for-ssd1307fb_deviceinfo-fl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1198-drm-amdkfd-Add-new-gfx_target_versions-for-GC-9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1198-drm-i915-Define-and-use-GuC-and-CTB-TLB-invalidation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1198-drm-xe-Introduce-xe_engine_is_idle.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1199-drm-amdkfd-Fix-MEC-pipe-interrupt-enablement.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1199-drm-i915-No-TLB-invalidation-on-suspended-GT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1199-drm-xe-Use-a-small-negative-initial-seqno.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1199-fbdev-g364fb-fix-build-failure-with-mips.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1200-backlight-qcom-wled-Explicitly-include-correct-DT-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1200-drm-amdgpu-Fix-create_dmamap_sg_bo-kdoc-warnings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1200-drm-i915-No-TLB-invalidation-on-wedged-GT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1200-drm-xe-tests-Test-both-CPU-and-GPU-page-table-update.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1201-drm-amd-display-Add-missing-kdoc-entries-in-update_p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1201-drm-i915-gt-Increase-sleep-in-gt_tlb-selftest-sanity.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1201-drm-xe-vm-Defer-vm-rebind-until-next-exec-if-nothing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1202-backlight-lp855x-Catch-errors-when-changing-brightne.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1202-drm-amd-display-Fix-up-kdoc-formats-in-dcn32_fpu.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1202-drm-i915-Enable-GuC-TLB-invalidations-for-MTL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1202-drm-xe-vram-start-tracking-the-io_size.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1203-drm-amdgpu-Initialize-xcc-mask.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1203-drm-i915-Prevent-potential-null-ptr-deref-in-engine_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1203-drm-xe-mcr-Separate-version-from-engine-type-selecti.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1204-backlight-lp855x-Drop-ret-variable-in-brightness-cha.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1204-drm-amdkfd-flag-added-to-handle-errors-from-svm-vali.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1204-drm-i915-mtl-Don-t-set-PIPE_CONTROL_FLUSH_L3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1204-drm-xe-buddy-remove-the-virtualized-start.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1205-backlight-led_bl-Remove-redundant-of_match_ptr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1205-drm-amdgpu-Fix-missing-parameter-desc-for-xcc_id-in-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1205-drm-mediatek-dsi-Add-dsi-cmdq_ctl-to-send-panel-init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1205-drm-xe-Use-max-wopcm-size-when-validating-the-preset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1206-drm-amdgpu-Fix-up-missing-kdoc-parameter-inst-in-get.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1206-drm-mediatek-Add-mt8188-dsi-compatible-to-mtk_dsi.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1206-drm-xe-Stop-accepting-value-in-xe_migrate_clear.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1207-drm-amdgpu-Fix-up-missing-parameter-in-kdoc-for-inst.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1207-drm-xe-buddy-add-visible-tracking.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1208-drm-amdgpu-Fix-missing-parameter-desc-for-xcp_id-in-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1208-drm-mediatek-dp-Add-the-audio-packet-flag-to-mtk_dp_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1208-drm-xe-buddy-add-compatible-and-intersects-hooks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1209-drm-amdgpu-set-finished-fence-error-if-job-timedout.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1209-drm-mediatek-dp-Add-the-audio-divider-to-mtk_dp_data.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1209-drm-xe-Drop-zero-length-arrays.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1210-drm-amdgpu-Fix-up-missing-parameters-kdoc-in-svm_mig.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1210-drm-mediatek-dp-Add-support-MT8188-dp-edp-function.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1210-drm-xe-Use-atomic-instead-of-mutex-for-xe_device_mem.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1211-drm-amdxcp-fix-Makefile-to-build-amdxcp-module.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1211-drm-xe-Reinstate-render-compute-cache-invalidation-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1212-drm-amd-display-Fix-up-kdoc-formatting-in-dcn32_reso.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1212-drm-xe-gt-some-error-handling-fixes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1213-drm-amd-display-Fix-up-missing-dc-pipe_ctx-kdoc-para.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1213-drm-mediatek-dsi-Add-mode_valid-callback-to-DSI-brid.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1213-drm-xe-Use-BO-s-GT-to-determine-dma_offset-when-prog.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1214-drm-amd-display-Correct-kdoc-formatting-for-DCN32_CR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1214-drm-xe-Fix-potential-deadlock-handling-page-faults.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1215-drm-amdkfd-remove-unused-sq_int_priv-variable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1215-drm-xe-huc-Support-for-loading-unversiond-HuC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1216-drm-amd-amdgpu-introduce-DRM_AMDGPU_WERROR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1216-drm-i915-gvt-Drop-final-dependencies-on-KVM-internal.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1216-drm-xe-Load-HuC-on-Alderlake-S.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1217-drm-amd-display-Fix-up-kdoc-formatting-in-display_mo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1217-drm-mediatek-Add-encoder_index-interface-for-mtk_ddp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1217-drm-xe-Add-max-engine-priority-to-xe-query.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1218-drm-amdgpu-Fix-up-kdoc-ring-parameter-in-sdma_v6_0_r.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1218-drm-mediatek-Add-connector-dynamic-selection-capabil.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1218-drm-nouveau-fence-fix-undefined-fence-state-after-em.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1218-drm-xe-Decrement-fault-mode-counts-in-xe_vm_close_an.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1219-drm-amdgpu-Fix-up-kdoc-in-amdgpu_device.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1219-drm-mediatek-dpi-Support-dynamic-connector-selection.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1219-drm-xe-pat-Move-PAT-setup-to-a-dedicated-file.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1220-drm-amd-display-Enable-Replay-for-static-screen-use-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1220-drm-amdgpu-Add-function-parameter-event-to-kdoc-in-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1220-drm-mediatek-dsi-Support-dynamic-connector-selection.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1220-drm-xe-pat-Use-table-based-programming-of-PAT-settin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1221-drm-amd-pm-Update-SMUv13.0.6-PMFW-headers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1221-drm-amdgpu-pm-Add-notification-for-no-DC-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1221-drm-mediatek-Support-dynamic-selection-of-MT8188-VDO.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1221-drm-xe-pat-Handle-unicast-vs-MCR-PAT-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1222-Documentation-gpu-Update-amdgpu-documentation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1222-drm-amd-pm-Fix-SMUv13.0.6-throttle-status-report.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1222-drm-xe-pat-Clean-up-PAT-register-definitions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1223-drm-amd-pm-add-unique-serial-number-support-for-smu_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1223-drm-amdgpu-Only-support-RAS-EEPROM-on-dGPU-platform.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1223-drm-xe-mtl-Fix-PAT-table-coherency-settings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1224-amd-amdkfd-drop-unused-KFD_IOCTL_SVM_FLAG_UNCACHED-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1224-drm-amdgpu-update-mall-info-v2-from-discovery.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1224-drm-mediatek-gamma-Adjust-mtk_drm_gamma_set_common-p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1224-drm-xe-mtl-Handle-PAT_INDEX-offset-jump.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1225-drm-amdgpu-update-gc_info-v2_1-from-discovery.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1225-drm-amdkfd-add-debug-and-runtime-enable-interface.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1225-drm-mediatek-gamma-Reduce-indentation-in-mtk_gamma_s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1225-drm-xe-add-XE_BO_CREATE_VRAM_MASK.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1226-drm-amd-pm-Update-SMUv13.0.6-PMFW-headers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1226-drm-amdkfd-display-debug-capabilities.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1226-drm-mediatek-gamma-Support-SoC-specific-LUT-size.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1226-drm-xe-bo-refactor-try_add_vram.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1227-drm-amd-pm-Add-critical-temp-for-GC-v9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1227-drm-amdkfd-prepare-per-process-debug-enable-and-disa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1227-drm-mediatek-gamma-Improve-and-simplify-HW-LUT-calcu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1227-drm-xe-pat-Define-PAT-tables-as-static.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1228-drm-amdgpu-add-kgd-hw-debug-mode-setting-interface.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1228-drm-amdgpu-jpeg-skip-change-of-power-gating-state-fo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1228-drm-mediatek-gamma-Enable-the-Gamma-LUT-table-only-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1228-drm-xe-don-t-auto-fall-back-to-execlist-mode-if-guc-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1229-drm-amdgpu-setup-hw-debug-registers-on-driver-initia.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1229-drm-amdkfd-retry-after-EBUSY-is-returned-from-hmm_ra.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1229-drm-mediatek-gamma-Use-bitfield-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1229-drm-xe-Better-error-messages-for-xe_gt_record_defaul.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1230-drm-amd-display-Drop-unused-DCN_BASE-variable-in-dcn.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1230-drm-amdgpu-Enable-ras-for-mp0-v13_0_6-sriov.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1230-drm-mediatek-aal-Use-bitfield-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1230-drm-xe-Include-hardware-prefetch-buffer-in-batchbuff.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1231-drm-amd-display-Roll-back-unit-correction.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1231-drm-amdkfd-clean-up-one-inconsistent-indenting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1231-drm-mediatek-De-commonize-disp_aal-disp_gamma-gamma_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1231-drm-xe-Adjust-batchbuffer-space-warning-when-creatin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1232-drm-amd-display-Correct-unit-conversion-for-vstartup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1232-drm-amdgpu-add-gfx9-hw-debug-mode-enable-and-disable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1232-drm-mediatek-gamma-Support-multi-bank-gamma-LUT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1232-drm-xe-Don-t-emit-extra-MI_BATCH_BUFFER_END-in-WA-ba.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1233-drm-amd-display-set-minimum-of-VBlank_nom.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1233-drm-amdgpu-add-gfx9.4.1-hw-debug-mode-enable-and-dis.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1233-drm-mediatek-gamma-Add-support-for-12-bit-LUT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1233-drm-xe-Remove-unused-revid-from-firmware-name.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1234-drm-amdgpu-Unset-baco-dummy-mode-on-nbio-v7.9.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1234-drm-amdkfd-fix-kfd_suspend_all_processes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1234-drm-mediatek-gamma-Add-support-for-MT8195.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1234-drm-xe-tests-Use-proper-batch-base-address.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1235-drm-amdgpu-add-gfx10-hw-debug-mode-enable-and-disabl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1235-drm-amdkfd-use-correct-method-to-get-clock-under-SRI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1235-drm-mediatek-gamma-Make-sure-relay-mode-is-disabled.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1235-drm-xe-tests-Set-correct-expectation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1236-drm-amdgpu-Add-bootloader-status-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1236-drm-amdgpu-add-gfx9.4.2-hw-debug-mode-enable-and-dis.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1236-drm-mediatek-gamma-Program-gamma-LUT-type-for-descen.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1236-drm-xe-Use-proper-vram-offset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1237-drm-amdgpu-Remove-SRAM-clock-gater-override-by-drive.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1237-drm-amdgpu-add-gfx11-hw-debug-mode-enable-and-disabl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1237-drm-mediatek-aal-Add-kerneldoc-for-struct-mtk_disp_a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1237-drm-xe-Fix-platform-order.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1238-drm-amd-pm-Fix-critical-temp-unit-of-SMU-v13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1238-drm-amdgpu-add-configurable-grace-period-for-unmap-q.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1238-drm-mediatek-gamma-Add-kerneldoc-for-struct-mtk_disp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1238-drm-xe-fix-pvc-unload-issue.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1239-drm-amdkfd-prepare-map-process-for-single-process-de.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1239-drm-mediatek-aal-Compress-of_device_id-entries-and-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1239-drm-xe-irq-Drop-gen3_-prefixes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1240-drm-amd-display-fix-static-screen-detection-setting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1240-drm-amdgpu-prepare-map-process-for-multi-process-deb.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1240-drm-xe-irq-Add-helpers-to-find-ISR-IIR-IMR-IER-regis.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1241-drm-amdgpu-Fix-the-return-for-gpu-mode1_reset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1241-drm-amdgpu-expose-debug-api-for-mes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1241-drm-msm-dpu-remove-irq_idx-argument-from-IRQ-callbac.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1241-drm-xe-irq-Drop-IRQ_INIT-and-IRQ_RESET-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1242-drm-amd-pm-fix-debugfs-pm_info-output.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1242-drm-amdkfd-add-per-process-hw-trap-enable-and-disabl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1242-drm-msm-dpu-extract-dpu_core_irq_is_valid-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1242-drm-xe-irq-Drop-unnecessary-GEN11_-and-GEN12_-regist.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1243-drm-amdgpu-Updated-TCP-UTCL1-programming.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1243-drm-amdkfd-apply-trap-workaround-for-gfx11.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1243-drm-msm-dpu-add-helper-to-get-IRQ-related-data.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1243-drm-xe-irq-Rename-and-clarify-top-level-interrupt-ha.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1244-drm-amdgpu-register-a-dirty-framebuffer-callback-for.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1244-drm-amdkfd-add-raise-exception-event-function.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1244-drm-msm-dpu-make-the-irq-table-size-static.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1244-drm-xe-irq-Drop-remaining-gen11_-prefix-from-IRQ-fun.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1245-drm-amdgpu-Add-bootloader-wait-for-PSP-v13.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1245-drm-amdkfd-add-send-exception-operation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1245-drm-msm-dpu-stop-using-raw-IRQ-indices-in-the-kernel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1245-drm-xe-irq-Drop-commented-out-code-for-non-existent-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1246-drm-amdkfd-add-runtime-enable-operation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1246-drm-msm-dpu-stop-using-raw-IRQ-indices-in-the-kernel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1246-drm-xe-irq-Don-t-clobber-display-interrupts-on-multi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1247-Partially-revert-drm-amd-display-update-add-plane-to.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1247-drm-amdkfd-add-debug-trap-enabled-flag-to-tma.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1247-drm-msm-dpu-shift-IRQ-indices-by-1.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1247-drm-xe-Extract-function-to-initialize-xe-info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1248-drm-amd-pm-update-SMU13-header-files-for-coming-OD-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1248-drm-amdgpu-Add-SMU-v13.0.6-default-reset-methods.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1248-drm-msm-Remove-unnecessary-NULL-values.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1248-drm-xe-Move-test-infra-out-of-xe_pci.-ch.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1249-drm-amdkfd-update-process-interrupt-handling-for-deb.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1249-drm-msm-dpu-Move-setting-of-dpu_enc-wide_bus_en-to-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1249-drm-xe-Use-symbol-namespace-for-kunit-tests.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1250-drm-amd-display-update-blank-state-on-ODM-changes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1250-drm-amdkfd-add-debug-set-exceptions-enabled-operatio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1250-drm-msm-dpu-Enable-widebus-for-DSI-INTF.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1250-drm-xe-Generalize-fake-device-creation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1251-drm-amdkfd-add-debug-wave-launch-override-operation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1251-drm-msm-dsi-Add-DATABUS_WIDEN-MDP_CTRL2-bit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1251-drm-xe-reg_sr-Save-errors-for-kunit-integration.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1252-drm-amdkfd-add-debug-wave-launch-mode-operation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1252-drm-msm-dsi-Enable-widebus-for-DSI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1252-drm-xe-Add-basic-unit-tests-for-rtp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1253-drm-amdgpu-Add-umc_info-v4_0-structure.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1253-drm-amdkfd-add-debug-suspend-and-resume-process-queu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1253-drm-msm-dp-Replace-open-coded-drm_dp_read_dpcd_caps.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1253-drm-xe-Add-test-for-GT-workarounds-and-tunings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1254-drm-amdgpu-Support-query-ecc-cap-for-aqua_vanjaram.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1254-drm-amdkfd-add-debug-set-and-clear-address-watch-poi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1254-drm-msm-dp-Use-drm_dp_read_sink_count-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1254-drm-xe-Update-GuC-HuC-firmware-autoselect-logic.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1255-drm-amdgpu-Allocate-coredump-memory-in-a-nonblocking.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1255-drm-amdkfd-add-debug-set-flags-operation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1255-drm-msm-dp-Remove-dead-code-related-to-downstream-ca.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1255-drm-xe-Always-write-GEN12_RCU_MODE.GEN12_RCU_MODE_CC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1256-drm-amdkfd-add-debug-query-event-operation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1256-drm-amdkfd-use-mask-to-get-v9-interrupt-sq-data-bits.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1256-drm-msm-dp-Remove-aux_cfg_update_done-and-related-co.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1256-drm-xe-Always-log-GuC-HuC-firmware-versions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1257-drm-amdgpu-use-read-modify-write-mode-for-gfx-v9_4_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1257-drm-amdkfd-add-debug-query-exception-info-operation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1257-drm-msm-dp-Simplify-with-drm_dp_-max_link_rate-max_l.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1257-drm-xe-Start-splitting-xe_device_desc-into-graphics-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1258-drm-amdgpu-Hide-xcp-partition-sysfs-under-SRIOV.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1258-drm-amdkfd-add-debug-queue-snapshot-operation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1258-drm-msm-dp-Inline-dp_link_parse_sink_count.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1258-drm-xe-Set-require_force_probe-in-each-platform-s-de.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1259-drm-amdgpu-Free-ras-cmd-input-buffer-properly.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1259-drm-amdkfd-add-debug-device-snapshot-operation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1259-drm-msm-dp-Remove-dp_display_is_ds_bridge.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1259-drm-xe-Move-most-platform-traits-to-graphics-IP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1260-drm-amdkfd-Add-missing-gfx11-MQD-manager-callbacks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1260-drm-amdkfd-bump-kfd-ioctl-minor-version-for-debug-ap.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1260-drm-xe-Move-engine-masks-into-IP-descriptor-structur.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1261-Revert-Revert-drm-amd-display-Implement-zpos-propert.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1261-drm-amd-pm-fulfill-SMU13-OD-settings-init-and-restor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1261-drm-msm-dpu-inline-_setup_pingpong_ops.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1261-drm-xe-Clarify-GT-counting-logic.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1262-drm-amd-pm-fulfill-the-OD-support-for-SMU13.0.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1262-drm-amdgpu-fix-amdgpu_cs_p1_user_fence.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1262-drm-msm-dpu-enable-PINGPONG-TE-operations-only-when-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1262-drm-xe-Add-printable-name-to-IP-descriptors.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1263-drm-amd-pm-Fill-metrics-data-for-SMUv13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1263-drm-msm-dpu-drop-the-DPU_PINGPONG_TE-flag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1263-drm-xe-Select-graphics-media-descriptors-from-GMD_ID.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1264-drm-amd-display-limit-the-v_startup-workaround-to-AS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1264-drm-amd-pm-fulfill-the-OD-support-for-SMU13.0.7.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1264-drm-msm-dpu-inline-_setup_intf_ops.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1264-drm-xe-Add-KUnit-test-for-xe_pci.c-IP-engine-lists.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1265-drm-amd-display-Fix-dc-dcn20-dcn20_optc.c-kdoc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1265-drm-msm-dpu-enable-INTF-TE-operations-only-when-supp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1265-drm-xe-Clean-up-xe_device_desc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1266-drm-amd-display-clean-up-some-inconsistent-indenting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1266-drm-msm-dpu-drop-DPU_INTF_TE-feature-flag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1266-drm-xe-fix-suspend-resume-for-dgfx.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1267-drm-amdgpu-Restrict-bootloader-wait-to-SMUv13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1267-drm-msm-dpu-drop-useless-check-from-dpu_encoder_phys.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1267-drm-xe-Fix-memory-use-after-free.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1268-drm-Add-initial-ci-subdirectory.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1268-drm-amdgpu-fix-debug-wait-on-idle-for-gfx9.4.1.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1268-drm-msm-dpu-move-INTF-tearing-checks-to-dpu_encoder_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1268-drm-xe-Let-primary-and-media-GT-share-a-kernel_bb_po.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1269-drm-ci-docs-fix-build-warning-add-missing-escape.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1269-drm-msm-dp-Inline-dp_display_is_sink_count_zero.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1269-drm-xe-Don-t-grab-runtime-PM-ref-in-engine-create-IO.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1270-drm-amdgpu-discovery-Replace-fake-flex-arrays-with-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1270-drm-drm_exec-Work-around-a-WW-mutex-lockdep-oddity.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1270-drm-msm-dp-Remove-error-message-when-downstream-port.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1270-drm-xe-Use-packed-bitfields-for-xe-info-feature-flag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1271-drm-amd-display-fix-compilation-error-due-to-shiftin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1271-drm-drm_connector-Provide-short-description-of-param.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1271-drm-msm-dp-support-setting-the-DP-subconnector-type.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1271-drm-xe-Track-whether-platform-has-LLC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1272-drm-amd-display-Address-kdoc-warnings-in-dcn30_fpu.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1272-drm-msm-a6xx-Add-missing-regs-for-A7XX.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1272-drm-xe-Only-request-PCODE_WRITE_MIN_FREQ_TABLE-on-LL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1273-drm-amd-display-Add-gnu_printf-format-attribute-for-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1273-drm-msm-a6xx-Add-skeleton-A7xx-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1273-drm-xe-GuC-and-HuC-loading-support-for-RKL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1274-Revert-drm-amd-display-Only-use-ODM2-1-policy-for-hi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1274-drm-amdkfd-Fix-reg-offset-for-setting-CWSR-grace-per.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1274-drm-msm-a6xx-Send-ACD-state-to-QMP-at-GMU-resume.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1274-drm-xe-mmio-stop-incorrectly-triggering-drm_warn.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1275-drm-amd-display-Program-OTG-vtotal-min-max-selectors.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1275-drm-amdkfd-Fix-unaligned-64-bit-doorbell-warning.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1275-drm-msm-a6xx-Mostly-implement-A7xx-gpu_state.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1275-drm-xe-Add-Rocketlake-device-info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1276-drm-amdgpu-Mark-kgd_gfx_aldebaran_clear_address_watc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1276-drm-amdgpu-Store-CU-info-from-all-XCCs-for-GFX-v9.4..patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1276-drm-msm-a6xx-Add-A730-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1276-drm-xe-tlb-fix-expected_seqno-calculation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1277-drm-amdgpu-pm-notify-driver-unloading-to-PMFW-for-SM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1277-drm-amdkfd-Update-cache-info-reporting-for-GFX-v9.4..patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1277-drm-msm-a6xx-Add-A740-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1277-drm-xe-sr-Apply-masked-registers-properly.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1278-drm-amd-pm-update-smu-driver-if-header-for-smu-13.0..patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1278-drm-amdkfd-Update-CU-masking-for-GFX-9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1278-drm-msm-a6xx-Poll-for-GBIF-unhalt-status-in-hw_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1278-drm-xe-sched_job-prefer-dma_fence_is_later.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1279-drm-amdgpu-pass-xcc-mask-to-ras-ta.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1279-drm-xe-lrc-give-start_seqno-a-better-default.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1280-Revert-drm-amd-Disable-S-G-for-APUs-when-64GB-or-mor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1280-drm-amdgpu-support-check-vcn-jpeg-block-mask.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1280-drm-xe-Fix-xe_mmio_rmw32-operation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1281-drm-amd-display-Add-dirty-rect-support-for-Replay.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1281-drm-amdgpu-convert-vcn-jpeg-logical-mask-to-physical.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1281-drm-msm-adreno-Add-ZAP-firmware-name-to-A635.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1281-drm-xe-Drop-GFX_FLSH_CNTL_GEN6-write-during-GGTT-inv.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1282-drm-amdgpu-fix-retry-loop-test.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1282-drm-msm-adreno-Add-A635-speedbin-0xac-A643.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1282-drm-xe-Keep-all-resize-bar-related-prints-inside-xe_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1283-drm-amd-display-Don-t-check-registers-if-using-AUX-B.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1283-drm-amd-display-Refactor-fast-update-to-use-new-HWSS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1283-drm-msm-allow-passing-struct-msm_kms-to-msm_drv_prob.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1283-drm-xe-guc_pc-Reorder-forcewake-and-xe_pm_runtime-ca.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1284-drm-amd-display-Wrong-index-type-for-pipe-iterator.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1284-drm-amdgpu-soc21-don-t-remap-HDP-registers-for-SR-IO.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1284-drm-msm-dpu-move-resource-allocation-to-the-_probe-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1284-drm-xe-Fix-build-without-CONFIG_PM_SLEEP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1285-drm-amd-display-Add-control-flag-to-dc_stream_state-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1285-drm-amdgpu-nbio4.3-set-proper-rmmio_remap.reg_offset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1285-drm-msm-mdp4-move-resource-allocation-to-the-_probe-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1285-drm-xe-Limit-the-system-memory-size-to-half-of-the-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1286-drm-amd-display-Fix-unused-variable-should_lock_all_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1286-drm-amdgpu-fallback-to-old-RAS-error-message-for-aqu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1286-drm-msm-mdp5-move-resource-allocation-to-the-_probe-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1286-drm-xe-Update-comment-on-why-d3cold-is-still-blocked.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1287-drm-amd-display-Adjust-the-MST-resume-flow.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1287-drm-amd-display-mark-dml31-s-UseMinimumDCFCLK-as-noi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1287-drm-msm-dsi-switch-to-devm_drm_bridge_add.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1287-drm-xe-Fix-print-of-RING_EXECLIST_SQ_CONTENTS_HI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1288-drm-amd-display-mark-dml314-s-UseMinimumDCFCLK-as-no.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1288-drm-amdkfd-Checkpoint-and-restore-queues-on-GFX11.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1288-drm-msm-hdmi-switch-to-devm_drm_bridge_add.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1288-drm-xe-Cleanup-page-related-defines.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1289-drm-amdgpu-Handle-null-atom-context-in-VBIOS-info-io.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1289-drm-amdgpu-display-Kconfig-replace-leading-spaces-wi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1289-drm-msm-dp-move-pdev-from-struct-dp_display_private-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1289-drm-xe-Rename-RC0-RC6-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1290-drm-amd-display-fix-replay_mode-kernel-doc-warning.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1290-drm-amd-pm-Fix-memory-some-memory-corruption.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1290-drm-msm-dp-switch-to-devm_drm_bridge_add.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1290-drm-xe-Rename-instruction-field-to-avoid-confusion.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1291-drm-amd-display-Add-DPIA-Link-Encoder-Assignment-Fix.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1291-drm-amd-display-Only-use-ODM2-1-policy-for-high-pixe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1291-drm-msm-remove-msm_drm_private-bridges-field.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1291-drm-xe-guc-Rename-GEN11_SOFT_SCRATCH-for-clarity.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1292-drm-amd-display-Fix-2nd-DPIA-encoder-Assignment.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1292-drm-amdkfd-potential-error-pointer-dereference-in-io.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1292-drm-msm-drop-pm-ops-from-the-headless-msm-driver.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1292-drm-xe-guc-Move-GuC-registers-to-regs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1293-drm-amdgpu-mmsch-Correct-the-definition-for-mmsch-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1293-drm-amdkfd-Insert-missing-TLB-flush-on-GFX10-and-lat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1293-drm-msm-rename-msm_pm_prepare-complete-to-note-the-K.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1293-drm-xe-Remove-extra-xe_mmio_read32-from-xe_mmio_wait.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1294-drm-amdgpu-Rename-ras-table-version.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1294-drm-msm-remove-shutdown-callback-from-msm_platform_d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1294-drm-xe-guc-Convert-GuC-registers-to-REG_FIELD-REG_BI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1295-drm-amdgpu-Add-RAS-table-v2.1-macro-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1295-drm-msm-rename-msm_drv_shutdown-to-msm_kms_shutdown.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1295-drm-xe-Drop-gen-afixes-from-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1296-Revert-drm-vkms-Fix-race-condition-between-the-hrtim.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1296-drm-amdgpu-Support-setting-EEPROM-table-version.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1296-drm-msm-switch-to-drmm_mode_config_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1296-drm-xe-Use-REG_FIELD-REG_BIT-for-all-regs-.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1297-drm-amdgpu-Add-support-EEPROM-table-v2.1.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1297-drm-msm-only-register-kms-debug-file-if-KMS-is-used.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1297-drm-xe-Clarify-register-types-on-PAT-programming.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1298-drm-amdgpu-Calculate-EEPROM-table-ras-info-bytes-sum.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1298-drm-msm-make-fb-debugfs-file-available-only-in-KMS-c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1298-drm-xe-Introduce-xe_reg-xe_reg_mcr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1299-drm-amdgpu-Set-EEPROM-ras-info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1299-drm-fix-up-fbdev-Kconfig-defaults.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1299-drm-msm-carve-out-KMS-code-from-msm_drv.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1299-drm-xe-Use-XE_REG-XE_REG_MCR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1300-drm-amdkfd-fix-vmfault-signalling-with-additional-da.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1300-drm-msm-fix-fault-injection-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1300-drm-nouveau-fence-fix-type-cast-warning-in-nouveau_f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1300-drm-xe-Annotate-masked-registers-used-by-RTP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1301-drm-amd-Check-that-a-system-is-a-NUMA-system-before-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1301-drm-msm-dsi-use-correct-lifetime-device-for-devm_drm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1301-drm-nouveau-sched-fix-leaking-memory-of-timedout-job.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1301-drm-xe-Plumb-xe_reg-into-WAs-rtp-etc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1302-drm-amdkfd-Fix-reserved-SDMA-queues-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1302-drm-msm-hdmi-use-correct-lifetime-device-for-devm_dr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1302-drm-xe-Move-helper-macros-to-separate-header.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1302-nouveau-u_memcpya-use-vmemdup_user.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1303-drm-connector-Convert-DRM_MODE_COLORIMETRY-to-enum.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1303-drm-msm-dp-use-correct-lifetime-device-for-devm_drm_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1303-drm-xe-Fix-media-detection-for-pre-GMD_ID-platforms.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1303-nouveau-u_memcpya-fix-NULL-vs-error-pointer-bug.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1304-accel-ivpu-40xx-Fix-buttress-interrupt-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1304-drm-connector-Add-enum-documentation-to-drm_colorspa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1304-drm-xe-Enable-Raptorlake-P.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1305-drm-connector-Pull-out-common-create_colorspace_prop.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1305-drm-xe-Include-only-relevant-header-in-xe_module.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1306-drm-connector-Use-common-colorspace_names-array.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1306-drm-msm-a6xx-Fix-up-QMP-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1306-drm-xe-Set-default-MOCS-value-for-cs-instructions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1306-fbdev-sh7760fb-Depend-on-FB-y.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1307-drm-connector-Print-connector-colorspace-in-state-de.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1307-drm-i915-gt-Prevent-error-pointer-dereference.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1307-drm-msm-dpu-create-a-dpu_hw_clk_force_ctrl-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1307-drm-xe-Set-default-MOCS-value-for-copy-cs-instructio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1308-drm-connector-Allow-drivers-to-pass-list-of-supporte.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1308-drm-msm-dpu-add-setup_clk_force_ctrl-op-to-sspp-wb.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1308-drm-xe-Fix-splat-during-error-dump.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1309-drm-amd-display-Always-pass-connector_state-to-strea.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1309-drm-amd-display-Fix-MST-recognizes-connected-display.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1309-drm-msm-dpu-move-setup_force_clk_ctrl-handling-into-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1309-drm-xe-Enable-the-compat-ioctl-functionality.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1310-Revert-drm-amdgpu-Report-vbios-version-instead-of-PN.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1310-drm-amd-display-Register-Colorspace-property-for-DP-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1310-drm-msm-dpu-sm8550-remove-unused-VIG-and-DMA-clock-c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1310-drm-xe-Do-not-mark-1809175790-as-a-WA.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1311-drm-amd-display-Signal-mode_changed-if-colorspace-ch.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1311-drm-amdgpu-fix-a-memory-leak-in-amdgpu_ras_feature_e.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1311-drm-msm-dpu-enable-writeback-on-SM8550.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1311-drm-xe-Fix-comment-on-Wa_22013088509.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1312-drm-amd-display-Send-correct-DP-colorspace-infopacke.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1312-drm-msm-a7xx-actually-use-a7xx-state-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1312-drm-xe-guc-Remove-special-handling-for-PVC-A.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1313-drm-amd-display-Always-set-crtcinfo-from-create_stre.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1313-drm-amdkfd-Use-gpu_offset-for-user-queue-s-wptr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1313-drm-xe-guc-Handle-RCU_MODE-as-masked-from-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1314-drm-amd-display-Add-debugfs-for-testing-output-color.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1314-drm-i915-gt-Fix-reservation-address-in-ggtt_reserve_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1314-drm-xe-Do-not-sleep-in-atomic.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1315-accel-ivpu-Add-Arrow-Lake-pci-id.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1315-drm-amd-display-Refactor-avi_info_frame-colorimetry-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1315-drm-xe-Print-GT-info-on-TLB-inv-failure.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1315-i915-guc-Get-runtime-pm-in-busyness-worker-only-if-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1316-drm-amdgpu-pm-update-SMU-13.0.0-PMFW-version-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1316-drm-i915-Don-t-set-PIPE_CONTROL_FLUSH_L3-for-aux-inv.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1316-drm-xe-destroy-clients-engine-and-vm-xarrays-on-clos.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1317-drm-amdgpu-disable-virtual-display-support-on-APP-de.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1317-drm-amdgpu-umsch-add-suspend-and-resume-callback.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1317-drm-i915-Register-engines-early-to-avoid-type-confus.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1317-drm-xe-Handle-EDEADLK-case-in-preempt-worker.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1318-accel-ivpu-40xx-Ensure-clock-resource-ownership-Ack-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1318-drm-amdgpu-skip-to-resume-rlcg-for-gc-9.4.3-in-vf-si.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1318-drm-i915-Invalidate-the-TLBs-on-each-GT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1318-drm-xe-Handle-EDEADLK-case-in-exec-ioctl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1319-accel-ivpu-40xx-Disable-frequency-change-interrupt.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1319-drm-amd-display-Add-missing-lines-of-code-in-dc.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1319-drm-amd-pm-add-unique_id-for-gc-11.0.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1319-drm-amd-pm-fix-vclk-setting-failed-for-SMU-v13.0.4.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1319-drm-xe-mmio-Use-struct-xe_reg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1320-accel-ivpu-40xx-Fix-missing-VPUIP-interrupts.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1320-drm-amd-pm-enable-vclk-and-dclk-Pstates-for-SMU-v13..patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1320-drm-amdgpu-Add-hive-ras-recovery-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1320-drm-amdgpu-Fix-a-memory-leak.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1320-drm-xe-Rename-reg-field-to-addr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1321-drm-amd-Fix-logic-error-in-sienna_cichlid_update_pci.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1321-drm-amd-pm-enable-more-Pstates-profile-levels-for-SM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1321-drm-amdgpu-mes11-remove-aggregated-doorbell-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1321-drm-xe-Fix-indent-in-xe_hw_engine_print_state.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1322-drm-amd-Fix-detection-of-_PR3-on-the-PCIe-root-port.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1322-drm-amdkfd-fix-and-enable-debugging-for-gfx11.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1322-drm-xe-fix-tlb_invalidation_seqno_past.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1323-Revert-Revert-drm-amd-display-Enable-Freesync-Video-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1323-drm-amd-display-apply-edge-case-DISPCLK-WDIVIDER-cha.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1323-drm-amdgpu-update-to-the-latest-GC-11.5-headers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1323-drm-xe-adlp-Add-revid-step-mapping.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1324-drm-amd-Add-missing-kernel-doc-for-prepare_suspend.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1324-drm-amdgpu-add-the-accelerator-PCIe-class.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1324-drm-tests-Fix-kunit_release_action-ctx-argument.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1324-drm-xe-adln-Enable-ADL-N.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1325-drm-amdgpu-Wrap-Wunused-but-set-variable-in-cc-optio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1325-drm-panel-orientation-quirks-Add-quirk-for-One-Mix-2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1325-drm-xe-Load-HuC-on-Alderlake-P.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1326-drm-amd-Move-microcode-init-step-to-early_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1326-drm-amdgpu-add-option-params-to-enforce-process-isol.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1326-drm-nouveau-chan-use-struct-nvif_mclass.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1326-drm-xe-Remove-unused-define.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1327-drm-amd-Don-t-parse-IMU-ucode-version-if-it-won-t-be.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1327-drm-amd-pm-enable-more-Pstates-profile-levels-for-ye.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1327-drm-nouveau-chan-use-channel-class-definitions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1327-drm-xe-Get-rid-of-MAKE_INIT_EXIT_FUNCS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1328-drm-amd-Read-IMU-FW-version-from-scratch-register-du.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1328-drm-amd-display-add-NULL-pointer-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1328-drm-nouveau-exec-report-max-pushs-through-getparam.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1328-drm-xe-Call-exit-functions-when-xe_register_pci_driv.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1329-Revert-drm-amd-display-cache-trace-buffer-size.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1329-dma-buf-add-dma_fence_timestamp-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1329-drm-amd-display-Remove-brackets-in-macro-to-conform-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1329-drm-xe-Allow-compute-VMs-to-output-dma-fences-on-bin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1330-drm-amd-display-DSC-Programming-Deltas.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1330-drm-amdkfd-clean-up-some-inconsistent-indenting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1330-drm-vmwgfx-fix-typo-of-sizeof-argument.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1330-drm-xe-Allow-dma-fences-as-in-syncs-for-compute-faul.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1331-drm-amd-display-Filter-out-AC-mode-frequencies-on-DC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1331-drm-amd-display-Fix-a-handful-of-spelling-mistakes-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1331-drm-xe-Introduce-GT-oriented-log-messages.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1332-drm-amdgpu-Workaround-to-skip-kiq-ring-test-during-r.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1332-drm-i915-display-Print-useful-information-on-error.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1332-drm-panel-boe-tv101wum-nl6-Completely-pull-GPW-to-VG.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1332-drm-xe-Use-GT-oriented-log-messages-in-xe_gt.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1333-drm-amdgpu-Log-UE-corrected-by-replay-as-correctable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1333-drm-atomic-helper-relax-unregistered-connector-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1333-drm-i915-No-10bit-gamma-on-desktop-gen3-parts.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1333-drm-xe-Introduce-the-dev_coredump-infrastructure.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1334-drm-amd-pm-Support-for-getting-power1_cap_min-value.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1334-drm-i915-display-Extract-display-init-from-intel_dev.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1334-drm-tiny-correctly-print-struct-resource-on-error.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1334-drm-xe-Do-not-take-any-action-if-our-device-was-remo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1335-drm-amdkfd-remove-unused-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1335-drm-i915-Fix-error-handling-if-driver-creation-fails.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1335-drm-msm-dp-do-not-reinitialize-phy-unless-retry-duri.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1335-drm-xe-Extract-non-mapped-regions-out-of-GuC-CTB-int.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1336-drm-amdgpu-define-ras_reset_error_count-function.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1336-drm-i915-debugfs-stop-using-edid_blob_ptr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1336-drm-msm-mdss-fix-highest-bank-bit-for-msm8998.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1336-drm-xe-Convert-GuC-CT-print-to-snapshot-capture-and-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1337-drm-amdgpu-Enable-software-RAS-in-vcn-v4_0_3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1337-drm-i915-plane-warn-on-non-zero-plane-offset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1337-drm-msm-dsi-skip-the-wait-for-video-mode-done-if-not.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1337-drm-xe-Add-GuC-CT-snapshot-to-xe_devcoredump.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1338-drm-i915-ddi-drop-unused-but-set-variable-intel_dp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1338-drm-msm-dsi-fix-irq_of_parse_and_map-error-checking.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1338-drm-xe-Introduce-guc_submit_types.h-with-relevant-st.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1339-drm-amd-display-clean-up-some-inconsistent-indenting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1339-drm-i915-dsi-drop-unused-but-set-variable-data.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1339-drm-msm-dpu-change-_dpu_plane_calc_bw-to-use-u64-to-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1339-drm-xe-Convert-GuC-Engine-print-to-snapshot-capture-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1340-drm-amd-display-Remove-duplicated-include-in-dce110_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1340-drm-i915-dsi-drop-unused-but-set-variable-vbp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1340-drm-msm-dp-Add-newlines-to-debug-printks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1340-drm-xe-Add-GuC-Submit-Engine-snapshot-to-xe_devcored.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1341-drm-amd-display-Remove-unneeded-semicolon.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1341-drm-i915-dpll-drop-unused-but-set-variables-bestn-an.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1341-drm-msm-dpu-fail-dpu_plane_atomic_check-based-on-mdp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1341-drm-xe-Convert-Xe-HW-Engine-print-to-snapshot-captur.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1342-drm-amd-display-Don-t-set-dpms_off-for-seamless-boot.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1342-drm-amd-display-Simplify-bool-conversion.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1342-drm-i915-fb-drop-unused-but-set-variable-cpp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1342-drm-xe-Add-HW-Engine-snapshot-to-xe_devcoredump.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1343-drm-amd-display-clean-up-some-inconsistent-indenting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1343-drm-amdgpu-add-missing-NULL-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1343-drm-i915-irq-drop-unused-but-set-variable-tmp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1343-drm-xe-Limit-CONFIG_DRM_XE_SIMPLE_ERROR_CAPTURE-to-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1344-drm-amd-display-Respect-CONFIG_FRAME_WARN-0-in-DML2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1344-drm-amdgpu-fix-SI-failure-due-to-doorbells-allocatio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1344-drm-i915-gt-uc-drop-unused-but-set-variable-sseu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1344-drm-xe-Move-Media-GuC-register-definition-to-regs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1345-drm-amdgpu-Add-UVD_VCPU_INT_EN2-to-dpg-sram.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1345-drm-i915-gem-drop-unused-but-set-variable-unpinned.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1345-drm-xe-Change-GuC-interrupt-data.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1345-fbdev-atyfb-only-use-ioremap_uc-on-i386-and-ia64.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1346-drm-amdgpu-Enable-mca-debug-mode-mode-when-ras-enabl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1346-drm-i915-gem-annotate-maybe-unused-but-set-variable-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1346-drm-xe-fix-kernel-doc-issues.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1346-fbdev-omapfb-fix-some-error-codes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1347-drm-amdgpu-Fix-delete-nodes-that-have-been-relesed.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1347-drm-i915-selftest-annotate-maybe-unused-but-set-vari.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1347-drm-xe-Do-not-forget-to-drm_dev_put-in-xe_pci_probe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1347-fbdev-sa1100fb-mark-sa1100fb_init-static.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1348-drm-amd-amdgpu-vcn-Add-RB-decouple-feature-under-SRI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1348-drm-i915-annotate-maybe-unused-but-set-intel_plane_s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1348-drm-xe-Call-drmm_add_action_or_reset-early-in-xe_dev.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1348-fbdev-uvesafb-Remove-uvesafb_exec-prototype-from-inc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1349-drm-amd-amdgpu-vcn-Add-RB-decouple-feature-under-SRI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1349-drm-i915-annotate-maybe-unused-but-set-intel_crtc_st.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1349-drm-xe-Fail-xe_device_create-if-wq-allocation-fails.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1349-fbdev-uvesafb-Call-cn_del_callback-at-the-end-of-uve.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1350-drm-amd-amdgpu-vcn-Add-RB-decouple-feature-under-SRI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1350-drm-i915-dp-Fix-log-level-for-CDS-interlane-align-do.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1350-drm-xe-Add-stepping-support-for-GMD_ID-platforms.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1350-fbdev-core-cfbcopyarea-fix-sloppy-typing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1351-drm-amd-amdgpu-vcn-Add-RB-decouple-feature-under-SRI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1351-drm-i915-fix-the-derating-percentage-for-MTL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1351-drm-xe-Apply-upper-limit-to-sg-element-size.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1351-fbdev-core-syscopyarea-fix-sloppy-typing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1352-drm-amdgpu-fix-typo-for-amdgpu-ras-error-data-print.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1352-drm-i915-update-the-QGV-point-frequency-calculations.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1352-drm-xe-Add-explicit-padding-to-uAPI-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1353-drm-amdgpu-Enable-RAS-feature-by-default-for-APU.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1353-drm-amdgpu-Reserve-fences-for-VM-update.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1353-drm-i915-store-the-peak-bw-per-QGV-point.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1353-drm-xe-Validate-uAPI-padding-and-reserved-fields.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1353-fbdev-mmp-Annotate-struct-mmphw_ctrl-with-__counted_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1354-drm-amdgpu-fix-missing-stuff-in-NBIO-v7.11.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1354-drm-bridge-ti-sn65dsi86-Associate-DSI-device-lifetim.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1354-drm-i915-extract-intel_bw_check_qgv_points.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1354-drm-xe-pvc-Don-t-try-to-invalidate-AuxCCS-TLB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1354-fbdev-mmp-Annotate-struct-mmp_path-with-__counted_by.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1355-drm-amdgpu-add-clockgating-support-for-NBIO-v7.7.1.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1355-drm-i915-modify-max_bw-to-return-index-to-intel_bw_i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1355-drm-panel-Move-AUX-B116XW03-out-of-panel-edp-back-to.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1355-drm-xe-Fix-Wa_22011802037-annotation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1356-drm-amdgpu-replace-reset_error_count-with-amdgpu_ras.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1356-drm-i915-mtl-find-the-best-QGV-point-for-the-SAGV-co.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1356-drm-nouveau-exec-fix-ioctl-kernel-doc-warning.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1356-drm-xe-rtp-Split-rtp-process-initialization.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1357-drm-amdgpu-add-set-get-mca-debug-mode-operations.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1357-drm-i915-mtl-Add-support-for-PM-DEMAND.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1357-drm-nouveau-disp-fix-DP-capable-DSM-connectors.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1357-drm-xe-rtp-Replace-XE_WARN_ON.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1358-drm-amdgpu-update-the-xgmi-ta-interface-header.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1358-drm-i915-display-Include-of-display-limits-doesn-t-n.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1358-drm-ttm-Reorder-sys-manager-cleanup-step.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1358-drm-xe-rtp-Add-_sr-to-entry-function-names.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1359-drm-amdgpu-drop-status-query-reset-for-GCEA-9.4.3-an.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1359-drm-edid-add-8-bpc-quirk-to-the-BenQ-GW2765.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1359-drm-xe-rtp-Allow-to-track-active-workarounds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1360-drm-amdgpu-Unset-context-priority-is-now-invalid.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1360-drm-amdgpu-prepare-the-output-buffer-for-GET_PEER_LI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1360-drm-i915-re-enable-Wunused-but-set-variable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1360-drm-xe-wa-Track-gt-engine-lrc-active-workarounds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1361-drm-amdgpu-support-the-port-num-info-based-on-the-ca.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1361-drm-i915-use-pointer-to-i915-instead-of-rpm-in-waker.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1361-drm-xe-debugfs-Dump-active-workarounds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1361-gpu-drm-Eliminate-DRM_SCHED_PRIORITY_UNSET.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1362-drm-amdgpu-Encapsulate-all-device-reset-info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1362-drm-i915-add-a-dedicated-workqueue-inside-drm_i915_p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1362-drm-i915-cx0-Only-clear-set-the-Pipe-Reset-bit-of-th.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1362-drm-xe-rtp-Rename-STEP-to-GRAPHICS_STEP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1363-drm-amdgpu-Move-coredump-code-to-amdgpu_reset-file.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1363-drm-i915-Retry-gtt-fault-when-out-of-fence-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1363-drm-i915-selftests-add-local-workqueue-for-SW-fence-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1363-drm-xe-rtp-Add-check-for-media-stepping.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1364-drm-amdgpu-Create-version-number-for-coredumps.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1364-drm-mediatek-Correctly-free-sg_table-in-gem-prime-vm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1364-drm-xe-rtp-Add-support-for-entries-with-no-action.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1364-fbdev-Use-comment-in-initializer-macro.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1365-drm-amdgpu-ignore-duplicate-BOs-again.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1365-drm-amdkfd-remap-unaligned-svm-ranges-that-have-spli.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1365-drm-xe-Include-build-directory.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1366-drm-amd-display-Reduce-stack-size-by-splitting-funct.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1366-drm-amd-display-amdgpu_dm-amdgpu_dm_helpers-Move-SYN.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1366-drm-dp_mst-Fix-NULL-deref-in-get_mst_branch_device_b.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1366-drm-xe-Add-support-for-OOB-workarounds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1367-drm-amd-display-Fix-stack-size-issue-on-DML2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1367-drm-amdgpu-Remove-redundant-call-to-priority_is_vali.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1367-drm-amdgpu-Rename-DRM-schedulers-in-amdgpu-TTM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1367-drm-xe-guc-Port-Wa_22012773006-to-xe_wa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1368-drm-amdkfd-reserve-a-fence-slot-while-locking-the-BO.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1368-drm-bridge-megachips-stdpxxxx-ge-b850v3-fw-switch-to.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1368-drm-xe-guc-Port-Wa_16011759253-to-xe_wa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1369-drm-amdgpu-Fix-kdoc-warning.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1369-drm-logicvc-Kconfig-select-REGMAP-and-REGMAP_MMIO.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1369-drm-ssd130x-Fix-atomic_check-for-disabled-planes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1369-drm-xe-guc-Port-Wa_14012197797-Wa_22011391025-to-xe_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1370-drm-amd-amdgpu-enable-W-1-for-amdgpu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1370-drm-i915-perf-Determine-context-valid-in-OA-reports.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1370-drm-xe-guc-Port-Wa_16011777198-to-xe_wa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1371-drm-amdgpu-expose-num_hops-and-num_links-xgmi-info-t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1371-drm-i915-mcr-Hold-GT-forcewake-during-steering-opera.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1371-drm-panel-st7703-Fix-timings-when-entering-exiting-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1371-drm-xe-guc-Port-Wa_22012727170-Wa_22012727685-to-xe_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1372-accel-ivpu-Don-t-enter-d0i3-during-FLR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1372-drm-amd-display-add-debugfs-for-allow_edp_hotplug_de.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1372-drm-i915-pmu-Check-if-pmu-is-closed-before-stopping-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1372-drm-xe-guc-Port-Wa_16015675438-Wa_18020744125-to-xe_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1372-i2c-Add-i2c_get_match_data.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1373-drm-adv7511-Add-struct-adv7511_chip_info-and-use-i2c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1373-drm-amd-Disable-ASPM-for-VI-w-all-Intel-systems.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1373-drm-amd-display-Add-DP2-Metrics.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1373-drm-xe-guc-Port-Wa_1509372804-to-xe_wa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1374-accel-ivpu-Extend-address-range-for-MMU-mmap.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1374-drm-adv7511-Add-max_mode_clock_khz-variable-to-struc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1374-drm-amd-display-Add-Error-Code-for-Dml-Validation-Fa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1374-drm-xe-rtp-Also-check-gt-type.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1375-drm-adv7511-Add-max_lane_freq_khz-variable-to-struct.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1375-drm-amd-display-Promote-DAL-to-3.2.238.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1375-drm-xe-guc-Port-Wa_14014475959-to-xe_wa-and-fix-it.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1376-drm-adv7511-Add-supply_names-and-num_supplies-variab.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1376-drm-amd-display-Fix-disbling-PSR-slow-response-issue.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1376-drm-xe-Fix-the-migrate-selftest-for-integrated-GPUs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1377-drm-adv7511-Add-reg_cec_offset-variable-to-struct-ad.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1377-drm-amd-display-SubVP-high-refresh-only-if-all-displ.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1377-drm-xe-Support-copying-of-data-between-system-memory.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1378-drm-adv7511-Add-has_dsi-variable-to-struct-adv7511_c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1378-drm-amd-display-Re-enable-DPP-HUBP-Power-Gating.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1378-drm-xe-bo-further-limit-where-CCS-pages-are-needed.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1379-drm-adv7511-Add-link_config-variable-to-struct-adv75.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1379-drm-amd-display-Re-enable-SubVP-high-refresh.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1379-drm-xe-migrate-retain-CCS-aux-state-for-vram-vram.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1380-drm-adv7511-Add-hpd_override_enable-variable-to-stru.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1380-drm-amd-display-Do-not-disable-phantom-pipes-in-driv.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1380-drm-xe-don-t-allocate-under-ct-lock.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1381-drm-amd-display-Block-SubVP-DRR-if-the-DRR-is-PSR-ca.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1381-drm-bridge-synopsys-dw-mipi-dsi-Add-dw_mipi_dsi_get_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1381-drm-xe-keep-pulling-mem_access_get-further-back.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1382-drm-amd-display-Bug-fix-in-dcn315_populate_dml_pipes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1382-drm-bridge-synopsys-dw-mipi-dsi-Add-input-bus-format.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1382-drm-xe-Prevent-evicting-for-page-tables.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1383-accel-ivpu-37xx-Fix-missing-VPUIP-interrupts.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1383-drm-amd-display-Limit-Minimum-FreeSync-Refresh-Rate.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1383-drm-bridge-synopsys-dw-mipi-dsi-Force-input-bus-flag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1383-drm-xe-Rework-size-helper-to-be-a-little-more-correc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1384-drm-amd-display-Include-CSC-updates-in-new-fast-upda.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1384-drm-bridge-synopsys-dw-mipi-dsi-Add-mode-fixup-suppo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1384-drm-xe-Simplify-rebar-sizing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1385-Revert-drm-amd-display-reallocate-DET-for-dual-displ.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1385-drm-bridge-synopsys-dw-mipi-dsi-Use-pixel-clock-rate.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1385-drm-xe-Size-GT-device-memory-correctly.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1386-drm-amd-display-fix-pixel-rate-update-sequence.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1386-drm-bridge-synopsys-dw-mipi-dsi-Set-minimum-lane-byt.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1386-drm-xe-Rename-GPU-offset-helper-to-reflect-true-usag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1387-drm-amd-display-3.2.239.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1387-drm-bridge-synopsys-dw-mipi-dsi-Disable-HSTX-and-LPR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1387-drm-xe-Replace-PVC-check-by-engine-type-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1388-drm-amd-pm-fix-vclk-setting-failed-for-SMU-v13.0.5.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1388-drm-bridge-imx-Add-i.MX93-MIPI-DSI-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1388-drm-xe-vm-fix-double-list-add.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1389-drm-xe-mtl-Disable-media-GT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1390-drm-amd-pm-enable-vclk-and-dclk-Pstates-for-SMU-v13..patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1390-drm-xe-Introduce-xe_tile.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1391-drm-amdkfd-fix-null-queue-check-on-debug-setting-exc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1391-drm-xe-Add-backpointer-from-gt-to-tile.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1392-Revert-drm-amd-display-fix-dpms_off-issue-when-disab.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1392-drm-rockchip-remove-NR_LAYERS-macro-on-vop2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1392-drm-xe-Add-for_each_tile-iterator.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1393-drm-amd-display-don-t-free-stolen-console-memory-dur.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1393-drm-panel-st7703-Add-Powkiddy-RGB30-Panel-Support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1393-drm-xe-Move-register-MMIO-into-xe_tile.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1394-Documentation-gpu-Add-a-VM_BIND-async-document.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1394-drm-amdkfd-To-enable-traps-for-GC_11_0_4-and-up.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1394-drm-xe-Move-GGTT-from-GT-to-tile.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1395-drm-amdgpu-Print-client-id-for-the-unregistered-inte.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1395-drm-gpuvm-Dual-licence-the-drm_gpuvm-code-GPL-2.0-OR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1395-drm-xe-Move-VRAM-from-GT-to-tile.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1396-drm-amdgpu-Add-missing-function-parameter-optc-enabl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1396-drm-ssd130x-Replace-.page_height-field-in-device-inf.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1396-drm-xe-Memory-allocations-are-tile-based-not-GT-base.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1397-drm-amd-display-Correct-kdoc-formats-in-dcn10_opp.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1397-drm-ssd130x-Add-a-controller-family-id-to-the-device.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1397-drm-xe-Move-migration-from-GT-to-tile.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1398-drm-amd-display-Correct-and-remove-excess-function-p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1398-drm-ssd130x-Rename-commands-that-are-shared-across-c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1398-drm-xe-Clarify-gt-retrieval-for-primary-tile.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1399-drm-amd-display-Provide-function-name-for-optc32_ena.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1399-drm-ssd130x-Add-support-for-the-SSD132x-OLED-control.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1399-drm-xe-Drop-vram_id.patch (jsc#PED-9898
  jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237
  jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1400-drm-amd-display-Correct-kdoc-formats-in-dcn32_resour.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1400-drm-xe-Drop-extra_gts-declarations-and-XE_GT_TYPE_RE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1400-fbdev-Provide-I-O-memory-helpers-as-module.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1401-drm-amd-display-Clean-up-dcn10_optc.c-kdoc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1401-drm-xe-Allocate-GT-dynamically.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1401-fbdev-68328fb-Initialize-fb_ops-to-fbdev-I-O-memory-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1402-drm-amdgpu-add-wait_for-helper-for-spirom-update.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1402-drm-xe-Add-media-GT-to-tile.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1402-fbdev-amba-clcd-Initialize-fb_ops-to-fbdev-I-O-memor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1403-drm-amdgpu-Release-SDMAv4.4.2-ecc-irq-properly.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1403-drm-xe-Interrupts-are-delivered-per-tile-not-per-GT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1403-fbdev-amifb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1404-drm-amdkfd-Remove-DUMMY_VRAM_SIZE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1404-drm-xe-irq-Move-ASLE-backlight-interrupt-logic.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1404-fbdev-arkfb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1405-drm-amdgpu-Report-ras_num_recs-in-debugfs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1405-drm-xe-irq-Ensure-primary-GuC-won-t-clobber-media-Gu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1405-fbdev-atafb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1406-drm-xe-irq-Untangle-postinstall-functions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1406-fbdev-atyfb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1407-drm-xe-Replace-xe_gt_irq_postinstall-with-xe_irq_ena.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1407-fbdev-au1100fb-Initialize-fb_ops-to-fbdev-I-O-memory.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1408-drm-radeon-Fix-missing-prototypes-in-radeon_atpx_han.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1408-drm-xe-Invalidate-TLB-on-all-affected-GTs-during-GGT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1408-fbdev-cirrusfb-Initialize-fb_ops-to-fbdev-I-O-memory.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1409-drm-amd-pm-enable-more-Pstates-profile-levels-for-SM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1409-drm-xe-tlb-Obtain-forcewake-when-doing-GGTT-TLB-inva.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1409-fbdev-cobalt-lcd-Initialize-fb_ops-to-fbdev-I-O-memo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1410-drm-amdkfd-decrement-queue-count-on-mes-queue-destro.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1410-drm-xe-Allow-GT-looping-and-lookup-on-standalone-med.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1410-fbdev-controlfb-Initialize-fb_ops-to-fbdev-I-O-memor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1411-drm-amd-display-Convert-to-kdoc-formats-in-dc-core-d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1411-drm-xe-Update-query-uapi-to-support-standalone-media.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1411-fbdev-cyber2000fb-Initialize-fb_ops-to-fbdev-I-O-mem.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1412-drm-amd-pm-Align-eccinfo-table-structure-with-smu-v1.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1412-drm-xe-Reinstate-media-GT-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1412-fbdev-dnfb-Initialize-fb_ops-to-fbdev-I-O-memory-hel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1413-drm-amdgpu-Update-total-channel-number-for-umc-v8_10.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1413-drm-xe-Add-kerneldoc-description-of-multi-tile-devic.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1413-fbdev-ep93xx-fb-Initialize-fb_ops-to-fbdev-I-O-memor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1414-drm-amdgpu-Add-channel_dis_num-to-ras-init-flags.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1414-drm-xe-Replace-deprecated-DRM_ERROR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1414-fbdev-gbefb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1415-drm-amdgpu-Optimize-checking-ras-supported.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1415-drm-xe-Reformat-xe_guc_regs.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1415-fbdev-hgafb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1416-drm-amdgpu-Add-checking-mc_vram_size.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1416-drm-xe-Initialize-MOCS-earlier.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1416-fbdev-hitfb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1417-drm-xe-Don-t-hardcode-GuC-s-MOCS-index-in-register-h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1417-fbdev-hpfb-Initialize-fb_ops-to-fbdev-I-O-memory-hel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1418-drm-xe-REBAR-resize-should-be-best-effort.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1418-fbdev-i810fb-Initialize-fb_ops-to-fbdev-I-O-memory-h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1419-drm-amdgpu-Change-nbio-v7.9-xcp-status-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1419-drm-xe-wa-Extend-scope-of-Wa_14015795083.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1419-fbdev-imsttfb-Initialize-fb_ops-to-fbdev-I-O-memory-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1420-drm-amdgpu-Use-PSP-FW-API-for-partition-switch.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1420-drm-xe-Use-SPDX-License-Identifier-instead-of-licens.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1420-fbdev-intelfb-Initialize-fb_ops-to-fbdev-I-O-memory-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1421-drm-amdgpu-mark-GC-9.4.3-experimental-for-now.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1421-drm-xe-Group-engine-related-structs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1421-fbdev-matroxfb-Initialize-fb_ops-to-fbdev-I-O-memory.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1422-drm-amdgpu-add-amdgpu_error_-debugfs-file.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1422-drm-xe-Fix-some-formatting-issues-in-uAPI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1422-fbdev-neofb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1423-drm-amdgpu-mark-force-completed-fences-with-ECANCELE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1423-drm-xe-guc-Read-HXG-fields-from-DW1-of-G2H-response.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1423-fbdev-nvidiafb-Initialize-fb_ops-to-fbdev-I-O-memory.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1424-drm-amdgpu-mark-soft-recovered-fences-with-ENODATA.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1424-drm-xe-reg_sr-Use-a-single-parameter-for-xe_reg_sr_a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1424-fbdev-omapfb-Initialize-fb_ops-to-fbdev-I-O-memory-h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1425-drm-amdgpu-abort-submissions-during-prepare-on-error.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1425-drm-xe-reg_sr-Apply-limit-to-register-whitelisting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1425-fbdev-pm2fb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1426-drm-amdgpu-reset-VM-when-an-error-is-detected.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1426-drm-xe-Invalidate-TLB-also-on-bind-if-in-scratch-pag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1426-fbdev-pm3fb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1427-drm-amdgpu-add-VM-generation-token.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1427-drm-xe-Emit-a-render-cache-flush-after-each-rcs-ccs-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1427-fbdev-pvr2fb-Initialize-fb_ops-to-fbdev-I-O-memory-h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1428-drm-amdgpu-add-entity-error-check-in-amdgpu_ctx_get_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1428-drm-xe-Handle-unmapped-userptr-in-analyze-VM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1428-fbdev-radeon-Initialize-fb_ops-to-fbdev-I-O-memory-h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1429-drm-scheduler-avoid-infinite-loop-if-entity-s-depend.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1429-drm-xe-Use-Xe-ordered-workqueue-for-rebind-worker.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1429-fbdev-rivafb-Initialize-fb_ops-to-fbdev-I-O-memory-h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1430-drm-amdkfd-add-event-age-tracking.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1430-drm-xe-s-XE_PTE_READ_ONLY-XE_PTE_FLAG_READ_ONLY.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1430-fbdev-s1d13xxxfb-Initialize-fb_ops-to-fbdev-I-O-memo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1431-drm-amdkfd-add-event_age-tracking-when-receiving-int.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1431-drm-xe-Move-XE_PTE_FLAG_READ_ONLY-to-xe_vm_types.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1431-fbdev-s3fb-Initialize-fb_ops-to-fbdev-I-O-memory-hel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1432-drm-amdkfd-set-activated-flag-true-when-event-age-un.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1432-drm-xe-Rename-pte-pde-encoding-functions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1432-fbdev-sa1100fb-Initialize-fb_ops-to-fbdev-I-O-memory.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1433-drm-amdkfd-update-user-space-last_event_age.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1433-drm-xe-guc-Fix-typo-s-enabled-enable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1433-fbdev-savagefb-Initialize-fb_ops-to-fbdev-I-O-memory.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1434-drm-amdkfd-bump-kfd-ioctl-minor-version-for-event-ag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1434-drm-xe-guc-Normalize-error-messages-with-x.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1434-fbdev-sisfb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1435-drm-amdgpu-Remove-unused-NBIO-interface.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1435-drm-xe-Donot-apply-forcewake-while-reading-actual-fr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1435-fbdev-sm501fb-Initialize-fb_ops-to-fbdev-I-O-memory-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1436-drm-amdgpu-Enable-translate-further-for-GC-v9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1436-drm-xe-Fix-GT-looping-for-standalone-media.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1436-fbdev-sm712fb-Initialize-fb_ops-to-fbdev-I-O-memory-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1437-drm-amdgpu-Increase-hmm-range-get-pages-timeout.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1437-drm-xe-Fix-uninitialized-variables.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1437-fbdev-stifb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1438-drm-xe-Fix-check-for-platform-without-geometry-pipel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1438-fbdev-sunxvr500-Initialize-fb_ops-to-fbdev-I-O-memor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1439-drm-msm-Remove-unnecessary-void-conversions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1439-drm-xe-mtl-Add-some-initial-MTL-workarounds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1439-fbdev-tdfxfb-Initialize-fb_ops-to-fbdev-I-O-memory-h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1440-drm-msm-mdss-Add-SM6350-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1440-drm-xe-limit-GGTT-size-to-GUC_GGTT_TOP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1440-fbdev-tgafb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1441-drm-Xe-Use-EOPNOTSUPP-instead-of-ENOTSUPP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1441-drm-msm-mdss-Add-SM6375-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1441-fbdev-tridentfb-Initialize-fb_ops-to-fbdev-I-O-memor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1442-drm-msm-dpu-enable-DPU_CTL_SPLIT_DISPLAY-for-sc8280x.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1442-drm-xe-NULL-binding-implementation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1442-fbdev-vermilionfb-Initialize-fb_ops-to-fbdev-I-O-mem.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1443-drm-xe-Long-running-job-update.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1443-fbdev-vga16fb-Initialize-fb_ops-to-fbdev-I-O-memory-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1444-drm-msm-dpu-enable-DSPP-and-DSC-on-sc8180x.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1444-drm-xe-Ensure-LR-engines-are-not-persistent.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1444-fbdev-viafb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1445-drm-msm-dpu-use-CTL_SC7280_MASK-for-sm8450-s-ctl_0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1445-drm-xe-Only-try-to-lock-external-BOs-in-VM-bind.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1445-fbdev-vt8623fb-Initialize-fb_ops-to-fbdev-I-O-memory.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1446-drm-ast-Rename-AST_IO_AR_PORT_WRITE-to-AST_IO_VGAARI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1446-drm-msm-dpu-simplify-intf-allocation-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1446-drm-xe-VM-LRU-bulk-move.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1447-drm-ast-Rename-AST_IO_MISC_PORT_WRITE-to-AST_IO_VGAM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1447-drm-msm-dpu-add-HDMI-output-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1447-drm-xe-bo-handle-PL_TT-PL_TT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1448-drm-ast-Rename-AST_IO_VGA_ENABLE_PORT-to-AST_IO_VGAE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1448-drm-msm-dpu-use-hsync-vsync-polarity-set-by-the-enco.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1448-drm-xe-Skip-applying-copy-engine-fuses.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1449-drm-ast-Rename-AST_IO_SEQ_PORT-to-AST_IO_VGASRI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1449-drm-xe-Fix-unreffed-ptr-leak-on-engine-lookup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1450-drm-ast-Rename-AST_IO_DAC_INDEX_READ-to-AST_IO_VGADR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1450-drm-msm-dpu-set-max-cursor-width-to-512x512.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1450-drm-xe-Document-structures-for-device-query.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1451-drm-ast-Rename-AST_IO_DAC_INDEX_WRITE-to-AST_IO_VGAD.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1451-drm-xe-Move-defines-before-relevant-fields.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1452-drm-ast-Rename-AST_IO_DAC_DATA-to-AST_IO_VGAPDR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1452-drm-msm-dpu-stop-mapping-the-regdma-region.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1452-drm-xe-Document-topology-mask-query.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1453-drm-ast-Rename-AST_IO_GR_PORT-to-AST_IO_VGAGRI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1453-drm-msm-dpu-Drop-unused-members-from-HW-structs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1453-drm-xe-uapi-restrict-system-wide-accounting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1454-drm-ast-Rename-AST_IO_CRTC_PORT-to-AST_IO_VGACRI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1454-drm-msm-dpu-Pass-catalog-pointers-in-RM-to-replace-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1454-drm-xe-uapi-add-some-kernel-doc-for-region-query.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1455-drm-ast-Rename-AST_IO_INPUT_STATUS1_READ-to-AST_IO_V.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1455-drm-msm-dpu-remove-DPU_DSPP_GC-handling-in-dspp-flus.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1455-drm-xe-uapi-silence-kernel-doc-errors.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1456-drm-ast-Rename-AST_IO_MISC_PORT_READ-to-AST_IO_VGAMR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1456-drm-doc-include-xe_drm.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1456-drm-msm-dpu-remove-DPU_DSPP_IGC-handling-in-dspp-flu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1457-drm-ast-Move-register-constants-to-ast_reg.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1457-drm-msm-dpu-remove-GC-and-IGC-related-code-from-dpu-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1457-drm-xe-bo-consider-bo-flags-in-xe_bo_migrate.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1458-drm-msm-dpu-drop-DSPP_MSM8998_MASK-from-hw-catalog.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1458-drm-panel-ili9882t-Break-out-as-separate-driver.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1458-drm-xe-add-a-new-sysfs-directory-for-gtidle-properti.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1459-drm-msm-dpu-drop-unused-SSPP-sub-block-information.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1459-drm-panel-ili9882t-Avoid-blurred-screen-from-fast-sl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1459-drm-xe-mtl-Add-support-to-get-C6-residency-status-of.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1460-drm-msm-dpu-add-writeback-support-for-sc7280.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1460-drm-xe-bo-Fix-swapin-when-moving-to-VRAM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1461-drm-doc-use-cross-references-for-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1461-drm-xe-bo-Avoid-creating-a-system-resource-when-allo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1462-drm-client-Convert-drm_client_buffer_addfb-to-drm_mo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1462-drm-msm-dpu-Remove-extraneous-register-define-indent.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1462-drm-xe-bo-Gracefully-handle-errors-from-ttm_bo_move_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1463-drm-bridge-synopsys-dw-mipi-dsi-Fix-hcomponent-lbcc-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1463-drm-msm-dpu-Sort-INTF-registers-numerically.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1463-drm-xe-bo-Evict-VRAM-to-TT-rather-than-to-system.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1464-drm-msm-dpu-Take-INTF-index-as-parameter-in-interrup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1464-drm-rockchip-vop-fix-format-bpp-calculation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1464-drm-xe-Fix-vm-refcount-races.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1465-accel-ivpu-Add-ivpu_bo_vaddr-and-ivpu_bo_size.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1465-drm-xe-pm-Disable-PM-on-unbounded-pcie-parent-bridge.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1466-drm-rockchip-vop2-Add-more-supported-10bit-formats.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1466-drm-xe-kunit-Handle-fake-device-creation-for-all-pla.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1467-drm-rockchip-vop2-rename-window-formats-to-show-wind.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1467-drm-xe-Add-missing-ADL-entries-to-xe_test_wa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1468-drm-fourcc-Add-NV20-and-NV30-YUV-formats.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1468-drm-msm-dpu-Disable-MDP-vsync-source-selection-on-DP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1468-drm-xe-fix-HuC-FW-ordering-for-DG1.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1469-drm-msm-dpu-Move-dpu_hw_-tear_check-pp_vsync_info-to.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1469-drm-rockchip-vop-Add-NV15-NV20-and-NV30-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1469-drm-xe-slpc-Start-SLPC-before-GuC-submission-on-rese.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1470-drm-doc-document-DRM_IOCTL_MODE_CREATE_DUMB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1470-drm-msm-dpu-Factor-out-shared-interrupt-register-in-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1470-drm-xe-fix-bounds-checking-for-len-in-xe_engine_crea.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1471-drm-doc-ci-Require-more-context-for-flaky-tests.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1471-drm-msm-dpu-Describe-TEAR-interrupt-registers-for-DS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1471-drm-xe-properly-check-bounds-for-xe_wait_user_fence_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1472-drm-ci-pick-up-external-fixes-from-the-merge-target-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1472-drm-msm-dpu-Add-TEAR-READ-pointer-interrupt-to-INTF-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1472-drm-xe-Use-nanoseconds-instead-of-jiffies-in-uapi-fo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1473-drm-ci-force-enable-CONFIG_MSM_MMCC_8996-as-built-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1473-drm-msm-dpu-Merge-setup_-and-enable_tearcheck-pingpo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1473-drm-xe-Add-sysfs-entry-for-tile.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1474-drm-ci-Enable-CONFIG_BACKLIGHT_CLASS_DEVICE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1474-drm-msm-dpu-Implement-tearcheck-support-on-INTF-bloc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1474-drm-xe-Add-GTs-under-respective-tile-sysfs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1475-drm-ci-uprev-mesa-version-fix-container-build-crosvm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1475-drm-msm-dpu-Remove-intr_rdptr-from-DPU-5.0.0-pingpon.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1475-drm-xe-Add-sysfs-entry-to-report-per-tile-memory-siz.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1476-drm-ci-fix-DEBIAN_ARCH-and-get-amdgpu-probing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1476-drm-msm-dpu-drop-SSPP-s-SRC-subblock.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1476-drm-xe-Make-usable-size-of-VRAM-readable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1477-drm-ci-add-helper-script-update-xfails.py.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1477-drm-msm-dpu-access-QSEED-registers-directly.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1477-drm-xe-Return-GMD_ID-revid-properly.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1478-drm-ci-uprev-IGT-and-make-sure-core_getversion-is-ru.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1478-drm-msm-dpu-access-CSC-CSC10-registers-directly.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1478-drm-xe-Don-t-raise-error-on-fused-off-media.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1479-drm-xe-Print-proper-revid-value-for-unknown-media-re.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1480-drm-ci-add-subset-1-gfx-to-LAVA_TAGS-and-adjust-shar.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1480-drm-msm-dpu-replace-IS_ERR_OR_NULL-with-IS_ERR-durin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1480-drm-xe-Enable-PCI-device-earlier.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1481-drm-ci-increase-i915-job-timeout-to-1h30m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1481-drm-msm-dpu-remove-futile-checks-from-dpu_rm_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1481-drm-xe-Make-page-table-updates-using-the-default-eng.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1482-drm-ci-export-kernel-config.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1482-drm-msm-dpu-use-PINGPONG_NONE-for-LMs-with-no-PP-att.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1482-drm-xe-mmio-add-xe_mmio_read16.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1483-drm-ci-do-not-automatically-retry-on-error.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1483-drm-msm-dpu-move-PINGPONG_NONE-check-to-dpu_lm_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1483-drm-xe-guc-Fix-h2g_write-usage-of-GUC_CTB_MSG_MAX_LE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1484-drm-ci-docs-add-step-about-how-to-request-privileges.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1484-drm-msm-dpu-fix-SSPP-register-definitions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1484-drm-xe-make-GT-sysfs-init-return-void.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1485-drm-msm-dpu-simplify-CDP-programming.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1485-drm-sched-Convert-the-GPU-scheduler-to-variable-numb.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1485-drm-xe-make-kobject-type-struct-as-constant.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1486-drm-amdgpu-move-buffer-funcs-setting-up-a-level.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1486-drm-msm-dpu-fix-the-condition-for-not-applying-QoS-t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1486-drm-xe-Use-internal-VM-flags-in-xe_vm_create.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1487-drm-amd-pm-record-mca-debug-mode-in-RAS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1487-drm-msm-dpu-rearrange-QoS-setting-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1487-drm-xe-Ban-a-VM-if-rebind-worker-hits-an-error.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1488-drm-amd-display-reprogram-det-size-while-seamless-bo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1488-drm-msm-dpu-drop-DPU_PLANE_QOS_VBLANK_CTRL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1488-drm-xe-Add-helpers-to-hide-struct-xe_vma-internals.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1489-drm-amdgpu-fix-find-ras-error-node-error.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1489-drm-msm-dpu-simplify-qos_ctrl-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1489-drm-xe-Remove-__xe_vm_bind-forward-declaration.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1490-drm-amdgpu-refine-ras-error-kernel-log-print.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1490-drm-msm-dpu-drop-DPU_PLANE_QOS_PANIC_CTRL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1490-drm-xe-Port-Xe-to-GPUVA.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1491-drm-msm-dpu-remove-struct-dpu_hw_pipe_qos_cfg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1491-drm-xe-tlb-drop-unnecessary-smp_wmb.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1492-drm-amdgpu-modify-if-condition-in-nbio_v7_7.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1492-drm-msm-dpu-use-common-helper-for-WB-and-SSPP-QoS-se.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1492-drm-xe-tlb-ensure-we-access-seqno_recv-once.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1493-drm-amd-pm-drop-unneeded-dpm-features-disablement-fo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1493-drm-xe-hold-mem_access.ref-for-CT-fast-path.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1494-drm-amdgpu-add-tmz-support-for-GC-IP-v11.5.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1494-drm-msm-dpu-add-DPU_PINGPONG_DSC-feature-bit-for-DPU.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1494-drm-xe-ct-hold-fast_lock-when-reserving-space-for-g2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1495-drm-amdgpu-Add-API-to-get-full-IP-version.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1495-drm-msm-dpu-Guard-PINGPONG-DSC-ops-behind-DPU_PINGPO.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1495-drm-xe-tlb-increment-next-seqno-after-successful-CT-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1496-drm-amd-pm-Fix-the-return-value-in-default-case.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1496-drm-msm-dpu-Introduce-PINGPONG_NONE-to-disconnect-DS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1496-drm-xe-ct-serialise-fast_lock-during-CT-disable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1497-drm-amd-display-Set-the-DML2-attribute-to-false-in-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1497-drm-xe-gt-tweak-placement-for-signalling-TLB-fences-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1498-drm-msm-dpu-separate-DSC-flush-update-out-of-interfa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1498-drm-xe-tlb-also-update-seqno_recv-during-reset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1499-drm-amd-display-Fix-DMUB-errors-introduced-by-DML2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1499-drm-msm-dpu-Tear-down-DSC-datapath-on-encoder-cleanu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1499-drm-xe-tlb-print-seqno_recv-on-fence-TLB-timeout.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1500-drm-amdgpu-vpe-correct-queue-stop-programing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1500-drm-xe-ct-update-g2h-outstanding-for-CTB-capture.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1501-drm-amdgpu-enable-RAS-poison-mode-for-APU.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1501-drm-msm-dpu-merge-dpu_encoder_init-and-dpu_encoder_s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1501-drm-xe-handle-TLB-invalidations-from-CT-fast-path.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1502-drm-amdgpu-bypass-RAS-error-reset-in-some-conditions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1502-drm-msm-dpu-separate-common-function-to-init-physica.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1502-drm-xe-mmio-update-gt_count-when-probing-multi-tile.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1503-drm-msm-dpu-drop-duplicated-intf-wb-indices-from-enc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1503-drm-xe-Fix-BUG_ON-during-bind-with-prefetch.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1504-drm-amdkfd-Address-remap_list-not-described-in-svm_r.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1504-drm-msm-dpu-inline-dpu_encoder_get_wb.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1504-drm-xe-Fix-lockdep-warning-from-xe_vm_madvise.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1505-drm-amdgpu-remove-restriction-of-sriov-max_pfn-on-Ve.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1505-drm-msm-dpu-call-dpu_rm_get_intf-from-dpu_encoder_ge.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1505-drm-xe-Cleanup-SPACING-style-issues.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1506-drm-amd-display-Add-missing-copyright-notice-in-DMUB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1506-drm-msm-dpu-drop-temp-variable-from-dpu_encoder_phys.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1506-drm-xe-Cleanup-OPEN_BRACE-style-issues.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1507-drm-amd-display-Fix-copyright-notice-in-DML2-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1507-drm-msm-dpu-simplify-dpu_encoder_phys_wb_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1507-drm-xe-Cleanup-POINTER_LOCATION-style-issues.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1508-drm-amd-display-Fix-copyright-notice-in-DC-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1508-drm-msm-dpu-use-PINGPONG_NONE-to-unbind-INTF-from-PP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1508-drm-xe-Cleanup-CODE_INDENT-style-issues.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1509-Revert-drm-amdkfd-remove-unused-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1509-drm-msm-dpu-use-PINGPONG_NONE-to-unbind-WB-from-PP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1509-drm-xe-Cleanup-TRAILING_WHITESPACE-style-issues.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1510-Revert-drm-amdkfd-Use-partial-migrations-in-GPU-page.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1510-drm-msm-dpu-Add-SM6350-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1510-drm-xe-Cleanup-COMPLEX_MACRO-style-issues.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1511-drm-msm-dpu-Add-SM6375-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1511-drm-xe-Fix-typos.patch (jsc#PED-9898
  jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237
  jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1512-drm-amd-Move-AMD_IS_APU-check-for-ASPM-into-top-leve.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1512-drm-msm-dpu-add-DSC-blocks-to-the-catalog-of-MSM8998.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1512-drm-xe-Prevent-flooding-the-kernel-log-with-XE_IOCTL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1513-drm-amd-Explicitly-disable-ASPM-when-dynamic-switchi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1513-drm-msm-dpu-tidy-up-some-error-checking.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1513-drm-xe-Cleanup-style-warnings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1514-drm-amd-display-Fix-MST-Multi-Stream-Not-Lighting-Up.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1514-drm-msm-dp-remove-most-of-usbpd-related-remains.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1514-drm-xe-remove-gucrc-disable-from-suspend-path.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1515-drm-amd-display-Revert-Improve-x86-and-dmub-ips-hand.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1515-drm-msm-dp-Clean-up-logs-dp_power-module.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1515-drm-xe-pm-Add-pci-d3cold_capable-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1516-drm-amd-display-Add-a-check-for-idle-power-optimizat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1516-drm-msm-dp-Clean-up-pdev-dev-duplication-in-dp_power.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1516-drm-xe-pm-Refactor-xe_pm_runtime_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1517-drm-amd-display-Update-SDP-VSC-colorimetry-from-DP-t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1517-drm-msm-dsi-Stop-unconditionally-powering-up-DSI-hos.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1517-drm-xe-pm-Add-vram_d3cold_threshold-Sysfs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1518-drm-msm-dsi-More-properly-handle-errors-in-regards-t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1518-drm-xe-pm-Toggle-d3cold_allowed-using-vram_usages.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1519-drm-amd-display-add-pipe-resource-management-callbac.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1519-drm-xe-pm-Init-pcode-and-restore-vram-on-power-lost.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1520-drm-amd-display-implement-map-dc-pipe-with-callback-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1520-drm-msm-dsi-remove-extra-call-to-dsi_get_pclk_rate.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1520-drm-xe-fix-xe_device_mem_access_get-races.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1521-drm-amd-display-Fix-IPS-handshake-for-idle-optimizat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1521-drm-msm-dsi-use-mult_frac-for-pclk_bpp-calculation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1521-drm-xe-vm-tidy-up-xe_runtime_pm-usage.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1522-drm-amd-display-Fix-HDMI-framepack-3D-test-issue.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1522-drm-msm-dpu-drop-dpu_encoder_phys_ops-late_register.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1522-drm-xe-debugfs-grab-mem_access-around-forcewake.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1523-drm-amd-display-Revert-drm-amd-display-allow-edp-upd.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1523-drm-msm-dpu-drop-mostly-unused-DPU_NAME_SIZE-define.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1523-drm-xe-guc_pc-add-missing-mem_access-for-freq_rpe_sh.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1524-drm-amd-display-Set-emulated-sink-type-to-HDMI-accor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1524-drm-msm-dsi-Add-configuration-for-MSM8226.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1524-drm-xe-mmio-grab-mem_access-in-xe_mmio_ioctl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1525-drm-amd-display-Correct-enum-typo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1525-drm-msm-dsi-Add-phy-configuration-for-MSM8226.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1525-drm-xe-ensure-correct-access_put-ordering.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1526-drm-amd-display-Add-prefix-to-amdgpu-crtc-functions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1526-drm-msm-mdp5-Add-MDP5-configuration-for-MSM8226.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1526-drm-xe-drop-xe_device_mem_access_get-from-guc_ct_sen.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1527-drm-amd-display-Add-prefix-for-plane-functions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1527-drm-xe-ggtt-prime-ggtt-lock-against-FS_RECLAIM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1528-drm-amd-display-fix-num_ways-overflow-error.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1528-drm-msm-drop-unused-ring-variable-in-msm_ioctl_gem_s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1528-drm-xe-drop-xe_device_mem_access_get-from-invalidati.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1529-drm-amd-display-Update-FAMS-sequence-for-DCN30-DCN32.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1529-drm-xe-add-lockdep-annotation-for-xe_device_mem_acce.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1530-drm-amd-display-add-null-check-for-invalid-opps.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1530-drm-msm-Move-cmdstream-dumping-out-of-sched-kthread.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1530-drm-xe-selftests-hold-rpm-for-evict_test_run_device.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1531-drm-amd-display-Fix-shaper-using-bad-LUT-params.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1531-drm-msm-adreno-Add-Adreno-A690-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1531-drm-xe-selftests-hold-rpm-for-ccs_test_migrate.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1532-drm-amd-display-Disable-SYMCLK32_SE-RCO-on-DCN314.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1532-drm-msm-a6xx-Fix-a690-CP_PROTECT-settings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1532-drm-xe-selftests-restart-GT-after-xe_bo_restore_kern.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1533-drm-amd-display-Read-before-writing-Backlight-Mode-S.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1533-drm-xe-add-missing-bulk_move-reset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1534-drm-amd-display-add-interface-to-query-SubVP-status.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1534-drm-msm-adreno-warn-if-chip-revn-is-verified-before-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1534-drm-xe-Normalize-XE_VM_FLAG-names.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1535-drm-amd-display-3.2.256.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1535-drm-msm-adreno-change-adreno_is_-functions-to-accept.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1535-drm-xe-Use-FIELD_PREP-FIELD_GET-for-tile-id-encoding.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1536-drm-amdgpu-Use-discovery-table-s-subrevision.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1536-drm-msm-adreno-make-adreno_is_a690-s-argument-const.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1536-drm-xe-Rely-on-kmalloc-kzalloc-log-message.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1537-drm-amdgpu-get-RAS-poison-status-from-DF-v4_6_2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1537-drm-xe-execlist-Remove-leftover-printk-messages.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1538-drm-amd-pm-call-smu_cmn_get_smc_version-in-is_mode1_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1538-drm-msm-dpu-catalog-define-DSPP-blocks-found-on-sdm8.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1538-drm-xe-Cleanup-style-warnings-and-errors.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1539-drm-amdgpu-Add-a-read-to-GFX-v9.4.3-ring-test.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1539-drm-display-dsc-Add-flatness-and-initial-scale-value.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1539-drm-xe-execlist-Log-when-using-execlist-submission.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1540-drm-display-dsc-add-helper-to-set-semi-const-paramet.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1540-drm-xe-Introduce-a-range-fence-utility.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1541-drm-amdgpu-Use-pcie-domain-of-xcc-acpi-objects.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1541-drm-display-dsc-Add-drm_dsc_get_bpp_int-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1541-drm-xe-Make-bind-engines-safe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1542-drm-amd-amdgpu-fix-the-GPU-power-print-error-in-pm-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1542-drm-msm-dsi-use-DRM-DSC-helpers-for-DSC-setup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1542-drm-xe-Remove-xe_vma_op_unmap.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1543-drm-amdxcp-fix-amdxcp-unloads-incompletely.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1543-drm-msm-Add-MSM-specific-DSC-helper-methods.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1543-drm-xe-Avoid-doing-rebinds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1544-drm-amd-display-fix-S-G-display-enablement.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1544-drm-msm-dpu-Use-fixed-DRM-DSC-helper-for-det_thresh_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1544-drm-xe-Reduce-the-number-list-links-in-xe_vma.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1545-drm-amdgpu-Fix-typo-in-IP-discovery-parsing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1545-drm-xe-Replace-list_del_init-with-list_del-for-userp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1546-drm-amdgpu-Identify-data-parity-error-corrected-in-r.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1546-drm-msm-dsi-Use-MSM-and-DRM-DSC-helper-methods.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1546-drm-xe-Change-tile-masks-from-u64-to-u8.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1547-drm-amdgpu-Retrieve-CE-count-from-ce_count_lo_chip-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1547-drm-msm-dsi-update-hdisplay-calculation-for-dsi_timi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1547-drm-xe-Combine-destroy_cb-and-destroy_work-in-xe_vma.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1548-drm-amdgpu-Add-EXT_COHERENT-support-for-APU-and-NUMA.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1548-drm-msm-dpu-add-support-for-DSC-encoder-v1.2-engine.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1548-drm-xe-Only-alloc-userptr-part-of-xe_vma-for-userptr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1549-drm-amd-amdgpu-avoid-to-disable-gfxhub-interrupt-whe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1549-drm-msm-dpu-add-DSC-1.2-hw-blocks-for-relevant-chips.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1549-drm-xe-Use-migrate-engine-for-page-fault-binds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1550-drm-xe-add-lockdep-annotation-for-xe_device_mem_acce.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1550-msm-drm-dsi-Round-up-DSC-hdisplay-calculation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1551-drm-msm-dsi-Reduce-pclk-rate-for-compression.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1551-drm-xe-mtl-Map-PPGTT-as-CPU-WC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1552-drm-msm-dpu-Add-DPU_INTF_DATA_COMPRESS-feature-flag-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1552-drm-xe-xe_engine_create_ioctl-should-check-gt_count-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1553-drm-msm-dpu-Set-DATA_COMPRESS-on-command-mode-for-DC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1553-drm-xe-bo-support-tiered-vram-allocation-for-small-b.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1554-drm-xe-uapi-add-the-userspace-bits-for-small-bar.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1555-drm-nouveau-Use-pci_get_base_class-to-reduce-duplica.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1555-drm-xe-fully-turn-on-small-bar-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1556-drm-amdgpu-Use-pci_get_base_class-to-reduce-duplicat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1556-drm-xe-uapi-Remove-XE_QUERY_CONFIG_FLAGS_USE_GUC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1557-accel-ivpu-Use-ratelimited-warn-and-err-in-IPC-JSM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1557-drm-radeon-Use-pci_get_base_class-to-reduce-duplicat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1557-drm-xe-Invert-guc-vs-execlists-parameters-and-info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1558-accel-ivpu-Fix-verbose-version-of-REG_POLL-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1558-drm-virtio-Use-pci_is_vga-to-identify-VGA-devices.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1558-drm-xe-Always-use-xe_vm_queue_rebind_worker-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1559-accel-ivpu-Read-clock-rate-only-if-device-is-up.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1559-drm-qxl-Use-pci_is_vga-to-identify-VGA-devices.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1559-drm-xe-Signal-out-syncs-on-VM-binds-if-no-operations.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1560-accel-ivpu-Print-IPC-type-string-instead-of-number.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1560-drm-msm-dpu-remove-unused-INTF_NONE-interfaces.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1560-drm-xe-engine-add-missing-rpm-for-bind-engines.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1561-accel-ivpu-Do-not-initialize-parameters-on-power-up.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1561-drm-msm-dsi-dsi_host-drop-unused-clocks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1561-drm-xe-Fix-checking-for-unset-value.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1561-mei-fix-doc-typos.patch (jsc#PED-9898
  jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237
  jsc#PED-10340 jsc#PED-10852 jsc#PED-11022 jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Update
  patches.suse/1562-accel-ivpu-37xx-Remove-support-for-FPGA-and-simics.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1562-drm-msm-dsi-split-dsi_ctrl_config-function.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1562-drm-xe-fix-mcr-semaphore-locking-for-MTL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1562-mei-bus-add-send-and-recv-api-with-timeout.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1563-accel-ivpu-Delete-the-TODO-file.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1563-drm-msm-adreno-Use-adreno_is_revn-for-A690.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1563-drm-xe-Remove-vma-arg-from-xe_pte_encode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1563-mei-pxp-recover-from-recv-fail-under-memory-pressure.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1564-drm-msm-a6xx-Remove-static-keyword-from-sptprac-en-d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1564-drm-xe-Decouple-vram-check-from-xe_bo_addr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1564-mei-pxp-re-enable-client-on-errors.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1565-drm-msm-a6xx-Move-force-keepalive-vote-removal-to-a6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1565-drm-xe-Set-PTE_DM-bit-for-stolen-on-MTL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1565-mei-update-mei-pxp-s-component-interface-with-timeou.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1566-drm-msm-a6xx-Move-a6xx_bus_clear_pending_transaction.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1566-drm-xe-Fix-MTL-stolen-memory-mapping.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1566-mei-docs-use-correct-structures-name-in-kdoc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1567-drm-msm-a6xx-Improve-a6xx_bus_clear_pending_transact.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1567-drm-xe-Carve-out-top-of-DSM-as-reserved.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1567-mei-docs-add-missing-entries-to-kdoc-in-struct-mei_c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1568-drm-msm-a6xx-Add-a-helper-for-software-resetting-the.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1568-drm-xe-Sort-xe_regs.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1568-mei-docs-fix-spelling-errors.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1569-drm-msm-a6xx-Remove-both-GBIF-and-RBBM-GBIF-halt-on-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1569-drm-xe-Fix-an-invalid-locking-wait-context-bug.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1569-misc-mei-hw.h-fix-kernel-doc-warnings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1570-drm-msm-a6xx-Extend-and-explain-UBWC-config.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1570-drm-xe-Invert-mask-and-val-in-xe_mmio_wait32.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1570-misc-mei-client.c-fix-kernel-doc-warnings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1571-drm-msm-a6xx-Move-CX-GMU-power-counter-enablement-to.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1571-drm-xe-Notify-Userspace-when-gt-reset-fails.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1571-misc-mei-dma-ring.c-fix-kernel-doc-warnings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1572-drm-msm-a6xx-Introduce-GMU-wrapper-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1572-drm-xe-Introduce-fault-injection-for-gt-reset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1572-misc-mei-hbm.c-fix-kernel-doc-warnings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1573-drm-msm-adreno-Disable-has_cached_coherent-in-GMU-wr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1573-drm-xe-Only-set-PCI-d3cold_allowed-when-we-are-reall.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1573-misc-mei-hw-me.c-fix-kernel-doc-warnings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1574-drm-msm-a6xx-Add-support-for-A619_holi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1574-drm-xe-Move-d3cold_allowed-decision-all-together.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1574-misc-mei-interrupt.c-fix-kernel-doc-warnings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1575-drm-msm-a6xx-Add-A610-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1575-drm-xe-Fix-the-runtime_idle-call-and-d3cold.allowed-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1575-misc-mei-main.c-fix-kernel-doc-warnings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1576-drm-msm-a6xx-Fix-some-A619-tunables.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1576-drm-xe-Only-init-runtime-PM-after-all-d3cold-config-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1576-mei-me-emit-error-only-if-reset-was-unexpected.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1577-drm-msm-a6xx-Use-else-if-in-GPU-speedbin-rev-matchin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1577-drm-xe-Ensure-memory-eviction-on-s2idle.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1577-vgacon-rework-Kconfig-dependencies.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1578-drm-msm-a6xx-Use-adreno_is_aXYZ-macros-in-speedbin-m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1578-drm-xe-mtl-Reduce-Wa_14018575942-scope-to-the-CCS-en.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1578-dummycon-limit-Arm-console-size-hack-to-footbridge.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1579-drm-msm-a6xx-Add-A619_holi-speedbin-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1579-drm-xe-Remove-XE_GUC_CT_SELFTEST.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1579-vgacon-remove-screen_info-dependency.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1580-drm-msm-a6xx-Add-A610-speedbin-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1580-drm-xe-Remove-ct-fence_context.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1581-drm-i915-gsc-take-a-wakeref-for-the-proxy-init-compl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1581-drm-xe-Add-define-WQ_HEADER_SIZE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1581-hyperv-avoid-dependency-on-screen_info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1582-drm-i915-huc-Fix-missing-error-code-in-intel_huc_ini.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1582-drm-nouveau-mmu-tu102-remove-write-to-0x100e68-durin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1582-drm-xe-macro-Remove-unused-constant.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1583-drm-i915-make-i915_drm_client_fdinfo-reference-condi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1583-drm-nouveau-nvkm-bump-maximum-number-of-NVDEC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1583-drm-xe-Prefer-WARN-over-BUG-to-avoid-crashing-the-ke.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1584-drm-i915-Fix-a-NULL-vs-IS_ERR-bug.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1584-drm-nouveau-nvkm-bump-maximum-number-of-NVJPG.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1584-drm-xe-remove-header-variable-from-parse_g2h_msg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1585-drm-nouveau-gsp-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1585-drm-nouveau-stop-using-is_swiotlb_active.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1585-drm-xe-Fix-error-paths-of-__xe_bo_create_locked.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1586-drm-nouveau-acr-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1586-drm-xe-Rename-xe_engine.-ch-to-xe_exec_queue.-ch.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1586-sticon-parisc-Allow-64-bit-STI-calls-in-PDC-firmware.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1587-drm-nouveau-bar-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1587-drm-xe-Rename-engine-to-exec_queue.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1587-sticon-parisc-Fix-STI-console-on-64-bit-only-machine.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1588-backlight-lm3630a-Turn-off-both-led-strings-when-dis.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1588-drm-nouveau-bus-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1588-drm-xe-Add-sysfs-entries-for-engines-under-its-GT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1589-backlight-Switch-i2c-drivers-back-to-use-.probe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1589-drm-nouveau-devinit-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1589-drm-xe-Add-sysfs-for-default-engine-scheduler-proper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1590-backlight-pwm_bl-Remove-unneeded-checks-for-valid-GP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1590-drm-nouveau-fault-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1590-drm-xe-Add-job-timeout-engine-property-to-sysfs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1591-drm-nouveau-fb-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1591-drm-xe-Add-timeslice-duration-engine-property-to-sys.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1591-video-backlight-lp855x-Get-PWM-for-PWM-mode-during-p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1592-backlight-led_bl-Take-led_access-lock-when-required.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1592-drm-nouveau-fuse-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1592-drm-xe-Add-sysfs-for-preempt-reset-timeout.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1593-drm-nouveau-gpio-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1593-drm-xe-Add-min-max-cap-for-engine-scheduler-properti.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1593-mei-bus-drop-useless-cldev-null-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1594-drm-nouveau-i2c-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1594-drm-xe-Fix-error-path-in-xe_guc_pc_gucrc_disable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1594-mei-bus-fixup-fix-buffer-type.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1595-drm-i915-adlp-Allow-DC-states-along-with-PW2-only-fo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1595-drm-nouveau-imem-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1595-drm-xe-Fix-error-path-in-xe_guc_pc_start.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1596-drm-i915-mtl-Fix-SSC-selection-for-MPLLA.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1596-drm-nouveau-ltc-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1596-drm-xe-guc_submit-prevent-repeated-unregister.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1597-drm-nouveau-mc-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1597-drm-xe-Set-max-pte-size-when-skipping-rebinds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1598-drm-nouveau-mmu-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1598-drm-xe-Update-ARL-S-DevIDs-to-the-latest-BSpec.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1599-drm-i915-hdcp-Assign-correct-hdcp-content-type.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1599-drm-nouveau-pmu-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1599-drm-xe-Implement-HW-workaround-14016763929.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1600-drm-i915-Add-missing-forward-declarations-includes-t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1600-drm-nouveau-privring-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1600-drm-xe-don-t-warn-for-bogus-pagefaults.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1601-amd-display-dc-remove-repeating-expression.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1601-drm-nouveau-therm-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1601-drm-xe-Add-Wa_14015150844-for-DG2-and-Xe_LPG.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1602-drm-nouveau-top-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1602-drm-xe-pm-Add-vram_d3cold_threshold-for-d3cold-capab.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1603-drm-amdgpu-Move-calculation-of-xcp-per-memory-node.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1603-drm-nouveau-vfn-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1603-drm-xe-guc_submit-fixup-deregister-in-job-timeout.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1604-drm-amd-pm-remove-unneeded-variable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1604-drm-nouveau-ce-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1604-drm-xe-skip-rebind_list-if-vma-destroyed.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1605-drm-amdgpu-Remove-CONFIG_DEBUG_FS-guard-around-body-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1605-drm-nouveau-disp-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1605-drm-xe-Call-__guc_exec_queue_fini_async-direct-for-K.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1606-drm-amdgpu-atomfirmware-fix-LPDDR5-width-reporting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1606-drm-nouveau-fifo-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1606-drm-xe-Make-xe_mem_region-struct.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1607-drm-amdgpu-Add-vbios-attribute-only-if-supported.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1607-drm-nouveau-gr-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1607-drm-xe-Improve-vram-info-debug-printing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1608-drm-amdkfd-set-coherent-host-access-capability-flag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1608-drm-nouveau-nvdec-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1608-drm-xe-dg2-Remove-Wa_15010599737.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1609-drm-nouveau-nvenc-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1609-drm-xe-Simplify-engine-class-sched_props-setting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1610-drm-nouveau-sec2-tu102-prepare-for-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1610-drm-xe-Add-CONFIG_DRM_XE_PREEMPT_TIMEOUT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1611-drm-amdgpu-Move-clocks-closer-to-its-only-usage-in-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1611-drm-nouveau-kms-tu102-disable-vbios-parsing-when-run.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1611-drm-xe-common-function-to-assign-queue-name.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1612-drm-amdgpu-Skip-TMR-for-MP0_HWIP-13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1612-drm-nouveau-nvkm-support-loading-fws-into-sg_table.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1612-drm-xe-base-definitions-for-the-GSCCS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1613-drm-amd-display-disable-power-gating-for-DCN314.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1613-drm-nouveau-gsp-r535-add-support-for-booting-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1613-drm-xe-add-GSCCS-irq-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1614-drm-amd-display-disable-RCO-for-DCN314.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1614-drm-nouveau-gsp-r535-add-support-for-rm-control.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1614-drm-xe-add-GSCCS-ring-ops.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1615-Revert-drm-amd-display-Move-DCN314-DOMAIN-power-cont.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1615-drm-nouveau-gsp-r535-add-support-for-rm-alloc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1615-drm-xe-GSC-forcewake-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1616-drm-nouveau-gsp-r535-add-interrupt-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1616-drm-xe-don-t-expose-the-GSCCS-to-users.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1617-drm-nouveau-mmu-r535-initial-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1617-drm-xe-enable-idle-msg-and-set-hysteresis-for-GSCCS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1618-drm-amd-display-Add-Clock-Table-Entry-With-Max-DC-Va.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1618-drm-nouveau-disp-r535-initial-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1618-drm-xe-Stop-tracking-4-tile-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1619-drm-amd-display-add-missing-ABM-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1619-drm-nouveau-fifo-r535-initial-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1619-drm-xe-xe2-Update-render-compute-context-image-sizes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1620-drm-amd-display-Fix-pipe-check-condition-for-manual-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1620-drm-nouveau-ce-r535-initial-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1620-drm-xe-xe2-Add-GT-topology-readout.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1621-drm-amd-display-Clear-update-flags-at-end-of-flip.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1621-drm-nouveau-gr-r535-initial-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1621-drm-xe-xe2-Add-MCR-register-steering-for-primary-GT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1622-drm-amd-display-enable-the-new-fast-update-path-for-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1622-drm-nouveau-nvdec-r535-initial-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1622-drm-xe-xe2-Add-MCR-register-steering-for-media-GT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1623-drm-amd-display-Disable-DC-Mode-Capping-On-DCN321.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1623-drm-nouveau-nvenc-r535-initial-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1623-drm-xe-xe2-Update-context-image-layouts.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1624-drm-nouveau-nvjpg-r535-initial-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1624-drm-xe-xe2-Handle-fused-off-CCS-engines.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1625-drm-amd-display-Add-MST-Preferred-Link-Setting-Entry.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1625-drm-nouveau-ofa-r535-initial-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1625-drm-xe-xe2-AuxCCS-is-no-longer-used.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1626-drm-amd-display-fix-odm-k2-div-calculation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1626-drm-xe-xe2-Define-Xe2_LPG-IP-features.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1626-nouveau-fix-r535-build-on-32-bit-arm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1627-drm-xe-xe2-Define-Xe2_LPM-IP-features.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1627-nouveau-disp-fix-post-gsp-build-on-32-bit-arm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1628-drm-amd-display-Enable-dc-mode-clock-switching-for-D.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1628-drm-xe-xe2-Track-VA-bits-independently-of-max-page-t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1628-nouveau-gsp-move-to-535.113.01.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1629-drm-amd-display-3.2.240.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1629-drm-xe-xe2-Add-MOCS-table.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1629-nouveau-gsp-fix-message-signature.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1630-drm-xe-xe2-Program-GuC-s-MOCS-on-Xe2-and-beyond.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1630-nouveau-gsp-add-some-basic-registry-entries.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1631-drm-amdkfd-Enable-GWS-on-GFX9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1631-drm-renesas-shmobile-Fix-overlay-plane-disable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1631-drm-xe-lnl-Add-LNL-platform-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1632-drm-renesas-shmobile-Fix-ARGB32-overlay-format-typo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1632-drm-xe-lnl-Add-GuC-firmware-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1633-drm-amdgpu-remove-vm-sanity-check-from-amdgpu_vm_mak.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1633-drm-renesas-shmobile-Correct-encoder-connector-types.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1633-drm-xe-lnl-Hook-up-MOCS-table.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1634-drm-renesas-shmobile-Add-support-for-Runtime-PM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1634-drm-xe-Avoid-64-bit-register-reads.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1635-drm-renesas-shmobile-Restore-indentation-of-shmob_dr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1635-drm-xe-Drop-xe_mmio_write64.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1636-drm-amdgpu-Remove-sdma-halt-unhalt-during-frontdoor-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1636-drm-renesas-shmobile-Use-p4cc-to-print-fourcc-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1636-drm-xe-fix-submissions-without-vm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1637-drm-amdgpu-Modify-for_each_inst-macro.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1637-drm-renesas-shmobile-Add-missing-YCbCr-formats.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1637-drm-xe-split-kernel-vs-permanent-engine-flags.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1638-drm-amd-pm-Provide-energy-data-in-15.625mJ-units.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1638-drm-renesas-shmobile-Improve-shmob_drm_format_info-t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1638-drm-xe-standardize-vm-less-kernel-submissions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1639-drm-renesas-shmobile-Remove-backlight-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1639-drm-xe-ct-fix-resv_space-print.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1640-drm-renesas-shmobile-Don-t-set-display-info-width-an.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1640-drm-xe-pvc-Blacklist-BCS_SWCTRL-register.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1641-drm-amdkfd-Update-interrupt-handling-for-GFX-9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1641-drm-renesas-shmobile-Rename-input-clocks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1641-drm-xe-pvc-Force-even-num-engines-to-use-64B.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1642-drm-renesas-shmobile-Remove-support-for-SYS-panels.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1642-drm-xe-pvc-Use-fast-copy-engines-as-migrate-engine-o.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1643-drm-amdgpu-port-SRIOV-VF-missed-changes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1643-drm-renesas-shmobile-Improve-error-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1643-drm-xe-Add-patch-version-on-guc-firmware-init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1644-drm-amd-display-Work-around-bad-DPCD-state-on-link-l.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1644-drm-renesas-shmobile-Convert-to-use-devm_request_irq.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1644-drm-xe-Prevent-return-with-locked-vm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1645-drm-amd-display-Remove-asserts.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1645-drm-renesas-shmobile-Remove-custom-plane-destroy-cal.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1645-drm-xe-nuke-GuC-on-unload.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1646-drm-amd-pm-fulfill-the-missing-enablement-for-vega12.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1646-drm-renesas-shmobile-Use-drmm_universal_plane_alloc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1646-drm-xe-fix-has_llc-on-rkl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1647-drm-renesas-shmobile-Embed-drm_device-in-shmob_drm_d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1647-drm-xe-Convert-xe_vma_op_flags-to-BIT-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1648-drm-renesas-shmobile-Convert-container-helpers-to-st.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1648-drm-xe-Fixup-unwind-on-VM-ops-errors.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1649-drm-gpuva-Add-drm_gpuva_for_each_op_reverse.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1649-drm-renesas-shmobile-Replace-.dev_private-with-conta.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1650-drm-renesas-shmobile-Use-struct-videomode-in-platfor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1650-drm-xe-Fix-array-of-binds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1651-drm-amd-Don-t-initialize-PSP-twice-for-Navi3x.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1651-drm-xe-pm-Use-PM-functions-only-if-CONFIG_PM_SLEEP-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1652-drm-amdgpu-make-mcbp-a-per-device-setting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1652-drm-renesas-shmobile-Use-media-bus-formats-in-platfo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1652-drm-xe-selftests-consider-multi-GT-for-eviction-test.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1653-drm-amdgpu-enable-mcbp-by-default-on-gfx9.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1653-drm-renesas-shmobile-Move-interface-handling-to-conn.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1653-drm-xe-selftests-make-eviction-test-tile-centric.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1654-drm-amdgpu-gpu-recovers-from-fatal-error-in-poison-m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1654-drm-renesas-shmobile-Unify-plane-allocation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1654-drm-xe-pat-Use-0-instead-of-space-on-error.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1655-drm-amdgpu-remove-duplicated-doorbell-range-init-for.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1655-drm-renesas-shmobile-Rename-shmob_drm_crtc.crtc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1655-drm-xe-reg_sr-Simplify-check-for-masked-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1656-drm-amdgpu-vcn-Need-to-unpause-dpg-before-stop-dpg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1656-drm-renesas-shmobile-Rename-shmob_drm_connector.conn.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1656-drm-xe-reg_sr-Use-xe_gt_dbg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1657-drm-amd-pm-Enable-pp_feature-attribute.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1657-drm-renesas-shmobile-Rename-shmob_drm_plane.plane.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1657-drm-xe-Add-dbg-messages-for-LRC-WAs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1658-drm-amd-pm-Add-GFX-v9.4.3-unique-id-to-sysfs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1658-drm-renesas-shmobile-Use-drm_crtc_handle_vblank.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1658-drm-xe-Fix-LRC-workarounds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1658-intel-drm-Remove-now-superfluous-sentinel-element-fr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1659-drm-amdgpu-share-drm-device-for-pci-amdgpu-device-wi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1659-drm-renesas-shmobile-Move-shmob_drm_crtc_finish_page.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1659-drm-xe-uapi-Typo-lingo-and-other-small-backwards-com.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1660-drm-renesas-shmobile-Wait-for-page-flip-when-turning.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1660-drm-xe-uapi-Remove-useless-max_page_size.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1661-drm-amd-display-program-DPP-shaper-and-3D-LUT-if-upd.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1661-drm-renesas-shmobile-Turn-vblank-on-off-when-enablin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1661-drm-xe-mmio-Account-for-GSI-offset-when-checking-ran.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1662-drm-amdgpu-Keep-non-psp-path-for-partition-switch.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1662-drm-renesas-shmobile-Shutdown-the-display-on-remove.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1662-drm-xe-bo-Simplify-xe_bo_lock.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1663-drm-amd-display-Fix-the-delta-clamping-for-shaper-LU.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1663-drm-renesas-shmobile-Cleanup-encoder.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1663-drm-xe-vm-Simplify-and-document-xe_vm_lock.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1664-drm-amd-display-Limit-new-fast-update-path-to-addr-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1664-drm-renesas-shmobile-Atomic-conversion-part-1.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1664-drm-xe-bo-Remove-the-lock_no_vm-unlock_no_vm-interfa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1665-drm-renesas-shmobile-Atomic-conversion-part-2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1665-drm-xe-Rework-xe_exec-and-the-VM-rebind-worker-to-us.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1666-drm-amd-display-For-new-fast-update-path-loop-throug.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1666-drm-renesas-shmobile-Use-suspend-resume-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1666-drm-xe-Convert-pagefaulting-code-to-use-drm_exec.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1667-drm-renesas-shmobile-Remove-internal-CRTC-state-trac.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1667-drm-xe-Convert-remaining-instances-of-ttm_eu_reserve.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1668-drm-amd-display-Create-debugging-mechanism-for-Gamin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1668-drm-renesas-shmobile-Atomic-conversion-part-3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1668-drm-xe-Fix-fence-reservation-accouting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1669-drm-amd-display-Take-full-update-path-if-number-of-p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1669-drm-renesas-shmobile-Add-DT-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1669-drm-xe-Replace-XE_WARN_ON-with-drm_warn-when-just-pr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1670-drm-amd-display-3.2.241.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1670-drm-ssd130x-Fix-possible-uninitialized-usage-of-crtc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1670-drm-xe-Introduce-Xe-assert-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1671-drm-amdgpu-check-RAS-supported-first-in-ras_reset_er.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1671-drm-xe-Use-Xe-assert-macros-instead-of-XE_WARN_ON-ma.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1672-drm-amd-pm-Fix-warnings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1672-drm-amd-pm-avoid-unintentional-shutdown-due-to-tempe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1672-drm-xe-guc-Switch-to-major-only-GuC-FW-tracking-for-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1673-drm-amdgpu-Drop-deferred-error-in-uncorrectable-erro.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1673-drm-xe-Get-GT-clock-to-nanosecs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1674-drm-amdgpu-remove-amdgpu_mes_self_test-in-gpu-recove.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1674-drm-xe-Use-spinlock-in-forcewake-instead-of-mutex.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1675-drm-amd-pm-fix-the-high-voltage-and-temperature-issu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1675-drm-i915-use-mock-device-info-for-creating-mock-devi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1675-drm-xe-pmu-Enable-PMU-interface.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1676-drm-amdgpu-add-unmap-latency-when-gfx11-set-kiq-reso.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1676-drm-panel-Fine-tune-Starry-ili9882t-panel-HFP-and-HB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1676-drm-xe-uc-Rename-guc_submission_enabled-to-uc_enable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1677-drm-amdgpu-set-XGMI-IP-version-manually-for-v6_4.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1677-drm-client-Send-hotplug-event-after-registering-a-cl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1677-drm-xe-uc-Fix-uC-status-tracking.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1678-drm-amdgpu-Fix-the-vram-base-start-address.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1678-drm-xe-uc-Add-GuC-HuC-firmware-path-overrides.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1679-drm-xe-Reinstate-pipelined-fence-enable_signaling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1680-drm-amdgpu-remove-unused-macro-HW_REV.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1680-drm-xe-Simplify-final-return-from-xe_irq_install.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1681-drm-amd-pm-Return-0-as-default-min-power-limit-for-l.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1681-drm-xe-Disallow-pinning-dma-bufs-in-VRAM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1682-drm-amdgpu-doorbell-range-should-be-set-when-gpu-rec.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1682-drm-xe-wa-Apply-tile-workarounds-at-probe-resume.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1683-drm-amdgpu-use-mode-2-reset-for-RAS-poison-consumpti.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1683-drm-i915-perf-Consider-OA-buffer-boundary-when-zeroi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1683-drm-xe-Add-child-contexts-to-the-GuC-context-lookup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1684-drm-i915-Remove-dead-code-from-gen8_pte_encode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1684-drm-xe-Add-drm-client-infrastructure.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1685-drm-amdgpu-don-t-use-ATRM-for-external-devices.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1685-drm-xe-Interface-xe-drm-client-with-fdinfo-interface.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1686-drm-xe-Add-tracking-support-for-bos-per-client.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1687-drm-amd-Fix-UBSAN-array-index-out-of-bounds-for-Powe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1687-drm-xe-Record-each-drm-client-with-its-VM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1688-drm-radeon-replace-1-element-arrays-with-flexible-ar.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1688-drm-xe-Track-page-table-memory-usage-for-client.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1689-drm-amdgpu-ungate-power-gating-when-system-suspend.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1689-drm-xe-Account-ring-buffer-and-context-state-storage.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1690-drm-xe-Implement-fdinfo-memory-stats-printing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1691-drm-xe-proper-setting-of-irq-enabled-flag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1692-drm-amdgpu-don-t-put-MQDs-in-VRAM-on-ARM-ARM64.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1692-drm-xe-change-old-msi-irq-api-to-a-new-one.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1693-drm-amdkfd-Populate-cache-info-for-GFX-9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1693-drm-xe-add-msix-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1694-drm-amdkfd-Update-cache-info-for-GFX-9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1694-drm-xe-Accept-a-const-xe-device.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1695-drm-xe-Align-size-to-PAGE_SIZE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1696-drm-amd-display-Increase-frame-warning-limit-with-KA.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1696-drm-xe-Add-Wa_18028616096.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1697-drm-amdkfd-Improve-amdgpu_vm_handle_moved.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1697-drm-xe-irq-Clear-GFX_MSTR_IRQ-as-part-of-IRQ-reset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1698-drm-amdgpu-Attach-eviction-fence-on-alloc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1698-drm-xe-Infer-service-copy-functionality-from-engine-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1699-Revert-drm-i915-use-localized-__diag_ignore_all-inst.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1699-drm-amd-pm-only-check-sriov-vf-flag-once-when-creati.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1699-drm-xe-Normalize-pte-pde-encoding.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1700-drm-amd-Use-amdgpu_device_pcie_dynamic_switching_sup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1700-drm-amdgpu-check-recovery-status-of-xgmi-hive-in-ras.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1700-drm-xe-Remove-check-for-vma-NULL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1701-drm-amd-display-export-some-optc-function-for-reuse.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1701-drm-xe-Use-vfunc-for-pte-pde-ppgtt-encoding.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1702-drm-amd-display-add-DCN301-specific-logic-for-OTG-pr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1702-drm-amdgpu-Optimize-the-asic-type-fix-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1702-drm-xe-migrate-Do-not-hand-encode-pte.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1703-drm-amdgpu-Add-C2PMSG_109-126-reg-field-shift-masks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1703-drm-xe-Use-vfunc-to-initialize-PAT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1704-drm-amd-swsmu-update-smu-v14_0_0-driver-if-and-metri.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1704-drm-xe-dg2-Fix-using-wrong-PAT-table.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1705-drm-amd-swsmu-remove-fw-version-check-in-sw_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1705-drm-xe-pat-Prefer-the-arch-IP-names.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1706-drm-amdgpu-Add-psp-v13-function-to-query-boot-status.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1706-drm-xe-pat-Keep-track-of-relevant-indexes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1707-drm-amdgpu-Allow-the-initramfs-generator-to-include-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1707-drm-amdgpu-Query-and-report-boot-status.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1707-drm-xe-Use-pat_index-to-encode-pde-pte.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1708-drm-amd-display-Program-plane-color-setting-correctl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1708-drm-xe-Use-vfunc-for-ggtt-pte-encoding.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1709-drm-amd-display-Fix-blend-LUT-programming.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1709-drm-xe-do-not-register-to-PM-if-GuC-is-disabled.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1710-drm-amd-display-Enable-fast-update-on-blendTF-change.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1710-drm-xe-Ensure-mutex-are-destroyed.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1711-drm-xe-Add-a-missing-mutex_destroy-to-xe_ttm_vram_mg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1712-drm-xe-set-PTE_AE-for-all-platforms-supporting-it.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1713-drm-xe-timeout-needs-to-be-a-signed-value.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1714-drm-amdgpu-Allocate-root-PD-on-correct-partition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1714-drm-xe-tuning-Add-missing-engine-class-rules-for-LRC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1715-drm-amdgpu-fix-slab-out-of-bounds-issue-in-amdgpu_vm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1715-drm-i915-mtl-Apply-notify_guc-to-all-GTs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1715-drm-xe-xe2-Extend-reserved-stolen-sizes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1716-drm-amdgpu-vm-use-the-same-xcp_id-from-root-PD.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1716-drm-xe-Adjust-mocs-field-mask-definitions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1717-drm-amdgpu-use-a-macro-to-define-no-xcp-partition-ca.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1717-drm-xe-Rename-MEM_SET-instruction.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1718-drm-xe-xe2-Set-tile-y-type-in-XY_FAST_COPY_BLT-to-Ti.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1719-drm-xe-xe2-Update-MOCS-fields-in-blitter-instruction.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1720-drm-xe-Leverage-ComputeCS-read-L3-caching.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1720-fbdev-imxfb-switch-to-DEFINE_SIMPLE_DEV_PM_OPS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1721-drm-xe-Fix-exec-queue-usage-for-unbinds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1722-drm-amd-Disable-XNACK-on-SRIOV-environment.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1722-drm-xe-hwmon-Expose-power-attributes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1722-fbdev-imxfb-Convert-to-devm_kmalloc_array.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1723-drm-amd-display-On-boot-disable-domain22-force-power.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1723-drm-xe-hwmon-Expose-card-reactive-critical-power.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1723-fbdev-imxfb-Convert-to-devm_platform_ioremap_resourc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1724-drm-amd-display-FW-Promotion-Release-0.0.189.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1724-drm-xe-hwmon-Expose-input-voltage-attribute.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1724-fbdev-imxfb-remove-unneeded-labels.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1725-drm-amd-display-decouple-dmcub-execution-to-reduce-l.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1725-drm-xe-hwmon-Expose-hwmon-energy-attribute.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1725-vgacon-switch-vgacon_scrolldelta-and-vgacon_restore_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1726-drm-amd-display-3.2.257.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1726-drm-xe-vm-print-the-correct-keep-when-printing-gpuva.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1726-vgacon-remove-unneeded-forward-declarations.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1727-drm-amd-display-Fix-missing-blendTF-programming.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1727-drm-xe-vm-use-list_last_entry-to-fetch-last_op.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1727-vgacon-remove-unused-xpos-from-vgacon_set_cursor_siz.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1728-drm-amd-display-Fix-FRL-assertion-on-boot.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1728-drm-xe-fix-range-printing-for-debug-messages.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1728-vgacon-let-vgacon_doresize-return-void.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1729-drm-amd-display-Enable-RCO-options-for-dcn35.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1729-drm-xe-Fix-RING_MI_MODE-label-in-devcoredump.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1729-vgacon-cache-vc_cell_height-in-vgacon_cursor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1730-drm-amd-display-Enable-more-IPS-options.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1730-drm-xe-Fix-devcoredump-readout-of-IPEHR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1730-sticon-make-sticon_set_def_font-void-and-remove-op-p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1731-drm-amd-display-Allow-16-max_slices-for-DP2-DSC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1731-drm-xe-Remove-devcoredump-readout-of-IPEIR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1731-fbcon-remove-unused-display-p-from-fbcon_redraw.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1732-drm-amd-display-Update-test-link-rate-DPCD-bit-field.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1732-drm-xe-xe2-Add-missing-mocs-entry.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1732-fbdev-kyro-make-some-const-read-only-arrays-static-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1733-drm-amd-display-Update-DP-HPO-MSA-with-colorimetry-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1733-drm-xe-hwmon-fix-uaf-on-unload.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1734-drm-amd-display-DCN35-Disable-cm-power-optimization.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1734-drm-xe-Add-infrastructure-for-per-engine-tuning.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1734-fbdev-ep93xx-fb-fix-return-value-check-in-ep93xxfb_p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1735-drm-amd-display-Introduce-flag-for-disabling-Replay-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1735-drm-xe-add-gt-tuning-for-indirect-state.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1735-fbdev-Explicitly-include-correct-DT-includes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1736-drm-amd-display-amend-HPD-handler-for-Replay.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1736-drm-fb-helper-Remove-unused-inline-function-drm_fb_h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1736-drm-xe-vm-Prefer-xe_assert-over-XE_WARN_ON.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1737-drm-amd-display-Fix-OTG-disable-workaround-logic.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1737-drm-xe-xe2-Follow-XeHPC-for-TLB-invalidation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1738-drm-amd-display-Add-missing-dml2-init-value-for-dcn3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1738-drm-xe-xe_migrate.c-Use-DPA-offset-for-page-table-en.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1739-drm-amd-display-3.2.258.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1739-drm-amdkfd-fix-trap-handling-work-around-for-debuggi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1739-drm-xe-tests-xe_migrate.c-Add-vram-to-vram-KUNIT-tes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1740-drm-amd-display-FW-Promotion-Release-0.0.190.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1740-drm-amdgpu-Fix-infinite-loop-in-gfxhub_v1_2_xcc_gart.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1740-drm-xe-xe2-Program-PAT-tables.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1741-drm-amd-display-Revise-Replay-Desync-Error-IRQ-handl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1741-drm-xe-xe2-Add-one-more-bit-to-encode-PAT-to-ppgtt-e.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1742-drm-amd-display-Disable-OTG-for-mode-timing-switch-o.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1742-drm-xe-pat-Add-debugfs-node-to-dump-PAT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1743-drm-amd-display-Create-optc.h-file.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1743-drm-xe-gt-Dump-PAT-table-when-failing-to-initialize.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1744-drm-amd-display-Don-t-apply-FIFO-resync-W-A-if-rdivi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1744-drm-amd-display-Remove-unused-duplicate-register-def.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1744-drm-xe-rtp-Fix-doc-for-XE_RTP_ACTIONS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1745-drm-amd-display-save-and-restore-mall-state-when-app.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1745-drm-xe-rplu-s-ADLP-ALDERLAKE_P.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1746-drm-amd-display-Promote-DAL-to-3.2.259.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1746-drm-xe-rpls-Add-RPLS-Support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1747-drm-amd-display-Remove-references-to-unused-dml-arch.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1747-drm-amdgpu-Restore-HQD-persistent-state-register.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1747-drm-xe-rpls-Add-Stepping-info-for-RPLS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1748-drm-amd-display-Enable-physymclk-RCO.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1748-drm-xe-Add-missing-ADL-entries-to-xe_test_wa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1749-drm-amd-display-For-cursor-P-State-allow-for-SubVP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1749-drm-xe-pat-trim-the-xelp-PAT-table.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1750-accel-habanalabs-add-more-debugfs-stub-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1750-drm-amd-display-Fix-handling-duplicate-planes-on-one.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1750-drm-xe-directly-use-pat_index-for-pte_encode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1751-drm-amd-display-Set-stream-s-DP-test-pattern-upon-te.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1751-drm-xe-add-28-bit-address-support-in-struct-xe_reg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1752-drm-amdgpu-soc21-add-mode2-asic-reset-for-SMU-IP-v14.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1752-drm-msm-adreno-Fix-warn-splat-for-devices-without-re.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1752-drm-xe-add-read-write-support-for-MMIO-extension-spa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1753-drm-amdgpu-Fix-sdma-4.4.2-doorbell-rptr-wptr-init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1753-drm-msm-a690-Remove-revn-and-name.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1753-drm-xe-add-a-flag-to-bypass-multi-tile-config-from-M.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1754-drm-amd-pm-Hide-irrelevant-pm-device-attributes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1754-drm-xe-add-MMIO-extension-support-flags.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1755-drm-amd-display-avoid-variable-reinitialization.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1755-drm-xe-map-MMIO-BAR-according-to-the-num-of-tiles-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1756-drm-amd-pm-not-stop-rlc-for-IMU-enabled-APUs-when-su.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1756-drm-xe-refactor-xe_mmio_probe_tiles-to-support-MMIO-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1757-drm-amdgpu-handle-extra-UE-register-entries-for-gfx-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1757-drm-xe-Set-PTE_AE-for-smem-allocations-in-integrated.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1758-drm-amdgpu-add-RAS-reset-query-operations-for-XGMI-v.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1758-drm-xe-Add-new-DG2-PCI-IDs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1759-drm-amdgpu-fix-AGP-init-order.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1759-drm-xe-dg2-Remove-one-PCI-ID.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1760-drm-xe-gsc-add-HECI2-register-offsets.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1761-drm-panel-samsung-s6d7aa0-Add-MODULE_DEVICE_TABLE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1761-drm-xe-gsc-add-has_heci_gscfi-indication-to-device.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1762-drm-amdgpu-Don-t-warn-for-unsupported-set_xgmi_plpd_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1762-drm-xe-gsc-add-gsc-device-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1763-drm-amd-pm-Hide-pp_dpm_pcie-device-attribute.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1763-drm-xe-Make-MI_FLUSH_DW-immediate-size-more-explicit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1764-drm-amdgpu-correct-amdgpu-ip-block-rev-info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1764-drm-xe-Separate-number-of-registers-from-MI_LRI-opco.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1765-drm-amd-pm-raise-the-deep-sleep-clock-threshold-for-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1765-drm-xe-Clarify-number-of-dwords-qwords-stored-by-MI_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1766-drm-amdgpu-Add-flag-to-enable-indirect-RLCG-access-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1766-drm-xe-Extract-MI_-instructions-to-their-own-header.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1767-drm-amdgpu-Add-xcc-param-to-SRIOV-kiq-write-and-WREG.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1767-drm-xe-debugfs-Add-dump-of-default-LRCs-MI-instructi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1768-drm-amdgpu-correct-smu-v13.0.6-umc-ras-error-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1768-drm-xe-debugfs-Include-GFXPIPE-commands-in-LRC-dump.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1769-drm-amd-Resolve-Sphinx-unexpected-indentation-warnin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1769-drm-xe-Fix-array-bounds-check-for-queries.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1770-drm-amdgpu-Skip-PCTL0_MMHUB_DEEPSLEEP_IB-write-in-jp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1770-drm-i915-gvt-Fix-bug-in-getting-msg-length-in-AUX-CH.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1770-drm-xe-Set-the-correct-type-for-xe_to_user_engine_cl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1771-drm-amdgpu-Do-not-program-PF-only-regs-in-hdp_v4_0.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1771-drm-xe-Correlate-engine-and-cpu-timestamps-with-bett.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1772-drm-amdgpu-refine-smu-v13.0.6-mca-dump-driver.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1772-drm-xe-uapi-Separate-VM_BIND-s-operation-and-flag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1773-drm-amdgpu-Support-multiple-error-query-modes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1773-drm-xe-vm-Remove-VM_BIND_OP-macro.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1774-drm-amdgpu-disable-smu-v13.0.6-mca-debug-mode-by-def.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1774-drm-xe-uapi-Remove-MMIO-ioctl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1775-Revert-drm-bridge-lt9611-Do-not-generate-HFP-HBP-HSA.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1775-drm-amdgpu-Change-extended-scope-MTYPE-on-GC-9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1775-drm-xe-Fix-xe_exec_queue_is_idle-for-parallel-exec-q.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1776-drm-amdgpu-add-pcs-xgmi-v6.4.0-ras-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1776-drm-xe-Deprecate-XE_EXEC_QUEUE_SET_PROPERTY_COMPUTE_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1777-drm-amdgpu-correct-acclerator-check-architecutre-dum.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1777-drm-xe-Rename-exec_queue_kill_compute-to-xe_vm_remov.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1778-drm-amdgpu-correct-mca-debugfs-dump-reg-list.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1778-drm-xe-Remove-XE_EXEC_QUEUE_SET_PROPERTY_COMPUTE_MOD.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1779-drm-amd-display-remove-duplicated-argument.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1779-drm-xe-uapi-Use-common-drm_xe_ext_set_property-exten.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1780-drm-xe-Kill-XE_VM_PROPERTY_BIND_OP_ERROR_CAPTURE_ADD.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1781-drm-amdgpu-add-smu-v13.0.6-pcs-xgmi-ras-error-query-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1781-drm-xe-uapi-Kill-DRM_XE_UFENCE_WAIT_VM_ERROR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1782-drm-amdgpu-Use-correct-KIQ-MEC-engine-for-gfx9.4.3-v.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1782-drm-xe-Remove-async-worker-and-rework-sync-binds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1783-drm-amdgpu-Change-WREG32_RLC-to-WREG32_SOC15_RLC-whe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1783-drm-xe-Fix-VM-bind-out-sync-signaling-ordering.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1784-drm-amd-Explicitly-check-for-GFXOFF-to-be-enabled-fo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1784-drm-amd-pm-disable-the-SMU13-OD-feature-support-temp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1784-drm-xe-uapi-Document-drm_xe_query_gt.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1785-drm-amdgpu-move-kfd_resume-before-the-ip-late-init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1785-drm-xe-uapi-Replace-useless-instance-per-unique-gt_i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1786-drm-amd-pm-Fix-SMU-v13.0.6-energy-reporting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1786-drm-amdgpu-move-UVD-and-VCE-sched-entity-init-after-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1786-drm-xe-uapi-Remove-unused-field-of-drm_xe_query_gt.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1787-drm-xe-uapi-Rename-gts-to-gt_list.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1788-drm-xe-uapi-Fix-naming-of-XE_QUERY_CONFIG_MAX_EXEC_Q.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1789-drm-amdgpu-gfx11-only-enable-CP-GFX-shadowing-on-SR-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1789-drm-xe-guc-Bump-PVC-GuC-version-to-70.9.1.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1789-fbdev-omapfb-Do-not-shadow-error-code-from-platform_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1790-drm-amdkfd-ignore-crat-by-default.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1790-drm-xe-fix-pat-2-programming-with-2M-1G-pages.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1790-fbdev-omapfb-Replace-custom-memparse-implementation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1791-drm-amdkfd-disable-IOMMUv2-support-for-KV-CZ.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1791-drm-xe-Simplify-xe_res_get_buddy.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1791-fbdev-offb-Simplify-offb_init_fb.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1792-drm-amdkfd-disable-IOMMUv2-support-for-Raven.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1792-drm-xe-xe2-Add-initial-workarounds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1793-drm-xe-Add-performance-tuning-settings-for-MTL-and-X.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1793-fbdev-viafb-use-new-array-copying-wrapper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1794-drm-xe-Add-event-tracing-for-CTB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1795-drm-i915-fix-display-probe-for-IVB-Q-and-IVB-D-GT2-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1795-drm-xe-trace-Optimize-trace-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1796-drm-panel-JDI-LT070ME05000-simplify-with-dev_err_pro.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1796-drm-xe-Prepare-to-emit-non-register-state-while-reco.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1796-fbdev-atmel_lcdfb-Stop-using-platform_driver_probe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1797-drm-xe-Emit-SVG-state-on-RCS-during-driver-load-on-D.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1797-fbdev-omapfb-analog-tv-Don-t-put-.remove-in-.exit.te.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1798-drm-xe-xe2-Update-SVG-state-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1798-fbdev-omapfb-dpi-Don-t-put-.remove-in-.exit.text-and.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1799-drm-xe-mocs-MOCS-registers-are-multicast-on-Xe_HP-an.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1799-fbdev-omapfb-dsi-cm-Don-t-put-.remove-in-.exit.text-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1800-drm-amd-pm-disallow-the-fan-setting-if-there-is-no-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1800-drm-xe-Extend-rpX-values-extraction-for-future-platf.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1800-fbdev-omapfb-dvi-Don-t-put-.remove-in-.exit.text-and.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1801-drm-amdgpu-disable-mcbp-if-parameter-zero-is-set.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1801-drm-xe-uc-Prepare-for-parsing-of-different-header-ty.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1801-fbdev-omapfb-hdmi-Don-t-put-.remove-in-.exit.text-an.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1802-drm-xe-huc-Extract-version-and-binary-offset-from-ne.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1802-fbdev-omapfb-opa362-Don-t-put-.remove-in-.exit.text-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1803-drm-xe-huc-HuC-is-not-supported-on-GTs-that-don-t-ha.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1803-fbdev-omapfb-sharp-ls037v7dw01-Don-t-put-.remove-in-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1804-drm-amd-pm-Update-pci-link-width-for-smu-v13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1804-drm-xe-huc-Don-t-re-auth-HuC-if-it-s-already-authent.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1804-fbdev-omapfb-tfp410-Don-t-put-.remove-in-.exit.text-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1805-drm-amdgpu-skip-xcp-drm-device-allocation-when-out-o.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1805-drm-xe-huc-Define-HuC-for-MTL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1805-fbdev-omapfb-tpd12s015-Don-t-put-.remove-in-.exit.te.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1806-drm-xe-Fix-WA-14010918519-write-to-wrong-register.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1806-fbdev-atmel_lcdfb-Convert-to-platform-remove-callbac.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1807-drm-xe-xe_exec_queue-Add-check-for-access-counter-gr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1807-fbdev-omapfb-analog-tv-Convert-to-platform-remove-ca.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1808-drm-xe-xelpmp-Extend-Wa_22016670082-to-Xe_LPM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1808-fbdev-omapfb-dpi-Convert-to-platform-remove-callback.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1809-drm-xe-migrate-fix-MI_ARB_ON_OFF-usage.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1809-fbdev-omapfb-dsi-cm-Convert-to-platform-remove-callb.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1810-drm-xe-bo-consider-dma-resv-fences-for-clear-job.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1810-fbdev-amifb-Replace-zero-length-arrays-with-DECLARE_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1810-fbdev-omapfb-dvi-Convert-to-platform-remove-callback.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1811-drm-xe-bo-sync-kernel-fences-for-KMD-buffers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1811-fbdev-omapfb-hdmi-Convert-to-platform-remove-callbac.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1812-drm-xe-hwmon-Add-kernel-doc-and-refactor-xe-hwmon.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1812-fbdev-omapfb-opa362-Convert-to-platform-remove-callb.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1812-fbdev-ssd1307fb-Print-the-PWM-s-label-instead-of-its.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1813-drm-xe-hwmon-Protect-hwmon-rw-attributes-with-hwmon_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1813-fbdev-kyro-Remove-unused-declarations.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1813-fbdev-omapfb-sharp-ls037v7dw01-Convert-to-platform-r.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1814-drm-xe-hwmon-Expose-power1_max_interval.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1814-fbdev-atmel_lcdfb-Remove-redundant-of_match_ptr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1814-fbdev-omapfb-tfp410-Convert-to-platform-remove-callb.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1815-drm-xe-Replace-xe_ttm_vram_mgr.tile-with-xe_mem_regi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1815-fbdev-omapfb-tpd12s015-Convert-to-platform-remove-ca.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1816-drm-bridge-samsung-dsim-Fix-init-during-host-transfe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1816-drm-xe-Remove-unused-xe_bo_to_tile.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1816-fbdev-hyperv_fb-fix-uninitialized-local-variable-use.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1817-drm-xe-Replace-usage-of-mem_type_to_tile.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1817-fbdev-amifb-Mark-driver-struct-with-__refdata-to-pre.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1818-drm-xe-Dump-CTB-during-TLB-timeout.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1818-fbdev-amifb-Convert-to-platform-remove-callback-retu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1819-drm-xe-Adjust-tile_present-mask-when-skipping-rebind.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1820-drm-ci-make-github-dependabot-happy-again.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1820-drm-xe-Fix-dequeue-of-access-counter-work-item.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1821-drm-xe-xe2-Program-correct-MOCS-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1821-nouveau-gsp-r535-uninitialized-variable-in-r535_gsp_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1822-drm-xe-mtl-Use-16.67-Mhz-freq-scale-factor-to-get-rp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1822-nouveau-gsp-r535-Fix-a-NULL-vs-error-pointer-bug.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1823-drm-i915-fix-Sphinx-indentation-warning.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1823-drm-xe-Add-Wa_14019821291.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1824-drm-panel-orientation-quirks-Add-quirk-for-Lenovo-Le.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1824-drm-xe-stringify-the-argument-to-avoid-potential-vul.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1825-drm-i915-Fix-HPD-polling-reenabling-the-output-poll-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1825-drm-xe-implement-driver-initiated-function-reset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1825-nouveau-don-t-fail-driver-load-if-no-display-hw-pres.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1826-drm-xe-Fix-pagefault-and-access-counter-worker-funct.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1827-drm-xe-Update-SPDX-deprecated-license-identifier.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1828-drm-xe-xelpmp-Add-Wa_16021867713.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1829-drm-amdgpu-Address-member-ring-not-described-in-amdg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1829-drm-xe-Fix-unbind-of-unaccessed-VMA-fault-mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1830-drm-xe-move-the-lmem-verification-code-into-a-separa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1831-drm-xe-clear-the-serviced-bits-on-INTR_IDENTITY_REG.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1832-drm-amd-pm-Update-metric-table-for-smu-v13_0_6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1832-drm-xe-Add-Wa_14019877138.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1833-drm-amd-pm-Fill-pcie-error-counters-for-gpu-v1_4.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1833-drm-xe-gsc-enable-pvc-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1834-drm-amd-display-Add-null-checks-for-8K60-lightup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1834-drm-xe-tests-Fix-migrate-test.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1835-drm-xe-Drop-EXECLIST_CONTROL-from-error-state-dump.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1836-drm-amd-display-fix-NULL-dereference.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1836-drm-xe-Fix-build-with-KUNIT-m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1837-drm-xe-Raise-GT-frequency-before-GuC-HuC-load.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1838-drm-xe-Use-pool-of-ordered-wq-for-GuC-submission.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1839-drm-amdgpu-fix-ras-err_data-null-pointer-issue-in-am.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1839-drm-xe-display-Implement-display-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1840-drm-amd-pm-Don-t-send-unload-message-for-reset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1840-drm-xe-display-Improve-s2idle-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1841-drm-amd-display-Negate-IPS-allow-and-commit-bits.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1841-drm-xe-display-Silence-kernel-doc-warnings-related-t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1842-drm-amdgpu-add-and-populate-the-port-num-into-xgmi-t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1842-drm-xe-display-ensure-clear-color-surfaces-are-cpu-m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1843-drm-xe-display-fix-error-handling-flow-when-device-p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1844-drm-amd-display-Fix-encoder-disable-logic.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1844-drm-xe-display-Use-acpi_target_system_state-only-if-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1845-drm-amdgpu-gmc11-fix-logic-typo-in-AGP-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1845-drm-xe-display-Add-struct-i915_active-for-Xe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1846-drm-amdgpu-add-a-module-parameter-to-control-the-AGP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1846-drm-xe-display-Add-macro-to-get-i915-device-from-xe_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1847-drm-amdgpu-gmc11-disable-AGP-aperture.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1847-drm-xe-display-Add-frontbuffer-setter-getter-for-xe_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1848-drm-amdgpu-gmc10-disable-AGP-aperture.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1848-drm-xe-display-Add-i915_active.h-compatibility-heade.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1849-drm-amdgpu-gmc9-disable-AGP-aperture.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1849-drm-xe-display-Add-empty-def-for-i915_gem_object_flu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1850-drm-xe-display-Add-empty-define-for-i915_ggtt_clear_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1851-drm-msm-remove-exra-drm_kms_helper_poll_init-call.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1851-drm-xe-display-Xe-stolen-memory-handling-for-fbc-sup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1852-drm-xe-display-Add-i915_gem.h-compatibility-header.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1853-drm-msm-dp-don-t-touch-DP-subconnector-property-in-e.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1853-drm-xe-display-Add-Xe-implementation-for-fence-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1854-drm-msm-dp-attach-the-DP-subconnector-property.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1854-drm-xe-display-Create-a-dummy-version-for-vga-decode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1855-drm-msm-remove-unnecessary-NULL-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1855-drm-xe-hdcp-Define-intel_hdcp_gsc_check_status-in-Xe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1856-drm-xe-display-Don-t-try-to-use-vram-if-not-availabl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1857-drm-xe-display-Add-writing-of-remapped-dpt.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1858-drm-xe-guc-Promote-guc_to_gt-xe-helpers-to-.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1859-drm-xe-uapi-Remove-useless-XE_QUERY_CONFIG_NUM_PARAM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1860-drm-xe-uapi-Remove-GT_TYPE_REMOTE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1861-drm-xe-uapi-Kill-VM_MADVISE-IOCTL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1862-drm-xe-uapi-Remove-unused-inaccessible-memory-region.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1862-nouveau-gsp-allocate-enough-space-for-all-channel-id.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1863-drm-i915-dp_mst-Fix-race-between-connector-registrat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1863-drm-xe-uapi-Remove-unused-QUERY_CONFIG_MEM_REGION_CO.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1864-drm-xe-uapi-Remove-unused-QUERY_CONFIG_GT_COUNT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1865-drm-xe-pmu-Drop-interrupt-pmu-event.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1866-drm-xe-Make-xe_mmio_tile_vram_size-static.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1867-drm-xe-uapi-Add-missing-DRM_-prefix-in-uAPI-constant.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1868-drm-bridge-panel-Check-device-dependency-before-mana.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1868-drm-xe-uapi-Add-_FLAG-to-uAPI-constants-usable-for-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1869-drm-xe-uapi-Change-rsvd-to-pad-in-struct-drm_xe_clas.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1870-Revert-drm-bridge-panel-Check-device-dependency-befo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1870-drm-xe-uapi-Rename-_mem_regions-masks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1871-Revert-drm-bridge-panel-Add-a-device-link-between-dr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1871-drm-xe-uapi-Rename-query-s-mem_usage-to-mem_regions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1872-drm-gpuvm-Fix-deprecated-license-identifier.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1872-drm-xe-uapi-Standardize-the-FLAG-naming-and-assignme.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1873-drm-xe-uapi-Differentiate-WAIT_OP-from-WAIT_MASK.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1874-drm-xe-uapi-Be-more-specific-about-the-vm_bind-prefe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1874-nouveau-gsp-r535-remove-a-stray-unlock-in-r535_gsp_r.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1875-drm-xe-dg2-Wa_18028616096-now-applies-to-all-DG2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1875-nouveau-gsp-replace-zero-length-array-with-flex-arra.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1876-drm-xe-guc-Fix-wrong-assert-about-full_len.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1877-drm-xe-guc-Copy-response-data-from-proper-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1878-drm-xe-guc-Fix-handling-of-GUC_HXG_TYPE_NO_RESPONSE_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1879-drm-amd-display-Add-z-state-support-policy-for-dcn35.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1879-drm-xe-guc-Use-valid-scratch-register-for-posting-re.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1880-drm-amdgpu-update-xgmi-num-links-info-post-gc9.4.2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1880-drm-xe-bo-don-t-hold-dma-resv-lock-over-drm_gem_hand.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1881-drm-amd-display-Update-DCN35-watermarks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1881-drm-xe-Fold-GEN11_MOCS_ENTRIES-into-gen12_mocs_desc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1882-drm-amd-display-fix-a-pipe-mapping-error-in-dcn32_fp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1882-drm-xe-mocs-Bring-comment-about-mocs-back-to-reality.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1883-drm-amdgpu-optimize-RLC-powerdown-notification-on-Va.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1883-drm-xe-Remove-GEN-0-9-_-prefixes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1884-drm-amd-display-Add-Z8-watermarks-for-DML2-bbox-over.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1884-drm-xe-Only-set-xe_vma_op.map-fields-for-GPUVA-map-o.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1885-drm-xe-Include-RPL-U-to-pciidlist.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1886-drm-xe-Add-missing-RPL-and-ADL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1887-drm-amd-display-Feed-SR-and-Z8-watermarks-into-DML2-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1887-drm-xe-ATS-M-device-ID-update.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1888-drm-amd-display-Fix-MPCC-1DLUT-programming.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1888-drm-xe-Fix-modpost-warning-on-kunit-modules.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1889-drm-xe-Add-mocs-kunit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1890-drm-amd-display-Do-not-read-DPREFCLK-spread-info-fro.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1890-drm-xe-mmio-Move-xe_mmio_wait32-to-xe_mmio.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1891-drm-xe-mmio-Make-xe_mmio_wait32-aware-of-interrupts.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1892-drm-xe-xe2-Add-workaround-14017421178.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1893-drm-amdgpu-add-init_registers-for-nbio-v7.11.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1893-drm-xe-xe2-Add-workaround-16021867713.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1894-drm-xe-xe2-Add-workaround-14019449301.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1895-drm-xe-Add-device-flag-to-indicate-SR-IOV-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1896-drm-xe-Prepare-for-running-in-different-SR-IOV-modes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1897-drm-xe-Print-virtualization-mode-during-probe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1898-drm-xe-Ensure-that-we-don-t-access-the-placements-ar.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1899-drm-amd-display-Update-DCN35-clock-table-policy.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1899-drm-xe-bo-Rename-xe_bo_get_sg-to-xe_bo_sg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1900-drm-amd-display-Remove-config-update.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1900-drm-xe-bo-Remove-leftover-trace_printk.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1901-drm-xe-vm-Fix-ASID-XA-usage.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1902-drm-amd-display-Fix-conversions-between-bytes-and-KB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1902-drm-xe-Internally-change-the-compute_mode-and-no_dma.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1903-drm-amd-display-Fix-black-screen-on-video-playback-w.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1903-drm-xe-Sync-MTL-PCI-IDs-with-i915.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1904-drm-xe-dg2-Drop-Wa_22014600077.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1905-drm-xe-xe2-Add-workaround-14020013138.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1906-drm-amdgpu-fix-AGP-addressing-when-GART-is-not-at-0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1906-drm-xe-Encapsulate-all-the-module-parameters.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1907-drm-xe-uc-Rework-uC-version-tracking.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1908-drm-xe-gsc-Introduce-GSC-FW.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1909-drm-xe-gsc-Parse-GSC-FW-header.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1910-drm-amd-display-Allow-DTBCLK-disable-for-DCN35.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1910-drm-xe-gsc-GSC-FW-load.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1911-drm-xe-gsc-Implement-WA-14015076503.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1912-drm-xe-gsc-Trigger-a-driver-flr-to-cleanup-the-GSC-o.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1913-drm-amd-display-Fix-some-HostVM-parameters-in-DML.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1913-drm-xe-gsc-Query-GSC-compatibility-version.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1914-drm-xe-gsc-Define-GSCCS-for-MTL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1915-drm-xe-gsc-Define-GSC-FW-for-MTL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1916-drm-i915-Check-pipe-active-state-in-planes-vrr-_-ena.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1916-drm-xe-fix-mem_access-for-early-lrc-generation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1917-drm-xe-kunit-Return-number-of-iterated-devices.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1918-drm-xe-uapi-Add-support-for-CPU-caching-mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1919-drm-xe-pat-annotate-pat_index-with-coherency-mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1920-drm-i915-correct-the-input-parameter-on-_intel_dsb_c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1920-drm-xe-uapi-support-pat_index-selection-with-vm_bind.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1921-drm-xe-explicitly-set-GGTT-access-for-GuC-DMA.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1921-nouveau-gsp-document-some-aspects-of-GSP-RM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1922-drm-xe-guc-Drop-ancient-GuC-CTB-definitions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1923-drm-panfrost-Consider-dma-buf-imported-objects-as-re.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1923-drm-xe-guc-Remove-obsolete-GuC-CTB-documentation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1924-drm-panfrost-Fix-incorrect-updating-of-current-devic.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1924-drm-xe-guc-Include-only-required-GuC-ABI-headers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1925-drm-xe-doc-Include-documentation-about-xe_assert.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1926-drm-xe-Rename-xe_gt_idle_sysfs-to-xe_gt_idle.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1927-accel-ivpu-avoid-build-failure-with-CONFIG_PM-n.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1927-drm-xe-Add-skip_guc_pc-flag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1928-drm-amd-display-Use-channel_width-2-for-vram-table-3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1928-drm-xe-Manually-setup-C6-when-skip_guc_pc-is-set.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1929-drm-xe-mocs-update-MOCS-table-for-xe2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1930-drm-amd-display-Fix-array-index-out-of-bounds-in-dml.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1930-drm-xe-add-skip_pcode-flag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1931-drm-amd-swsmu-update-smu-v14_0_0-driver-if-version-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1931-drm-xe-rename-bypass_mtcfg-to-skip_mtcfg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1932-drm-amd-pm-support-new-mca-smu-error-code-decoding.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1932-drm-xe-Fix-header-guard-warning.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1933-drm-amdgpu-Update-fw-version-for-boot-time-error-que.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1933-drm-xe-Skip-calling-drm_dev_put-on-probe-error.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1934-drm-amdgpu-optimize-the-printing-order-of-error-data.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1934-drm-xe-Use-managed-pci_enable_device.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1935-drm-xe-irq-Don-t-call-pci_free_irq_vectors.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1936-drm-amdgpu-Restrict-extended-wait-to-PSP-v13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1936-drm-xe-Move-xe_set_dma_info-outside-of-MMIO-setup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1937-drm-xe-Move-xe_mmio_probe_tiles-outside-of-MMIO-setu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1938-drm-amdgpu-Update-HDP-4.4.2-clock-gating-flags.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1938-drm-xe-Support-device-page-faults-on-integrated-plat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1939-drm-amdgpu-Avoid-querying-DRM-MGCG-status.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1939-drm-xe-xe2-Respond-to-TRTT-faults-as-unsuccessful-pa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1940-drm-amdgpu-fix-buffer-funcs-setting-order-on-suspend.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1940-drm-xe-xe2-Add-workaround-16020292621.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1941-drm-xe-dsb-DSB-implementation-for-xe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1942-drm-xe-Split-xe_info_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1943-drm-xe-Introduce-xe_tile_init_early-and-use-at-earli.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1943-mei-pxp-fix-mei_pxp_send_message-return-value.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1944-drm-xe-Map-the-entire-BAR0-and-hold-onto-the-initial.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1945-drm-xe-device-Introduce-xe_device_probe_early.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1946-drm-mediatek-mtk_disp_gamma-Fix-breakage-due-to-merg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1946-drm-xe-Don-t-peek-into-GMD_ID.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1947-drm-xe-Move-system-memory-management-init-to-earlier.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1948-drm-xe-Move-force_wake-init-to-earlier-point-in-prob.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1949-drm-xe-Reorder-GGTT-init-to-earlier-point-in-probe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1950-drm-xe-Add-a-helper-for-DRM-device-lifetime-BO-creat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1951-drm-xe-uc-Split-xe_uc_fw_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1952-drm-xe-uc-Store-firmware-binary-in-system-memory-bac.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1953-drm-xe-uc-Extract-xe_uc_sanitize_reset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1954-drm-xe-guc-Split-GuC-params-used-for-hwconfig-and-po.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1955-drm-xe-add-some-debug-info-for-d3cold.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1956-drm-amdgpu-fix-buffer-funcs-setting-order-on-suspend.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1956-drm-xe-Extend-drm_xe_vm_bind_op.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1957-drm-amd-pm-fix-pp_-clk_od-typo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1957-drm-xe-uapi-Separate-bo_create-placement-from-flags.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1958-drm-amd-display-fix-hw-rotated-modes-when-PSR-SU-is-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1958-drm-xe-Make-DRM_XE_DEVICE_QUERY_ENGINES-future-proof.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1959-drm-xe-uapi-Reject-bo-creation-of-unaligned-size.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1960-drm-amdgpu-jpeg-configure-doorbell-for-each-playback.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1960-drm-xe-uapi-Align-on-a-common-way-to-return-arrays-m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1961-drm-amd-display-Revert-Fix-conversions-between-bytes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1961-drm-xe-uapi-Align-on-a-common-way-to-return-arrays-g.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1962-drm-amd-display-Populate-dtbclk-from-bounding-box.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1962-drm-xe-uapi-Align-on-a-common-way-to-return-arrays-e.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1963-drm-xe-uapi-Split-xe_sync-types-from-flags.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/1964-drm-xe-uapi-Kill-tile_mask.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1965-drm-amd-Fix-a-probing-order-problem-on-SDMA-2.4.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1965-drm-xe-uapi-Crystal-Reference-Clock-updates.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1966-drm-xe-uapi-Add-Tile-ID-information-to-the-GT-info-q.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1967-drm-amdgpu-warn-when-there-are-still-mappings-when-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1967-drm-xe-uapi-Fix-various-struct-padding-for-64b-align.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1968-drm-xe-uapi-Move-xe_exec-after-xe_exec_queue.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1969-drm-xe-uapi-Use-LR-abbrev-for-long-running-vms.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1970-drm-xe-Remove-unused-extension-definition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1971-drm-xe-uapi-Kill-exec_queue_set_property.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1972-drm-panel-ltk050h3146w-Set-burst-mode-for-ltk050h314.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1972-drm-xe-Expand-XE_REG_OPTION_MASKED-documentation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1973-drm-nouveau-Fixup-gk20a-instobj-hierarchy.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1973-drm-xe-kunit-Remove-handling-of-XE_TEST_SUBPLATFORM_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1974-drm-nouveau-kms-nv50-Don-t-allow-inheritance-of-head.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1974-drm-xe-kunit-Move-fake-pci-data-to-test-priv.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1975-drm-amd-display-Revert-drm-amd-display-Use-channel_w.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1975-drm-xe-kunit-Add-stub-to-read_gmdid.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1976-drm-xe-kunit-Test-WAs-for-MTL-and-LNL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1977-drm-amd-display-disable-FPO-and-SubVP-for-older-DMUB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1977-drm-xe-huc-Prepare-for-2-step-HuC-authentication.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1978-drm-xe-huc-HuC-authentication-via-GSC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1979-drm-xe-xe2-Add-workaround-14019988906.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1980-drm-amd-display-dereference-variable-before-checking.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1980-drm-xe-xe2-Add-workaround-18032095049-and-1602163944.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1981-drm-xe-Enable-Fixed-CCS-mode-setting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1982-drm-i915-display-Get-bigjoiner-config-before-dsc-con.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1982-drm-xe-Allow-userspace-to-configure-CCS-mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1983-drm-xe-Avoid-any-races-around-ccs_mode-update.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1984-drm-xe-Define-DRM_XE_DEBUG_SRIOV-config.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1985-drm-xe-Introduce-SR-IOV-logging-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1986-drm-xe-pf-Introduce-Local-Memory-Translation-Table.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1987-drm-xe-kunit-Enable-CONFIG_PCI_IOV-in-.kunitconfig.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1988-drm-xe-kunit-Add-test-for-LMTT-operations.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1989-drm-xe-Rename-info.supports_-to-info.has_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1990-drm-xe-vm-Avoid-asid-lookup-if-none-allocated.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1991-drm-xe-Change-the-name-of-frequency-sysfs-attributes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1992-drm-xe-Create-a-xe_gt_freq-component-for-raw-managem.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1993-drm-xe-Add-frequency-throttle-reasons-sysfs-attribut.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1994-drm-amd-pm-Use-separate-metric-table-for-APU.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/1994-drm-xe-Restrict-huge-PTEs-to-1GiB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1995-drm-amd-pm-Update-metric-table-for-jpeg-vcn-data.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1995-drm-xe-Use-NULL-PTEs-as-scratch-PTEs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1996-drm-xe-Check-skip_guc_pc-before-disabling-gucrc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1997-drm-xe-Fix-lockdep-warning-in-xe_force_wake-calls.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1998-drm-xe-Use-DRM-GPUVM-helpers-for-external-and-evicte.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/1999-drm-amd-pm-Add-mem_busy_percent-for-GCv9.4.3-apu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/1999-drm-xe-Use-DRM_GPUVM_RESV_PROTECTED-for-gpuvm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2000-drm-amd-pm-Add-gpu_metrics_v1_5.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/2000-drm-xe-Use-a-flags-field-instead-of-bools-for-VMA-cr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2001-drm-amd-pm-Use-gpu_metrics_v1_5-for-SMUv13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/2001-drm-xe-Use-a-flags-field-instead-of-bools-for-sync-p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2002-drm-xe-Remove-vram-size-info-from-sysfs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2002-nouveau-gsp-add-three-notifier-callbacks-that-we-see.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/2003-drm-xe-Allow-num_batch_buffer-num_binds-0-in-IOCTLs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2003-nouveau-gsp-drop-some-acpi-related-debug.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/2004-drm-xe-Remove-duplicate-RING_MAX_NONPRIV_SLOTS-defin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2004-nouveau-fix-disp-disabling-with-GSP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/2005-drm-xe-xe2-Determine-bios-enablement-for-flat-ccs-on.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2005-nouveau-gsp-free-acpi-object-after-use.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/2006-drm-xe-xe2-Modify-main-memory-to-ccs-memory-ratio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2006-nouveau-gsp-free-userd-allocation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/2007-drm-nouveau-gsp-Fix-ACPI-MXDM-MXDS-method-invocation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/2007-drm-xe-xe2-Allocate-extra-pages-for-ccs-during-bo-cr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2008-drm-xe-xe2-Updates-on-XY_CTRL_SURF_COPY_BLT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2008-nouveau-gsp-convert-gsp-errors-to-generic-errors.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/2009-drm-xe-xe_migrate-Use-NULL-1G-PTE-mapped-at-255GiB-V.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2009-nouveau-gsp-don-t-free-ctrl-messages-on-errors.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/2010-drm-xe-xe2-Update-chunk-size-for-each-iteration-of-c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2010-nouveau-gsp-always-free-the-alloc-messages-on-r535.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/2011-drm-xe-xe2-Update-emit_pte-to-use-compression-enable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2011-nouveau-push-event-block-allowing-out-of-the-fence-c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/2012-drm-nouveau-dp-Honor-GSP-link-training-retry-timeout.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/2012-drm-xe-xe2-Handle-flat-ccs-move-for-igfx.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2013-drm-xe-xe2-Modify-xe_bo_test-for-system-memory.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2014-drm-xe-xe2-Support-flat-ccs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2015-drm-xe-Drop-_REG-suffix-from-CSFE_CHICKEN1.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2016-drm-xe-Move-some-per-engine-register-definitions-to-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2017-drm-xe-Fix-whitespace-in-register-definitions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2018-drm-xe-Move-engine-base-offsets-to-engine-register-h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2019-drm-xe-Move-GSC-HECI-base-offsets-out-of-register-he.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2020-drm-xe-Define-interrupt-vector-bits-with-the-interru.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2021-drm-xe-Re-sort-GT-register-header.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2022-drm-xe-Drop-some-unnecessary-header-includes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2023-drm-xe-Return-error-if-drm_buddy_init-fails.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2024-drm-xe-bo-Remove-unusued-variable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2025-drm-xe-display-Fix-dummy-__i915_inject_probe_error.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2026-drm-xe-Enable-W-1-warnings-by-default.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2027-drm-xe-uapi-add-exec_queue_id-member-to-drm_xe_wait_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2028-drm-xe-uapi-Return-correct-error-code-for-xe_wait_us.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2029-drm-xe-uapi-Remove-DRM_IOCTL_XE_EXEC_QUEUE_SET_PROPE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2030-drm-xe-uapi-Remove-DRM_XE_UFENCE_WAIT_MASK_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2031-drm-xe-pmu-Remove-PMU-from-Xe-till-uapi-is-finalized.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2032-drm-xe-uapi-Ensure-every-uapi-struct-has-drm_xe-pref.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2033-drm-xe-uapi-Remove-sync-binds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2034-drm-xe-uapi-Add-a-comment-to-each-struct.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2035-drm-xe-uapi-Add-missing-documentation-for-struct-mem.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2036-drm-xe-uapi-Document-use-of-size-in-drm_xe_device_qu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2037-drm-xe-uapi-Document-drm_xe_query_config-keys.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2038-drm-xe-uapi-Document-DRM_XE_DEVICE_QUERY_HWCONFIG.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2039-drm-xe-uapi-Make-constant-comments-visible-in-kernel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2040-drm-xe-uapi-Order-sections.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2041-drm-xe-uapi-More-uAPI-documentation-additions-and-co.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2042-drm-xe-uapi-Document-the-memory_region-bitmask.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2043-drm-xe-uapi-Add-block-diagram-of-a-device.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2044-drm-xe-uapi-Add-examples-of-user-space-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2045-drm-xe-uapi-Move-CPU_CACHING-defines-before-doc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2046-drm-xe-uapi-Move-DRM_XE_ACC_GRANULARITY_-where-they-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2047-drm-xe-uapi-Remove-reset-uevent-for-now.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2048-drm-xe-Fix-build-without-CONFIG_FAULT_INJECTION.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2049-drm-xe-Remove-ci-only-GuC-FW-definitions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2050-drm-xe-Remove-uninitialized-variable-from-warning.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2051-drm-xe-Disable-32bits-build.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2052-drm-imagination-Fixed-infinite-loop-in-pvr_vm_mips_m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2053-drm-imagination-Fixed-oops-when-misusing-ioctl-CREAT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2054-drm-imagination-Fix-ERR_PTR-test-on-pointer-to-point.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2055-drm-imagination-Fix-error-path-in-pvr_vm_create_cont.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2056-drm-bridge-properly-refcount-DT-nodes-in-aux-bridge-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2058-accel-habanalabs-add-pcie-reset-prepare-done-hooks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2059-accel-habanalabs-update-device-boot-error-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2060-accel-habanalabs-gaudi2-assume-hard-reset-by-FW-upon.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2061-accel-habanalabs-add-log-when-eq-event-is-not-receiv.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2063-accel-habanalabs-fix-EQ-heartbeat-mechanism.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2064-accel-habanalabs-gaudi2-fix-undef-opcode-reporting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2065-accel-habanalabs-remove-get-temperature-debug-print.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2066-accel-habanalabs-set-hard-reset-flag-if-graceful-res.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2067-accel-habanalabs-gaudi2-get-the-correct-QM-CQ-info-u.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2068-accel-habanalabs-print-error-code-when-mapping-fails.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2069-accel-habanalabs-update-sysfs-driver-habanalabs-with.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2070-accel-habanalabs-expose-module-id-through-sysfs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2071-accel-habanalabs-gaudi2-use-correct-registers-to-dum.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2072-accel-habanalabs-gaudi2-add-signed-dev-info-uAPI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2073-accel-habanalabs-report-3-instances-of-Infineon-seco.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2074-accel-habanalabs-gaudi2-add-zero-padding-when-printi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2075-accel-habanalabs-add-parent_device-sysfs-attribute.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2076-accel-habanalabs-gaudi2-avoid-overriding-existing-un.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2076-accel-ivpu-37xx-Fix-interrupt_clear_with_0-WA-initia.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2078-drm-xe-Fix-UBSAN-splat-in-add_preempt_fences.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2079-drm-xe-Fix-warning-on-impossible-condition.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2081-drm-Warn-when-freeing-a-framebuffer-that-s-still-on-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2082-drm-rockchip-vop2-Avoid-use-regmap_reinit_cache-at-r.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2083-drm-rockchip-vop2-clean-up-some-inconsistent-indenti.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2084-drm-gpuvm-fix-all-kernel-doc-warnings-in-include-drm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2085-drm-imagination-pvr_device.h-fix-all-kernel-doc-warn.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2086-drm-amd-display-Unify-optimize_required-flags-and-VR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2087-drm-amd-display-Add-function-for-dumping-clk-registe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2088-drm-amd-display-Add-a-new-DC-debug-mask-for-PSR-SU.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2090-Documentation-amdgpu-Add-Hawk-Point-processors.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2091-Documentation-amdgpu-Remove-a-spurious-character.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2092-drm-amd-Add-missing-definitions-for-SMU_MAX_LEVELS_V.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2093-drm-amdkfd-Use-partial-hmm-page-walk-during-buffer-v.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2094-drm-amd-display-skip-error-logging-when-DMUB-is-inac.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2095-drm-amd-display-Set-test_pattern_changed-update-flag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2096-drm-amd-display-add-debug-option-for-ExtendedVBlank-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2100-drm-amd-display-Wake-DMCUB-before-executing-GPINT-co.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2023-52624 bsc#1222083).
- Update
  patches.suse/2101-drm-amd-display-Refactor-dc_state-interface.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2102-drm-amd-display-Refactor-phantom-resource-allocation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2103-drm-amd-display-Fix-null-reference-to-state-when-get.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2104-drm-amd-display-Create-dc_state-after-resource-initi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2105-drm-amd-display-Deep-copy-dml2_context-when-copying-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2106-drm-amd-display-Fix-lightup-regression-with-DP2-sing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2108-drm-amd-display-Fix-hang-underflow-when-transitionin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2023-52671 bsc#1224729).
- Update
  patches.suse/2109-drm-amd-display-change-static-screen-wait-frame_coun.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2110-drm-amd-display-FW-Promotion-Release-0.0.197.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2111-drm-amd-display-3.2.265.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2112-drm-amdgpu-MCA-supports-recording-umc-address-inform.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2113-drm-amdgpu-Add-poison-mode-check-error-condition-for.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2114-drm-amd-pm-smu-v13_0_6-supports-ecc-info-by-default.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2115-drm-amdgpu-Add-umc-page-retirement-for-umc-v12_0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2116-drm-amd-display-remove-redundant-initialization-of-v.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2117-drm-amdgpu-Add-register-read-write-debugfs-support-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2118-drm-amd-display-Disable-IPS-by-default.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2119-drm-amd-display-enable-dcn35-idle-power-optimization.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2121-drm-amd-display-Fix-subvp-drr-logic-errors.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2122-drm-amd-display-Don-t-allow-FPO-if-no-planes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2123-drm-amd-display-Add-more-mechanisms-for-tests.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2124-drm-amd-display-Add-HDMI-capacity-computations-using.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2125-drm-amd-display-Add-null-pointer-guards-where-needed.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2127-drm-amd-display-Correctly-restore-user_level.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2129-drm-amd-display-Assign-stream-status-for-FPO-Vactive.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2130-drm-amd-display-Add-log-end-specifier.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2131-drm-amd-display-Always-exit-DMCUB-idle-when-called.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2132-drm-amd-display-Wait-forever-for-DMCUB-to-wake-up.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2133-drm-amdgpu-gfx11-need-acquire-mutex-before-access-CP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2134-drm-amd-display-Switch-DMCUB-notify-idle-command-to-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2136-drm-amd-display-For-FPO-and-SubVP-DRR-configs-progra.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2137-drm-amd-display-Refactor-INIT-into-component-folder.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2138-drm-amd-display-Fix-Mismatch-between-pipe-and-stream.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2139-drm-amd-display-Verify-disallow-bits-were-cleared-fo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2140-drm-amd-display-Fixing-stream-allocation-regression.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2141-Re-revert-drm-amd-display-Enable-Replay-for-static-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2142-drm-amd-display-Add-some-functions-for-Panel-Replay.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2143-drm-amdgpu-Cleanup-indenting-in-amdgpu_connector_dvi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2144-drm-amdgpu-Use-kzalloc-instead-of-kmalloc-__GFP_ZERO.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2145-drm-amdgpu-Use-kvcalloc-instead-of-kvmalloc_array-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2146-drm-amd-display-Address-function-parameter-context-n.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2147-drm-amd-display-Adjust-kdoc-for-dcn35_hw_block_power.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2148-drm-amdgpu-Drop-redundant-unsigned-0-comparision-amd.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2151-Revert-drm-amdgpu-enable-mca-debug-mode-on-APU-by-de.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2152-drm-amd-display-Removing-duplicate-copyright-text.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2153-drm-amdgpu-Remove-unreachable-code-in-atom_skip_src_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2154-drm-amdgpu-add-param-to-specify-fw-bo-location-for-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2161-drm-amd-display-Fix-hdcp1_execution.c-codestyle.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2162-drm-amd-display-Fix-hdcp_psp.c-codestyle.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2163-drm-amd-display-Fix-freesync.c-codestyle.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2164-drm-amd-display-Fix-hdcp_psp.h-codestyle.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2165-drm-amd-display-Fix-hdcp2_execution.c-codestyle.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2166-drm-amd-display-Fix-hdcp_log.h-codestyle.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2167-drm-amd-display-Fix-power_helpers.c-codestyle.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2170-drm-amd-display-Fix-recent-checkpatch-errors-in-amdg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2171-drm-amd-display-Move-fixpt_from_s3132-to-amdgpu_dm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2174-drm-amd-display-Allow-z8-z10-from-driver.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2175-drm-i915-selftests-Fix-spelling-mistake-initialiased.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2176-drm-i915-uapi-fix-typos-spellos-and-punctuation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2177-drm-i915-Add-Wa_14019877138.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2178-drm-i915-Use-kmap_local_page-in-gem-i915_gem_object..patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2179-drm-i915-Use-memcpy_-from-to-_page-in-gem-i915_gem_p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2180-drm-i915-Use-kmap_local_page-in-gem-i915_gem_shmem.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2181-drm-i915-Use-kmap_local_page-in-gem-selftests-huge_p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2182-drm-i915-Use-kmap_local_page-in-gem-selftests-i915_g.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2183-drm-i915-Use-kmap_local_page-in-gem-selftests-i915_g.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2184-drm-i915-Use-memcpy_from_page-in-gt-uc-intel_uc_fw.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2185-drm-i915-Use-kmap_local_page-in-i915_cmd_parser.c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2186-drm-i915-Use-kmap_local_page-in-gem-i915_gem_execbuf.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2188-fbdev-imxfb-move-PCR-bitfields-near-their-offset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2189-fbdev-imxfb-use-BIT-FIELD_-GET-PREP-and-GENMASK-macr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2190-fbdev-imxfb-replace-some-magic-numbers-with-constant.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2191-fbdev-imxfb-add-missing-SPDX-tag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2192-fbdev-imxfb-drop-ftrace-like-logging.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2193-fbdev-imxfb-add-missing-spaces-after.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2194-fbdev-imxfb-Fix-style-warnings-relating-to-printk.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2195-fbdev-imxfb-use-__func__-for-function-name.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2196-fbdev-imxfb-add-on-a-separate-line-in-block-comment.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2197-fbdev-fsl-diu-fb-Fix-sparse-warning-due-to-virt_to_p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2199-fbdev-hgafb-fix-kernel-doc-comments.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2200-fbdev-Remove-support-for-Carillo-Ranch-driver.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2201-fbdev-amba-clcd-Delete-the-old-CLCD-driver.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2203-fbdev-flush-deferred-IO-before-closing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2204-video-sticore-Store-ROM-device-in-STI-struct.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2205-fbdev-stifb-Allocate-fb_info-instance-with-framebuff.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2206-arch-parisc-Detect-primary-video-device-from-device-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2207-video-sticore-Remove-info-field-from-STI-struct.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2208-video-logo-use-u-format-specifier-for-unsigned-int-v.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2209-fbdev-sis-Remove-dependency-on-screen_info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2210-drm-hyperv-Remove-firmware-framebuffers-with-apertur.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2211-fbdev-hyperv_fb-Remove-firmware-framebuffers-with-ap.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2212-firmware-sysfb-Clear-screen_info-state-after-consumi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2213-fbdev-hyperv_fb-Do-not-clear-global-screen_info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2214-fbdev-intelfb-Remove-driver.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2215-pwm-Rename-pwm_apply_state-to-pwm_apply_might_sleep.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2216-drm-i915-display-Fix-C20-pll-selection-for-state-ver.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2217-drm-i915-dp-Fix-the-PSR-debugfs-entries-wrt.-MST-con.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2218-drm-i915-don-t-make-assumptions-about-intel_wakeref_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2220-drm-i915-gem-reconcile-Excess-struct-member-kernel-d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2221-drm-i915-gt-reconcile-Excess-struct-member-kernel-do.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2222-drm-i915-guc-reconcile-Excess-struct-member-kernel-d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2223-drm-i915-perf-reconcile-Excess-struct-member-kernel-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2224-drm-rockchip-vop2-Drop-superfluous-include.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2225-drm-rockchip-vop2-Drop-unused-if_dclk_rate-variable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2226-drm-v3d-Fix-support-for-register-debugging-on-the-RP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2228-vgacon-drop-IA64-reference-in-VGA_CONSOLE-dependency.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2229-mei-Add-transport-driver-for-IVSC-device.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2230-mei-Add-MEI-hardware-support-for-IVSC-device.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2231-mei-fix-spellos-in-mei.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2232-mei-pxp-spdx-should-be-at-first-line.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2233-mei-vsc-Rework-firmware-image-names.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2234-mei-fix-vsc-dependency.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2235-mei-rework-Kconfig-dependencies.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2236-iommu-tegra-Use-tegra_dev_iommu_get_stream_id-in-the.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2237-backlight-mp3309c-Add-support-for-MPS-MP3309C.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2238-backlight-pwm_bl-Use-dev_err_probe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2239-backlight-mp3309c-Fix-uninitialized-local-variable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2240-backlight-ili922x-Drop-kernel-doc-for-local-macros.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2241-backlight-ili922x-Add-an-error-code-check-in-ili922x.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2243-drm-remove-I2C_CLASS_DDC-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2244-fbdev-remove-I2C_CLASS_DDC-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2245-drm-amd-pm-Remove-I2C_CLASS_SPD-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2248-drm-amd-display-Disconnect-phantom-pipe-OPP-from-OPT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2249-drm-amd-display-revert-for-FPO-SubVP-DRR-config-prog.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2250-drm-amd-display-revert-Optimize-VRR-updates-to-only-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2252-Revert-drm-amd-display-Fix-conversions-between-bytes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2253-drm-amd-display-Update-z8-latency.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2254-drm-amd-display-Dpia-hpd-status-not-in-sync-after-S4.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2255-drm-amd-display-3.2.266.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2256-drm-amdgpu-Drop-unnecessary-sentences-about-CE-and-d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2258-drm-amdgpu-Support-poison-error-injection-via-ras_ct.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2259-drm-amdgpu-Packed-socket_id-to-ras-feature-mask.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2261-drm-amdkfd-Fix-sparse-__rcu-annotation-warnings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2263-drm-amdgpu-make-a-correction-on-comment.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2264-drm-amd-display-cleanup-inconsistent-indenting-in-am.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2268-drm-amdgpu-pm-clarify-debugfs-pm-output.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2269-drm-amdgpu-update-headers-for-nbio-v7.11.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2270-drm-amdgpu-update-ATHUB_MISC_CNTL-offset-for-athub-v.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2272-drm-amdgpu-Do-not-program-VM_L2_CNTL-under-SRIOV.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2274-drm-amdgpu-Fix-unsigned-comparison-with-less-than-ze.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2278-Revert-drm-amdgpu-add-param-to-specify-fw-bo-locatio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2279-drm-amdgpu-add-debug-flag-to-place-fw-bo-on-vram-for.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2280-drm-amdgpu-move-debug-options-init-prior-to-amdgpu-d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2287-drm-amd-display-Init-link-enc-resources-in-dc_state-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2288-drm-amd-display-Add-logging-resource-checks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2290-drm-amd-display-Clear-OPTC-mem-select-on-disable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2295-drm-amdkfd-init-drm_client-with-funcs-hook.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2297-drm-amd-display-Drop-acrtc-and-add-new_crtc_state-NU.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2300-drm-xe-Fix-definition-of-intel_wakeref_t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2301-drm-xe-Fix-exec-IOCTL-long-running-exec-queue-ring-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2302-drm-xe-vm-Fix-an-error-path.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2303-drm-xe-Use-__iomem-for-the-regs-pointer.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2304-drm-xe-Annotate-xe_mem_region-mapping-with-__iomem.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2305-drm-xe-Annotate-multiple-mmio-pointers-with-__iomem.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2306-drm-xe-Annotate-xe_ttm_stolen_mgr-mapping-with-__iom.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2307-drm-xe-Fix-guc_exec_queue_set_priority.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2308-drm-xe-Fix-modifying-exec_queue-priority-in-xe_migra.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2309-drm-xe-Check-skip_guc_pc-before-setting-SLPC-flag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2310-drm-xe-Fix-build-bug-for-GCC-11.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2311-drm-xe-device-clean-up-on-error-in-probe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2312-drm-xe-selftests-Fix-an-error-pointer-dereference-bu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2313-drm-xe-unlock-on-error-path-in-xe_vm_add_compute_exe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2314-drm-xe-migrate-Fix-CCS-copy-for-small-VRAM-copy-chun.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2315-drm-xe-Fix-bounds-checking-in-__xe_bo_placement_for_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2316-drm-xe-display-support-should-not-depend-on-EXPERT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2317-Revert-firmware-sysfb-Clear-screen_info-state-after-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2318-drm-ttm-fix-ttm-pool-initialization-for-no-dma-devic.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2319-fbdev-vt8500lcdfb-Remove-unnecessary-print-function-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2322-fbcon-Fix-incorrect-printed-function-name-in-fbcon_p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2323-fbdev-stifb-Fix-crash-in-stifb_blank.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2326-drm-v3d-Free-the-job-and-assign-it-to-NULL-if-initia.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2327-drm-exynos-fix-incorrect-type-issue.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2330-drm-xe-dmabuf-Make-xe_dmabuf_ops-static.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2331-drm-xe-Use-a-NULL-pointer-instead-of-0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2332-drm-xe-Use-_ULL-for-u64-division.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2333-drm-xe-mmio-Cast-to-u64-when-printing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2334-drm-xe-display-Avoid-calling-readq.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2335-drm-xe-xe2-Use-XE_CACHE_WB-pat-index.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2336-drm-xe-vm-bugfix-in-xe_vm_create_ioctl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2337-drm-xe-Remove-PVC-from-xe_wa-kunit-tests.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2338-drm-amd-pm-udpate-smu-v13.0.6-message-permission.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2344-drm-amdgpu-Fix-null-pointer-dereference.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2349-drm-amd-display-Allow-IPS2-during-Replay.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2350-drm-amd-display-Add-Replay-IPS-register-for-DMUB-com.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2351-drm-amd-display-Add-IPS-checks-before-dcn-register-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2352-drm-amd-display-Replay-IPS-ABM-in-Full-Screen-VPB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2354-drm-amd-Add-a-DC-debug-mask-for-IPS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2355-drm-amd-display-Enable-IPS-by-default.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2356-drm-sched-Drain-all-entities-in-DRM-sched-run-job-wo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2363-drm-ttm-allocate-dummy_read_page-without-DMA32-on-fa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2364-drm-tests-mm-Call-drm_mm_print-in-drm_test_mm_debug.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2367-accel-ivpu-Dump-MMU-events-in-case-of-VPU-boot-timeo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2368-accel-ivpu-Call-diagnose-failure-in-ivpu_mmu_cmdq_sy.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2369-accel-ivpu-Add-debug-prints-for-MMU-map-unmap-operat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2370-accel-ivpu-Add-diagnostic-messages-when-VPU-fails-to.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2371-accel-ivpu-Fix-for-missing-lock-around-drm_gem_shmem.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2372-accel-ivpu-Free-buffer-sgt-on-unbind.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2373-accel-ivpu-Disable-buffer-sharing-among-VPU-contexts.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2374-accel-ivpu-Improve-buffer-object-debug-logs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2375-accel-ivpu-Deprecate-DRM_IVPU_PARAM_CONTEXT_PRIORITY.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2378-drm-dp_mst-Separate-failing_port-list-in-drm_dp_mst_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2380-accel-ivpu-Fix-dev-open-close-races-with-unbind.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2381-accel-ivpu-Improve-stability-of-ivpu_submit_ioctl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2382-accel-ivpu-Improve-recovery-and-reset-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2388-dma-buf-heaps-Don-t-track-CMA-dma-buf-pages-under-Rs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2389-drm-xe-Fix-crash-in-trace_dma_fence_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2390-drm-xe-Grab-mem_access-when-disabling-C6-on-skip_guc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2391-drm-xe-Only-allow-1-ufence-per-exec-bind-IOCTL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2392-drm-xe-Annotate-mcr_-un-lock.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2393-drm-xe-Don-t-use-__user-error-pointers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2394-drm-xe-Use-LRC-prefix-rather-than-CTX-prefix-in-lrc-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2395-drm-xe-vm-Subclass-userptr-vmas.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2396-drm-xe-Make-all-GuC-ABI-shift-values-unsigned.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2398-drm-amdgpu-move-the-drm-client-creation-behind-drm-d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2399-drm-amdkfd-Correct-partial-migration-virtual-addr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2400-drm-amdkfd-Use-S_ENDPGM_SAVED-in-trap-handler.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2402-Revert-drm-amd-display-initialize-all-the-dpm-level-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2405-drm-amd-display-Fix-DPSTREAM-CLK-on-and-off-sequence.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2407-drm-amd-display-Underflow-workaround-by-increasing-S.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2409-drm-amdgpu-Fix-the-warning-info-in-mode1-reset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2415-drm-amdgpu-drm-amdgpu-remove-golden-setting-for-gfx-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2416-drm-amdgpu-remove-asymmetrical-irq-disabling-in-vcn-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2418-drm-amdgpu-pm-Use-inline-function-for-IP-version-che.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2421-drm-sched-Re-queue-run-job-worker-when-drm_sched_ent.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2424-accel-ivpu-Force-snooping-for-MMU-writes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2425-accel-ivpu-Correct-MMU-queue-size-checking-functions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2426-accel-ivpu-Disable-d3hot_delay-on-all-NPU-generation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2427-accel-ivpu-40xx-Enable-D0i3-message.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2428-accel-ivpu-40xx-Stop-passing-SKU-boot-parameters-to-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2429-accel-ivpu-Add-job-status-for-jobs-aborted-by-the-dr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2430-drm-xe-Fix-loop-in-vm_bind_ioctl_ops_unwind.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2431-drm-xe-Take-a-reference-in-xe_exec_queue_last_fence_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2432-drm-xe-Pick-correct-userptr-VMA-to-repin-on-REMAP-op.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2433-drm-xe-circumvent-bogus-stringop-overflow-warning.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2434-drm-xe-Map-both-mem.kernel_bb_pool-and-usm.bb_pool.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2435-drm-xe-display-Fix-memleak-in-display-initialization.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2436-drm-xe-Assume-large-page-size-if-VMA-not-yet-bound.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2437-drm-xe-vm-don-t-ignore-error-when-in_kthread.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2438-drm-xe-Remove-TEST_VM_ASYNC_OPS_ERROR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2439-drm-i915-Replace-dead-01.org-link.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2443-drm-amd-display-set-odm_combine_policy-based-on-cont.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2446-drm-amdgpu-remove-asymmetrical-irq-disabling-in-jpeg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2447-drm-amd-display-Increase-eval-entry-delay-for-DCN35.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2450-drm-amd-display-Update-phantom-pipe-enable-disable-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2451-drm-amd-display-Disable-ODM-by-default-for-DCN35.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2453-drm-amd-display-Clear-phantom-stream-count-and-plane.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2455-drm-amd-display-Implement-bounds-check-for-stream-en.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2024-26660 bsc#1222266).
- Update
  patches.suse/2461-drm-msm-mdss-specify-cfg-bandwidth-for-SDM670.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2462-accel-ivpu-Fix-DevTLB-errors-on-suspend-resume-and-r.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2463-drm-nouveau-don-t-fini-scheduler-if-not-initialized.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2464-drm-nouveau-omit-to-create-schedulers-using-the-lega.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2468-drm-rockchip-vop2-add-a-missing-unlock-in-vop2_crtc_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2472-drm-xe-vm-Avoid-reserving-zero-fences.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2473-drm-xe-display-fix-i915_gem_object_is_shmem-wrapper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2474-drm-xe-pt-Allow-for-stricter-type-and-range-checking.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2475-drm-xe-avoid-function-cast-warnings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2492-drm-amd-display-Increase-ips2_eval-delay-for-DCN35.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2493-drm-amdkfd-update-SIMD-distribution-algo-for-GFXIP-9.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2494-drm-amdgpu-Fix-implicit-assumtion-in-gfx11-debug-fla.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2496-drm-msm-a6xx-set-highest_bank_bit-to-13-for-a610.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2515-drm-xe-uapi-Remove-support-for-persistent-exec_queue.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2516-drm-xe-Fix-xe_vma_set_pte_size.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2517-drm-xe-Add-XE_VMA_PTE_64K-VMA-flag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2518-drm-xe-Return-2MB-page-size-for-compact-64k-PTEs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2519-drm-xe-xe_gt_idle-Drop-redundant-newline-in-name.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2520-drm-xe-Fix-modpost-warning-on-xe_mocs-kunit-module.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2521-nouveau-gsp-add-kconfig-option-to-enable-GSP-paths-b.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2525-drm-bridge-aux-hpd-fix-OF-node-leaks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2526-drm-bridge-aux-hpd-separate-allocation-and-registrat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2528-drm-ttm-tests-depend-on-UML-COMPILE_TEST.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2532-drm-xe-Add-uapi-for-dumpable-bos.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2533-drm-xe-uapi-Remove-DRM_XE_VM_BIND_FLAG_ASYNC-comment.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2534-drm-xe-uapi-Remove-unused-flags.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2535-drm-xe-Fix-execlist-splat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2536-drm-xe-Don-t-support-execlists-in-xe_gt_tlb_invalida.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2537-drm-xe-Use-vmalloc-for-array-of-bind-allocation-in-b.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2538-drm-xe-get-rid-of-MAX_BINDS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2539-drm-xe-mmio-fix-build-warning-for-BAR-resize-on-32-b.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2540-drm-xe-xe_bo_move-Enhance-xe_bo_move-trace.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2541-drm-xe-Use-pointers-in-trace-events.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2542-drm-xe-Expose-user-fence-from-xe_sync_entry.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2543-drm-xe-Deny-unbinds-if-uapi-ufence-pending.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2544-drm-xe-xe_trace-Add-move_lacks_source-detail-to-xe_b.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2545-Revert-drm-msm-dp-use-drm_bridge_hpd_notify-to-repor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2553-fbdev-hyperv_fb-Fix-logic-error-for-Gen2-VMs-in-hvfb.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2560-drm-i915-dp-Fix-connector-DSC-HW-state-readout.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2561-drm-i915-panelreplay-Move-out-psr_init_dpcd-from-ini.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2562-drm-xe-Return-immediately-on-tile_init-failure.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/2570-drm-udl-Add-ARGB8888-as-a-format.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2571-Revert-drm-udl-Add-ARGB8888-as-a-format.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2575-mei-Add-Meteor-Lake-support-for-IVSC-device.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2577-kunit-replace-KUNIT_TRIGGER_STATIC_STUB-maro-with-KU.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/2578-sizes.h-Add-entries-between-SZ_32G-and-SZ_64T.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/Input-ads7846-Convert-to-use-software-nodes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/Partially-revert-drm-amd-display-Fix-possible-underf.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/Revert-Revert-drm-amdgpu-display-change-pipe-p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/Revert-drivers-firmware-Move-sysfb_init-from-device_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/Revert-drm-amd-Disable-PSR-SU-on-Parade-0803-TC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/Revert-drm-amd-display-Enable-Replay-for-static-scre.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/Revert-drm-amd-display-Remove-v_startup-workaround-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/Revert-drm-amd-display-disable-SubVP-DRR-to-pr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/Revert-drm-amd-display-edp-do-not-add-non-edid-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/Revert-drm-amd-display-fix-bandwidth-validation-fail.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/Revert-drm-amd-display-increased-min_dcfclk_mhz-and-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/Revert-drm-amd-pm-fix-the-high-voltage-and-temperatu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/Revert-drm-amd-pm-resolve-reboot-exception-for-si-ol.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2023-52657 bsc#1224722).
- Update
  patches.suse/Revert-drm-amdgpu-Program-xcp_ctl-registers-as-neede.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/Revert-drm-amdkfd-Relocate-TBA-TMA-to-opposite-side-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/Revert-drm-bridge-Add-200ms-delay-to-wait-FW-HPD-sta.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/Revert-drm-i915-dsi-Do-display-on-sequence-later-on-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/Revert-drm-msm-gpu-Push-gpu-lock-down-past-runpm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/Revert-drm-omapdrm-Annotate-dma-fence-critical-secti.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/Revert-drm-prime-Unexport-helpers-for-fd-handle-conv.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/Revert-drm-rockchip-vop2-Use-regcache_sync-to-fix-su.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/Revert-drm-tidss-Annotate-dma-fence-critical-section.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/Revert-nouveau-push-event-block-allowing-out-of-the-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/accel-habanalabs-add-support-for-Gaudi2C-device.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/accel-habanalabs-fix-information-leak-in-sec_attest_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes bsc#1217930 CVE-2023-50431).
- Update
  patches.suse/accel-ivpu-37xx-Fix-hangs-related-to-MMIO-reset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/accel-ivpu-Add-set_pages_array_wc-uc-for-inter.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628).
- Update
  patches.suse/accel-ivpu-Disable-PLL-after-VPU-IP-reset-during-FLR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/accel-ivpu-Don-t-enable-any-tiles-by-default-on-VPU4.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/accel-ivpu-refactor-deprecated-strncpy.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/accel-qaic-Add-consistent-integer-overflow-chec.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628).
- Update
  patches.suse/accel-qaic-Clean-up-integer-overflow-checking-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628).
- Update patches.suse/accel-qaic-Fix-GEM-import-path-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/accel-qaic-Fix-a-leak-in-map_user_pages.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628).
- Update patches.suse/accel-qaic-Fix-slicing-memory-leak.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628).
- Update
  patches.suse/accel-qaic-Implement-quirk-for-SOC_HW_VERSION.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/accel-qaic-tighten-bounds-checking-in-decode_me.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628).
- Update
  patches.suse/accel-qaic-tighten-bounds-checking-in-encode_me.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628).
- Update
  patches.suse/amdgpu-validate-offset_in_bo-of-drm_amdgpu_gem_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/backlight-bd6107-Compare-against-struct-fb_info.devi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/backlight-gpio_backlight-Compare-against-struct-fb_i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/backlight-gpio_backlight-Drop-output-GPIO-direction-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/backlight-hx8357-Convert-to-agnostic-GPIO-API.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/backlight-lp855x-Initialize-PWM-state-on-first-brigh.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/backlight-lv5207lp-Compare-against-struct-fb_info.de.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/backlight-pwm_bl-Disable-PWM-on-shutdown-suspend-and.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/dma-buf-dma-resv-Stop-leaking-on-krealloc-failu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/dma-buf-fix-an-error-pointer-vs-NULL-bug.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/dma-buf-fix-check-in-dma_resv_add_fence.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/dma-buf-keep-the-signaling-time-of-merged-fence.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/dma-buf-sw_sync-Avoid-recursive-lock-during-fe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-Add-an-HPD-poll-helper-to-reschedule-the-p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-Add-fixed-point-helper-to-get-rounded-integ.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-Allow-drivers-to-indicate-the-damage-helpers-to-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-Call-drm_atomic_helper_shutdown-at-shutdown-remo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-Disable-the-cursor-plane-on-atomic-contexts-with.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-Don-t-unref-the-same-fb-many-times-by-mistake-du.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2023-52486 bsc#1221277).
- Update
  patches.suse/drm-Fix-FD-ownership-check-in-drm_master_check_perm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-Fix-TODO-list-mentioning-non-KMS-drivers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-Fix-output-poll-work-for-drm_kms_helper_poll-n.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-Remove-references-to-removed-transitional-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-Update-file-owner-during-use.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-adv7511-Fix-low-refresh-rate-register-for-ADV753.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-Align-SMU11-SMU_MSG_OverridePcieParamet.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-Disable-PP_PCIE_DPM_MASK-when-dynamic-speed-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-Disable-PSR-SU-on-Parade-0803-TCON.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628 bsc#1212848).
- Update
  patches.suse/drm-amd-Disable-S-G-for-APUs-when-64GB-or-more.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628 bsc#1213787).
- Update
  patches.suse/drm-amd-Don-t-init-MEC2-firmware-when-it-fails-to-lo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-Don-t-try-to-enable-secure-display-TA-m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628 bsc#1212848).
- Update patches.suse/drm-amd-Enable-PCIe-PME-from-D3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-Fix-UBSAN-array-index-out-of-bounds-for-Pola.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071 CVE-2023-52819 bsc#1225532).
- Update
  patches.suse/drm-amd-Fix-an-error-handling-mistake-in-psp_sw.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-Make-fence-wait-in-suballocator-uninterrupti.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-Move-helper-for-dynamic-speed-switch-ch.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-Stop-evicting-resources-on-APUs-in-suspend.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-Update-update_pcie_parameters-functions-to-u.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-amdgpu-Assign-GART-pages-to-AMD-device-mappi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-amdgpu-amdgpu_doorbell_mgr-Correct-misdocume.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Add-FAMS-validation-before-tryi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Add-NULL-check-for-kzalloc-in-amdgpu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Add-NULL-test-for-timing-generator-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2024-26661 bsc#1222323).
- Update
  patches.suse/drm-amd-display-Add-Null-check-for-DPP-resource.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-amd-display-Add-align-done-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Add-case-for-dcn35-to-support-usb4-d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Add-dml2-copy-functions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update
  patches.suse/drm-amd-display-Add-dpia-display-mode-validation-log.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Add-logging-for-display-MALL-re.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Add-monitor-patch-for-specific-eDP-b7cdccc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Add-monitor-patch-for-specific-eDP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Add-monitor-specific-edid-quirk.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Add-polling-method-to-handle-MS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Add-smu-write-msg-id-fail-retry-proc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Align-the-returned-error-code-with-l.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Apply-60us-prefetch-for-DCFCLK.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Avoid-enum-conversion-warning.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Bail-from-dm_check_crtc_cursor-if-no.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Blank-phantom-OTG-before-enabling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Change-the-DMCUB-mailbox-memory-loca.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Check-all-enabled-planes-in-dm_check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Clean-up-errors-warnings-in-amd.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Clear-dpcd_sink_ext_caps-if-not-set.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Convert-Delaying-Aux-I-Disable-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Correct-DMUB_FW_VERSION-macro.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Disable-MPC-split-by-default-on.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Disable-PSR-SU-on-Parade-0803-TCON-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Disable-ips-before-dc-interrupt-sett.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Do-not-set-drr-on-pipe-commit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Don-t-lock-phantom-pipe-on-disabling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Don-t-show-stack-trace-for-mis.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Don-t-use-fsleep-for-PSR-exit-waits.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-amd-display-Enable-dcn314-DPP-RCO.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Enable-fast-plane-updates-on-DCN3.2-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Exit-idle-optimizations-before-attem.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Explicitly-specify-update-type-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Fix-128b132b-link-loss-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628 bsc#1212848).
- Update
  patches.suse/drm-amd-display-Fix-DML2-watermark-calculation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Fix-DSC-not-Enabled-on-Direct-MST-Si.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Fix-MST-Null-Ptr-for-RV.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2024-26700 bsc#1222870).
- Update
  patches.suse/drm-amd-display-Fix-MST-PBN-X.Y-value-calculations.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Fix-Replay-Desync-Error-IRQ-handler.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Fix-a-regression-on-Polaris-ca.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628 bsc#1212874).
- Update
  patches.suse/drm-amd-display-Fix-a-switch-statement-in-populate_d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Fix-a-test-CalculatePrefetchSch.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Fix-a-test-dml32_rq_dlg_get_rq_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Fix-array-index-out-of-bounds-in-dcn.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2024-26699 bsc#1222602).
- Update
  patches.suse/drm-amd-display-Fix-artifacting-on-eDP-panels-w.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Fix-buffer-overflow-in-get_host_rout.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Fix-conversions-between-bytes-and-KB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Fix-dcn35-8k30-Underflow-Corruption-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2024-26913 bsc#1223204).
- Update
  patches.suse/drm-amd-display-Fix-in-secure-display-context-c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Fix-memory-leak-in-dm_sw_fini.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2024-26833 bsc#1223036).
- Update
  patches.suse/drm-amd-display-Fix-minor-issues-in-BW-Allocation-Ph.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Fix-panel_cntl-could-be-null-in-dcn2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2024-26662 bsc#1222324).
- Update
  patches.suse/drm-amd-display-Fix-possible-NULL-dereference-on-dev.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Fix-possible-buffer-overflow-in-find.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Fix-possible-underflow-for-disp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Fix-possible-use-of-uninitialized-ma.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Fix-potential-null-pointer-dereferen.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2024-26729 bsc#1222552).
- Update
  patches.suse/drm-amd-display-Fix-sending-VSC-colorimetry-packets-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Fix-tiled-display-misalignment.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Fix-uninitialized-variable-usage-in-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Fix-variable-deferencing-before-NULL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2024-26648 bsc#1222067).
- Update patches.suse/drm-amd-display-Fix-vs-typos.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-For-prefetch-mode-0-extend-prefetch-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Force-p-state-disallow-if-leaving-no.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Guard-DCN31-PHYD32CLK-logic-against-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Guard-against-invalid-RPTR-WPTR-bein.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Include-udelay-when-waiting-for-INBO.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Increase-frame-larger-than-for-all-d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Increase-frame-warning-limit-with-KA.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Increase-num-voltage-states-to-40.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Initialize-wait_time_microsec-variab.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Keep-PHY-active-for-DP-displays.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Keep-disable-aux-i-delay-as-0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Limit-DCN32-8-channel-or-less-p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Only-allow-dig-mapping-to-pwrseq-in-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Only-clear-symclk-otg-flag-for-HDMI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Pass-pwrseq-inst-for-backlight-and-A.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Port-DENTIST-hang-and-TDR-fixes-to-O.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Preserve-original-aspect-ratio-in-cr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Prevent-potential-buffer-overflow-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2024-26797 bsc#1222425).
- Update
  patches.suse/drm-amd-display-Prevent-vtotal-from-being-set-t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Reduce-default-backlight-min-from-5-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Refactor-DMCUB-enter-exit-idle-inter.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2023-52625 bsc#1222085).
- Update
  patches.suse/drm-amd-display-Refactor-dm_get_plane_scale-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Refactor-edp-power-control.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Remove-Phantom-Pipe-Check-When-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Remove-min_dst_y_next_start-check-fo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Remove-power-sequencing-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Remove-v_startup-workaround-fo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Remove-wait-while-locked.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Request-usb4-bw-for-mst-streams.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Restore-guard-against-default-backli.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Return-drm_connector-from-find_first.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Set-minimum-requirement-for-usi-cd2e31a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Set-minimum-requirement-for-usi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Simplify-brightness-initialization.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Skip-DPP-DTO-update-if-root-cl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-To-adjust-dprefclk-by-down-spread-pe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Unconditionally-print-when-DP-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Unlock-on-error-path-in-dm_hand.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Update-DTBCLK-for-DCN32.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Update-correct-DCN314-register-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Update-min-Z8-residency-time-to-2100.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Use-DRAM-speed-from-validation-for-d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-Use-drm_connector-in-create_stream_f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-Wake-DMCUB-before-sending-a-command.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  CVE-2023-52485 bsc#1220835 git-fixes).
- Update
  patches.suse/drm-amd-display-add-a-NULL-pointer-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628 bsc#1212848).
- Update patches.suse/drm-amd-display-add-nv12-bounding-box.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-add-pixel-rate-based-CRB-alloca.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-add-seamless-pipe-topology-transitio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-add-support-for-DTO-genarated-dscclk.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-adjust-few-initialization-order-in-d.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-always-switch-off-ODM-before-committ.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-avoid-stringop-overflow-warnings-for.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-check-TG-is-non-null-before-che.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-check-attr-flag-before-set-cur.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-check-dc_link-before-dereferencing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-dc.h-eliminate-kernel-doc-warnings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-disable-seamless-boot-if-force_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628 bsc#1212848).
- Update
  patches.suse/drm-amd-display-do-not-send-commands-to-DMUB-if-DMUB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-enable-cursor-degamma-for-DCN3-DRM-l.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-ensure-async-flips-are-only-accepted.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-amd-display-fix-ABM-disablement.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-fix-USB-C-flag-update-after-enc10-fe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-fix-a-NULL-pointer-dereference-in-am.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071 CVE-2023-52773 bsc#1225041).
- Update
  patches.suse/drm-amd-display-fix-bandwidth-validation-failure-on-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-fix-dcn315-single-stream-crb-al.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-fix-incorrect-mpc_combine-array-size.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2024-26914 bsc#1223205).
- Update
  patches.suse/drm-amd-display-fix-input-states-translation-error-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update
  patches.suse/drm-amd-display-fix-is_timing_changed-prototype.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-amd-display-fix-mode-scaling-RMX_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-fix-null-pointer-dereference-on-edid.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2024-26728 bsc#1222370).
- Update
  patches.suse/drm-amd-display-fix-seamless-odm-transitions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-fix-the-ability-to-use-lower-resolut.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-fix-the-white-screen-issue-when-64GB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-fix-usb-c-connector_type.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-fixed-integer-types-and-null-check-l.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2024-26767).
- Update
  patches.suse/drm-amd-display-force-toggle-rate-wa-for-first-link-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-get-dprefclk-ss-info-from-integratio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-handle-range-offsets-in-VRR-ranges.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update
  patches.suse/drm-amd-display-increased-min_dcfclk_mhz-and-min_fcl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-make-flip_timestamp_in_us-a-64-bit-v.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-display-only-accept-async-flips-for-fas.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-pbn_div-need-be-updated-for-hotplug-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-perform-a-bounds-check-before-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628 bsc#1212848).
- Update
  patches.suse/drm-amd-display-prevent-potential-division-by-zero-e.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-refactor-ILR-to-make-it-work.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-register-edp_backlight_control-for-D.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-remove-useless-check-in-should_enabl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-update-dcn315-lpddr-pstate-latency.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-update-extended-blank-for-dcn31.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-display-use-full-update-for-clip-size-increa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-flush-any-delayed-gfxoff-on-suspend-en.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-pm-Add-error-log-for-smu-v13.0.6-reset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-pm-Fetch-current-power-limit-from-FW.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-pm-Fix-a-memory-leak-on-an-error-path.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-pm-Fix-error-of-MACO-flag-setting-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-pm-Fix-smuv13.0.6-current-clock-reporting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-pm-Fix-temperature-unit-of-SMU-v13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-pm-Handle-non-terminated-overdrive-commands.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-pm-add-abnormal-fan-detection-for-smu-1.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628 bsc#1212848).
- Update
  patches.suse/drm-amd-pm-conditionally-disable-pcie-lane-spee.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-pm-correct-the-pcie-width-for-smu-13.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-pm-expose-swctf-threshold-setting-for-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-pm-fix-a-double-free-in-amdgpu_parse_extende.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-pm-fix-a-memleak-in-aldebaran_tables_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-amd-pm-fix-smu-i2c-data-read-risk.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-pm-fix-variable-dereferenced-issue-in-amdgpu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-pm-revise-the-ASPM-settings-for-thunder.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628 bsc#1212848).
- Update
  patches.suse/drm-amd-pm-share-the-code-around-SMU13-pcie-par.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-pm-skip-the-RLC-stop-when-S0i3-suspend.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-pm-smu7-fix-a-memleak-in-smu7_hwmgr_backend_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-pm-update-the-LC_L1_INACTIVITY-setting-to-ad.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1212848).
- Update
  patches.suse/drm-amd-pm-update-the-power-cap-setting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-powerplay-Fix-kzalloc-parameter-ATOM_Tonga_P.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amd-smu-use-AverageGfxclkFrequency-to-replace-pr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amd-swsmu-modify-the-gfx-activity-scaling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update
  patches.suse/drm-amdgpu-Add-NULL-checks-for-function-pointers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-Avoid-fetching-VRAM-vendor-info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-Avoid-fetching-vram-vendor-information.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-Do-not-issue-gpu-reset-from-nbio-v7_9-bif.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-Do-not-program-VF-copy-regs-in-mmhub-v1.8.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-Drop-fence-check-in-to_amdgpu_amdkfd_fenc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-Enable-GFXOFF-for-Compute-on-GFX11.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-Enable-gpu-reset-for-S3-abort-cases-on-Ra.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update
  patches.suse/drm-amdgpu-Enable-tunneling-on-high-priority-compute.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-Fix-HDP-flush-for-VFs-on-nbio-v7.9.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-Fix-a-null-pointer-access-when-the-smc_rr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071 CVE-2023-52817 bsc#1225569).
- Update
  patches.suse/drm-amdgpu-Fix-cat-debugfs-amdgpu_regs_didt-causes-k.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-Fix-ecc-irq-enable-disable-unpaired.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-Fix-fw-from-request_firmware-not-released.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-Fix-integer-overflow-in-amdgpu_cs_p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-Fix-memcpy-in-sienna_cichlid_append_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-Fix-missing-error-code-in-gmc_v6-7-8-9_0_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-Fix-possible-NULL-dereference-in-amdgpu_r.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2023-52585 bsc#1221080).
- Update
  patches.suse/drm-amdgpu-Fix-possible-null-pointer-dereference.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-Fix-refclk-reporting-for-SMU-v13.0.6.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-Fix-shared-buff-copy-to-user.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-Fix-the-runtime-resume-failure-issue.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-Fix-usage-of-UMC-fill-record-in-RAS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-Fix-variable-mca_funcs-dereferenced-befor.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2024-26672 bsc#1222358).
- Update
  patches.suse/drm-amdgpu-Fix-with-right-return-code-EIO-in-amdgpu_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-Force-order-between-a-read-and-write-to-t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-Increase-IH-soft-ring-size-for-GFX-v9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-amdgpu-Let-KFD-sync-with-VM-fences.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-Match-against-exact-bootloader-status.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-Release-adev-pm.fw-before-return-in-amdgp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-Remove-duplicate-fdinfo-fields.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-Remove-unused-variables-from-amdgpu_show_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-Show-vram-vendor-only-if-available.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-Skip-mark-offset-for-high-priority-r.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628 bsc#1212848).
- Update
  patches.suse/drm-amdgpu-Update-EEPROM-I2C-address-for-smu-v13_0_0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-Update-min-to-min_t-in-amdgpu_info_ioctl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-Use-RMW-accessors-for-changing-LNKCTL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-Use-another-offset-for-GC-9.4.3-remap.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-amdgpu-Validate-VM-ioctl-flags.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-add-a-retry-for-IP-discovery-init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-apply-the-RV2-system-aperture-fix-to-RN-C.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-avoid-integer-overflow-warning-in-amdgpu_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-avoid-restore-process-run-into-dead-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-check-RAS-irq-existence-for-VCN-JPEG.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628 bsc#1212848).
- Update
  patches.suse/drm-amdgpu-correct-chunk_ptr-to-a-pointer-to-chunk.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-correct-the-amdgpu-runtime-dereference-us.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-correct-the-cu-count-for-gfx-v11.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-debugfs-fix-error-code-when-smc-register-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/drm-amdgpu-disable-MCBP-by-default.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-display-Initialize-gamma-correction-mode-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-don-t-use-pci_is_thunderbolt_attached.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-drop-exp-hw-support-check-for-GC-9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-fall-back-to-INPUT-power-for-AVG-power-vi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-finalizing-mem_partitions-at-the-end-of-G.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-fix-GRBM-read-timeout-when-do-mes_self_te.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-fix-avg-vs-input-power-reporting-on-smu7.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-fix-calltrace-warning-in-amddrm_bud.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-fix-clearing-mappings-for-BOs-that-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628 bsc#1212848).
- Update
  patches.suse/drm-amdgpu-fix-error-handling-in-amdgpu_bo_list_get.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-fix-error-handling-in-amdgpu_vm_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-fix-ftrace-event-amdgpu_bo_move-always-mo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-fix-memory-leak-in-mes-self-test.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-fix-memory-overflow-in-the-IB-test.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-fix-number-of-fence-calculations.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628 bsc#1212848).
- Update
  patches.suse/drm-amdgpu-fix-possible-UAF-in-amdgpu_cs_pass1.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-fix-software-pci_unplug-on-some-chips.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-fix-tear-down-order-in-amdgpu_vm_pt_free.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-gfx10-11-use-memcpy_to-fromio-for-MQDs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-gfx10-set-UNORD_DISPATCH-in-compute-MQDs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-gfx11-set-UNORD_DISPATCH-in-compute-MQDs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-install-stub-fence-into-potential-u.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-keep-irq-count-in-amdgpu_irq_disabl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-lower-CS-errors-to-debug-severity.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-make-sure-BOs-are-locked-in-amdgpu_v.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628 bsc#1212848).
- Update
  patches.suse/drm-amdgpu-make-sure-that-BOs-have-a-backing-st.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1012628 bsc#1212848).
- Update
  patches.suse/drm-amdgpu-not-to-save-bo-in-the-case-of-RAS-err_eve.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-pm-Fix-the-error-of-pwm1_enable-setting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update
  patches.suse/drm-amdgpu-pm-Fix-the-power-source-flag-error.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-pm-Fix-the-power1_min_cap-value.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-pm-fix-throttle_status-for-other-th.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-pm-make-gfxclock-consistent-for-sien.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-pm-make-mclk-consistent-for-smu-13.0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-re-create-idle-bo-s-PTE-during-VM-state-m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-reset-gpu-for-s3-suspend-abort-case.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-revert-Adjust-removal-control-flow-for-sm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-sdma5.2-add-begin-end_use-ring-callbacks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-skip-fence-GFX-interrupts-disable-e.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-skip-gpu_info-fw-loading-on-navi12.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-skip-to-program-GFXDEC-registers-for-susp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-smu13-drop-compute-workload-workaround.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-soc21-update-VCN-4-max-HEVC-encoding-reso.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-unmap-and-remove-csa_va-properly.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-update-regGL2C_CTRL4-value-in-golden-sett.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdgpu-update-retry-times-for-psp-BL-wait.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-update-retry-times-for-psp-vmbx-wait.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdgpu-vkms-relax-timer-deactivation-by-hrt.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdkfd-Fix-L2-cache-size-reporting-in-GFX9.4.3.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdkfd-Fix-iterator-used-outside-loop-in-kfd_add.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdkfd-Fix-lock-dependency-warning-with-srcu.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2023-52632 bsc#1222274).
- Update patches.suse/drm-amdkfd-Fix-lock-dependency-warning.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdkfd-Fix-node-NULL-check-in-svm_range_get_rang.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdkfd-Fix-potential-deallocation-of-previo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdkfd-Fix-shift-out-of-bounds-issue.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071 CVE-2023-52816 bsc#1225529).
- Update
  patches.suse/drm-amdkfd-Fix-type-of-dbg_flags-in-struct-kfd_proce.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdkfd-Free-gang_ctx_bo-and-wptr_bo-in-pqm_unini.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdkfd-Handle-errors-from-svm-validate-and-map.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdkfd-Remove-svm-range-validated_once-flag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdkfd-Use-common-function-for-IP-version-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdkfd-Use-correct-drm-device-for-cgroup-permiss.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdkfd-fix-mes-set-shader-debugger-process-manag.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdkfd-fix-some-race-conditions-in-vram-buffer-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdkfd-fixes-for-HMM-mem-allocation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdkfd-get-doorbell-s-absolute-offset-based-on-t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdkfd-only-flush-mes-process-context-if-mes-sup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdkfd-ratelimited-SQ-interrupt-messages.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-amdkfd-reserve-the-BO-before-validating-it.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-amdkfd-svm-range-always-mapped-flag-not-working-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-armada-Fix-off-by-one-error-in-armada_overlay_ge.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-ast-Add-BMC-virtual-connector.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-ast-Disconnect-BMC-if-physical-connector-is-conn.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-ast-Fix-DRAM-init-on-AST2200.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-ast-report-connection-status-on-Display-Port.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-atomic-Allow-vblank-enabled-self-refresh-di.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-atomic-Fix-potential-use-after-free-in-nonb.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071 bsc#1219120 CVE-2023-51043).
- Update
  patches.suse/drm-atomic-helper-Update-reference-to-drm_crtc_force.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-atomic-helpers-Invoke-end_fb_access-while-owning.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-Fix-kernel-doc-typo-in-desc-of-output_bus.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-Fix-typo-in-post_disable-description.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-bridge-anx7625-Drop-device-lock-before-drm_helpe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-anx7625-Ensure-bridge-is-suspended-in-dis.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-bridge-anx7625-Fix-Set-HPD-irq-detect-window-to-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-bridge-anx7625-Prevent-endless-probe-loop.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-anx7625-Use-common-macros-for-DP-power-se.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-anx7625-Use-common-macros-for-HDCP-capabi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-cdns-mhdp8546-Fix-use-of-uninitialized-va.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-bridge-dw-mipi-dsi-Fix-enable-disable-of-DSI-con.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-dw_hdmi-fix-connector-access-for-scd.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-fix-Wunused-const-variable-warning.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-for-GENERIC_PHY_MIPI_DPHY-also-select-GEN.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-imx93-mipi-dsi-Fix-a-couple-of-building-w.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-bridge-it6505-Check-power-state-with-it650.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-it6505-Move-a-variable-assignment-be.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-it66121-get_edid-callback-must-not-return.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-lt8912b-Add-missing-drm_bridge_attach-cal.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-bridge-lt8912b-Fix-bridge_detach.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-lt8912b-Fix-crash-on-bridge-detach.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071 CVE-2023-52856 bsc#1224932).
- Update
  patches.suse/drm-bridge-lt8912b-Manually-disable-HPD-only-if-it-w.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-lt9611uxc-fix-the-race-in-the-error-path.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-nxp-ptn3460-fix-i2c_master_send-error-che.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-bridge-nxp-ptn3460-simplify-some-error-checking.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-bridge-parade-ps8640-Ensure-bridge-is-suspended-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-bridge-parade-ps8640-Make-sure-we-drop-the-AUX-m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-bridge-parade-ps8640-Never-store-more-than-msg-s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-parade-ps8640-Wait-for-HPD-when-doing-an-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-bridge-ps8640-Fix-size-mismatch-warning-w-len.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-samsung-dsim-Don-t-use-FORCE_STOP_STATE.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-bridge-samsung-dsim-Fix-PMS-Calculator-on-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-samsung-dsim-Fix-waiting-for-empty-cmd-tr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-sii902x-Fix-audio-codec-unregistration.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-bridge-tc358767-Fix-return-value-on-error-case.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-bridge-tc358767-Switch-to-devm-MIPI-DSI-hel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-tc358768-Add-atomic_get_input_bus_fm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-tc358768-Clean-up-clock-period-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-bridge-tc358768-Fix-bit-updates.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-tc358768-Fix-tc358768_ns_to_cnt.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-tc358768-Fix-use-of-uninitialized-variabl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-tc358768-Print-logical-values-not-raw-reg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-tc358768-Rename-dsibclk-to-hsbyteclk.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-tc358768-Use-dev-for-dbg-prints-not-priv-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-tc358768-Use-struct-videomode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-tc358768-always-enable-HS-video-mode.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-tc358768-fix-PLL-parameters-computat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-tc358768-fix-PLL-target-frequency.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-tc358768-fix-TCLK_TRAILCNT-computati.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-tc358768-fix-TCLK_ZEROCNT-computatio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-tc358768-fix-THS_TRAILCNT-computatio.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-tc358768-fix-THS_ZEROCNT-computation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-tc358768-fix-TXTAGOCNT-computation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-tc358768-select-CONFIG_VIDEOMODE_HELPERS.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-ti-sn65dsi83-Fix-enable-disable-flow.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-ti-sn65dsi83-Fix-enable-error-path.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-ti-sn65dsi86-Fix-auxiliary-bus-lifet.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-bridge-ti-sn65dsi86-Never-store-more-than-msg-si.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-buddy-Fix-alloc_range-error-handling-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2024-26911 bsc#1223055).
- Update
  patches.suse/drm-buddy-Modify-duplicate-list_splice_tail-call.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-buddy-check-range-allocation-matches-alignment.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update patches.suse/drm-buddy-fix-range-bias.patch (jsc#PED-9898
  jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237
  jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-client-Fix-memory-leak-in-drm_client_modese.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-client-Fix-memory-leak-in-drm_client_target.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-crtc-Fix-uninit-value-bug-in-drm_mode_setcrtc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-crtc-fix-uninitialized-variable-use-even-harder.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-crtc-fix-uninitialized-variable-use.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-display-dp-Fix-the-DP-DSC-Receiver-cap-siz.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-dp_mst-Clear-MSG_RDY-flag-before-sending-ne.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-dp_mst-Fix-fractional-DSC-bpp-handling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-drm_file-fix-use-of-uninitialized-variable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-drv-propagate-errors-from-drm_modeset_register_a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-edid-Fixup-h-vsync_end-instead-of-h-vtotal.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-edid-also-call-add-modes-in-EDID-connector-updat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-etnaviv-fix-dumping-of-active-MMU-context.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-exynos-Call-drm_atomic_helper_shutdown-at-shutdo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-exynos-fix-a-potential-error-pointer-dereference.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-exynos-fix-a-wrong-error-checking.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-exynos-fix-accidental-on-stack-copy-of-exynos_dr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-exynos-gsc-minor-fix-for-loop-iteration-in-gsc_r.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-fbdev-dma-Fix-documented-default-preferred_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-framebuffer-Fix-use-of-uninitialized-variable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-gem-fb-helper-Consistenly-use-drm_dbg_kms.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-gm12u320-Fix-the-timeout-usage-for-usb_bulk_msg.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-gma500-Fix-call-trace-when-psb_gem_mm_init-fails.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-hyperv-Fix-a-compilation-issue-because-of-not-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-i915-Add-missing-CCS-documentation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Add-missing-GSCCS-documentation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Add-the-gen12_needs_ccs_aux_inv-helpe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Also-check-for-VGA-converter-in-eDP-probe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071 bsc#1217282).
- Update
  patches.suse/drm-i915-Bump-GLK-CDCLK-frequency-when-driving-multi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Call-intel_pre_plane_updates-also-for-pipes.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Check-before-removing-mm-notifier.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-i915-Consolidate-condition-for-Wa_22011802037.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Don-t-explode-when-the-dig-port-we-don-t-ha.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-i915-Don-t-preserve-dpll_hw_state-for-slave.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-i915-Drop-Wstringop-overflow.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/drm-i915-Eliminate-IS_MTL_DISPLAY_STEP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Eliminate-IS_MTL_GRAPHICS_STEP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-i915-Eliminate-IS_MTL_MEDIA_STEP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Fix-ADL-tiled-plane-stride-when-the-POT-str.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-i915-Fix-FEC-state-dump.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Fix-an-error-handling-path-in-igt_writ.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Fix-intel_atomic_setup_scalers-plane_state-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-i915-Fix-limited-range-csc-matrix.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Fix-one-wrong-caching-mode-enum-usage.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Fix-potential-spectre-vulnerability.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Fix-premature-release-of-request-s-re.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Fix-remapped-stride-with-CCS-on-ADL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Flush-WC-GGTT-only-on-required-platforms.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Introduce-crtc_state-enhanced_framing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Only-check-eDP-HPD-when-AUX-CH-is-shared.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Reject-async-flips-with-bigjoiner.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Replace-several-IS_METEORLAKE-with-proper-I.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Skip-some-timing-checks-on-BXT-GLK-DSI-tran.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Stop-printing-pipe-name-as-hex.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update patches.suse/drm-i915-Tidy-workaround-definitions.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Use-internal-class-when-counting-engine-res.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-Use-named-initializers-for-DPLL-info.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update patches.suse/drm-i915-dg2-Drop-Wa_16011777198.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-dg2-Drop-pre-production-GT-workarounds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-dg2-Drop-pre-production-display-workarounds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-dg2-Recognize-pre-production-hardware.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-i915-dgfx-Enable-d3cold-at-s2idle.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-display-Eliminate-IS_METEORLAKE-checks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-display-Move-display-device-info-to-he.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-display-Move-releasing-gem-object-away-from.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-i915-display-Use-i915_gem_object_get_dma_address.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update
  patches.suse/drm-i915-dmc-Don-t-enable-any-pipe-DMC-events.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-do-not-clean-GT-table-on-error-path.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-dp-Fix-passing-the-correct-DPCD_REV-for-drm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-dp-Fix-the-max-DSC-bpc-supported-by-source.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-i915-dp-Limit-SST-link-rate-to-8.1Gbps.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/drm-i915-dpt-Use-shmem-for-dpt-objects.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-dsc-Fix-the-macro-that-calculates-DSCC_-DSC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2024-26721 bsc#1222365).
- Update
  patches.suse/drm-i915-edp-don-t-write-to-DP_LINK_BW_SET-when-usin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-gsc-Mark-internal-GSC-engine-with-reserved-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-i915-gt-Add-workaround-14016712196.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-gt-Cleanup-aux-invalidation-registers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-gt-Enable-the-CCS_FLUSH-bit-in-the-pi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-gt-Ensure-memory-quiesced-before-inva.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-gt-Poll-aux-invalidation-register-bit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-gt-Rename-flags-with-bit_group_X-acco.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-gt-Support-aux-invalidation-on-all-en.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-guc-slpc-Apply-min-softlimit-correctly.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-guc-slpc-Provide-sysfs-for-efficient-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-guc-slpc-Restore-efficient-freq-earli.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-gvt-Don-t-rely-on-KVM-s-gfn_to_pfn-to-query.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-7322).
- Update
  patches.suse/drm-i915-gvt-Drop-unused-helper-intel_vgpu_reset_gtt.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-gvt-Error-out-on-an-attempt-to-shadowing-an.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-7322).
- Update
  patches.suse/drm-i915-gvt-Explicitly-check-that-vGPU-is-attached-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-7322).
- Update
  patches.suse/drm-i915-gvt-Fix-uninitialized-variable-in-handle_mm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-i915-gvt-Protect-gfn-hash-table-with-vgpu_lock.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-7322).
- Update
  patches.suse/drm-i915-gvt-Put-the-page-reference-obtained-by-KVM-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-gvt-Verify-hugepages-are-contiguous-in-phys.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-7322).
- Update
  patches.suse/drm-i915-gvt-Verify-pfn-is-valid-before-dereferencin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-gvt-remove-interface-intel_gvt_is_valid_gfn.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-7322).
- Update
  patches.suse/drm-i915-hdcp-Extract-hdcp-structure-from-correct-co.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-i915-hdcp-Move-to-direct-reads-for-HDCP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-i915-hdcp-Remove-additional-timing-for-reading-m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-i915-hide-mkwrite_device_info-better.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-hwmon-Fix-static-analysis-tool-reported-iss.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-mark-requests-for-GuC-virtual-engines-to-av.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-mst-Fix-.mode_valid_ctx-return-values.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-mst-Reject-modes-that-require-the-bigjoiner.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-i915-mtl-Eliminate-subplatforms.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-mtl-Fix-HDMI-DP-PLL-clock-selection.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-mtl-Support-HBR3-rate-with-C10-phy-and-eDP-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-mtl-Update-workaround-14016712196.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-mtl-avoid-stringop-overflow-warning.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-perf-Update-handling-of-MMIO-triggered-repo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-perf-add-sentinel-to-xehp_oa_b_counter.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-psr-Fix-BDW-PSR-AUX-CH-data-register-o.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-psr-Only-allow-PSR-in-LPSP-mode-on-HSW-non-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-i915-psr-Use-hw.adjusted-mode-when-calculat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-sdvo-fix-panel_type-initialization.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-selftests-Fix-dependency-of-some-timeouts-o.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-i915-selftests-Fix-engine-reset-count-storage-fo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-tc-Fix-Wformat-truncation-in-intel_tc_port_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-i915-tv-Fix-TV-mode.patch (jsc#PED-9898
  jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237
  jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-i915-xelpg-Call-Xe_LPG-workaround-functions-base.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-i915-xelpmp-Don-t-assume-workarounds-extend-to-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-imx-ipuv3-Fix-front-porch-adjustment-upon-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-imx-lcdc-Fix-double-free-of-driver-data.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-imx-lcdc-fix-a-NULL-vs-IS_ERR-bug-in-probe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-komeda-drop-all-currently-held-locks-if-deadlock.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-loongson-Fix-error-handling-in-lsdc_pixel_pll_se.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-mediatek-Add-cnt-checking-for-coverity-issue.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-mediatek-Add-crtc-path-enum-for-all_drm_priv-arr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-mediatek-Add-mmsys_dev_num-to-mt8188-vdosys0-dri.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-mediatek-Add-spinlock-for-setting-vblank-event-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-mediatek-Fix-access-violation-in-mtk_drm_crtc_dm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-mediatek-Fix-coverity-issue-with-unintentional-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071 CVE-2023-52857 bsc#1225581).
- Update
  patches.suse/drm-mediatek-Fix-dereference-before-null-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-mediatek-Fix-iommu-fault-by-swapping-FBs-after-u.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-mediatek-Fix-iommu-fault-during-crtc-enabling.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-mediatek-Fix-potential-memory-leak-if-vmap-fail.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-mediatek-Fix-underrun-in-VDO1-when-switches-off-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/drm-mediatek-Fix-uninitialized-symbol.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-mediatek-Fix-using-wrong-drm-private-data-to-bin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-mediatek-Fix-void-pointer-to-enum-cast-warning.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-mediatek-Remove-freeing-not-dynamic-allocated-me.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-mediatek-Remove-the-redundant-driver-data-for-DP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-mediatek-Return-error-if-MDP-RDMA-failed-to-enab.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-mediatek-dp-Add-missing-error-checks-in-mtk_dp_p.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-mediatek-dp-Add-phy_mtk_dp-module-as-pre-depende.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-mediatek-dp-fix-memory-leak-on-get_edid-callback-fcaf976.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-mediatek-dp-fix-memory-leak-on-get_edid-callback.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-mediatek-fix-kernel-oops-if-no-crtc-is-found.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-mediatek-mtk_dsi-Fix-NO_EOT_PACKET-settings-hand.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-meson-Don-t-remove-bridges-which-are-created-by-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-meson-fix-memory-leak-on-hpd_notify-callback.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071 CVE-2023-52563 bsc#1220937).
- Update
  patches.suse/drm-mgag200-Fix-gamma-lut-not-initialized-for-G200ER.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-mipi-dsi-Fix-detach-call-without-attach.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-msm-Disallow-submit-with-fence-id-0.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-Fix-IS_ERR_OR_NULL-vs-NULL-check-in-a5x.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-Fix-hw_fence-error-path-cleanup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-Reduce-fallout-of-fence-signaling-vs-reclaim.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update
  patches.suse/drm-msm-Update-dev-core-dump-to-not-print-backwards.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-msm-Wire-up-tlb-ops.patch (jsc#PED-9898
  jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237
  jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-msm-a2xx-Call-adreno_gpu_init-earlier.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-a5xx-really-check-for-A510-in-a5xx_gpu_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-msm-a690-Fix-reg-values-for-a690.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/drm-msm-a690-Switch-to-a660_gmu.bin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-msm-a6xx-Fix-GMU-lockdep-splat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-msm-a6xx-Fix-unknown-speedbin-case.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-msm-a6xx-add-QMP-dependency.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-msm-a6xx-don-t-set-IO_PGTABLE_QUIRK_ARM_OUT.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-msm-adreno-Fix-A680-chip-id.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/drm-msm-adreno-Fix-SM6375-GPU-ID.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-adreno-Fix-snapshot-BINDLESS_DATA-size.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-adreno-fix-sparse-warnings-in-a6xx-code.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dp-Add-DisplayPort-controller-for-SM8650.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-msm-dp-Drop-aux-devices-together-with-DP-co.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dp-Free-resources-after-unregistering-t.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dp-return-correct-Colorimetry-for-DP_TEST_DY.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-msm-dp-skip-validity-check-for-DP-CTS-EDID-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dpu-Add-missing-safe_lut_tbl-in-sc8180x-cata.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-msm-dpu-Add-missing-safe_lut_tbl-in-sc8280xp-cat.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dpu-Add-mutex-lock-in-control-vblank-irq.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2023-52586 bsc#1221081).
- Update
  patches.suse/drm-msm-dpu-Correct-UBWC-settings-for-sc8280xp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-msm-dpu-Disable-pingpong-TE-on-DPU-5.0.0-an.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dpu-Drop-enable-and-frame_count-parameters-f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-msm-dpu-Drop-unused-poll_timeout_wr_ptr-PIN.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dpu-Fix-slice_last_group_size-calculati.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dpu-Move-autorefresh-disable-from-CMD-e.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dpu-Ratelimit-framedone-timeout-msgs.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-msm-dpu-Set-DPU_DATA_HCTL_EN-for-in-INTF_SC.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-msm-dpu-Set-input_sel-bit-for-INTF.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-msm-dpu-Use-V4.0-PCC-DSPP-sub-block-in-SC7-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dpu-add-missing-flush-and-fetch-bits-fo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dpu-always-clear-every-individual-pendi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dpu-clean-up-dpu_kms_get_clk_rate-returns.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-msm-dpu-correct-MERGE_3D-length.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dpu-correct-clk-bit-for-WB2-block.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-msm-dpu-do-not-enable-color-management-if-D.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dpu-drop-MSM_ENC_VBLANK-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update
  patches.suse/drm-msm-dpu-drop-enum-dpu_core_perf_data_bus_id.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dpu-drop-the-regdma-configuration.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dpu-enable-DSPP_2-3-for-LM_2-3-on-sm845.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-msm-dpu-enable-SmartDMA-on-SM8450.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/drm-msm-dpu-enable-writeback-on-SM8350.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/drm-msm-dpu-enable-writeback-on-SM8450.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-msm-dpu-fix-cursor-block-register-bit-offse.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-msm-dpu-fix-kernel-doc-warnings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-msm-dpu-fix-sc7280-and-sc7180-PINGPONG-done.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dpu-fix-the-irq-index-in-dpu_encoder_phys_wb.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dpu-increase-memtype-count-to-16-for-sm8550.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dpu-populate-SSPP-scaler-block-version.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-msm-dpu-rename-dpu_encoder_phys_wb_setup_cdp-to-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-msm-dpu-set-DSC-flush-bit-correctly-at-MDP-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dpu-try-multirect-based-on-mdp-clock-limits.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update
  patches.suse/drm-msm-dpu-use-devres-managed-allocation-for-MDP-TO.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update
  patches.suse/drm-msm-dpu-use-drmm-managed-allocation-for-dpu_enco.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update
  patches.suse/drm-msm-dsi-Drop-unused-regulators-from-QCM2290.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-msm-dsi-Enable-runtime-PM.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-msm-dsi-Remove-incorrect-references-to-slic.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dsi-Use-pm_runtime_resume_and_get-to-prevent.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-msm-dsi-don-t-allow-enabling-14nm-VCO-with-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-msm-dsi-free-TX-buffer-in-unbind.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dsi-use-msm_gem_kernel_put-to-free-TX-buffer.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-dsi-use-the-correct-VREG_CTRL_1-value-for-4n.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-gem-Fix-double-resv-lock-aquire.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-msm-mdp4-flush-vblank-event-on-disable.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-msm-mdp5-Don-t-leak-some-plane-state.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-mdss-Rename-path-references-to-mdp_path.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update
  patches.suse/drm-msm-mdss-correct-UBWC-programming-for-SM855.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msm-mdss-switch-mdss-to-use-devm_of_icc_get.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update patches.suse/drm-msm-provide-fb_dirty-implemenation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-msms-dp-fixed-link-clock-divider-bits-be-over-wr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-mxsfb-Disable-overlay-plane-in-mxsfb_plane_overl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-nouveau-acr-Abort-loading-ACR-if-no-firmwar.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-nouveau-bring-back-blit-subchannel-for-pre-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-nouveau-disp-PIOR-DP-uses-GPIO-for-HPD-not-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-nouveau-disp-Revert-a-NULL-check-inside-no.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-nouveau-disp-fix-HDMI-on-gt215.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-nouveau-disp-g94-enable-HDMI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-nouveau-dispnv50-fix-missing-prototypes-war.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-nouveau-fence-fix-warning-directly-dereferencing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-nouveau-fix-several-DMA-buffer-leaks.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2024-26912 bsc#1223064).
- Update
  patches.suse/drm-nouveau-gr-enable-memory-loads-on-helper-i.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-nouveau-i2c-fix-number-of-aux-event-slots.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-nouveau-kms-nv50-init-hpd_irq_lock-for-PIOR.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-nouveau-mmu-r535-uninitialized-variable-in-r535_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-nouveau-nvkm-dp-Add-workaround-to-fix-DP-1.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-nouveau-nvkm_gsp_radix3_sg-should-use-nvkm_gsp_m.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-nouveau-remove-unused-tu102_gr_load-functi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-panel-auo-b101uan08.3-Fine-tune-the-panel-power-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-panel-boe-tv101wum-nl6-Fine-tune-Himax83102-j02--9dfc46c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-panel-boe-tv101wum-nl6-Fine-tune-Himax83102-j02-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-panel-edp-Add-override_edid_mode-quirk-for-gener.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-panel-edp-drm-panel-edp-Fix-AUO-B116XAK01-name-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-panel-edp-drm-panel-edp-Fix-AUO-B116XTN02-name.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-panel-elida-kd35t133-hold-panel-in-reset-for-unp.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/drm-panel-nt35510-fix-typo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-panel-nt36523-fix-return-value-check-in-nt36523_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-panel-nv3051d-Hold-panel-in-reset-for-unprepare.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-panel-raydium-rm692e5-select-CONFIG_DRM_DISPLAY_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-panel-samsung-s6d7aa0-drop-DRM_BUS_FLAG_DE_HIGH-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-panel-sharp-ls043t1le01-adjust-mode-setting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-panel-simple-Add-Powertip-PH800480T013-drm_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-panel-simple-Add-missing-connector-type-and-pixe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-panel-simple-Fix-AUO-G121EAN01-panel-timin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-panel-simple-Fix-Innolux-G101ICE-L01-bus-flags.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-panel-simple-Fix-Innolux-G101ICE-L01-timings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-panel-simple-add-missing-bus-flags-for-Tianma-tm.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-panel-simple-fix-active-size-for-Ampire-AM-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-panel-st7701-Fix-AVCL-calculation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-panel-st7703-Pick-different-reset-sequence.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-panel-starry-2081101qfh032011-53g-Fine-tune-the-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-panfrost-Ignore-core_mask-for-poweroff-and-disab.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-panfrost-Really-power-off-GPU-cores-in-panfrost_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-panfrost-Skip-speed-binning-on-EOPNOTSUPP.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-prime-Support-page-array-4GB.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/drm-qxl-fix-UAF-on-handle-creation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071 CVE-2023-39198 bsc#1216965).
- Update patches.suse/drm-qxl-prevent-memory-leak.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-radeon-Fix-integer-overflow-in-radeon_cs_pa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-radeon-Remove-the-references-of-radeon_gem_-prea.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-radeon-Use-RMW-accessors-for-changing-LNKCTL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-radeon-check-return-value-of-radeon_ring_lock.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-radeon-dpm-fix-a-memleak-in-sumo_parse_power_tab.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-radeon-fix-a-possible-null-pointer-dereference.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-radeon-fix-possible-division-by-zero-errors.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-radeon-make-fence-wait-in-suballocator-uninterrr.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-radeon-r100-Fix-integer-overflow-issues-in-r100_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-radeon-r600_cs-Fix-possible-int-overflows-in-r60.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-radeon-trinity_dpm-fix-a-memleak-in-trinity_pars.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-rcar-du-remove-R-Car-H3-ES1.-workarounds.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-repaper-Reduce-temporary-buffer-size-in-repaper_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-rockchip-Don-t-spam-logs-in-atomic-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-rockchip-Fix-type-promotion-bug-in-rockchip_gem_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-rockchip-cdn-dp-Fix-some-error-handling-paths-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-rockchip-remove-unused-struct-in-vop2.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-rockchip-vop-Fix-call-to-crtc-reset-helper.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-rockchip-vop-Fix-color-for-RGB888-BGR888-format-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-rockchip-vop-Fix-reset-of-state-in-duplicate-sta.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-rockchip-vop-Leave-vblank-enabled-in-self-r.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-rockchip-vop2-Add-missing-call-to-crtc-reset-hel.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-rockchip-vop2-Don-t-crash-for-invalid-duplicate_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-rockchip-vop2-clear-afbc-en-and-transform-bit-fo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update
  patches.suse/drm-rockchip-vop2-remove-the-unsupported-format-of-c.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-scheduler-set-entity-to-NULL-in-drm_sched_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-shmem-helper-Reset-vma-vm_ops-before-calli.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-ssd130x-Fix-screen-clearing.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-stm-ltdc-fix-late-dereference-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-sun4i_tcon-use-devm_clk_get_enabled-in-sun4.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-syncobj-call-drm_syncobj_fence_add_wait-when-WAI.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-syncobj-fix-DRM_SYNCOBJ_WAIT_FLAGS_WAIT_AVAILABL.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-syncobj-handle-NULL-fence-in-syncobj_eventfd_ent.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-tegra-Do-not-assume-that-a-NULL-domain-means-no-DMA-IOMMU
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-tegra-Remove-existing-framebuffer-only-if-we-sup.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-tegra-dpaux-Fix-incorrect-return-value-of-platfo.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-tests-Fix-incorrect-argument-in-drm_test_mm_inse.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-tests-helpers-Avoid-a-driver-uaf.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-tidss-Check-for-K2G-in-in-dispc_softreset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/drm-tidss-Fix-atomic_flush-check.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/drm-tidss-Fix-dss-reset.patch (jsc#PED-9898
  jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237
  jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-tidss-Move-reset-to-the-end-of-dispc_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-tidss-Return-error-value-from-from-softreset.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/drm-tilcdc-Fix-irq-free-on-unload.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-ttm-Don-t-leak-a-resource-on-eviction-error.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-ttm-Don-t-leak-a-resource-on-swapout-move-e.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-ttm-Fix-an-invalid-freeing-on-already-freed-page.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-ttm-check-null-pointer-before-accessing-wh.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-ttm-fix-bulk_move-corruption-when-adding-a-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-ttm-never-consider-pinned-BOs-for-eviction-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-using-mul_u32_u32-requires-linux-math64.h.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/drm-vc4-fix-typo.patch (jsc#PED-9898
  jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237
  jsc#PED-10340 jsc#PED-10852 jsc#PED-11022 jsc#PED-3527
  jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120
  jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069
  jsc#PED-6071).
- Update
  patches.suse/drm-vc4-tests-Fix-UAF-in-the-mock-helpers.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-virtio-Disable-damage-clipping-if-FB-changed-sin.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-virtio-Set-segment-size-for-virtio_gpu-device.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/drm-virtio-clean-out_fence-on-complete_submit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-vkms-Fix-RGB565-pixel-conversion.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-vkms-isolate-pixel-conversion-functionality.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-vmwgfx-Fix-possible-invalid-drm-gem-put-ca.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm-vmwgfx-Fix-shader-stage-validation.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-vmwgfx_surface.c-copy-user-array-safely.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-vram-helper-fix-function-names-in-vram-help.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/drm-xlnx-zynqmp_dpsub-Add-missing-check-for-dma_set_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/drm_lease.c-copy-user-array-safely.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/fbcon-always-restore-the-old-font-data-in-fbcon_do_s.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2024-26798 bsc#1222798).
- Update patches.suse/fbdev-Update-fbdev-source-file-paths.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/fbdev-acornfb-Fix-name-of-fb_ops-initializer-macro.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/fbdev-au1200fb-Fix-missing-IRQ-check-in-au1200f.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/fbdev-ep93xx-fb-Do-not-assign-to-struct-fb_info.dev.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/fbdev-fix-potential-OOB-read-in-fast_imageblit.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/fbdev-flush-deferred-work-in-fb_deferred_io_fsync.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/fbdev-fsl-diu-fb-mark-wr_reg_wa-static.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/fbdev-goldfishfb-Do-not-check-0-for-platform_get_irq.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/fbdev-imsttfb-fix-double-free-in-probe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/fbdev-imxfb-Removed-unneeded-release_mem_region.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/fbdev-imxfb-fix-left-margin-setting.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/fbdev-imxfb-warn-about-invalid-left-right-margi.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/fbdev-mmp-Fix-typo-and-wording-in-code-comment.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/fbdev-mmp-fix-value-check-in-mmphw_probe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/fbdev-omapfb-Drop-unused-remove-function.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/fbdev-omapfb-lcd_mipid-Fix-an-error-handling-pa.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/fbdev-savage-Error-out-if-pixclock-equals-zero.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2024-26778 bsc#1222770).
- Update
  patches.suse/fbdev-sis-Error-out-if-pixclock-equals-zero.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  git-fixes CVE-2024-26777 bsc#1222765).
- Update
  patches.suse/fbdev-sm712fb-Use-correct-initializer-macros-for-str.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/fbdev-stifb-Make-the-STI-next-font-pointer-a-32-bit-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/gpu-drm-radeon-fix-two-memleaks-in-radeon_vm_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/gpu-host1x-Correct-allocated-size-for-contexts.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/gpu-host1x-Skip-reset-assert-on-Tegra186.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/i915-pmu-Move-execlist-stats-initialization-to-execl.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/locking-rtmutex-Fix-task-pi_waiters-integrity.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/mei-gsc_proxy-match-component-when-GSC-is-on-differe.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/mei-me-add-arrow-lake-point-H-DID.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update patches.suse/mei-me-add-arrow-lake-point-S-DID.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update
  patches.suse/misc-mei-client.c-fix-problem-of-return-EOVERFLOW-in.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/misc-mei-client.c-return-negative-error-code-in-mei_.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/nouveau-add-an-ioctl-to-report-vram-usage.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update
  patches.suse/nouveau-add-an-ioctl-to-return-vram-bar-size.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes).
- Update
  patches.suse/nouveau-find-the-smallest-page-allocation-to-cover-a.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/nouveau-fix-function-cast-warnings.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/nouveau-gsp-handle-engines-in-runl-without-nonstall-.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/nouveau-gsp-use-correct-size-for-registry-rpc.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update patches.suse/nouveau-lock-the-client-object-tree.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  stable-fixes CVE-2024-27062 bsc#1223834).
- Update
  patches.suse/nouveau-offload-fence-uevents-work-to-workqueue.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  bsc#1222566 CVE-2024-26719).
- Update
  patches.suse/nouveau-report-byte-usage-in-VRAM-usage.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/nouveau-svm-fix-kvcalloc-argument-order.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/nouveau-tu102-flush-all-pdbs-on-vmm-flush.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/nouveau-use-an-rwlock-for-the-event-lock.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/nouveau-vmm-don-t-set-addr-on-the-fail-path-to-avoid.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update
  patches.suse/radeon-avoid-double-free-in-ci_dpm_init.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update
  patches.suse/string.h-add-array-wrappers-for-v-memdup_user.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- Update patches.suse/vga16fb-drop-powerpc-support.patch
  (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226
  jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022
  jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116
  jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041
  jsc#PED-6069 jsc#PED-6071).
- commit 2f4f742
* Thu Oct 31 2024 mfranc@suse.cz
- s390/pai_ext: Update PAI extension 1 counters (jsc#PED-9587).
- commit 195a513
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/qib: Fix truncation compilation warnings in qib_verbs.c (jsc#PED-11232)
- commit 96d5ad5
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/qib: Fix truncation compilation warnings in qib_init.c (jsc#PED-11232)
- commit 52cf153
* Thu Oct 31 2024 nmorey@suse.com
- IB/qib: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (jsc#PED-11232)
- commit 833518c
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/efa: Add support for node guid (jsc#PED-11232)
- commit 4527220
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/efa: Add EFA 0xefa3 PCI ID (jsc#PED-11232)
- commit 296c3e8
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/efa: Remove duplicate aenq enable macro (jsc#PED-11232)
- commit 88c9815
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/efa: Use offset_in_page() function (jsc#PED-11232)
- commit e39ac1c
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/efa: Fail probe on missing BARs (jsc#PED-11232)
- commit 2425f44
* Thu Oct 31 2024 dsterba@suse.com
- of: Add cleanup.h based auto release via __free(device_node) markings (bsc#1232386)
- commit 794e5ba
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/efa: Support QP with unsolicited write w/ imm. receive (jsc#PED-11232)
- commit 5faa630
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/efa: Add shutdown notifier (jsc#PED-11232)
- commit ec12045
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/efa: Limit EQs to available MSI-X vectors (jsc#PED-11232)
- commit 91eadf4
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/ipoib: Remove unused declarations (jsc#PED-11232)
- commit 971d497
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/ipoib: Remove NULL check before dev_{put, hold} (jsc#PED-11232)
- commit 014eb63
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/ipoib: Print symbolic error name instead of error code (jsc#PED-11232)
- commit c5b5241
* Thu Oct 31 2024 jlee@suse.com
- thermal/drivers/rcar_gen3: Add support for R-Car V4M
  (jsc#PED-11164).
- thermal/drivers/qoriq: Fix getting tmu range (jsc#PED-11164).
- thermal/drivers/sun8i: Don't fail probe due to zone registration
  failure (jsc#PED-11164).
- thermal/drivers/sun8i: Add support for H616 THS controller
  (jsc#PED-11164).
- commit e78a513
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/rxe: Fix __bth_set_resv6a (jsc#PED-11232)
- commit c17d38b
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/rxe: Fix misspelling of 'rmda' (jsc#PED-11232)
- commit 745557f
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/rxe: Use sizeof instead of hard code number (jsc#PED-11232)
- commit 767c403
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/rxe: Let destroy qp succeed with stuck packet (jsc#PED-11232)
- commit 946a03b
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/rxe: Get rid of pkt resend on err (jsc#PED-11232)
- commit b5a70de
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/rxe: Make rxe_loopback match rxe_send behavior (jsc#PED-11232)
- commit b08521e
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/rxe: Don't call direct between tasks (jsc#PED-11232)
- commit e929a8b
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/rxe: Don't call rxe_requester from rxe_completer (jsc#PED-11232)
- commit 29c270f
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/rxe: Don't schedule rxe_completer from rxe_requester (jsc#PED-11232)
- commit b897d64
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/rxe: Remove save/rollback_state in rxe_requester (jsc#PED-11232)
- commit 30d1cfb
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/rxe: Merge request and complete tasks (jsc#PED-11232)
- commit eebe779
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/rxe: Remove redundant scheduling of rxe_completer (jsc#PED-11232)
- commit 0942cff
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/rxe: Return the correct errno (jsc#PED-11232)
- commit 5d3acde
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/rxe: Remove unused 'iova' parameter from rxe_mr_init_user (jsc#PED-11232)
- commit bf8b273
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/rxe: Remove rxe_info from rxe_set_mtu (jsc#PED-11232)
- commit f465d25
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/rxe: Improve newline in printing messages (jsc#PED-11232)
- commit 90eaba3
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/hns: Add mutex_destroy() (jsc#PED-11232)
- commit 904c8fc
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/hns: Fix mismatch exception rollback (jsc#PED-11232)
- commit 85f29f4
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/hns: Remove unused parameters and variables (jsc#PED-11232)
- commit fa4851d
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/hns: Use macro instead of magic number (jsc#PED-11232)
- commit 90081b8
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/hns: Support DSCP (jsc#PED-11232)
  Refresh patches.suse/RDMA-hns-Fix-ah-error-counter-in-sw-stat-not-increas.patch
- commit 5676f51
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/hns: Append SCC context to the raw dump of QPC (jsc#PED-11232)
- commit bb1f974
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/hns: Support userspace configuring congestion control algorithm with QP granularity (jsc#PED-11232)
- commit 119cd72
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/hns: Simplify 'struct hns_roce_hem' allocation (jsc#PED-11232)
  Refresh patches.suse/RDMA-hns-Use-complete-parentheses-in-macros.patch
- commit ca8060f
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/hns: Support adaptive PBL hopnum (jsc#PED-11232)
- commit f55e3a5
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/hns: Support flexible umem page size (jsc#PED-11232)
- commit 495f1e3
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/hns: Alloc MTR memory before alloc_mtt() (jsc#PED-11232)
- commit d3f721f
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/hns: Refactor mtr_init_buf_cfg() (jsc#PED-11232)
- commit be31e97
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/hns: Refactor mtr find (jsc#PED-11232)
- commit a7237ff
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix an error path in bnxt_re_add_device (jsc#PED-11232)
- commit 683e1d2
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix a possible NULL pointer dereference (jsc#PED-11232)
- commit 090b952
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix the max WQEs used in Static WQE mode (jsc#PED-11232)
- commit b4fb8e4
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Remove the unused variable en_dev (jsc#PED-11232)
- commit 6a5624c
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Recover the device when FW error is detected (jsc#PED-11232)
- commit 4d4b952
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Group all operations under add_device and remove_device (jsc#PED-11232)
- commit 3222441
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Use the aux device for L2 ULP callbacks (jsc#PED-11232)
- commit d54eb11
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Change aux driver data to en_info to hold more information (jsc#PED-11232)
- commit f7a8018
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix the max WQE size for static WQE support (jsc#PED-11232)
- commit bdbea3d
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix the compatibility flag for variable size WQE (jsc#PED-11232)
- commit 10db167
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Add support for MR Relaxed Ordering (jsc#PED-11232)
- commit 9dfda26
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Avoid an extra hwrm per MR creation (jsc#PED-11232)
- commit 9167354
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Rename a variable (jsc#PED-11232)
- commit 10f95fe
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Update HW interface headers (jsc#PED-11232)
- commit b6163e9
* Thu Oct 31 2024 svarbanov@suse.de
- net: stmmac: dwmac-tegra: Fix link bring-up sequence (git-fixes)
- commit 277d940
* Thu Oct 31 2024 mgorman@suse.de
- net: Use backlog-NAPI to clean up the defer_list (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- Delete
  patches.suse/net-Avoid-the-IPI-to-free-the.patch.
- Add
  patches.suse/net-Allow-to-use-SMP-threads-for-backlog-NAPI.patch
  patches.suse/net-report-RCU-QS-on-threaded-NAPI-repolling.patch
  patches.suse/net-Use-backlog-NAPI-to-clean-up-the-defer_list.patch
  patches.suse/rcu-add-a-helper-to-report-consolidated-flavor-QS.patch
- commit ebf1b5c
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Share a page to expose per SRQ info with userspace (jsc#PED-11232)
- commit 21abeea
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Refactor the BNXT_RE_METHOD_GET_TOGGLE_MEM method (jsc#PED-11232)
- commit 09a05cd
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Get the toggle bits from SRQ events (jsc#PED-11232)
  Refresh patches.suse/RDMA-bnxt_re-Change-the-sequence-of-updating-the-CQ-.patch
- commit 8d2bb41
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Enable variable size WQEs for user space applications (jsc#PED-11232)
- commit 6aabfbd
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Handle variable WQE support for user applications (jsc#PED-11232)
- commit c653e38
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix the table size for PSN/MSN entries (jsc#PED-11232)
- commit 3ebe5d2
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Get the WQE index from slot index while completing the WQEs (jsc#PED-11232)
- commit c104143
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Add support for Variable WQE in Genp7 adapters (jsc#PED-11232)
  Refresh patches.suse/RDMA-bnxt_re-Fix-the-max-CQ-WQEs-for-older-adapters.patch
- commit 43d1473
* Thu Oct 31 2024 nmorey@suse.com
- RDMA: Pass uverbs_attr_bundle as part of '.reg_user_mr_dmabuf' API (jsc#PED-11232)
- commit b87cba8
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Disable doorbell moderation if hardware register read fails (jsc#PED-11232)
  Refresh patches.suse/RDMA-bnxt_re-Avoid-CPU-lockups-due-fifo-occupancy-ch.patch
- commit eff338a
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Enable DB moderation for genP7 adapters (jsc#PED-11232)
- commit d472310
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Update the correct DB FIFO depth and mask for GenP7 (jsc#PED-11232)
  Refresh patches.suse/RDMA-bnxt_re-Avoid-CPU-lockups-due-fifo-occupancy-ch.patch
- commit c20f50f
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Expose the MSN table capability for user library (jsc#PED-11232)
- commit 41f868d
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/bnxt_re: Allow MSN table capability check (jsc#PED-11232)
  Refresh patches.suse/RDMA-bnxt_re-Fix-the-GID-table-length.patch
- commit 0ddceb5
* Thu Oct 31 2024 nmorey@suse.com
- RDMA: Pass entire uverbs attr bundle to create cq function (jsc#PED-8667)
- commit b6ffb04
* Thu Oct 31 2024 nmorey@suse.com
- RDMA/rdmavt: Convert to use ERR_CAST() (jsc#PED-8667)
- commit 1a465a2
* Thu Oct 31 2024 jlee@suse.com
- thermal/drivers/sun8i: Add SRAM register access code
  (jsc#PED-11164).
  Refresh
  patches.suse/thermal-drivers-sun8i-Add-SRAM-register-access-code.patch.
- thermal/drivers/sun8i: Extend H6 calibration to support 4
  sensors (jsc#PED-11164).
- thermal/drivers/sun8i: Explain unknown H6 register value
  (jsc#PED-11164).
- thermal: core: Eliminate writable trip points masks
  (jsc#PED-11164).
  Refresh
  patches.suse/ACPI-thermal-Register-thermal-zones-without-valid-tr.patch.
- thermal: of: Set THERMAL_TRIP_FLAG_RW_TEMP directly
  (jsc#PED-11164).
- thermal: imx: Set THERMAL_TRIP_FLAG_RW_TEMP directly
  (jsc#PED-11164).
- wifi: iwlwifi: mvm: Set THERMAL_TRIP_FLAG_RW_TEMP directly
  (jsc#PED-11164).
- mlxsw: core_thermal: Set THERMAL_TRIP_FLAG_RW_TEMP directly
  (jsc#PED-11164).
- thermal: intel: Set THERMAL_TRIP_FLAG_RW_TEMP directly
  (jsc#PED-11164).
  Refresh
  patches.suse/thermal-intel-int340x-Support-MSI-interrupt-for-Luna.patch.
- thermal: core: Drop the .set_trip_hyst() thermal zone operation
  (jsc#PED-11164).
- thermal: core: Add flags to struct thermal_trip (jsc#PED-11164).
- thermal: Get rid of CONFIG_THERMAL_WRITABLE_TRIPS
  (jsc#PED-11164).
- thermal: intel: Adjust ops handling during thermal zone
  registration (jsc#PED-11164).
  Refresh
  patches.suse/thermal-intel-int340x_thermal-Use-thermal-zone-acces.patch.
- thermal: core: Store zone ops in struct thermal_zone_device
  (jsc#PED-11164).
  Refresh
  patches.suse/thermal-core-Move-initial-num_trips-assignment-befor.patch.
- thermal: intel: Discard trip tables after zone registration
  (jsc#PED-11164).
  Refresh
  patches.suse/thermal-intel-int340x-Support-MSI-interrupt-for-Luna.patch.
- thermal: gov_power_allocator: Avoid overwriting PID coefficients
  from setup time (jsc#PED-11164).
  Refresh
  patches.suse/thermal-gov_power_allocator-Allow-binding-without-tr.patch.
- thermal: core: Change governor name to const char pointer
  (jsc#PED-11164).
- thermal: gov_bang_bang: Fix possible cooling device state
  ping-pong (jsc#PED-11164).
- thermal: gov_fair_share: Fix dependency on trip points ordering
  (jsc#PED-11164).
- commit cdaf4d4
* Wed Oct 30 2024 dsterba@suse.com
- cpufreq: Avoid a bad reference count on CPU node (CVE-2024-50012 bsc#1232386)
- commit 283b9a0
* Wed Oct 30 2024 dsterba@suse.com
- ext4: update orig_path in ext4_find_extent() (CVE-2024-49881 bsc#1232201)
- commit 2ed2a04
* Wed Oct 30 2024 dsterba@suse.com
- ext4: fix slab-use-after-free in ext4_split_extent_at() (bsc#1232201)
- commit c78e4be
* Wed Oct 30 2024 tbogendoerfer@suse.de
- uapi: stddef.h: Provide UAPI macros for __counted_by_{le, be}
  (jsc#PED-11153).
- commit df6bf5d
* Wed Oct 30 2024 krisman@suse.de
- btrfs: don't BUG_ON on ENOMEM from btrfs_lookup_extent_info()
  in walk_down_proc() (CVE-2024-46841 bsc#1231094).
- commit fb4a0c7
* Wed Oct 30 2024 dsterba@suse.com
- ext4: aovid use-after-free in ext4_ext_insert_extent() (CVE-2024-49883 bsc#1232199)
- commit 2db9cb5
* Wed Oct 30 2024 dsterba@suse.com
- blk_iocost: fix more out of bound shifts (CVE-2024-49933 bsc#1232368)
- commit df53397
* Wed Oct 30 2024 tbogendoerfer@suse.de
- idpf: compile singleq code only under default-n
  CONFIG_IDPF_SINGLEQ (jsc#PED-11153).
- Update config files.
- commit d7431c2
* Wed Oct 30 2024 tbogendoerfer@suse.de
- net: intel: introduce {, Intel} Ethernet common library
  (jsc#PED-11153).
- Update config files.
- supported.conf: mark intel/libeth and intel/libie supported
- commit b8317b5
* Wed Oct 30 2024 tbogendoerfer@suse.de
- idpf: merge singleq and splitq &net_device_ops (jsc#PED-11153).
- Refresh patches.suse/0001-idpf-extend-tx-watchdog-timeout.patch.
- commit aa65973
* Wed Oct 30 2024 tbogendoerfer@suse.de
- idpf: split &idpf_queue into 4 strictly-typed queue structures
  (jsc#PED-11153).
- Refresh
  patches.suse/idpf-avoid-bloating-idpf_q_vector-with-big-NR_CPUS.patch.
- Refresh
  patches.suse/idpf-fix-UAFs-when-destroying-the-queues.patch.
- commit 72891e6
* Wed Oct 30 2024 mgorman@suse.de
- timers: Make sure TIMER_PINNED flag is set in add_timer_on()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- workqueue: Use global variant for add_timer() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- timers: Introduce add_timer() variants which modify timer flags
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers: Optimization for timer_base_try_to_set_idle()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers: Move marking timer bases idle into tick_nohz_stop_tick()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers: Split out get next timer interrupt (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- timers: Restructure get_next_timer_interrupt() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- timers: Add struct member description for timer_base
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- tick/sched: Add function description for tick_nohz_next_event()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
  Refresh
  - patches.suse/tick-Fix-timer-storm-since-introduction-of-timersd.patch
- timers: Fix nextevt calculation when no timers are pending
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers: Rework idle logic (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- timers: Use already existing function for forwarding timer base
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers: Split out forward timer base functionality (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- timers: Clarify check in forward_timer_base() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- timers: Move store of next event into __next_timer_interrupt()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- timers: Do not IPI for deferrable timers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- tracing/timers: Add tracepoint for tracking timer base is_idle
  flag (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- tracing/timers: Enhance timer_start tracepoint (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- tick-sched: Warn when next tick seems to be in the past
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- tick/sched: Cleanup confusing variables (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- tick-sched: Fix function names in comments (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: xilinx_uartps: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: vt8500: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: ucc_uart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: uartlite: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: timbuart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: sunzilog: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: sunsu: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: sunsab: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: sunhv: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: stm32: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: st-asc: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: sprd: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: sh-sci: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: txx9: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: mctrl_gpio: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: tegra: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: sb1250-duart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: samsung_tty: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: sa1100: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: rp2: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: qcom-geni: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: pmac_zilog: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: pic32: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: mvebu-uart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: mps2-uart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: mpc52xx: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: milbeaut_usio: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: men_z135_uart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: mcf: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: liteuart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: jsm: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: ip22zilog: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: imx: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: icom: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: fsl_lpuart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: linflexuart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: dz: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: digicolor: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: atmel: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: arc_uart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: apb: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: amba-pl010: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: altera_uart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: altera_jtaguart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: 8250_pci1xxxx: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: 8250_omap: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: 8250_mtk: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: 8250_fsl: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: 8250_exar: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: 8250_dw: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: 8250_dma: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: 8250: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: 8250_bcm7271: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: 8250_aspeed_vuart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: 21285: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- tick/nohz: Update comments some more (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- tick/nohz: Don't shutdown the lowres tick from itself
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- tick/nohz: Update obsolete comments (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- tick/nohz: Rename the tick handlers to more self-explanatory
  names (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- net: dsa: hellcreek: Replace bogus comment (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- posix-timers: Polish coding style in a few places (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- posix-timers: Remove pointless comments (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- posix-timers: Clarify posix_timer_fn() comments (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- posix-timers: Clarify posix_timer_rearm() comment (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- posix-timers: Comment SIGEV_THREAD_ID properly (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- posix-timers: Add proper comments in do_timer_create()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- posix-timers: Document nanosleep() details (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- posix-timers: Document sys_clock_settime() permissions in place
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- posix-timers: Document sys_clock_getoverrun() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- posix-timers: Document common_clock_get() correctly (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- posix-timers: Document sys_clock_getres() correctly (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- posix-timers: Split release_posix_timers() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- posix-timers: Remove pointless irqsafe from hash_lock
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- posix-timers: Set k_itimer:: It_signal to NULL on exit()
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- posix-timers: Annotate concurrent access to k_itimer:: It_signal
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- posix-timers: Add comments about timer lookup (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- posix-timers: Cleanup comments about timer ID tracking
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- posix-timers: Clarify timer_wait_running() comment (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit b3149df
* Wed Oct 30 2024 tbogendoerfer@suse.de
- idpf: deinit virtchnl transaction manager after vport and
  vectors (jsc#PED-11153).
- idpf: use actual mbx receive payload length (jsc#PED-11153).
- idpf: fix VF dynamic interrupt ctl register initialization
  (jsc#PED-11153).
- idpf: enable WB_ON_ITR (jsc#PED-11153).
- idpf: fix netdev Tx queue stop/wake (jsc#PED-11153).
- idpf: refactor Tx completion routines (jsc#PED-11153).
- netdevice: add netdev_tx_reset_subqueue() shorthand
  (jsc#PED-11153).
- idpf: convert to libeth Tx buffer completion (jsc#PED-11153).
- libeth: add Tx buffer completion helpers (jsc#PED-11153).
- idpf: remove redundant 'req_vec_chunks' NULL check
  (jsc#PED-11153).
- idpf: use libeth Rx buffer management for payload buffer
  (jsc#PED-11153).
- idpf: convert header split mode to libeth + napi_build_skb()
  (jsc#PED-11153).
- libeth: support different types of buffers for Rx
  (jsc#PED-11153).
- idpf: remove legacy Page Pool Ethtool stats (jsc#PED-11153).
- idpf: reuse libeth's definitions of parsed ptype structures
  (jsc#PED-11153).
- idpf: strictly assert cachelines of queue and queue vector
  structures (jsc#PED-11153).
- idpf: stop using macros for accessing queue descriptors
  (jsc#PED-11153).
- libeth: add cacheline / struct layout assertion helpers
  (jsc#PED-11153).
- cache: add __cacheline_group_{begin, end}_aligned() (+ couple
  more) (jsc#PED-11153).
- libeth: add Rx buffer management (jsc#PED-11153).
- page_pool: add DMA-sync-for-CPU inline helper (jsc#PED-11153).
- page_pool: constify some read-only function arguments
  (jsc#PED-11153).
- slab: introduce kvmalloc_array_node() and kvcalloc_node()
  (jsc#PED-11153).
- idpf: sprinkle __counted_by{,_le}() in the virtchnl2 header
  (jsc#PED-11153).
- idpf: make virtchnl2.h self-contained (jsc#PED-11153).
- compiler_types: add Endianness-dependent __counted_by_{le,be}
  (jsc#PED-11153).
- net: remove gfp_mask from napi_alloc_skb() (jsc#PED-11153).
- kmsan: compiler_types: declare __no_sanitize_or_inline
  (jsc#PED-11153).
- idpf: remove dealloc vector msg err in idpf_intr_rel
  (jsc#PED-11153).
- idpf: fix minor controlq issues (jsc#PED-11153).
- idpf: prevent deinit uninitialized virtchnl core
  (jsc#PED-11153).
- idpf: cleanup virtchnl cruft (jsc#PED-11153).
- idpf: refactor idpf_recv_mb_msg (jsc#PED-11153).
- idpf: add async_handler for MAC filter messages (jsc#PED-11153).
- idpf: refactor remaining virtchnl messages (jsc#PED-11153).
- idpf: refactor queue related virtchnl messages (jsc#PED-11153).
- idpf: refactor vport virtchnl messages (jsc#PED-11153).
- idpf: implement virtchnl transaction manager (jsc#PED-11153).
- idpf: add idpf_virtchnl.h (jsc#PED-11153).
- docs: ignore __counted_by attribute in structure definitions
  (jsc#PED-11153).
- Documentation: conf.py: Add __force to c_id_attributes
  (jsc#PED-11153).
- commit b2764b9
* Wed Oct 30 2024 mfranc@suse.cz
- Update config files.  Disable CONFIG_SMC_LO. (jsc#PED-10299)
- commit 3162c25
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: add the max value of fallback reason count
  (jsc#PED-10299).
- commit 9f52050
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: avoid overwriting when adjusting sock bufsizes
  (jsc#PED-10299).
- commit ed600cc
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: implement DMB-merged operations of loopback-ism
  (jsc#PED-10299).
- commit 1e4051d
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: adapt cursor update when sndbuf and peer DMB are merged
  (jsc#PED-10299).
- commit 6e12679
* Wed Oct 30 2024 vkarasulli@suse.de
- drm/amd/display: Fix index out of bounds in DCN30 color
  transformation (CVE-2024-49969 bsc#1232519).
- commit 7d6c264
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: {at|de}tach sndbuf to peer DMB if supported
  (jsc#PED-10299).
- commit a78ce86
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: add operations to merge sndbuf with peer DMB
  (jsc#PED-10299).
- commit 255d7db
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: register loopback-ism into SMC-D device list
  (jsc#PED-10299).
- commit 969c79b
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: ignore loopback-ism when dumping SMC-D devices
  (jsc#PED-10299).
- commit 09e1f8f
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: mark optional smcd_ops and check for support when
  called (jsc#PED-10299).
- commit dd1639b
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: implement DMB-related operations of loopback-ism
  (jsc#PED-10299).
- commit cd2698b
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: implement ID-related operations of loopback-ism
  (jsc#PED-10299).
- commit cc94331
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: introduce loopback-ism for SMC intra-OS shortcut
  (jsc#PED-10299).
- commit 62cd897
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: decouple ism_client from SMC-D DMB registration
  (jsc#PED-10299).
- commit 92fe80b
* Wed Oct 30 2024 tiwai@suse.de
- ASoC: fsl_micfil: Add a flag to distinguish with different
  volume control types (git-fixes).
- Bluetooth: hci_conn: Fix UAF in hci_enhanced_setup_sync
  (git-fixes).
- HID: i2c-hid: Skip SET_POWER SLEEP for Cirque touchpad on
  system suspend (stable-fixes).
- HID: i2c-hid: Renumber I2C_HID_QUIRK_ defines (stable-fixes).
- commit f003dc2
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: Avoid -Wflex-array-member-not-at-end warnings
  (jsc#PED-10299).
- commit 786ed77
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: make smc_hash_sk/smc_unhash_sk static (jsc#PED-10299).
- commit c82ca91
* Wed Oct 30 2024 mfranc@suse.cz
- net: smc: fix spurious error message from __sock_release()
  (jsc#PED-10299).
- commit e9423b1
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: change the term virtual ISM to Emulated-ISM
  (jsc#PED-10299).
- commit 89fb842
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: fix incorrect SMC-D link group matching logic
  (jsc#PED-10299).
- commit 414f46a
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: fix invalid link access in dumping SMC-R connections
  (jsc#PED-10299).
- commit 7a98bf7
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: manage system EID in SMC stack instead of ISM driver
  (jsc#PED-10299).
- commit d29a617
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: disable SEID on non-s390 archs where virtual ISM may
  be used (jsc#PED-10299).
- commit 9515da3
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: support extended GID in SMC-D lgr netlink attribute
  (jsc#PED-10299).
- commit 87abc59
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: compatible with 128-bits extended GID of virtual ISM
  device (jsc#PED-10299).
- commit 7d8af85
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: define a reserved CHID range for virtual ISM devices
  (jsc#PED-10299).
- commit 94a7601
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: introduce virtual ISM device support feature
  (jsc#PED-10299).
- commit 649e927
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: support SMCv2.x supplemental features negotiation
  (jsc#PED-10299).
- commit fe87065
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: unify the structs of accept or confirm message for
  v1 and v2 (jsc#PED-10299).
- commit c1a7f02
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: introduce sub-functions for
  smc_clc_send_confirm_accept() (jsc#PED-10299).
- commit 3759572
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: rename some 'fce' to 'fce_v2x' for clarity
  (jsc#PED-10299).
- commit 2849caa
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: remove unneeded atomic operations in
  smc_tx_sndbuf_nonempty (jsc#PED-10299).
- net/smc: add sysctl for max conns per lgr for SMC-R v2.1
  (jsc#PED-10299).
- net/smc: add sysctl for max links per lgr for SMC-R v2.1
  (jsc#PED-10299).
- net/smc: fix missing byte order conversion in CLC handshake
  (jsc#PED-10299).
- s390/ism: ism driver implies smc protocol (jsc#PED-10299).
- net/smc: put sk reference if close work was canceled
  (jsc#PED-10299).
- net/smc: allow cdc msg send rather than drop it with NULL
  sndbuf_desc (jsc#PED-10299).
- net/smc: fix dangling sock under state SMC_APPFINCLOSEWAIT
  (jsc#PED-10299).
- net/smc: return the right falback reason when prefix checks fail
  (jsc#PED-10299).
- net/smc: fix smc clc failed issue when netdevice not in init_net
  (jsc#PED-10299).
- net/smc: Fix dependency of SMC on ISM (jsc#PED-10299).
- commit 88ec756
* Wed Oct 30 2024 mfranc@suse.cz
- blacklist.conf: ibm has asked us to backport it (jsc#PED-10299)
- commit 9fc8aab
* Wed Oct 30 2024 tiwai@suse.de
- platform/x86/intel/pmc: Fix pmc_core_iounmap to call iounmap
  for valid addresses (git-fixes).
- ASoC: rsnd: Fix probe failure on HiHope boards due to endpoint
  parsing (git-fixes).
- ASoC: dapm: avoid container_of() to get component (git-fixes).
- ASoC: SOF: Intel: hda-loader: do not wait for HDaudio IOC
  (git-fixes).
- commit 9bed72f
* Wed Oct 30 2024 petr.pavlu@suse.com
- static_call: Replace pointless WARN_ON() in
  static_call_module_notify() (bsc#1232155 CVE-2024-49954).
- commit 03b6c35
* Wed Oct 30 2024 jlee@suse.com
- EINJ, CXL: Fix CXL device SBDF calculation (jsc#PED-11164).
- ACPI: APEI: EINJ: mark remove callback as non-__exit
  (jsc#PED-11164).
- commit 1bb8a8b
* Wed Oct 30 2024 petr.pavlu@suse.com
- module: abort module loading when sysfs setup suffer errors
  (git-fixes).
- Refresh patches.suse/add-suse-supported-flag.patch.
- commit db27509
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: Extend SMCR v2 linkgroup netlink attribute
  (jsc#PED-10299).
- net/smc: support max links per lgr negotiation in clc handshake
  (jsc#PED-10299).
- net/smc: support max connections per lgr negotiation
  (jsc#PED-10299).
- net/smc: support smc v2.x features validate (jsc#PED-10299).
- net/smc: add vendor unique experimental options area in clc
  handshake (jsc#PED-10299).
- net/smc: support smc release version negotiation in clc
  handshake (jsc#PED-10299).
- commit 15ac654
* Wed Oct 30 2024 mfranc@suse.cz
- net/smc: Remove unused function declarations (jsc#PED-10299).
- commit b4444f2
* Wed Oct 30 2024 petr.pavlu@suse.com
- blacklist.conf: add a not-relevant module commit
- commit 0874efa
* Wed Oct 30 2024 petr.pavlu@suse.com
- bpf,perf: Fix perf_event_detach_bpf_prog error handling
  (git-fixes).
- commit 5b6b2d4
* Wed Oct 30 2024 petr.pavlu@suse.com
- tracing: Consider the NULL character when validating the event
  length (git-fixes).
- commit 6b1d97f
* Wed Oct 30 2024 petr.pavlu@suse.com
- uprobe: avoid out-of-bounds memory access of fetching args
  (git-fixes).
- uprobes: encapsulate preparation of uprobe args buffer
  (git-fixes).
- commit ead6cfe
* Wed Oct 30 2024 mfranc@suse.cz
- s390/pci: Handle PCI error codes other than 0x3a (git-fixes
  bsc#1232629).
- commit e4948be
* Wed Oct 30 2024 mfranc@suse.cz
- s390/sclp: Deactivate sclp after all its users (git-fixes
  bsc#1232628).
- commit 9e889e7
* Wed Oct 30 2024 mfranc@suse.cz
- s390/sclp_vt220: Convert newlines to CRLF instead of LFCR
  (git-fixes bsc#1232627).
- commit 5725ee0
* Wed Oct 30 2024 mfranc@suse.cz
- KVM: s390: Change virtual to physical address access in diag
  0x258 handler (git-fixes bsc#1232626).
- commit 2b0b1e9
* Wed Oct 30 2024 mfranc@suse.cz
- KVM: s390: gaccess: Check if guest address is in memslot
  (git-fixes bsc#1232623).
- commit b583687
* Wed Oct 30 2024 petr.pavlu@suse.com
- fgraph: Use CPU hotplug mechanism to initialize idle shadow
  stacks (git-fixes).
- commit 4265ef9
* Wed Oct 30 2024 petr.pavlu@suse.com
- mm: khugepaged: fix the arguments order in
  khugepaged_collapse_file trace point (git-fixes).
- commit 43546b6
* Wed Oct 30 2024 petr.pavlu@suse.com
- tracing/hwlat: Fix a race during cpuhp processing (git-fixes).
- tracing/timerlat: Fix a race during cpuhp processing
  (git-fixes).
- tracing/timerlat: Drop interface_lock in stop_kthread()
  (git-fixes).
- tracing/timerlat: Fix duplicated kthread creation due to CPU
  online/offline (git-fixes).
- tracing/osnoise: Fix build when timerlat is not enabled
  (git-fixes).
- tracing/timerlat: Add interface_lock around clearing of kthread
  in stop_kthread() (git-fixes).
- tracing/timerlat: Only clear timer if a kthread exists
  (git-fixes).
- tracing/osnoise: Use a cpumask to know what threads are kthreads
  (git-fixes).
- tracing/timerlat: Move hrtimer_init to timerlat_fd open()
  (git-fixes).
- tracing/timerlat: Add user-space interface (git-fixes).
- tracing/osnoise: Skip running osnoise if all instances are off
  (git-fixes).
- tracing/osnoise: Switch from PF_NO_SETAFFINITY to
  migrate_disable (git-fixes).
- commit 8482ad0
* Wed Oct 30 2024 mgorman@suse.de
- hrtimer: Annotate hrtimer_cpu_base_.*_expiry() for sparse
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- serial: sifive: Remove 0 from fu540-c000-uart0 binding
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- net/core: Enable socket busy polling on -RT (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit a2a9bdb
* Wed Oct 30 2024 ailiop@suse.com
- ocfs2: pass u64 to ocfs2_truncate_inline maybe overflow
  (git-fixes).
- commit 24fea60
* Wed Oct 30 2024 mgorman@suse.de
- serial: pch: Use uart_prepare_sysrq_char() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: pch: Remove eg20t_port::lock (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: sifive: Use uart_prepare_sysrq_char() to handle sysrq
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- serial: rda: Use uart_prepare_sysrq_char() to handle sysrq
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- serial: owl: Use uart_prepare_sysrq_char() to handle sysrq
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- serial: lpc32xx_hs: Use uart_prepare_sysrq_char() to handle
  sysrq (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- serial: sunplus: Use uart_prepare_sysrq_char() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: pxa: Use uart_prepare_sysrq_char() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: lpc32xx_hs: remove redundant check and assignment of
  hsu_rate (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- serial: sifive: Declare PM operations as static (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: sunplus: Convert to platform remove callback returning
  void (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- serial: sifive: Convert to platform remove callback returning
  void (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- serial: rda: Convert to platform remove callback returning void
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- serial: owl: Convert to platform remove callback returning void
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- serial: lpc32xx_hs: Convert to platform remove callback
  returning void (bsc#1232534 (PREEMPT_RT prerequisite
  backports)).
- serial: sunplus-uart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: sifive: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: rda: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: pxa: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: pch: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: owl: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: lpc32xx_hs: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 279d376
* Wed Oct 30 2024 nik.borisov@suse.com
- Refresh patches.suse/x86-fix-user-address-masking-non-canonical-speculation-iss.patch. (bsc#1232529)
  Give check_range a unique label. Otherwise the macro's 1b label
  conflicts with __get_user_1's 1 label and this causes the exception fixup
  entry, installed at the end of the file to match the wrong thing.
  Instead of matching __get_user_1's 1b label it will match check_range's 1b
  label when this macro is expanded for the last time in __get_user_8.
  This fixes intermittent random crashes when copying data from userspace.
- commit 3a35fd0
* Wed Oct 30 2024 mgorman@suse.de
- serial: omap: Use uart_prepare_sysrq_char() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: omap: Convert to platform remove callback returning void
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- serial: omap: Use port lock wrappers (bsc#1232534 (PREEMPT_RT prerequisite backports)).
  Delete
  - patches.suse/tty-serial-omap-Make-the-locking-RT-aware.patch
    Later replaced by commit 63bd93ac6148 ("serial: omap: Use
    uart_prepare_sysrq_char().")
- commit 282140f
* Wed Oct 30 2024 petr.pavlu@suse.com
- jump_label: Fix static_key_slow_dec() yet again (git-fixes).
- commit ab363f5
* Wed Oct 30 2024 mgorman@suse.de
- serial: msm: Use uart_prepare_sysrq_char() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: meson: Use uart_prepare_sysrq_char() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: bcm63xx: Use uart_prepare_sysrq_char() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: msm: Use OPP table for DVFS support (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: msm: Convert to platform remove callback returning void
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- serial: meson: Convert to platform remove callback returning
  void (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- serial: bcm63xx: Convert to platform remove callback returning
  void (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- tty: serial: meson: Add a earlycon for the S4 SoC (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: msm: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: meson: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- serial: bcm63xx-uart: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 8688085
* Wed Oct 30 2024 jlee@suse.com
- ACPI: APEI: EINJ: Fix einj_dev release leak (jsc#PED-11164).
- EINJ: Add CXL error type support (jsc#PED-11164).
  Refresh
  patches.suse/acpi-Disable-APEI-error-injection-if-the-kernel-is-lockeddown.patch.
  Update config files.
  Add 'CONFIG_ACPI_APEI_EINJ_CXL is not set' to config/arm64/default
  Add 'CONFIG_ACPI_APEI_EINJ_CXL is not set' to config/x86_64/default
- commit e18a969
* Wed Oct 30 2024 tbogendoerfer@suse.de
- be2net: fix potential memory leak in be_xmit() (jsc#PED-8900
  jsc#PED-11249).
- ibmvnic: Inspect header requirements before using scrq direct
  (jsc#PED-9909).
- be2net: Remove unused declarations (jsc#PED-8900 jsc#PED-11249).
- ibmvnic: Perform tx CSO during send scrq direct (jsc#PED-9909).
- ibmvnic: Only record tx completed bytes once per handler
  (jsc#PED-9909).
- ibmvnic: Introduce send sub-crq direct (jsc#PED-9909).
- ibmvnic: Remove duplicate memory barriers in tx (jsc#PED-9909).
- ibmvnic: Reduce memcpys in tx descriptor generation
  (jsc#PED-9909).
- ibmvnic: Use header len helper functions on tx (jsc#PED-9909).
- ibmvnic: Only replenish rx pool when resources are getting low
  (jsc#PED-9909).
- ibmveth: Recycle buffers during replenish phase (jsc#PED-9908).
- ibmveth: Optimize poll rescheduling process (jsc#PED-9908).
- ibmvnic: Free any outstanding tx skbs during scrq reset
  (jsc#PED-9909).
- ibmvnic: Return error code on TX scrq flush fail (jsc#PED-9909).
- ibmvnic: replace deprecated strncpy with strscpy (jsc#PED-9909).
- ibmvnic: remove unused rc variable (jsc#PED-9909).
- commit 7ba274d
* Wed Oct 30 2024 petr.pavlu@suse.com
- SUNRPC: Fixup gss_status tracepoint error output (git-fixes).
- commit 84cc417
* Wed Oct 30 2024 jlee@suse.com
- ACPI: PM: s2idle: Evaluate all Low-Power S0 Idle _DSM functions
  (jsc#PED-11164).
- ACPI: PM: Improve kerneldoc comments for suspend and hibernation
  functions (jsc#PED-11164).
- ACPI: Document handle_eject_request() arguments (jsc#PED-11164).
- EINJ: Migrate to a platform driver (jsc#PED-11164).
  Refresh
  patches.suse/acpi-Disable-APEI-error-injection-if-the-kernel-is-lockeddown.patch.
- ACPI: HMAT: Introduce 2 levels of generic port access class
  (jsc#PED-11164).
- base/node / ACPI: Enumerate node access class for 'struct
  access_coordinate' (jsc#PED-11164).
- platform/x86: serial-multi-instantiate: Add support for CS35L54
  and CS35L57 (jsc#PED-11164).
- commit 6a19288
* Wed Oct 30 2024 jlee@suse.com
- thermal: ACPI: Constify acpi_thermal_zone_ops (jsc#PED-11164).
- ACPI: pfr_update: Convert to platform remove callback returning
  void (jsc#PED-11164).
- ACPI: pfr_telemetry: Convert to platform remove callback
  returning void (jsc#PED-11164).
- ACPI: fan: Convert to platform remove callback returning void
  (jsc#PED-11164).
- ACPI: GED: Convert to platform remove callback returning void
  (jsc#PED-11164).
- ACPI: DPTF: Convert to platform remove callback returning void
  (jsc#PED-11164).
- ACPI: AGDI: Convert to platform remove callback returning void
  (jsc#PED-11164).
- ACPI: TAD: Convert to platform remove callback returning void
  (jsc#PED-11164).
- ACPI: Drop the custom_method debugfs interface (jsc#PED-11164).
  Update config files.
  Removed 'CONFIG_ACPI_CUSTOM_METHOD is not set' in config/x86_64/default
  Removed 'CONFIG_ACPI_CUSTOM_METHOD is not set' in config/arm64/default
- ACPI: use %%pe for better readability of errors while printing
  (jsc#PED-11164).
- ACPI: APEI: Skip initialization of GHES_ASSIST structures for
  Machine Check Architecture (jsc#PED-11164).
- ACPI: APEI: GHES: Convert to platform remove callback returning
  void (jsc#PED-11164).
- ACPI: video: Handle fetching EDID that is longer than 256 bytes
  (jsc#PED-11164).
- ACPI: x86: Add DELL0501 handling to
  acpi_quirk_skip_serdev_enumeration() (jsc#PED-11164).
- ACPI: thermal_lib: Initialize temp_decik to zero
  (jsc#PED-11164).
- ACPI: NFIT: Switch to use acpi_evaluate_dsm_typed()
  (jsc#PED-11164).
- ACPI: resource: Use IRQ override on Maibenben X565
  (jsc#PED-11164).
  Refresh
  patches.suse/ACPI-resource-Do-IRQ-override-on-TongFang-GXxHRXx-an.patch.
- ACPI: resource: Add IRQ override quirk for ASUS ExpertBook
  B2502FBA (jsc#PED-11164).
- ACPI: resource: Skip IRQ override on ASUS ExpertBook B1502CVA
  (jsc#PED-11164).
- ACPI: PM: s2idle: Enable Low-Power S0 Idle MSFT UUID for
  non-AMD systems (jsc#PED-11164).
- ACPI: bus: make acpi_bus_type const (jsc#PED-11164).
- ACPI: scan: Consolidate Device Check and Bus Check notification
  handling (jsc#PED-11164).
- ACPI: scan: Rework Device Check and Bus Check notification
  handling (jsc#PED-11164).
- ACPI: scan: Make acpi_processor_add() check the device enabled
  bit (jsc#PED-11164).
- ACPI: scan: Relocate acpi_bus_trim_one() (jsc#PED-11164).
- ACPI: scan: Defer enumeration of devices with a _DEP pointing
  to IVSC device (jsc#PED-11164).
- cpuidle: ACPI/intel: fix MWAIT hint target C-state computation
  (jsc#PED-11164).
- commit 440728e
* Wed Oct 30 2024 jlee@suse.com
- ACPI: cpufreq: Add highest perf change notification
  (jsc#PED-11164).
- x86/acpi: Use %%rip-relative addressing in wakeup_64.S
  (jsc#PED-11164).
- commit baf7a5d
* Tue Oct 29 2024 dsterba@suse.com
- drm/amd/display: Deallocate DML memory if allocation fails (CVE-2024-49972 bsc#1232315)
- commit dd5ab13
* Tue Oct 29 2024 dsterba@suse.com
- drm/amd/display: Check stream before comparing them (CVE-2024-49896 bsc#1232221)
- commit 930546b
* Tue Oct 29 2024 dsterba@suse.com
- drm/amd/pm: ensure the fw_info is not null before using it (CVE-2024-49890 bsc#1232217)
- commit a0e8b9f
* Tue Oct 29 2024 dsterba@suse.com
- drm/amd/display: Initialize get_bytes_per_element's default to 1 (CVE-2024-49892 bsc#1232220)
- commit e1539d0
* Tue Oct 29 2024 mgorman@suse.de
- serial: ar933x: Use uart_prepare_sysrq_char() (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- serial: ar933x: Convert to platform remove callback returning
  void (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- serial: ar933x: Use port lock wrappers (bsc#1232534 (PREEMPT_RT
  prerequisite backports)).
- commit 85ea13e
* Tue Oct 29 2024 dsterba@suse.com
- drivers/perf: Fix ali_drw_pmu driver interrupt status clearing (CVE-2024-47731 bsc#1232117)
- commit 774dc33
* Tue Oct 29 2024 dsterba@suse.com
- padata: use integer wrap around to prevent deadlock on seq_nr overflow (CVE-2024-47739 bsc#1232124)
- commit 7e58560
* Tue Oct 29 2024 dsterba@suse.com
- media: mediatek: vcodec: Fix H264 stateless decoder smatch warning (CVE-2024-47752 bsc#1232130)
- commit 086cd43
* Tue Oct 29 2024 dsterba@suse.com
- media: mediatek: vcodec: Fix H264 multi stateless decoder smatch warning (CVE-2024-47754 bsc#1232131)
- commit dacb1c6
* Tue Oct 29 2024 dsterba@suse.com
- drm/v3d: Prevent out of bounds access in performance query extensions (CVE-2024-49984 bsc#1232095)
  Remove from blacklist.conf.
- commit 1e0ab9a
* Tue Oct 29 2024 dsterba@suse.com
- media: mediatek: vcodec: Fix VP8 stateless decoder smatch warning (CVE-2024-47753 bsc#1231868)
- commit fed66a9
* Tue Oct 29 2024 vkarasulli@suse.de
- iommu/vt-d: Always reserve a domain ID for identity setup
  (git-fixes).
- commit f7ecad0
* Tue Oct 29 2024 mfranc@suse.cz
- s390/disassembler: Add instructions (jsc#PED-9586).
- s390/disassembler: Update instruction mnemonics to latest spec
  (jsc#PED-9586).
- s390/disassembler: Use proper format specifiers for operand
  values (jsc#PED-9586).
- commit 8f368b8
* Tue Oct 29 2024 dsterba@suse.com
- btrfs: clean up our handling of refs == 0 in snapshot delete (CVE-2024-46840 bsc#1231105)
- commit 788d396
* Tue Oct 29 2024 mfranc@suse.cz
- s390/kprobes: Avoid stop machine if possible (jsc#PED-10287).
- s390/setup: Recognize sequential instruction fetching facility
  (jsc#PED-10287).
- commit be76bc8
* Tue Oct 29 2024 shung-hsi.yu@suse.com
- kABI: bpf: struct bpf_map kABI workaround (CVE-2024-50063
  bsc#1232435).
- selftests/bpf: Add test for lsm tail call (CVE-2024-50063
  bsc#1232435).
- bpf: Prevent tail call between progs attached to different hooks
  (CVE-2024-50063 bsc#1232435).
- commit 666246a
* Tue Oct 29 2024 mgorman@suse.de
- net: dst: Make dst_destroy() static and return void (bsc#1232534
  (PREEMPT_RT prerequisite backports)).
- commit 35b7e92
* Tue Oct 29 2024 lduncan@suse.com
- blacklist.conf: git-fix does not apply
  Needs other commits not present, else not needed.
- commit 9d203da
* Tue Oct 29 2024 vkarasulli@suse.de
- iommu/vt-d: Fix incorrect pci_for_each_dma_alias() for non-PCI
  devices (git-fixes).
- commit 28951a9
* Tue Oct 29 2024 mfranc@suse.cz
- s390/iucv: Fix vargs handling in iucv_alloc_device()
  (jsc#PED-10300).
- s390/smsgiucv_app: Make use of iucv_alloc_device()
  (jsc#PED-10300).
- s390/netiucv: Make use of iucv_alloc_device() (jsc#PED-10300).
- s390/iucv: Provide iucv_alloc_device() / iucv_release_device()
  (jsc#PED-10300).
- net/iucv: Avoid explicit cpumask var allocation on stack
  (jsc#PED-10300 CVE-2024-42094 bsc#1228679).
- s390/iucv: use new address translation helpers (jsc#PED-10300).
- s390/ctcm: use new address translation helpers (jsc#PED-10300).
- s390/lcs: use new address translation helpers (jsc#PED-10300).
- s390/qeth: use new address translation helpers (jsc#PED-10300).
- s390/iucv: fix receive buffer virtual vs physical address
  confusion (jsc#PED-10300).
- net/af_iucv: fix virtual vs physical address confusion
  (jsc#PED-10300).
- net/iucv: fix virtual vs physical address confusion
  (jsc#PED-10300).
- iucv: make iucv_bus const (jsc#PED-10300).
- s390/qeth: Fix typo 'weed' in comment (jsc#PED-10300).
- s390/qeth: replace deprecated strncpy with strscpy
  (jsc#PED-10300).
- s390/ctcm: replace deprecated strncpy with strscpy
  (jsc#PED-10300).
- s390/lcs: Remove FDDI option (jsc#PED-10300).
- commit 864492f
* Tue Oct 29 2024 mfranc@suse.cz
- blacklist.conf: IBM asked to backport this (jsc#PED-10300)
- commit 8c2151a
* Tue Oct 29 2024 tzimmermann@suse.com
- drm/amd/display: Check null pointers before multiple uses (bsc#1232313 CVE-2024-49920)
- commit 5447aa1
* Tue Oct 29 2024 mfranc@suse.cz
- s390/zfcp: use new address translation helpers (jsc#PED-10301).
- s390/cio: use new address translation helpers (jsc#PED-10301).
- s390/cio: use bitwise types to allow for type checking
  (jsc#PED-10301).
- s390/cio: introduce bitwise dma types and helper functions
  (jsc#PED-10301).
- s390/cio: fix virtual vs physical address confusion
  (jsc#PED-10301).
- scsi: zfcp: Replace strlcpy() with strscpy() (jsc#PED-10301).
- s390/cio: fix virtual vs physical address confusion
  (jsc#PED-10301).
- commit b320d48
* Tue Oct 29 2024 mgorman@suse.de
- serial: amba-pl011: Use port lock wrappers (bsc#1232534
  (PREEMPT_RT prerequisite backports)
- commit 2104d49
* Tue Oct 29 2024 mgorman@suse.de
- Update metadata patches.suse/x86-microcode-Remove-microcode_mutex.patch
  (bsc#1232534 (PREEMPT_RT prerequisite backports)).
- commit c29a244
* Tue Oct 29 2024 sjaeckel@suse.de
- Update
  patches.suse/bonding-change-ipsec_lock-from-spin-lock-to-mutex.patch
  (CVE-2024-46678 bsc#1230550 jsc#PED-10564).
- Update
  patches.suse/bonding-extract-the-use-of-real_device-into-local-va.patch
  (CVE-2024-46678 bsc#1230550 jsc#PED-10564).
- Update
  patches.suse/bonding-implement-xdo_dev_state_free-and-call-it-aft.patch
  (CVE-2024-46678 bsc#1230550 jsc#PED-10564).
- commit a6d64e4
* Tue Oct 29 2024 tzimmermann@suse.com
- drm/amd/display: Check link_res->hpo_dp_link_enc before using it (bsc#1231944)
- commit bf57b96
* Tue Oct 29 2024 tzimmermann@suse.com
- drm/amd/display: Check null-initialized variables (bsc#1232222 CVE-2024-49898)
- commit a00bfda
* Tue Oct 29 2024 tzimmermann@suse.com
- drm/amd/display: Check link_res->hpo_dp_link_enc before using it (bsc#1231944 CVE-2024-47704)
- commit 931c899
* Tue Oct 29 2024 tiwai@suse.de
- spi: spi-fsl-dspi: Fix crash when not using GPIO chip select
  (git-fixes).
- spi: mtk-snfi: fix kerneldoc for mtk_snand_is_page_ops()
  (git-fixes).
- spi: atmel-quadspi: Fix wrong register value written to MR
  (git-fixes).
- commit fd0b348
* Tue Oct 29 2024 jlee@suse.com
- firmware: xilinx: Export function to use in other module
  (jsc#PED-11164).
- firmware: xilinx: Add support to get platform information
  (jsc#PED-11164).
- commit f7cdf96
* Tue Oct 29 2024 jlee@suse.com
- efi/libstub: Cast away type warning in use of max()
  (jsc#PED-11167).
- commit bee4041
* Mon Oct 28 2024 krisman@suse.de
- crypto: stm32/cryp - call finalize with bh disabled
  (CVE-2024-47658 bsc#1231436).
- commit 2854148
* Mon Oct 28 2024 lduncan@suse.com
- block: add back disk_update_readahead (bsc#1228325
  jsc#PED-9783).
- scsi: mpi3mr: Avoid MAX_PAGE_ORDER WARNING for buffer
  allocations (git-fixes).
- scsi: mpi3mr: Add missing spin_lock_init() for
  mrioc->trigger_lock (git-fixes).
- scsi: mpi3mr: Driver version update (bsc#1228325 jsc#PED-9783).
- scsi: mpi3mr: Prevent PCI writes from driver during PCI error
  recovery (bsc#1228325 jsc#PED-9783).
- scsi: mpi3mr: Support PCI Error Recovery callback handlers
  (bsc#1228325 jsc#PED-9783).
- scsi: mpi3mr: Update driver version to 8.9.1.0.50 (bsc#1228325
  jsc#PED-9783).
- scsi: mpi3mr: Add ioctl support for HDB (bsc#1228325
  jsc#PED-9783).
- scsi: mpi3mr: Trigger support (bsc#1228325 jsc#PED-9783).
- scsi: mpi3mr: HDB allocation and posting for hardware and
  firmware buffers (bsc#1228325 jsc#PED-9783).
- block: remove disk_update_readahead (bsc#1228325 jsc#PED-9783).
- block: Drop locking annotation for limits_lock (git-fixes).
- fix missing vmalloc.h includes (bsc#1228325 jsc#PED-9783).
- scsi: mpi3mr: Switch to using ->device_configure (git-fixes).
- scsi: core: Add a device_configure method to the host template
  (bsc#1228325 jsc#PED-9783).
- scsi: core: Use the atomic queue limits API in scsi_add_lun()
  (bsc#1228325 jsc#PED-9783).
- scsi: mpi3mr: Pass queue_limits to bsg_setup_queue()
  (bsc#1228325 jsc#PED-9783).
- scsi: bsg: Pass queue_limits to bsg_setup_queue() (bsc#1228325
  jsc#PED-9783).
- scsi: block: Add a helper to cancel atomic queue limit updates
  (bsc#1228325 jsc#PED-9783).
- scsi: mpi3mr: Driver version update to 8.8.1.0.50 (bsc#1228325
  jsc#PED-9783).
- scsi: mpi3mr: Update MPI Headers to revision 31 (bsc#1228325
  jsc#PED-9783).
- scsi: mpi3mr: Debug ability improvements (bsc#1228325
  jsc#PED-9783).
- scsi: mpi3mr: Set the WriteSame Divert Capability in the
  IOCInit MPI Request (bsc#1228325 jsc#PED-9783).
- scsi: mpi3mr: Clear ioctl blocking flag for an unresponsive
  controller (bsc#1228325 jsc#PED-9783).
- scsi: mpi3mr: Set MPI request flags appropriately (bsc#1228325
  jsc#PED-9783).
- scsi: mpi3mr: Block devices are not removed even when VDs are
  offlined (bsc#1228325 jsc#PED-9783).
- scsi: mpi3mr: Replace deprecated strncpy() with assignments
  (bsc#1228325 jsc#PED-9783).
- scsi: mpi3mr: Avoid possible run-time warning with long
  manufacturer strings (bsc#1228325 jsc#PED-9783).
- block: set default max segment size in case of virt_boundary
  (git-fixes).
- block: allow device to have both virt_boundary_mask and max
  segment size (git-fixes).
- scsi: mpi3mr: Avoid memcpy field-spanning write WARNING
  (bsc#1228325 jsc#PED-9783).
- block: fix virt_boundary handling in blk_validate_limits
  (git-fixes).
- block: add an API to atomically update queue limits (bsc#1228325
  jsc#PED-9783).
- block: refactor disk_update_readahead (bsc#1228325
  jsc#PED-9783).
- block: move max_{open,active}_zones to struct queue_limits
  (bsc#1228325 jsc#PED-9783).
- block: rename and document BLK_DEF_MAX_SECTORS (bsc#1228325
  jsc#PED-9783).
- commit 2c0578b
* Mon Oct 28 2024 jlee@suse.com
- efi/libstub: fix efi_random_alloc() to allocate memory at
  alloc_min or higher address (jsc#PED-11167).
- commit d501c94
* Mon Oct 28 2024 henrique.carvalho@suse.com
- smb: client: fix UAF in async decryption (bsc#1232418
  CVE-2024-50047).
- commit 381863e
* Mon Oct 28 2024 jlee@suse.com
- EDAC/skx_common: Allow decoding of SGX addresses
  (jsc#PED-11164).
- EDAC/versal: Do not log total error counts (jsc#PED-11164).
- commit b302f9b
* Mon Oct 28 2024 tbogendoerfer@suse.de
- e1000e: fix force smbus during suspend flow (git-fixes).
- commit f9cbf12
* Mon Oct 28 2024 fdmanana@suse.com
- btrfs: wait for fixup workers before stopping cleaner kthread
  during umount (bsc#1232262 CVE-2024-49867).
- btrfs: fix race setting file private on concurrent lseek using
  same fd (bsc#1231869 CVE-2024-47741).
- commit af36a3e
* Mon Oct 28 2024 jlee@suse.com
- EDAC: constantify the struct bus_type usage (jsc#PED-11164).
- driver core: bus: constantify subsys_register() calls
  (jsc#PED-11164).
- commit 7c3a880
* Mon Oct 28 2024 tbogendoerfer@suse.de
- ppp: fix ppp_async_encode() illegal access (CVE-2024-50035
  bsc#1232392).
- net: avoid potential underflow in qdisc_pkt_len_init() with UFO
  (CVE-2024-49949 bsc#1232160).
- commit f4bcea0
* Mon Oct 28 2024 tbogendoerfer@suse.de
- ice: map XDP queues to vectors in ice_vsi_map_rings_to_vectors()
  (git-fixes).
- Refresh
  patches.suse/ice-move-netif_queue_set_napi-to-rtnl-protected-sect.patch.
- commit 7b44c3c
* Mon Oct 28 2024 tbogendoerfer@suse.de
- net/mlx5: Check capability for fw_reset (git-fixes).
- Refresh
  patches.suse/net-mlx5-Fix-MTMP-register-capability-offset-in-MCAM.patch.
- commit 480249d
* Mon Oct 28 2024 tbogendoerfer@suse.de
- net/mlx5e: Don't call cleanup on profile rollback failure
  (git-fixes).
- net/mlx5: Unregister notifier on eswitch init failure
  (git-fixes).
- net/mlx5: Fix command bitmask initialization (git-fixes).
- net/mlx5: Check for invalid vector index on EQ creation
  (git-fixes).
- e1000e: change I219 (19) devices to ADP (git-fixes).
- ice: Flush FDB entries before reset (git-fixes).
- ice: Fix netif_is_ice() in Safe Mode (git-fixes).
- ice: fix VLAN replay after reset (git-fixes).
- ice: disallow DPLL_PIN_STATE_SELECTABLE for dpll output pins
  (git-fixes).
- ice: clear port vlan config during reset (git-fixes).
- ice: set correct dst VSI in only LAN filters (git-fixes).
- net/mlx5: Added cond_resched() to crdump collection (git-fixes).
- vduse: avoid using __GFP_NOFAIL (git-fixes).
- igb: Always call igb_xdp_ring_update_tail() under Tx lock
  (git-fixes).
- ice: fix VSI lists confusion when adding VLANs (git-fixes).
- ice: fix accounting for filters shared by multiple VSIs
  (git-fixes).
- ice: Fix lldp packets dropping after changing the number of
  channels (git-fixes).
- net/mlx5: Add missing masks and QoS bit masks for scheduling
  elements (git-fixes).
- net/mlx5: Explicitly set scheduling element and TSAR type
  (git-fixes).
- net/mlx5e: Add missing link mode to ptys2ext_ethtool_map
  (git-fixes).
- net/mlx5e: Add missing link modes to ptys2ethtool_map
  (git-fixes).
- net/mlx5: Update the list of the PCI supported devices
  (git-fixes).
- ice: do not bring the VSI up, if it was down before the XDP
  setup (git-fixes).
- igc: Unlock on error in igc_io_resume() (git-fixes).
- igb: Fix not clearing TimeSync interrupts for 82580 (git-fixes).
- ice: fix truesize operations for PAGE_SIZE >= 8192 (git-fixes).
- ice: fix ICE_LAST_OFFSET formula (git-fixes).
- ice: fix page reuse when PAGE_SIZE is over 8k (git-fixes).
- cxgb4: add forgotten u64 ivlan cast before shift (git-fixes).
- igc: Fix qbv tx latency by setting gtxoffset (git-fixes).
- igc: Fix reset adapter logics when tx mode change (git-fixes).
- igc: Fix qbv_config_change_errors logics (git-fixes).
- igc: Fix packet still tx after gate close by reducing i226
  MAC retry buffer (git-fixes).
- net/mlx5e: Correctly report errors for ethtool rx flows
  (git-fixes).
- ice: Fix reset handler (git-fixes).
- idpf: fix UAFs when destroying the queues (git-fixes).
- idpf: fix memleak in vport interrupt configuration (git-fixes).
- idpf: fix memory leaks and crashes while performing a soft reset
  (git-fixes).
- igc: Fix double reset adapter triggered from a single taprio
  cmd (git-fixes).
- net/mlx5e: Add a check for the return value from
  mlx5_port_set_eth_ptys (git-fixes).
- net/mlx5e: Require mlx5 tc classifier action support for IPsec
  prio capability (git-fixes).
- net/mlx5: Lag, don't use the hardcoded value of the first port
  (git-fixes).
- net/mlx5: Fix error handling in irq_pool_request_irq
  (git-fixes).
- ice: add missing WRITE_ONCE when clearing ice_rx_ring::xdp_prog
  (git-fixes).
- ice: replace synchronize_rcu with synchronize_net (git-fixes).
- ice: don't busy wait for Rx queue disable in ice_qp_dis()
  (git-fixes).
- ice: respect netif readiness in AF_XDP ZC related ndo's
  (git-fixes).
- gve: Fix an edge case for TSO skb validity check (git-fixes).
- ice: Fix recipe read procedure (git-fixes).
- gve: Fix XDP TX completion handling when counters overflow
  (git-fixes).
- RDMA/mlx5: Use sq timestamp as QP timestamp when RoCE is
  disabled (git-fixes).
- idpf: avoid bloating &idpf_q_vector with big %%NR_CPUS
  (git-fixes).
- i40e: Fix XDP program unloading while removing the driver
  (git-fixes).
- ice: use proper macro for testing bit (git-fixes).
- ice: Reject pin requests with unsupported flags (git-fixes).
- e1000e: Fix S0ix residency on corporate systems (git-fixes).
- net/mlx5e: Add mqprio_rl cleanup and free in
  mlx5e_priv_cleanup() (git-fixes).
- ice: Rebuild TC queues on VSI queue reconfiguration (git-fixes).
- bnxt_en: Restore PTP tx_avail count in case of skb_pad() error
  (git-fixes).
- ice: Fix VSI list rule with ICE_SW_LKUP_LAST type (git-fixes).
- ice: implement AQ download pkg retry (git-fixes).
- ice: fix 200G link speed message log (git-fixes).
- ice: avoid IRQ collision to fix init failure on ACPI S3 resume
  (git-fixes).
- bnxt_en: Cap the size of HWRM_PORT_PHY_QCFG forwarded response
  (git-fixes).
- gve: ignore nonrelevant GSO type bits when processing TSO
  headers (git-fixes).
- net/mlx5e: Fix features validation check for tunneled UDP
  (non-VXLAN) packets (git-fixes).
- ice: add flag to distinguish reset from .ndo_bpf in XDP rings
  config (git-fixes).
- ice: remove af_xdp_zc_qps bitmap (git-fixes).
- ice: fix reads from NVM Shadow RAM on E830 and E825-C devices
  (git-fixes).
- ice: fix iteration of TLVs in Preserved Fields Area (git-fixes).
- net/mlx5: Stop waiting for PCI if pci channel is offline
  (git-fixes).
- ice: fix 200G PHY types to link speed mapping (git-fixes).
- e1000e: move force SMBUS near the end of enable_ulp function
  (git-fixes).
- ice: fix accounting if a VLAN already exists (git-fixes).
- idpf: don't enable NAPI and interrupts prior to allocating Rx
  buffers (git-fixes).
- net/mlx5e: Fix UDP GSO for encapsulated packets (git-fixes).
- net/mlx5e: Use rx_missed_errors instead of rx_dropped for
  reporting buffer exhaustion (git-fixes).
- net/mlx5e: Fix IPsec tunnel mode offload feature check
  (git-fixes).
- net/mlx5: Lag, do bond only if slaves agree on roce state
  (git-fixes).
- idpf: Interpret .set_channels() input differently (git-fixes).
- ice: Interpret .set_channels() input differently (git-fixes).
- idpf: don't skip over ethtool tcp-data-split setting
  (git-fixes).
- ice: Fix package download algorithm (git-fixes).
- mlx5: stop warning for 64KB pages (git-fixes).
- mlx5: avoid truncating error message (git-fixes).
- qed: avoid truncating work queue length (git-fixes).
- cxgb4: unnecessary check for 0 in the free_sge_txq_uld()
  function (git-fixes).
- cxgb4: Properly lock TX queue for the selftest (git-fixes).
- net: qede: use return from qede_parse_actions() (git-fixes).
- net: qede: use return from qede_parse_flow_attr() for flow_spec
  (git-fixes).
- net: qede: use return from qede_parse_flow_attr() for flower
  (git-fixes).
- net: qede: sanitize 'rc' in qede_add_tc_flower_fltr()
  (git-fixes).
- iavf: Fix TC config comparison with existing adapter TC config
  (git-fixes).
- i40e: Report MFS in decimal base instead of hex (git-fixes).
- eth: bnxt: fix counting packets discarded due to OOM and netpoll
  (git-fixes).
- bnxt_en: Fix error recovery for 5760X (P7) chips (git-fixes).
- bnxt_en: Fix the PCI-AER routines (git-fixes).
- bnxt_en: refactor reset close code (git-fixes).
- ice: Fix checking for unsupported keys on non-tunnel device
  (git-fixes).
- ice: tc: allow zero flags in parsing tc flower (git-fixes).
- ice: tc: check src_vsi in case of traffic from VF (git-fixes).
- vdpa: Fix an error handling path in eni_vdpa_probe()
  (git-fixes).
- vdpa_sim_blk: allocate the buffer zeroed (git-fixes).
- vdpa_sim_blk: Fix the potential leak of mgmt_dev (git-fixes).
- commit 58c03fe
* Mon Oct 28 2024 jlee@suse.com
- drivers: soc: xilinx: add check for platform (jsc#PED-11164).
- EDAC/skx_common: Filter out the invalid address (jsc#PED-11164).
- EDAC, pnd2: Sort headers alphabetically (jsc#PED-11164).
- EDAC, pnd2: Correct misleading error message in mk_region_mask()
  (jsc#PED-11164).
- EDAC, pnd2: Apply bit macros and helpers where it makes sense
  (jsc#PED-11164).
- EDAC, pnd2: Replace custom definition by one from sizes.h
  (jsc#PED-11164).
- EDAC/igen6: Add Intel Meteor Lake-P SoCs support
  (jsc#PED-11164).
- EDAC/igen6: Add Intel Meteor Lake-PS SoCs support
  (jsc#PED-11164).
- EDAC/igen6: Add Intel Raptor Lake-P SoCs support
  (jsc#PED-11164).
- EDAC/igen6: Add Intel Alder Lake-N SoCs support (jsc#PED-11164).
- EDAC/igen6: Make get_mchbar() helper function (jsc#PED-11164).
- EDAC/{sb,i7core}_edac: Do not use a plain integer for a NULL
  pointer (jsc#PED-11164).
- EDAC/armada_xp: Explicitly include correct DT includes
  (jsc#PED-11164).
- EDAC/pci_sysfs: Use PCI_HEADER_TYPE_MASK instead of literals
  (jsc#PED-11164).
- EDAC/fsl_ddr: Convert to platform remove callback returning void
  (jsc#PED-11164).
- EDAC/zynqmp: Convert to platform remove callback returning void
  (jsc#PED-11164).
- EDAC/xgene: Convert to platform remove callback returning void
  (jsc#PED-11164).
- EDAC/ti: Convert to platform remove callback returning void
  (jsc#PED-11164).
- EDAC/synopsys: Convert to platform remove callback returning
  void (jsc#PED-11164).
- EDAC/qcom: Convert to platform remove callback returning void
  (jsc#PED-11164).
- EDAC/ppc4xx: Convert to platform remove callback returning void
  (jsc#PED-11164).
- EDAC/octeon-pci: Convert to platform remove callback returning
  void (jsc#PED-11164).
- EDAC/octeon-pc: Convert to platform remove callback returning
  void (jsc#PED-11164).
- EDAC/octeon-lmc: Convert to platform remove callback returning
  void (jsc#PED-11164).
- EDAC/octeon-l2c: Convert to platform remove callback returning
  void (jsc#PED-11164).
- EDAC/npcm: Convert to platform remove callback returning void
  (jsc#PED-11164).
- EDAC/mpc85xx: Convert to platform remove callback returning void
  (jsc#PED-11164).
- EDAC/highbank_mc: Convert to platform remove callback returning
  void (jsc#PED-11164).
- EDAC/highbank_l2: Convert to platform remove callback returning
  void (jsc#PED-11164).
- EDAC/dmc520: Convert to platform remove callback returning void
  (jsc#PED-11164).
- EDAC/cpc925: Convert to platform remove callback returning void
  (jsc#PED-11164).
- EDAC/cell: Convert to platform remove callback returning void
  (jsc#PED-11164).
- EDAC/bluefield: Convert to platform remove callback returning
  void (jsc#PED-11164).
- EDAC/aspeed: Convert to platform remove callback returning void
  (jsc#PED-11164).
- EDAC/armada_xp: Convert to platform remove callback returning
  void (jsc#PED-11164).
- EDAC/altera: Convert to platform remove callback returning void
  (jsc#PED-11164).
- EDAC/altera: Use device_get_match_data() (jsc#PED-11164).
- EDAC/versal: Read num_csrows and num_chans using the correct
  bitfield macro (jsc#PED-11164).
- EDAC/mc_sysfs: Replace deprecated strncpy() with memcpy()
  (jsc#PED-11164).
- EDAC/versal: Add a Xilinx Versal memory controller driver
  (jsc#PED-11164).
  Update config files.
  Add 'CONFIG_EDAC_VERSAL is not set' to config/arm64/default
- commit 35cb378
* Mon Oct 28 2024 nik.borisov@suse.com
- dcache: keep dentry_hashtable or d_hash_shift even when not used (git-fixes).
- commit d6ce9b3
* Mon Oct 28 2024 jlee@suse.com
- efivarfs: Drop 'duplicates' bool parameter on efivar_init()
  (jsc#PED-11167).
- efivarfs: Drop redundant cleanup on fill_super() failure
  (jsc#PED-11167).
- efi/libstub: Add one kernel-doc comment (jsc#PED-11167).
- commit a0e8466
* Mon Oct 28 2024 jlee@suse.com
- x86/efistub: Avoid placing the kernel below LOAD_PHYSICAL_ADDR
  (jsc#PED-11167).
- x86/efistub: Give up if memory attribute protocol returns an
  error (jsc#PED-11167).
- efi: memmap: fix kernel-doc warnings (jsc#PED-11167).
- efivarfs: automatically update super block flag (jsc#PED-11167).
- efi: Add tee-based EFI variable driver (jsc#PED-11167).
  Update config files.
  Add 'CONFIG_TEE_STMM_EFI is not set' to config/arm64/default
- efi: Add EFI_ACCESS_DENIED status code (jsc#PED-11167).
- efi: expose efivar generic ops register function
  (jsc#PED-11167).
  Refresh
  patches.suse/0005-efi-generate-secret-key-in-EFI-boot-environment.patch.
- efivarfs: Move efivarfs list into superblock s_fs_info
  (jsc#PED-11167).
  Refresh
  patches.suse/efivarfs-Request-at-most-512-bytes-for-variable-name.patch.
- efi: dev-path-parser: use acpi_dev_uid_match() for matching _UID
  (jsc#PED-11167).
- efi/libstub: zboot: do not use $(shell ...) in cmd_copy_and_pad
  (jsc#PED-11167).
- commit 1303cf4
* Mon Oct 28 2024 nik.borisov@suse.com
- x86: fix user address masking non-canonical speculation issue (git-fixes).
- commit 561e50e
* Mon Oct 28 2024 nik.borisov@suse.com
- x86: make the masked_user_access_begin() macro use its argument only  once (git-fixes).
- commit aa2495e
* Mon Oct 28 2024 nik.borisov@suse.com
- x86: do the user address masking outside the user access area (git-fixes).
- commit a4b9c7b
* Mon Oct 28 2024 nik.borisov@suse.com
- x86: support user address masking instead of non-speculative conditional (git-fixes).
- commit 6536d1f
* Mon Oct 28 2024 nik.borisov@suse.com
- runtime constants: add x86 architecture support (git-fixes).
- commit 32e2def
* Mon Oct 28 2024 nik.borisov@suse.com
- runtime constants: add default dummy infrastructure (git-fixes).
- commit dd17ee6
* Mon Oct 28 2024 nik.borisov@suse.com
- vfs: dcache: move hashlen_hash() from callers into d_hash() (git-fixes).
- commit c440ebe
* Mon Oct 28 2024 ohering@suse.de
- hv_netvsc: Fix VF namespace also in synthetic NIC NETDEV_REGISTER event (git-fixes).
- commit 3dc5225
* Sat Oct 26 2024 tiwai@suse.de
- Drop USB dwc2 patch that caused a regression on RPi3 (bsc#1232342)
- commit c84227d
* Sat Oct 26 2024 tiwai@suse.de
- ACPI: PRM: Clean up guid type in struct prm_handler_info
  (git-fixes).
- commit 8c8a801
* Sat Oct 26 2024 tiwai@suse.de
- ALSA: hda/realtek: Add subwoofer quirk for Acer Predator G9-593
  (stable-fixes).
- commit 595e400
* Sat Oct 26 2024 tiwai@suse.de
- ACPI: PRM: Find EFI_MEMORY_RUNTIME block for PRM handler and
  context (git-fixes).
- ata: libata: Set DID_TIME_OUT for commands that actually timed
  out (git-fixes).
- ASoC: max98388: Fix missing increment of variable slot_found
  (git-fixes).
- ASoC: qcom: Fix NULL Dereference in
  asoc_qcom_lpass_cpu_platform_probe() (git-fixes).
- ALSA: hda/realtek: Update default depop procedure (git-fixes).
- ALSA: hda/tas2781: select CRC32 instead of CRC32_SARWATE
  (git-fixes).
- ALSA: firewire-lib: Avoid division by zero in
  apply_constraint_to_size() (git-fixes).
- cpufreq/amd-pstate: Fix amd_pstate mode switch on shared memory
  systems (git-fixes).
- ntb: intel: Fix the NULL vs IS_ERR() bug for
  debugfs_create_dir() (git-fixes).
- commit 33d7ff7
* Fri Oct 25 2024 vkarasulli@suse.de
- platform/x86: x86-android-tablets: Fix use after free on
  platform_device_register() errors (bsc#1232093 CVE-2024-49986).
- commit a5650bf
* Fri Oct 25 2024 vkarasulli@suse.de
- thermal: core: Free tzp copy along with the thermal zone
  (bsc#1231951 CVE-2024-50027).
- commit 5199a1f
* Fri Oct 25 2024 vkarasulli@suse.de
- device-dax: correct pgoff align in dax_set_mapping()
  (bsc#1231956 CVE-2024-50022).
- commit 527a95e
* Fri Oct 25 2024 tiwai@suse.de
- ntb: ntb_hw_switchtec: Fix use after free vulnerability in
  switchtec_ntb_remove due to race condition (CVE-2024-50059
  bsc#1232345).
- commit 4d86c47
* Fri Oct 25 2024 vbabka@suse.cz
- mm: call the security_mmap_file() LSM hook in remap_file_pages()
  (CVE-2024-47745 bsc#1232135).
- commit 18a36ea
* Fri Oct 25 2024 sjaeckel@suse.de
- Bluetooth: L2CAP: Fix uaf in l2cap_connect (CVE-2024-49950
  bsc#1232159).
- commit c906740
* Fri Oct 25 2024 jlee@suse.com
- x86/efistub: Use 1:1 file:memory mapping for PE/COFF .compat
  section (jsc#PED-11167).
- commit f7e3d23
* Fri Oct 25 2024 tiwai@suse.de
- Refresh patches.suse/1366-drm-xe-Add-support-for-OOB-workarounds.patch
  The creation of an empty *.rules file seems confusing sequence-patch in
  the --fast mode, resulting in the lack of the file, as found in the
  expanded tree.  Drop this chunk as it's basically useless.
- commit c282391
* Fri Oct 25 2024 mfranc@suse.cz
- s390/crypto: Add hardware acceleration for HMAC modes
  (jsc#PED-11040).
  Refresh
  patches.suse/s390-pkey-Introduce-pkey-base-with-handler-registry-and-handler-modules.patch.
- commit 4a4e5d0
* Fri Oct 25 2024 sjaeckel@suse.de
- rxrpc: Fix a race between socket set up and I/O thread creation
  (CVE-2024-49864 bsc#1232256).
- commit 9a8fa8a
* Fri Oct 25 2024 ailiop@suse.com
- jfs: Fix sanity check in dbMount (git-fixes).
- commit 82a9085
* Fri Oct 25 2024 jgross@suse.com
- Update
  patches.suse/xen-move-max_pfn-in-xen_memory_setup-out-of-function.patch
  (bsc#1226003 bsc#1231828).
- commit f79e57d
* Fri Oct 25 2024 tbogendoerfer@suse.de
- net/mlx5e: Fix NULL deref in mlx5e_tir_builder_alloc()
  (CVE-2024-50000 bsc#1232085).
- commit fe8d0fb
* Fri Oct 25 2024 mfranc@suse.cz
- s390/pkey_pckmo: Return with success for valid protected key
  types (jsc#PED-10278).
- commit 8957297
* Fri Oct 25 2024 lhenriques@suse.de
- ext4: fix double brelse() the buffer of the extents path
  (bsc#1232200 CVE-2024-49882).
- ext4: no need to continue when the number of entries is 1
  (bsc#1232140 CVE-2024-49967).
- commit 4a7f79c
* Fri Oct 25 2024 dwagner@suse.de
- nvme: disable CC.CRIME (NVME_CC_CRIME) (jsc#PED-9901).
- commit e02c81e
* Fri Oct 25 2024 tiwai@suse.de
- Bluetooth: ISO: Fix UAF on iso_sock_timeout (git-fixes).
- Bluetooth: SCO: Fix UAF on sco_sock_timeout (git-fixes).
- commit 3fc188a
* Fri Oct 25 2024 tbogendoerfer@suse.de
- ice: Fix improper handling of refcount in
  ice_sriov_set_msix_vec_count() (CVE-2024-50020 bsc#1231989).
- Refresh patches.suse/ice-Fix-increasing-MSI-X-on-VF.patch.
- commit 879bb19
* Fri Oct 25 2024 tbogendoerfer@suse.de
- igb: Do not bring the device up after non-fatal error
  (CVE-2024-50040 bsc#1231908).
- ice: Fix improper handling of refcount in
  ice_dpll_init_rclk_pins() (CVE-2024-50021 bsc#1231957).
- ppp: do not assume bh is held in ppp_channel_bridge_input()
  (CVE-2024-49946 bsc#1232164).
- net/mlx5e: Fix crash caused by calling __xfrm_state_delete()
  twice (CVE-2024-49953 bsc#1232156).
- net/mlx5: Fix error path in multi-packet WQE transmit
  (CVE-2024-50001 bsc#1232084).
- net: seeq: Fix use after free vulnerability in ether3 Driver
  Due to Race Condition (CVE-2024-47747 bsc#1232145).
- vdpa/mlx5: Fix invalid mr resource destroy (CVE-2024-47687
  bsc#1232003).
- Revert "ixgbe: Manual AN-37 for troublesome link partners for
  X550 SFI" (git-fixes).
- commit bf0d04c
* Fri Oct 25 2024 oneukum@suse.com
- net: usb: usbnet: fix name regression (get-fixes).
- commit 05e3778
* Fri Oct 25 2024 dsterba@suse.com
- r8169: add tally counter fields added with RTL8125 (CVE-2024-49973 bsc#1232105)
- commit bda1225
* Fri Oct 25 2024 dsterba@suse.com
- crypto: hisilicon/qm - flush all work before driver removed (bsc#1232075)
- commit fe52020
* Fri Oct 25 2024 dsterba@suse.com
- crypto: hisilicon/qm - inject error before stopping queue (CVE-2024-47730 bsc#1232075)
- commit 2ca1dd9
* Thu Oct 24 2024 dsterba@suse.com
- sock_map: Add a cond_resched() in sock_hash_free() (CVE-2024-47710 bsc#1232049)
- commit 0ac9917
* Thu Oct 24 2024 ematsumiya@suse.de
- cifs: Fix buffer overflow when parsing NFS reparse points
  (bsc#1232089, CVE-2024-49996).
- commit f42a100
* Thu Oct 24 2024 dsterba@suse.com
- netfilter: nf_reject_ipv6: fix nf_reject_ip6_tcphdr_put() (CVE-2024-47685 bsc#1231998)
- commit 8da2621
* Thu Oct 24 2024 dsterba@suse.com
- net: Fix an unsafe loop on the list (CVE-2024-50024 bsc#1231954)
- commit 89e6925
* Thu Oct 24 2024 dsterba@suse.com
- ipv6: avoid possible NULL deref in rt6_uncached_list_flush_dev() (CVE-2024-47707 bsc#1231935)
- commit cc8f915
* Thu Oct 24 2024 dsterba@suse.com
- netfilter: br_netfilter: fix panic with metadata_dst skb (CVE-2024-50045 bsc#1231903)
- commit e6591d1
* Thu Oct 24 2024 dsterba@suse.com
- block, bfq: fix possible UAF for bfqq->bic with merge chain (CVE-2024-47706 bsc#1231942)
- commit 5c1066e
* Thu Oct 24 2024 dsterba@suse.com
- tcp: check skb is non-NULL in tcp_rto_delta_us() (CVE-2024-47684 bsc#1231987)
- commit e27a5c2
* Thu Oct 24 2024 mfranc@suse.cz
- supported.conf: externally supported drivers/s390/crypto/pkey_* (jsc#PED-10278)
- commit 4981b7a
* Thu Oct 24 2024 mfranc@suse.cz
- s390x config: enable PKEY_CCA, PKEY_EP11 and PKEY_PCKMO (jsc#PED-10278)
- commit ca80891
* Thu Oct 24 2024 mfranc@suse.cz
- s390/pkey: Add AES xts and HMAC clear key token support
  (jsc#PED-10278).
- s390/cpacf: Add MSA 10 and 11 new PCKMO functions
  (jsc#PED-10278).
- s390/ap: Fix deadlock caused by recursive lock of the AP bus
  scan mutex (jsc#PED-10278).
- s390/pkey: Add function to enforce pkey handler modules load
  (jsc#PED-10278).
- s390/pkey: Add slowpath function to CCA and EP11 handler
  (jsc#PED-10278).
- s390/pkey: Introduce pkey base with handler registry and
  handler modules (jsc#PED-10278).
- s390/pkey: Unify pkey cca, ep11 and pckmo functions signatures
  (jsc#PED-10278).
- s390/pkey: Rework and split PKEY kernel module code
  (jsc#PED-10278).
- s390/paes: Reestablish retry loop in paes (jsc#PED-10278).
- s390/crypto: remove retry loop with sleep from PAES pkey
  invocation (jsc#PED-10278).
- commit 07f592c
* Thu Oct 24 2024 ohering@suse.de
- add bug references to existing mana changes (bsc#1232033, bsc#1232034, bsc#1232036).
- commit 36926a3
* Thu Oct 24 2024 ohering@suse.de
- add bug references to existing mana changes (bsc#1232033, bsc#1232034, bsc#1232036).
- commit e93ce92
* Thu Oct 24 2024 jbohac@suse.cz
- powerpc/crash: add crash memory hotplug support (jsc#PED-11175).
- commit 1651793
* Thu Oct 24 2024 jbohac@suse.cz
- powerpc/crash: add crash CPU hotplug support (jsc#PED-11175).
  Update config files.
- commit b5a10ec
* Thu Oct 24 2024 jbohac@suse.cz
- powerpc/kexec: move *_memory_ranges functions to ranges.c
  (jsc#PED-11175).
- commit 080f7b7
* Thu Oct 24 2024 jbohac@suse.cz
- crash: add a new kexec flag for hotplug support (jsc#PED-11175).
- commit 1b18f70
* Thu Oct 24 2024 jbohac@suse.cz
- crash: forward memory_notify arg to arch crash hotplug handler
  (jsc#PED-11175).
- commit ce15d0c
* Thu Oct 24 2024 jbohac@suse.cz
- Documentation/powerpc: update fadump implementation details
  (jsc#PED-9877).
- commit 07591b5
* Thu Oct 24 2024 mfranc@suse.cz
- s390/pkey: Split pkey_unlocked_ioctl function (jsc#PED-10278).
- commit 6c8a686
* Thu Oct 24 2024 jbohac@suse.cz
- powerpc/fadump: add hotplug_ready sysfs interface
  (jsc#PED-9877).
- commit 4b04e2d
* Thu Oct 24 2024 jbohac@suse.cz
- powerpc: make fadump resilient with memory add/remove events
  (jsc#PED-9877).
- commit 6516b39
* Thu Oct 24 2024 jbohac@suse.cz
- crash: hotplug support for kexec_load() (jsc#PED-11175).
- blacklist.conf:
- Refresh
  patches.suse/0001-Crash-add-lock-to-serialize-crash-hotplug-handling.patch.
- commit ea5ec24
* Thu Oct 24 2024 mfranc@suse.cz
- s390/ap: Refine AP bus bindings complete processing
  (jsc#PED-10277).
- commit efcbf3a
* Thu Oct 24 2024 mfranc@suse.cz
- s390/ap: Fix bind complete udev event sent after each AP bus
  scan (jsc#PED-10277).
- commit 31ed605
* Thu Oct 24 2024 mfranc@suse.cz
- s390/zcrypt: Use EBUSY to indicate temp unavailability
  (jsc#PED-10277).
- commit c22c62b
* Thu Oct 24 2024 mfranc@suse.cz
- s390/zcrypt: Handle ep11 cprb return code (jsc#PED-10277).
- commit fe7b04b
* Thu Oct 24 2024 mfranc@suse.cz
- s390/pkey: improve pkey retry behavior (jsc#PED-10277).
- commit b7ae070
* Thu Oct 24 2024 mfranc@suse.cz
- s390/zcrypt: improve zcrypt retry behavior (jsc#PED-10277).
- commit 2a3036f
* Thu Oct 24 2024 mfranc@suse.cz
- s390/zcrypt: introduce retries on in-kernel send CPRB functions
  (jsc#PED-10277).
- commit cc2b838
* Thu Oct 24 2024 mfranc@suse.cz
- s390/ap: introduce mutex to lock the AP bus scan
  (jsc#PED-10277).
- commit 495818c
* Thu Oct 24 2024 mfranc@suse.cz
- s390/ap: rework ap_scan_bus() to return true on config change
  (jsc#PED-10277).
- commit f7d8bba
* Thu Oct 24 2024 mfranc@suse.cz
- s390/ap: clarify AP scan bus related functions and variables
  (jsc#PED-10277).
- commit f1e33e0
* Thu Oct 24 2024 mfranc@suse.cz
- s390/ap: rearm APQNs bindings complete completion
  (jsc#PED-10277).
- commit 9af7be9
* Thu Oct 24 2024 mfranc@suse.cz
- s390/ap: explicitly include ultravisor header (jsc#PED-10277).
- commit b0400ed
* Thu Oct 24 2024 mfranc@suse.cz
- s390/zcrypt: add debug possibility for CCA and EP11 messages
  (jsc#PED-10277).
- commit 1810032
* Thu Oct 24 2024 mfranc@suse.cz
- s390/ap: add debug possibility for AP messages (jsc#PED-10277).
- commit 5216354
* Thu Oct 24 2024 mfranc@suse.cz
- s390/zcrypt: introduce dynamic debugging for AP and zcrypt code
  (jsc#PED-10277).
- commit f8b4469
* Thu Oct 24 2024 mfranc@suse.cz
- s390/zcrypt: harmonize debug feature calls and defines
  (jsc#PED-10277).
- commit a340294
* Thu Oct 24 2024 mfranc@suse.cz
- s390/ap: make ap_bus_type const (jsc#PED-10277).
- commit 55af3f4
* Thu Oct 24 2024 mfranc@suse.cz
- s390/ap: handle outband SE bind state change (jsc#PED-10277).
- commit b058356
* Thu Oct 24 2024 mfranc@suse.cz
- s390/ap: store TAPQ hwinfo in struct ap_card (jsc#PED-10277).
- commit 1b348ab
* Thu Oct 24 2024 mfranc@suse.cz
- s390/ap: fix vanishing crypto cards in SE environment
  (jsc#PED-10277).
- commit a97f63b
* Thu Oct 24 2024 mfranc@suse.cz
- s390/zcrypt: don't report online if card or queue is in
  check-stop state (jsc#PED-10277).
- commit a927f98
* Thu Oct 24 2024 mfranc@suse.cz
- s390/ap: re-enable interrupt for AP queues (jsc#PED-10277).
- commit 1b309cc
* Thu Oct 24 2024 mfranc@suse.cz
- s390/ap: rework to use irq info from ap queue status
  (jsc#PED-10277).
- commit d698700
* Thu Oct 24 2024 mfranc@suse.cz
- s390/ap: show APFS value on error reply 0x8B (jsc#PED-10277).
- commit 4507956
* Thu Oct 24 2024 mfranc@suse.cz
- s390/zcrypt: introduce new internal AP queue se_bound attribute
  (jsc#PED-10277).
- commit 7f3e5f1
* Thu Oct 24 2024 mfranc@suse.cz
- s390/zcrypt: update list of EP11 operation modes
  (jsc#PED-10277).
- commit 835effb
* Thu Oct 24 2024 mfranc@suse.cz
- s390/zcrypt: utilize dev_set_name() ability to use a formatted
  string (jsc#PED-10277).
- commit e0003bf
* Thu Oct 24 2024 mfranc@suse.cz
- s390/zcrypt: remove CEX2 and CEX3 device drivers
  (jsc#PED-10277).
- commit 39e6ba7
* Thu Oct 24 2024 mfranc@suse.cz
- s390: fix various typos (jsc#PED-10277).
  Refresh patches.suse/KVM-s390-pv-relax-WARN_ONCE-condition-for-destroy-fast.patch.
- commit 8f4cef6
* Thu Oct 24 2024 mfranc@suse.cz
- s390/zcrypt: remove ZCRYPT_MULTIDEVNODES kernel config option
  (jsc#PED-10277).
- commit 0dba100
* Thu Oct 24 2024 mfranc@suse.cz
- s390/zcrypt: cleanup some debug code (jsc#PED-10277).
- commit ec740a5
* Thu Oct 24 2024 mfranc@suse.cz
- s390/zcrypt: use kvmalloc_array() instead of kzalloc()
  (jsc#PED-10277).
- commit 502478a
* Thu Oct 24 2024 mfranc@suse.cz
- s390/crypto: Add hardware acceleration for full AES-XTS mode
  (jsc#PED-10271).
- commit 3405776
* Thu Oct 24 2024 mfranc@suse.cz
- s390/sha3: Fix SHA3 selftests failures (jsc#PED-10279).
- s390/sha3: Support sha3 performance enhancements
  (jsc#PED-10279).
- commit 6b103fd
* Thu Oct 24 2024 nik.borisov@suse.com
- config: Disable CONFIG_ADDRESS_MASKING (bsc#1217845)
  Disable LAM until LASS lands.
- commit 2f2899f
* Thu Oct 24 2024 rgoldwyn@suse.com
- filemap: remove use of wait bookmarks  (bsc#1224088).
- commit 323bb54
* Thu Oct 24 2024 pjakobsson@suse.de
- supported.conf: Add unsupported entry for panthor drm driver
- commit ab05a49
* Thu Oct 24 2024 pjakobsson@suse.de
- blacklist.conf: Blacklist git-fixes for DRM v6.10 backport
- commit d854f55
* Thu Oct 24 2024 pjakobsson@suse.de
- fbdev: add HAS_IOPORT dependencies (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit ab7b0b4
* Thu Oct 24 2024 pjakobsson@suse.de
- drm: move DRM-related CONFIG options into DRM submenu (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 3790be8
* Thu Oct 24 2024 pjakobsson@suse.de
- Revert "drm/display: Make all helpers visible and switch to depends on" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 6ff783d
* Thu Oct 24 2024 pjakobsson@suse.de
- Revert "drm: Make drivers depends on DRM_DW_HDMI" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 289f823
* Thu Oct 24 2024 pjakobsson@suse.de
- Revert "drm: Switch DRM_DISPLAY_HELPER to depends on" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit ce1a1b0
* Thu Oct 24 2024 pjakobsson@suse.de
- Revert "drm/bridge: dw-hdmi: Make DRM_DW_HDMI selectable" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 002a9f5
* Thu Oct 24 2024 pjakobsson@suse.de
- drm/panel: Add driver for EDO RM69380 OLED panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 22daee1
* Thu Oct 24 2024 pjakobsson@suse.de
- drm/xe: select X86_PLATFORM_DEVICES when ACPI_WMI is selected (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit cc64ff3
* Thu Oct 24 2024 jlee@suse.com
- x86/boot: Increase section and file alignment to 4k/512
  (jsc#PED-11167).
- x86/boot: Split off PE/COFF .data section (jsc#PED-11167).
- x86/boot: Drop PE/COFF .reloc section (jsc#PED-11167).
- x86/boot: Construct PE/COFF .text section from assembler
  (jsc#PED-11167).
- x86/boot: Derive file size from _edata symbol (jsc#PED-11167).
- x86/boot: Define setup size in linker script (jsc#PED-11167).
- x86/boot: Set EFI handover offset directly in header asm
  (jsc#PED-11167).
- x86/boot: Grab kernel_info offset from zoffset header directly
  (jsc#PED-11167).
- x86/boot: Drop references to startup_64 (jsc#PED-11167).
- x86/boot: Drop redundant code setting the root device
  (jsc#PED-11167).
- x86/boot: Omit compression buffer from PE/COFF image memory
  footprint (jsc#PED-11167).
- x86/boot: Remove the 'bugger off' message (jsc#PED-11167).
- x86/efi: Drop alignment flags from PE section headers
  (jsc#PED-11167).
- commit 3dbd6bb
* Thu Oct 24 2024 pjakobsson@suse.de
- drm: panel: Add LG sw43408 panel driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 34eac76
* Thu Oct 24 2024 pjakobsson@suse.de
- drm/bridge: dw-hdmi: Make DRM_DW_HDMI selectable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 3d0a7a2
* Thu Oct 24 2024 pjakobsson@suse.de
- drm: Switch DRM_DISPLAY_HELPER to depends on (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit f8ba445
* Thu Oct 24 2024 tiwai@suse.de
- platform/x86/intel/hid: Add Lunar Lake and Arrow Lake support
  (jsc#PED-10333).
- commit a0ad3eb
* Thu Oct 24 2024 pjakobsson@suse.de
- drm: Make drivers depends on DRM_DW_HDMI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit ca0f437
* Thu Oct 24 2024 pjakobsson@suse.de
- drm/display: Reorder Kconfig symbols (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 8985c61
* Thu Oct 24 2024 pjakobsson@suse.de
- drm/display: Make all helpers visible and switch to depends on (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 704f535
* Thu Oct 24 2024 nik.borisov@suse.com
- config: Disable LAM on x86 (bsc#1217845)
  LAM is affected by speculative execution vulnerabilities so until LASS
  lands it's advisable to be disabled.
- commit 405fa97
* Thu Oct 24 2024 shung-hsi.yu@suse.com
- selftests/bpf: adjust global_func15 test to validate prog exit
  precision (CVE-2024-47703 bsc#1231946).
- selftests/bpf: validate async callback return value check
  correctness (CVE-2024-47703 bsc#1231946).
- bpf: enforce precision of R0 on program/async callback return
  (CVE-2024-47703 bsc#1231946).
- bpf: unify async callback and program retval checks
  (CVE-2024-47703 bsc#1231946).
- commit d5ff894
* Thu Oct 24 2024 shung-hsi.yu@suse.com
- bpf: enforce precise retval range on program exit
  (CVE-2024-47703 bsc#1231946).
- selftests/bpf: add selftest validating callback result is
  enforced (CVE-2024-47703 bsc#1231946).
- bpf: enforce exact retval range on subprog/callback exit
  (CVE-2024-47703 bsc#1231946).
- Refresh patches.kabi/bpf-verifier-kABI-workarounds.patch
- bpf: provide correct register name for exception callback
  retval check (CVE-2024-47703 bsc#1231946).
- bpf: rearrange bpf_func_state fields to save a bit of memory
  (CVE-2024-47703 bsc#1231946).
- Refresh patches.suse/bpf-Add-some-comments-to-stack-representation.patch
- Refresh patches.kabi/bpf-verifier-kABI-workarounds.patch
- bpf: Treat first argument as return value for bpf_throw
  (CVE-2024-47703 bsc#1231946).
- commit 5efe683
* Thu Oct 24 2024 pjakobsson@suse.de
- drm/display: Make DisplayPort AUX bus Kconfig name consistent (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 9f7f3fe
* Thu Oct 24 2024 pjakobsson@suse.de
- drm/display: Make DisplayPort CEC-over-AUX Kconfig name consistent (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 2e329e0
* Thu Oct 24 2024 pjakobsson@suse.de
- drm/display: Make DisplayPort AUX Chardev Kconfig name consistent (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 664307c
* Thu Oct 24 2024 osalvador@suse.de
- drm/amd/display: Add null check for head_pipe in
  dcn32_acquire_idle_pipe_for_head_pipe_in_layer (CVE-2024-49918
  bsc#1231967).
- commit 0e6515f
* Thu Oct 24 2024 pjakobsson@suse.de
- drm/panel: add samsung s6e3fa7 panel driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 895893a
* Thu Oct 24 2024 pjakobsson@suse.de
- drm/panthor: Allow driver compilation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit e6c7ae6
* Thu Oct 24 2024 pjakobsson@suse.de
- drm: Add CONFIG_DRM_WERROR (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 111d7ea
* Thu Oct 24 2024 tiwai@suse.de
- thermal: core: Free tzp copy along with the thermal zone
  (git-fixes).
- ACPI: resource: Do IRQ override on MECHREV GM7XG0M (git-fixes).
- commit 6b1abac
* Thu Oct 24 2024 jlee@suse.com
- efi: move screen_info into efi init code (jsc#PED-11167).
- x86/boot: efistub: Assign global boot_params variable
  (jsc#PED-11167).
- Revert "x86/boot: efistub: Assign global boot_params variable"
  - This reverts commit 3d4c9a732198e04e95688b8c0a7cf051fc4e032b.
  - Removed
    patches.suse/x86-boot-efistub-Assign-global-boot_params-variable-50dcc2e0.patch.
  - Removed db7724134c26 because it be removed by 2b95bb05265 merge.
- blacklist.conf: Add db7724134c26fdf16886a560646d02292563f5a4
  - the change in this commit be removed in 2b95bb052656 merge commit, so we
    removed it.
- Refresh
  patches.suse/efi-x86-Fix-the-missing-KASLR_FLAG-bit-in-boot_param.patch.
  - rollback to boot_params_ptr.
- x86/boot: Rename conflicting 'boot_params' pointer to
  'boot_params_ptr' (jsc#PED-11167).
- x86/efi: Disregard setup header of loaded image (jsc#PED-11167).
- x86/efi: Drop EFI stub .bss from .data section (jsc#PED-11167).
  Refresh
  patches.suse/1225-treewide-update-LLVM-Bugzilla-links.patch.
- commit 7dd4a70
* Thu Oct 24 2024 osalvador@suse.de
- drm/amd/display: Add NULL check for clk_mgr and clk_mgr->funcs
  in dcn30_init_hw (bsc#1231965 CVE-2024-49917).
- commit 0859f94
* Wed Oct 23 2024 ailiop@suse.com
- ocfs2: reserve space for inline xattr before attaching reflink
  tree (bsc#1232151 CVE-2024-49958).
- commit 9d01096
* Wed Oct 23 2024 oneukum@suse.com
- media: v4l: async: Fix duplicated list deletion (jsc#PED-10837).
- commit 2c66b38
* Wed Oct 23 2024 oneukum@suse.com
- media: xilinx-vipp: Look for entities also in waiting_list
  (jsc#PED-10837).
- commit f1e6781
* Wed Oct 23 2024 oneukum@suse.com
- staging: media: tegra-video: fix infinite recursion regression
  (jsc#PED-10837).
- commit 48edeb0
* Wed Oct 23 2024 iivanov@suse.de
- arm64: probes: Fix uprobes for big-endian kernels (git-fixes)
- commit 5114e0b
* Wed Oct 23 2024 iivanov@suse.de
- arm64: probes: Fix simulate_ldr*_literal() (git-fixes)
- commit 2795830
* Wed Oct 23 2024 iivanov@suse.de
- arm64: probes: Remove broken LDR (literal) uprobe support (git-fixes)
- commit 83d2001
* Wed Oct 23 2024 dsterba@suse.com
- spi: hisi-kunpeng: Add verification for the max_frequency provided by the firmware (CVE-2024-47664 bsc#1231442)
- commit 89945c9
* Wed Oct 23 2024 iivanov@suse.de
- arm64: Subscribe Microsoft Azure Cobalt 100 to erratum 3194386 (git-fixes)
- commit ad9716f
* Wed Oct 23 2024 iivanov@suse.de
- arm64: errata: Expand speculative SSBS workaround once more (git-fixes)
- commit f66e878
* Wed Oct 23 2024 iivanov@suse.de
- arm64: cputype: Add Neoverse-N3 definitions (git-fixes)
- commit 6a20007
* Wed Oct 23 2024 iivanov@suse.de
- arm64: esr: Define ESR_ELx_EC_* constants as UL (git-fixes)
- commit 28e8491
* Wed Oct 23 2024 oneukum@suse.com
- media: marvell: cafe: Register V4L2 device earlier
  (jsc#PED-10837).
- commit f7ac324
* Wed Oct 23 2024 oneukum@suse.com
- media: qcom: camss: Fix V4L2 async notifier error path
  (jsc#PED-10837).
- blacklist.conf: breaker commit needed for backport
- commit b754b19
* Wed Oct 23 2024 oneukum@suse.com
- media: qcom: Initialise V4L2 async notifier later
  (jsc#PED-10837).
- commit 6964845
* Wed Oct 23 2024 oneukum@suse.com
- media: davinci: Init async notifier after registering V4L2
  device (jsc#PED-10837).
- commit c3bb3c4
* Wed Oct 23 2024 oneukum@suse.com
- media: xilinx-vipp: Init async notifier after registering V4L2
  device (jsc#PED-10837).
- commit 68d1454
* Wed Oct 23 2024 oneukum@suse.com
- media: v4l: async: Support fwnode endpoint list matching for
  subdevs (jsc#PED-10837).
- commit d0ff231
* Wed Oct 23 2024 oneukum@suse.com
- media: imx-mipi-csis: Remove an incorrect fwnode_handle_put()
  call (jsc#PED-10837).
- commit f2bb939
* Wed Oct 23 2024 oneukum@suse.com
- media: i2c: rdacm21: Remove an incorrect fwnode_handle_put()
  call (jsc#PED-10837).
- commit e2de15a
* Wed Oct 23 2024 oneukum@suse.com
- media: i2c: max9286: Remove an incorrect fwnode_handle_put()
  call (jsc#PED-10837).
- commit c5c4123
* Wed Oct 23 2024 oneukum@suse.com
- blacklist.conf: not applicable
- commit a8b7e22
* Wed Oct 23 2024 oneukum@suse.com
- media: adv748x: Return to endpoint matching (jsc#PED-10837).
- commit 0ab78e2
* Wed Oct 23 2024 oneukum@suse.com
- media: v4l: async: Try more connections (jsc#PED-10837).
- commit 151d3c2
* Wed Oct 23 2024 oneukum@suse.com
- media: v4l: async: Drop unneeded list entry initialisation
  (jsc#PED-10837).
- commit e66e474
* Wed Oct 23 2024 oneukum@suse.com
- media: v4l: async: Allow multiple connections between entities
  (jsc#PED-10837).
- media: v4l: async: Obtain async connection based on sub-device
  (jsc#PED-10837).
- commit 42f844c
* Wed Oct 23 2024 pjakobsson@suse.de
- mei: vsc: Fix spelling error (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit abeca7f
* Wed Oct 23 2024 pjakobsson@suse.de
- mei: vsc: Enhance SPI transfer of IVSC ROM (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 638c3a7
* Wed Oct 23 2024 pjakobsson@suse.de
- mei: vsc: Utilize the appropriate byte order swap function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f4d3dfc
* Wed Oct 23 2024 pjakobsson@suse.de
- mei: vsc: Prevent timeout error with added delay post-firmware (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7c97f40
* Wed Oct 23 2024 pjakobsson@suse.de
- mei: vsc: Enhance IVSC chipset stability during warm reboot (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 948a879
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Reset freesync config before update new state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d2328a0
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Fix sync-only jobs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c0d7ef3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Don't check the array stride on empty uobj arrays (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 622c27f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: panel-orientation-quirks: Add labels for both Valve Steam Deck (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4f76e8d
* Wed Oct 23 2024 pjakobsson@suse.de
- firmware: sysfb: Fix reference count of sysfb parent device (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drivers-firmware-skip-simpledrm-if-nvidia-drm.modese.patch.
- commit 7126c31
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/mcr: Avoid clobbering DSS steering (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8451ec3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: fix error handling in xe_migrate_update_pgtables (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit 4c7d30a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: For MTL+ platforms skip mg dp programming (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1fbbb17
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Don't show false warning for reg list (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7e74311
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/swsmu: add MALL init support workaround for smu_v14_0_1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5eec6dc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/vf: Don't touch GuC irq registers if using memory irqs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 32dc680
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: init TA fw for psp v14 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0de103f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: cleanup MES11 command submission (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 592646b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Attempt to avoid empty TUs when endpoint is DPIA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f58a22
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Change dram_clock_latency to 34us for dcn351 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 326f4b0
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: revert "take runtime pm reference when we attach a (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0deba8b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: prevent register access while in IPS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3a2727a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Remove redundant idle optimization check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 65dfec3
* Wed Oct 23 2024 pjakobsson@suse.de
- mei: vsc: Fix wrong invocation of ACPI SID method (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bf5ef96
* Wed Oct 23 2024 pjakobsson@suse.de
- mei: vsc: Don't stop/restart mei device during system suspend/resume (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6cc79bd
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: move disable_c6 call (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3ca7289
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: flush engine buffers before signalling user fence on all (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 439fe94
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/pf: Assert LMEM provisioning is done only on DGFX (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7949710
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/xe_gt_idle: use GT forcewake domain assertion (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 27a6341
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/komeda: remove unused struct 'gamma_curve_segment' (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7ce3274
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu/pptable: Fix UBSAN array-index-out-of-bounds (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c35273e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd: Fix shutdown (again) on some SMU v13.0.4/11 platforms (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6421092
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/pf: Update the LMTT when freeing VF GT config (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 684338a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/pm: remove deprecated I2C_CLASS_SPD support from newly added (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 369eda4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Make CPX mode auto default in NPS4 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 15e582d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdkfd: simplify APU VRAM handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f4c3290
* Wed Oct 23 2024 pjakobsson@suse.de
- Rename to patches.suse/1416-drm-amdgpu-fix-dereference-null-return-value-for-the.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0226249
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Adjust logic in amdgpu_device_partner_bandwidth() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8150f43
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: correct hbm field in boot status (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8657935
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Properly handle alloc_guc_id() failure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9c7689b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Only use reserved BCS instances for usm migrate exec queue (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5b37a7d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Change pcode timeout to 50msec while polling again (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 417ce57
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/selftests: Set always_coherent to false when reading from (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c19743b
* Wed Oct 23 2024 pjakobsson@suse.de
- Revert "drm/i915: Remove extra multi-gt pm-references" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e3f7d73
* Wed Oct 23 2024 pjakobsson@suse.de
- arm/komeda: Remove all CONFIG_DEBUG_FS conditional compilations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c1037c9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: renesas: shmobile: Call drm_atomic_helper_shutdown() at shutdown (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5e1b410
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/nouveau: remove unused struct 'init_exec' (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 968c2d2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Fix the BO release clear memory warning (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 00e872d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: have config DRM_WERROR depend on !WERROR (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d85ca5b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/vmwgfx: remove unused struct 'vmw_stdu_dma' (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7eb1a94
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/vmwgfx: Don't destroy Screen Target when CRTC is enabled but (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4edcc32
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/vmwgfx: Standardize use of kibibytes when logging (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 384bd26
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/vmwgfx: Remove STDU logic from generic mode_valid function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 09f0a7b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/vmwgfx: Filter modes which exceed graphics memory (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c3285be
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: remove python 3.9 dependency for compiling msm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 91ede20
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel/lg-sw43408: mark sw43408_backlight_ops as static (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c72d277
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel/lg-sw43408: select CONFIG_DRM_DISPLAY_DP_HELPER (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 538be16
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/gem-shmem: Add import attachment warning to locked pin function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b1f689a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/lima: Fix dma_resv deadlock at drm object pin time (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 61ac656
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panfrost: Fix dma_resv deadlock at drm object pin time (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 70aa134
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/bridge: adv7511: Attach next bridge without creating connector (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8749b06
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdkfd: handle duplicate BOs in reserve_bo_and_cond_vms (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c5d6353
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Call panthor_sched_post_reset() even if the reset failed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 76506ed
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Reset the FW VM to NULL on unplug (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 29f684d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Keep a ref to the VM at the panthor_kernel_bo level (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 62dcdec
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Force an immediate reset on unrecoverable faults (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d73a55b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Document drm_panthor_tiler_heap_destroy::handle validity (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 818498b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Fix an off-by-one in the heap context retrieval logic (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 98da517
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Relax the constraints on the tiler chunk size (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9d4a83a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Make sure the tiler initial/max chunks are consistent (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ccb0420
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Fix tiler OOM handling to allow incremental rendering (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2ef8bfb
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: xlnx: zynqmp_dpsub: Fix compilation error (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 68ee730
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: xlnx: zynqmp_dpsub: Fix few function comments (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb581c5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/buddy: Fix the warn on's during force merge (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 27b98eb
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/virtio: drop owner assignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 25c9f73
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: only use hard-float, not altivec on powerpc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d23fde6
* Wed Oct 23 2024 pjakobsson@suse.de
- mei: bus: constify the struct mei_cl_bus_type usage (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 268913a
* Wed Oct 23 2024 pjakobsson@suse.de
- mei: Avoid a bunch of -Wflex-array-member-not-at-end warnings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f2d96d9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/bridge: aux-hpd-bridge: correct devm_drm_dp_hpd_bridge_add() stub (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 910c9c6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: ci: arm64.config: update ONBOARD_USB_HUB to ONBOARD_USB_DEV (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 66b4210
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: sky81452-backlight: Remove unnecessary call to (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit efd6716
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: mp3309c: Fix LEDs flickering in PWM mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1472fc7
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: otm3225a: Drop driver owner assignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f925985
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: lp8788: Drop support for platform data (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f4edb6f
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: lcd: Make lcd_class constant (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit baef99e
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: Make backlight_class constant (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 93825e5
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: mp3309c: Fix signedness bug in mp3309c_parse_fwnode() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 963bdb1
* Wed Oct 23 2024 pjakobsson@suse.de
- fbdev: omap: lcd_ams_delta: Constify lcd_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 94c3707
* Wed Oct 23 2024 pjakobsson@suse.de
- fbdev: imx: Constify lcd_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0b4a305
* Wed Oct 23 2024 pjakobsson@suse.de
- fbdev: clps711x: Constify lcd_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 561cd21
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: tdo24m: Constify lcd_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 529c7e2
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: platform_lcd: Constify lcd_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 96efd2b
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: otm3225a: Constify lcd_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 181c699
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: ltv350qv: Constify lcd_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit af43ba5
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: lms501kf03: Constify lcd_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c6da768
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: lms283gf05: Constify lcd_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6141ad0
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: l4f00242t03: Constify lcd_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8c30a4b
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: jornada720_lcd: Constify lcd_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7d952bc
* Wed Oct 23 2024 pmladek@suse.com
- printk: Add notation to console_srcu locking (bsc#1232183).
- commit b5edcce
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: ili9320: Constify lcd_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5492ea2
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: ili922x: Constify lcd_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0b74abf
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: hx8357: Constify lcd_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1703e52
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: corgi_lcd: Constify lcd_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1147f3c
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: ams369fg06: Constify lcd_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e785e26
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: lcd: Constify lcd_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8107a84
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: Add controls_device callback to struct backlight_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 91591c7
* Wed Oct 23 2024 pjakobsson@suse.de
- hid: hid-picolcd: Remove struct backlight_ops.check_fb (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3fbbb3a
* Wed Oct 23 2024 pjakobsson@suse.de
- fbdev: ssd1307fb: Remove struct backlight_ops.check_fb (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2cea520
* Wed Oct 23 2024 pjakobsson@suse.de
- fbdev: ssd1307fb: Init backlight before registering framebuffer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 992b436
* Wed Oct 23 2024 pjakobsson@suse.de
- fbdev: sh_mobile_lcdc_fb: Remove struct backlight_ops.check_fb (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c3bcd2f
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: pwm-backlight: Remove struct backlight_ops.check_fb (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8e9e248
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: aat2870-backlight: Remove struct backlight.check_fb (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5929a44
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: Match backlight device against struct fb_info.bl_dev (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8061a85
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: Remove fb_blank from struct backlight_properties (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 57b3469
* Wed Oct 23 2024 pjakobsson@suse.de
- auxdisplay: ht16k33: Remove struct backlight_ops.check_fb (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3252cd8
* Wed Oct 23 2024 pjakobsson@suse.de
- auxdisplay: ht16k33: Replace use of fb_blank with backlight helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 342dfdb
* Wed Oct 23 2024 pjakobsson@suse.de
- fbdev: omap2/omapfb: Replace use of fb_blank with backlight helpers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 10a7c19
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: omap1: Replace FB_BLANK_ states with simple on/off (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9e49ede
* Wed Oct 23 2024 pjakobsson@suse.de
- backlight: omap1: Remove unused struct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5c743c4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Use PCI_IRQ_INTX instead of PCI_IRQ_LEGACY (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2406cbc
* Wed Oct 23 2024 pjakobsson@suse.de
- arch: Fix name collision with ACPI's video.o (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7920779
* Wed Oct 23 2024 pjakobsson@suse.de
- arch: Rename fbdev header and source files (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit 35f8c39
* Wed Oct 23 2024 pmladek@suse.com
- Update patches.suse/kthread-unpark-only-parked-kthread.patch
  (git-fixes, bsc#1231990, CVE-2024-50019).
- commit 1ac001a
* Wed Oct 23 2024 pjakobsson@suse.de
- arch: Remove struct fb_info from video helpers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 24b3d50
* Wed Oct 23 2024 pjakobsson@suse.de
- arch/sparc: Add module license and description for fbdev helpers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9fd7c77
* Wed Oct 23 2024 pjakobsson@suse.de
- arch/parisc: Implement <asm/fb.h> with generic helpers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 42f8b5e
* Wed Oct 23 2024 pjakobsson@suse.de
- arch: Select fbdev helpers with CONFIG_VIDEO (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f7af3ff
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/buddy: Fix the range bias clear memory allocation issue (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit df6b9e8
* Wed Oct 23 2024 pjakobsson@suse.de
- fbdev: offb: replace of_node_put with __free(device_node) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bbb976b
* Wed Oct 23 2024 pjakobsson@suse.de
- video: hdmi: prefer length specifier in format over string copying (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 76b6792
* Wed Oct 23 2024 pjakobsson@suse.de
- fbdev: au1200fb: replace deprecated strncpy with strscpy (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 59403fe
* Wed Oct 23 2024 pjakobsson@suse.de
- fbdev: fsl-diu-fb: replace deprecated strncpy with strscpy_pad (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb39bdb
* Wed Oct 23 2024 pjakobsson@suse.de
- video: logo: Drop full path of the input filename in generated file (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ad60f80
* Wed Oct 23 2024 pjakobsson@suse.de
- fbdev: omap2: replace of_graph_get_next_endpoint() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2a44fe6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/fb_dma: Add checks in drm_fb_dma_get_scanout_buffer() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3de1aee
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Fix the FW reset logic (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e013ea0
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Make sure we handle 'unknown group state' case properly (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d947b5c
* Wed Oct 23 2024 pjakobsson@suse.de
- Revert "drm: Switch DRM_DISPLAY_DP_AUX_BUS to depends on" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 218bb37
* Wed Oct 23 2024 pjakobsson@suse.de
- Revert "drm: Switch DRM_DISPLAY_DP_HELPER to depends on" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6e240fd
* Wed Oct 23 2024 pjakobsson@suse.de
- Revert "drm: Switch DRM_DISPLAY_HDCP_HELPER to depends on" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3ab2138
* Wed Oct 23 2024 pjakobsson@suse.de
- Revert "drm: Switch DRM_DISPLAY_HDMI_HELPER to depends on" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 467c10f
* Wed Oct 23 2024 pjakobsson@suse.de
- Revert "drm: fix DRM_DISPLAY_DP_HELPER dependencies" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5e078fd
* Wed Oct 23 2024 pjakobsson@suse.de
- Revert "drm/display: Select DRM_KMS_HELPER for DP helpers" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aebe776
* Wed Oct 23 2024 pjakobsson@suse.de
- Revert "drm: fix DRM_DISPLAY_DP_HELPER dependencies, part 2" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 88b6750
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Kill the faulty_slots variable in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c247100
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/gen_header: allow skipping the validation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a99e65c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/a6xx: Cleanup indexed regs const'ness (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d54563b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: Add devcoredump support for a750 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b13d2b4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: Adjust a7xx GBIF debugbus dumping (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0b54700
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: Update a6xx registers XML (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d26e87f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: Fix imported a750 snapshot header for upstream (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 241085a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: Import a750 snapshot registers from kgsl (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 833c682
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/a7xx: allow writing to CP_BV counter selection registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e159975
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/mdp4: use drmm-managed allocation for mdp4_plane (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 967db2f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/mdp5: use drmm-managed allocation for mdp5_plane (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a7b90ea
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: drop msm_kms_funcs::get_format() callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3ab9771
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: merge dpu format database to MDP formats (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fd92aa3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: convert msm_format::unpack_align_msb to the flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cb483f9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: convert msm_format::unpack_tight to the flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1ef3918
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: merge dpu_format and mdp_format in struct msm_format (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cb595fc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/dpu: pull format flag definitions to mdp_format.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 04fe898
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/dpu: in dpu_format replace bitmap with unsigned long field (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 69a02f5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: add arrays listing formats supported by MDP4/MDP5 hardware (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cedbab6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/dpu: use format-related definitions from mdp_common.xml.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8b8b1bb
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/dpu: Rename `ctx` parameter to `intf` to match other (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4bccc4f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/dpu: Allow configuring multiple active DSC blocks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d6dbf87
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/dsi: simplify connector creation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4561cc2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/dsi: move next bridge acquisition to dsi_bind (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 53ab840
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/dsi: remove the drm_bridge_attach fallback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b688446
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: Drop msm_read/writel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e9e8419
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: Fix gen_header.py for older python3 versions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9d7a169
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: drop A6xx header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 52ee509
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: drop C++ parts of a6xx.xml.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9750aeb
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: drop A6xx GMU header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ffdd1e0
* Wed Oct 23 2024 nik.borisov@suse.com
- x86/bugs: Do not use UNTRAIN_RET with IBPB on entry (git-fixes).
- commit 9059d40
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: drop A5xx header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c3f5655
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: drop A3xx and A4xx headers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4e7ed92
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: drop A2xx and common headers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4db9c3b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: drop display-related headers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 73c238b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: generate headers on the fly (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bfc9666
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: import gen_header.py script from Mesa (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d2e4e9b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: import A6xx XML display registers database (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 89ed4c6
* Wed Oct 23 2024 nik.borisov@suse.com
- x86/bugs: Skip RSB fill at VMEXIT (git-fixes).
- commit 1c2e2e9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: import A5xx XML display registers database (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit efd1775
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: import A2xx-A4xx XML display registers database (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 723bbd3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: import XML display registers database (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe44759
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: remove dependencies from core onto adreno headers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5385c0e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: move msm_gpummu.c to adreno/a2xx_gpummu.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 09e9804
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/dsi: drop mmss_cc.xml.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7090594
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/hdmi: drop qfprom.xml.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4771d7a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/mdp5: add writeback block bases (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e8942e5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/dp: Use function arguments for audio operations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dfc4b3f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/dp: Use function arguments for timing configuration (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d050606
* Wed Oct 23 2024 mfranc@suse.cz
- supported.conf: mark ultravisor userspace access as supported (bsc#1232090)
  This is needed for secure execution attestations feature.
- commit 9d4c7ad
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/dp: Use function arguments for aux writes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c74e6c8
* Wed Oct 23 2024 nik.borisov@suse.com
- x86/entry: Have entry_ibpb() invalidate return predictions (git-fixes).
- commit 8e4a09c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/dp: Remove unused defines and members (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2d0f0da
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/dp: Removed fixed nvid "support" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0cc5369
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/dp: Drop unused dp_debug struct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e90f0d5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/hdmi: Replace of_gpio.h by proper one (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9e96f75
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: convert all pixel format logging to use %%p4cc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1810f64
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/dp: Delete the old 500 ms wait for eDP HPD in aux transfer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4debdb5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/dp: Account for the timeout in wait_hpd_asserted() callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 25d0686
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/dpu: add current resource allocation to dumped state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e7d59b9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/dp: Remove now unused connector_type from desc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 310cf5b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/dp: Add support for the X1E80100 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f756862
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm/dp: Add support for determining the eDP/DP mode from DT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b68a2fe
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Merge 16021540221 and 18034896535 WAs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 857b0d2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dpio: Extract vlv_dpio_phy_regs.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2c5aa5a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dpio: Clean up the vlv/chv PHY register bits (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b6d26c9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dpio: Clean up VLV/CHV DPIO PHY register defines (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b2fc980
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dpio: Rename a few CHV DPIO PHY registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 38dbcfe
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dpio: Give VLV DPIO group register a clearer name (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4e2db42
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dpio: Derive the phy from the port rather than pipe in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f59541e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dpio: s/pipe/ch/ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c79dcc7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dpio: s/port/ch/ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 376d662
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dpio: Rename some variables (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8bece05
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dpio: Remove pointless variables from vlv/chv DPLL code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 40d6f41
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dpio: Fix VLV DPIO PLL register dword numbering (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b89697a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dpio: s/VLV_PLL_DW9_BCAST/VLV_PCS_DW17_BCAST/ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2c19531
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dpio: s/VLV_REF_DW13/VLV_REF_DW11/ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 67f1f90
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dpio: Remove pointless VLV_PCS01_DW8 read (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d703ada
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPE_WGC_C22 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a73b5dd
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPE_WGC_C21_C20 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5e238a7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPE_WGC_C12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ac189b5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPE_WGC_C11_C10 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c9252cf
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPE_WGC_C02 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6344bda
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PIPE_WGC_C01_C00 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 61e39a5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv explicitly to PALETTE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4162130
* Wed Oct 23 2024 ptesarik@suse.com
- task_work: make TWA_NMI_CURRENT handling conditional on IRQ_WORK
  (bsc#1229741).
- commit 7597955
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: split out intel_sprite_regs.h from i915_reg.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e7da677
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: split out intel_fbc_regs.h from i915_reg.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ca8d897
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/color: move palette registers to intel_color_regs.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 461552f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/audio: move LPE audio regs to intel_audio_regs.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d8806c4
* Wed Oct 23 2024 nik.borisov@suse.com
- x86/cpufeatures: Add a IBPB_NO_RET BUG flag (git-fixes).
- commit 4411a53
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/{i915, xe}: Implement fbdev emulation as in-kernel client (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f627757
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/{i915,xe}: Implement fbdev client callbacks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cf67f08
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/{i915,xe}: Unregister in-kernel clients (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 352d8e9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Initialize fbdev DRM client with callback functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4cb4589
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Move fbdev functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1e5e17d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/client: Export drm_client_dev_unregister() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a9f2b60
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: pass dev_priv to _MMIO_PIPE2, _MMIO_TRANS2, _MMIO_CURSOR2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dc26dc1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: convert _MMIO_PIPE3()/_MMIO_PORT3() to accept base (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb63b98
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add some HDCP registers DCN35 list (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1942873
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu/mes11: update ADD_QUEUE interface (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fcfd584
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu/mes: add mes mapping legacy queue support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8afd585
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Code style adjustments (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0002207
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Adjust registers sequence in the DIO list (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8259f92
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Clean up code in DC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa54d38
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: skip ip dump if devcoredump flag is set (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8c0272a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Modify the contiguous flags behaviour (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-amdgpu-Handle-sg-size-limit-for-contiguous-alloc.patch.
- commit 634bdf4
* Wed Oct 23 2024 ptesarik@suse.com
- perf: Split __perf_pending_irq() out of perf_pending_irq()
  (bsc#1229741).
- perf: Don't disable preemption in perf_pending_task()
  (bsc#1229741).
- perf: Move swevent_htable::recursion into task_struct
  (bsc#1229741).
- perf: Shrink the size of the recursion counter (bsc#1229741).
- perf: Enqueue SIGTRAP always via task_work (bsc#1229741).
- task_work: Add TWA_NMI_CURRENT as an additional notify mode
  (bsc#1229741).
- perf: Move irq_work_queue() where the event is prepared
  (bsc#1229741).
- commit bb4dbdc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Fix uninitialized variables in DC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-amd-display-Skip-to-enable-dsc-if-it-has-been-of.patch.
- commit 96ad84f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Fix uninitialized variables in DC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6c522ab
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Remove redundant include file (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2c3f660
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Do not return negative stream id for array (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b1c3709
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdkfd: Enable SQ watchpoint for gfx10 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 65c8a29
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Fix ras mode2 reset failure in ras aca mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe18174
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: fix double free err_addr pointer warnings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7385f3c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: initialize the last_jump_jiffies in atom_exec_context (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 45cd561
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add check before free wb entry (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1baf11a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add return result for amdgpu_i2c_{get/put}_byte (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c8fe7a4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Use new interface to reserve bad page (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9c27624
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Fix address translation defect (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4509a1a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdkfd: Enforce queue BO's adev (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 84de93b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Increase SAT_UPDATE_PENDING timeout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit be00ff9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add some missing HDMI registers for DCN3x (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0eb67bf
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: support ACA logging ecc errors (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b92ae9a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add poison consumption handler (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2d837bf
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: prepare to handle pasid poison consumption (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 32508f4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: retire bad pages for umc v12_0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1fa8301
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add condition check for amdgpu_umc_fill_error_record (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3f5d0fd
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Add delay work to retire bad pages (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cdfd92f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: umc v12_0 logs ecc errors (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6cc6a43
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: umc v12_0 converts error address (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b1965a0
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add interface to update umc v12_0 ecc status (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 19b0036
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add poison creation handler (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ebc0e3f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: prepare for logging ecc errors (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 47a6430
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add message fifo to handle RAS poison events (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cca788e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add TMDS DC balancer control (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 76babe3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Remove unnecessary NULL check in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d335b8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu/mes11: Use a separate fence per transaction (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b1713a3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add missing dwb registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 23ad1a6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: use mpcc_count to log MPC state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e37f77b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add a spinlock to wb allocation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3b3b4b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: update fw_share for VCN5 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8875e3b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Remove duplicated function signature from dcn3.01 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e71c641
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: update jpeg max decode resolution (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5e46a11
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add missing debug registers for DCN2/3/3.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1352d41
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add ip dump for each ip in devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa0b4db
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: dump ip state before reset for each ip (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 35d2c39
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add support for gfx v10 print (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2ce754c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add protype for print ip state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b093dc2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add support of gfx10 register dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 67f4846
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add prototype for ip dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f9ae67b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Add interface to reserve bad page (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2430ca6
* Wed Oct 23 2024 nik.borisov@suse.com
- x86/cpufeatures: Define X86_FEATURE_AMD_IBPB_RET (git-fixes).
- commit 589671a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Update CGCG settings for GFXIP 9.4.3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e9fe059
* Wed Oct 23 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Add fallback configuration when set DRR" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b5099f9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Fix snprintf buffer size in smu_v14_0_init_microcode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 520b2eb
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: replace tmz flag into buffer flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 77c4b56
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Remove duplicate dcn32/dcn32_clk_mgr.h header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e4aefab
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu/vcn: fix unitialized variable warnings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4fdef0b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu/mes11: print MES opcodes rather than numbers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d124d89
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/swsmu: add if condition for smu v14.0.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5fca8b9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu/pm: Print od status info (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4decf74
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Support setting reset_method at runtime (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1c6119f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdkfd: demote unsupported device messages to dev_info (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 27ef8a2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Fix gt reset with GuC submission is disabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4a7138a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Refactor confusing __intel_gt_reset() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4d765e6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dg2: wait for HuC load completion before running selftests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4ff2b3d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/guc: Remove usage of the deprecated ida_simple_xx() API (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 66e6977
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/guc: Remove bogus null check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8700902
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/gem: Replace dev_priv with i915 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 93a1a0f
* Wed Oct 23 2024 pjakobsson@suse.de
- Revert "drm/i915: Wait for active retire before i915_active_fini()" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 73aad50
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Remove extra multi-gt pm-references (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1a247ac
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/xelpg: Add Wa_14020495402 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dc0212c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/selftests: Pick correct caching mode. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 145cb39
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Drop WA 16015675438 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5c4a60d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/guc: Enable Wa_14019159160 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e6d6d6a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/guc: Add support for w/a KLVs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ac599b7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Enable Wa_16019325821 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ffcf666
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/guc: Use context hints for GT frequency (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0b45e74
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/guc: Simplify/extend platform check for Wa_14018913170 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 660a20a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/selftest_hangcheck: Check sanity with more patience (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c5274ac
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/guc: Correct capture of EIR register on hang (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a7e7b83
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/guc: Use the new gt_to_guc() wrapper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eaa33ae
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/gt: Create the gt_to_guc() wrapper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fccafa9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: dsi: Correct calculation formula of PHY Timing (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8f37a5d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: padding: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e8df193
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: mdp_rdma: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 45db499
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: ethdr: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1608115
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: rdma: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b969a9f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: ovl_adaptor: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 058bd96
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: ovl: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9c39193
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: merge: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bdc637e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: gamma: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 80fc66f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: color: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8b77810
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: ccorr: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 55818df
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: aal: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8207542
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: Rename mtk_ddp_comp functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8eca7b9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: Rename files "mtk_drm_gem.c" to "mtk_gem.c" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dfc652c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: Rename files "mtk_drm_gem.h" to "mtk_gem.h" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9860a88
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: Rename files "mtk_drm_plane.c" to "mtk_plane.c" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Delete patches.suse/drm-mediatek-Add-missing-plane-settings-when-async-u.patch.
- commit 79db339
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: Rename files "mtk_drm_plane.h" to "mtk_plane.h" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 115cb32
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: Rename files "mtk_drm_ddp_comp.c" to "mtk_ddp_comp.c" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Delete patches.suse/drm-mediatek-Remove-less-than-zero-comparison-of-an-.patch.
- commit e3c4eac
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: Rename files "mtk_drm_ddp_comp.h" to "mtk_ddp_comp.h" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit be9c2a7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: Rename files "mtk_drm_crtc.c" to "mtk_crtc.c" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit baf031a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: Rename files "mtk_drm_crtc.h" to "mtk_crtc.h" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1ce9fb0
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: Rename "mtk_drm_hdmi" to "mtk_hdmi" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5310ed6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: Rename "mtk_drm_gem" to "mtk_gem" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1829179
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: Rename "mtk_drm_plane" to "mtk_plane" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2d926ca
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: Rename "mtk_drm_ddp_comp" to "mtk_ddp_comp" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit abb0a9a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: Rename "mtk_drm_crtc" to "mtk_crtc" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-mediatek-Set-DRM-mode-configs-accordingly.patch.
- commit ca06dd3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: Add gamma support for MT8195 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5861fda
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mediatek: Use devm_platform_get_and_ioremap_resource() in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c8a84aa
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/loongson: fix build after debugfs include change (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e496a9b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/omap: add missing seq_file include (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2c59d9c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/komeda: fix missing seq_file includes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 517feb3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: fix build with missing debugfs includes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f7ea5f7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/print: drop include seq_file.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit de56ce4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/print: drop include debugfs.h and include where needed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 630de03
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/bridge: imx: Fix unmet depenency for PHY_FSL_SAMSUNG_HDMI_PHY (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 619c87b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: xlnx: zynqmp_dpsub: Set input live format (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 85f0afd
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: xlnx: zynqmp_dpsub: Minimize usage of global flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8c3288b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: xlnx: zynqmp_dpsub: Anounce supported input formats (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 194ec8e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: xlnx: zynqmp_dpsub: Add connected live layer helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5ba1bee
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: xlnx: zynqmp_dpsub: Update live format defines (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 64ecab3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: xlnx: zynqmp_dpsub: Set layer mode during creation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 88e1ff1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/bridge: tc358764: drop driver owner assignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3e72c58
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/bridge: chipone-icn6211: drop driver owner assignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 20c860b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel: jdi-fhd-r63452: make use of prepare_prev_first (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d3838aa
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/bridge: adv7511: make it honour next bridge in DT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 36299fb
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel: visionox-rm69299: stop calling regulator_set_load manually (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c35bfde
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel: novatek-nt36672a: stop calling regulator_set_load manually (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c875f5a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel: novatek-nt36672e: stop calling regulator_set_load manually (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d268a7f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel: novatek-nt36672e: stop setting register load before (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c439548
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/v3d: Fix race-condition between sysfs/fdinfo and interrupt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 23d2087
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/v3d: Decouple stats calculation from printing (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f710dd1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/v3d: Create function to update a set of GPU stats (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a04a0a3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/v3d: Create a struct to store the GPU stats (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 36e9537
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/v3d: Create two functions to update all GPU stats variables (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9e91835
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel-edp: Add panel CSOT MNB601LS1-1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c1be690
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/bridge: tc358775: Configure hs_rate and lp_rate (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aad551a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/bridge: tc358775: Add support for tc358765 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7a85799
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/bridge: tc358775: Enable pre_enable_prev_first flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 44b3eff
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/bridge: tc358775: Add burst and low-power modes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1bc309f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/bridge: tc358775: Get bridge data lanes instead of the DSI host (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d8dc14a
* Wed Oct 23 2024 oneukum@suse.com
- media: v4l: async: Rework internal lists (jsc#PED-10837).
- commit f64e71d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/bridge: tc358775: make standby GPIO optional (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f2dc51
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/bridge: add lvds controller support for sam9x7 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 446d688
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/rockchip: rk3066_hdmi: switch to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd70939
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: switch to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e0ff550
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/rockchip: cdn-dp: switch to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b5a75c1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/gud: switch to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5cd5404
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/vc4: hdmi: switch to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 247d6d5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/sun4i: hdmi: switch to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 17b5153
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel-edp: switch to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 77cb143
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel-samsung-atna33xc20: switch to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a479eec
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel: simple: switch to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d6f90c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Enable clear page functionality (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 093fc95
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/buddy: Implement tracking clear page feature (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/0009-drm-tests-buddy-stop-using-PAGE_SIZE.patch.
- commit 922308a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: Fix plane SIZE_HINTS property docs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 70cf835
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/edid: Parse topology block for all DispID structure v1.x (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6bad0f1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel: add Khadas TS050 V2 panel support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3bc0492
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: clean up some types in panthor_sched_suspend() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7c5b198
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/rockchip: cdn-dp: drop driver owner assignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4de29ce
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/rockchip: lvds: Remove include of drm_dp_helper.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3738a2
* Wed Oct 23 2024 pjakobsson@suse.de
- gpu: drm: exynos: hdmi: eliminate uses of of_node_put() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 54fb4dc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/exynos: mixer: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 890c48a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/exynos: hdmi: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4ec0a45
* Wed Oct 23 2024 oneukum@suse.com
- media: v4l: async: Drop duplicate handling when adding
  connections (jsc#PED-10837).
- commit e96d294
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/exynos: vidi: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 85acd10
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/exynos: scaler: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ee58812
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/exynos: rotator: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b81879f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/exynos: mic: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 38fc30c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/exynos: gsc: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f0c6255
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/exynos: g2d: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0d1fdb3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/exynos: dsi: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 22315aa
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/exynos: fimd: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cd99d9e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/exynos: fimc: drop driver owner initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b59d6c1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dsi: pass display to register macros instead of implicit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 544256c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dsi: unify connector/encoder type and name usage (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 90c2aa8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dsi: add VLV_ prefix to VLV only register macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c63d963
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dsi: remove unused _MIPIA_AUTOPWG register definition (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 219ae2c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: move dmc_firmware_path to display params (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9b4d653
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dmc: change how to disable DMC firmware using module param (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c496358
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dmc: split out per-platform firmware path selection (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d1e131e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dmc: improve firmware parse failure propagation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5164110
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dmc: handle request_firmware() errors separately (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 91e1a05
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Enable per-lane DP drive settings for bxt/glk (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0f05242
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dpio: Program bxt/glk PHY TX registers per-lane (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 201c97d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dpio: s/ddi/dpio/ for bxt/glk PHY stuff (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e4e5066
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dpio: Use intel_de_rmw() for BXT DPIO latency optim setup (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a696f04
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dpio: Introdude bxt_ddi_phy_rmw_grp() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e390ba9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dpio: Extract bxt_dpio_phy_regs.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7a762ac
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dpio: Add per-lane PHY TX register definitons for bxt/glk (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 969e6a7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dpio: Clean up bxt/glk PHY registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ccca2e3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Enable HBLANK expansion quirk for UHBR rates (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 23edd04
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Make HBLANK expansion quirk work for logical ports (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 24795c9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/dp_mst: Add drm_dp_mst_aux_for_parent() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c1ecd33
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/dp_mst: Factor out drm_dp_mst_port_is_logical() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0ceadc2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/dp: Add drm_dp_128b132b_supported() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ebae149
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Sanitize calculating the DSC DPT bpp limit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 696c642
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Account with the DSC DPT bpp limit on MTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f378cb5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Account for channel coding efficiency in the DSC DPT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6ed933d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Fix BW limit check when calculating DSC DPT bpp (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 245301e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Fix symbol clock when calculating the DSC DPT bpp (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f2cf5e5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dp: Fix DSC line buffer depth programming (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 51ad4d5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: force qgv check after the hw state readout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3f0e7b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: handle systems with duplicate psf gv points (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0074f11
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: Disable SAGV on bw init, to force QGV point (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ecaffd7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: extract code to prepare qgv points mask (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5abf5e1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: Extract code required to calculate max qgv/psf gv (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 58e6969
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: Add meaningful traces for QGV point info error (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7943eda
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dmc: use struct intel_display more (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 201fd65
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/de: allow intel_display and drm_i915_private for de (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3622af6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dmc: convert dmc wakelock interface to struct intel_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c8da153
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: rename __intel_wait_for_register_nowl() to indicate (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0687d71
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/quirks: convert struct drm_i915_private to struct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1c5e6da
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: accept either i915 or display for feature tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e6d7da3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: add generic __to_intel_display() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 17667ce
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: add generic to_intel_display() macro (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 23ed208
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: add intel_display -> drm_device backpointer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dcf38cd
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: use system include for drm headers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c6c08d8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: limit eDP MSO pipe only for display version 20 and below (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 53b3932
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Suck snps/cx0 PLL states into dpll_hw_state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c7919ab
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Unionize dpll_hw_state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f41848a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Carve up struct intel_dpll_hw_state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 69fa7be
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Add local DPLL 'hw_state' variables (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e42c15d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: s/pipe_config/crtc_state/ in legacy PLL code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 62cac38
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Drop pointless 'crtc' argument from *_crtc_clock_get() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8bd6742
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Modernize i9xx_pll_refclk() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1097d97
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Inline {i9xx,ilk}_update_pll_dividers() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 23bb019
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Extract {i9xx,i8xx,ilk,vlv,chv}_dpll() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 970f6a3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Extract i965_dpll_md() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7ccdc4c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Pass the PLL hw_state to pll->enable() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 928f549
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Extract i9xx_dpll_get_hw_state() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b51e014
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Extract ilk_dpll_compute_fp() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b1fe6a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Extract ilk_fb_cb_factor() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ea92986
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Introduce some local PLL state variables (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-i915-Fix-possible-int-overflow-in-skl_ddi_calcul.patch.
- commit cc48498
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Rename PLL hw_state variables/arguments (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4b4ab76
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Use printer for the rest of PLL debugfs dump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b1df8da
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Replace hand rolled PLL state dump with (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6e5d012
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/pf: Fix xe_gt_sriov_pf_config_print_available_ggtt() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ad057a9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Kill xe_device_mem_access_{get*,put} (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5bf7fc4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Define all possible engines in media IP descriptors (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 010626f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Convert intel_runtime_pm_get_noresume towards raw wakeref (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c579564
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/pm: Capture errors and handle them (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5a06ed0
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/tile: Abort driver load for sysfs creation failure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 963c007
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/gt: Abort driver load for sysfs creation failure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 866aba0
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Return NULL in case of drmm_add_action_or_reset failure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8dab9ce
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Simplify function return using drmm_add_action_or_reset() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2065f84
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/xe2lpg: Extend Wa_14020338487 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 855d667
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Add outer runtime_pm protection to xe_live_ktest@xe_dma_buf (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e7aefc2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Ensure all the inner access are using the _noresume variant (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 98bb556
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Convert mem_access_if_ongoing to direct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 227e85d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Removing extra mem_access protection from runtime pm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 084a32e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Convert xe_gem_fault to use direct xe_pm_runtime calls (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 24c5510
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Remove useless mem_access during probe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b3162a2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Move lockdep protection from mem_access to xe_pm_runtime (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 360f8d7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: convert inner wakeref get towards get_if_in_use (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9807e07
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Introduce intel_runtime_pm_get_noresume at (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ae2abde
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Introduce xe_pm_runtime_get_noresume for inner callers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 89fa1c3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/lnl: Apply GuC Wa_13011645652 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 71f2081
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/vm: don't include xe_gt.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5ee6861
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/vm: drop vm->destroy_work (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c2ada09
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/stolen: ignore first page for FBC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit de8a1ce
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/stolen: lower the default alignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 799f006
* Wed Oct 23 2024 ptesarik@suse.com
- perf: Fix event leak upon exec and file release (bsc#1229741).
- task_work: Introduce task_work_cancel() again (bsc#1229741).
- task_work: s/task_work_cancel()/task_work_cancel_func()/
  (bsc#1229741).
- commit f17adca
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/bmg: Some LNL workarounds also apply to BMG (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a451b69
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/lnl: Enable more GuC based workarounds (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3c47344
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/pf: Add support to configure SR-IOV VFs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3595fa0
* Wed Oct 23 2024 pjakobsson@suse.de
- lib/string_choices: Add str_plural() helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bf7faf1
* Wed Oct 23 2024 pjakobsson@suse.de
- lib/string_choices: Add str_write_read() helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a411f74
* Wed Oct 23 2024 pjakobsson@suse.de
- lib/string_choices: Add str_high_low() helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7a95228
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/pf: Add SR-IOV PF specific early GT initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6dffb3b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/guc: Add PF2GUC_UPDATE_VF_CFG to ABI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 44cd8bb
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Add xe_ttm_vram_get_avail (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 160a5ff
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Allow to assign GGTT region to the VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b107e8c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Add helper to format SR-IOV function name (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 675e71e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/gt: Add L3 bank mask to GT topology (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 88aac18
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/pf: Add support to configure GuC SR-IOV policies (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8940cb8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/guc: Add helpers for GuC KLVs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1cf9add
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/guc: Add PF2GUC_UPDATE_VGT_POLICY to ABI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2caec0e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/pf: Introduce helper functions for use by PF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb7f4a8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/pf: Introduce mutex to protect VFs configurations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 82035c6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Use hmm_range_fault to populate user pages (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c339cc1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Introduce helper to populate userptr (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 727e918
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Remove devcoredump during driver release (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd69965
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Add xe_guc_ads.c to uses_generated_oob (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f6119f7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/guc: Prefer GT oriented asserts in CTB code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cc6fa2b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/guc: Prefer GT oriented logs in GuC CTB code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9b1a532
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: re-order lmem init check and wait for initialization to (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9695d42
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: check pcode init status only on root gt of root tile (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f1d5679
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Add SR-IOV info attribute to debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 669c660
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Add proper detection of the SR-IOV PF mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1b69160
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Add max_vfs module parameter (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8a68207
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Check pat.ops before dumping PAT settings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d400b34
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Assert pat.ops function pointers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1328e0f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/xe2hpm: Add initial set of workarounds (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8cd4067
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/xe2hpg: Introduce performance tuning changes for Xe2_HPG. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 63661e0
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/xe2hpg: Add initial GT workarounds (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2ea2e48
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/xe2: Add workaround 18034896535 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 75fa377
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/xe2hpg: Remove extra allocation of CCS pages for dgfx (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ad20ee5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/xe2hpg: Determine flat ccs offset for vram (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9363a36
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/bmg: Program an additional discrete-specific PAT setting (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 185d3f5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/bmg: Add BMG mocs table (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f69623
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/bmg: Add BMG platform definition (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b9dd341
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/xe2: Recognize Xe2_HPM IP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f1ea204
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/xe2: Recognize Xe2_HPG IP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0eadf60
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/hwmon: Update xe_hwmon_get_reg to return struct xe_reg (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0e6029e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Define xe_reg_is_valid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 38ad481
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/lnl: Enable GuC Wa_14019882105 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f520cf2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/guc: Add support for workaround KLVs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 74ea8c8
* Wed Oct 23 2024 ptesarik@suse.com
- blacklist.conf: drop RT prerequisites:
- 3a5465418f5f ("perf: Fix event leak upon exec and file release")
- 68cbd415dd4b ("task_work: s/task_work_cancel()/task_work_cancel_func()/")
- commit 1eabb3d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Capture GuC CT snapshot when stopped (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8002709
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Always capture exec queues on snapshot (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 581d62f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/uapi: Restore flags VM_BIND_FLAG_READONLY and (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 48474c0
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Remove dead clock code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 26eb687
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Remove debug message from migrate_clear() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 19c20d9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/vf: Mark supported firmwares as preloaded (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 391eca2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/vf: Don't try to read legacy GuC MMIO notification if VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5dc820e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/vf: Don't try to program MOCS if VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bf58920
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/vf: Don't emit access to Global HWSP if VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6a8350e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/guc: Initialize GuC ID manager sooner (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5bfb2a8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/guc: Use drm_device-managed version of mutex_init() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 79ccee8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Drop xe_vm_assert_held() macro definition from xe_bo.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d656777
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Move PTE/PDE bit definitions to proper header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f002ee5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: fix multicast support for Xe_LP platforms (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aa684ca
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/guc: Reuse code while debugging GuC params (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dcd5e4c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/guc: Prefer GT oriented logs for GuC messages (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f8b01a9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/xe_hw_engine_class_sysfs: use sysfs_emit() for attr's _show() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 72adb98
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: prefer snprintf over sprintf (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a5a4d86
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Protect devcoredump access after unbind (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0803873
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/xe2: Add workaround 18033852989 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 173ee8d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Normalize bo flags macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c82534c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Stop passing user flag to xe_bo_create_user() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b893ef5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/xe_devcoredump: Check NULL before assignments (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1877a67
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/hwmon: Add infra to support card power and energy attributes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3fe709f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Refactor GT debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b0a3d92
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Define helper for GT specific debugfs files (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit da968be
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Store pointer to struct xe_gt in gt/ debugfs directory (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e184137
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/uapi: Define topology types as indexes rather than masks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d90236d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/gsc: Implement WA 14018094691 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a2df83f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/pf: Add minimal support for VF_STATE_NOTIFY events (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ab97872
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/guc: Add VF_STATE_NOTIFY and VF_CONTROL to ABI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4df4fd6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/vf: Add proper detection of the SR-IOV VF mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b1e570c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Move SR-IOV probe to xe_device_probe_early() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2228c70
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Separate pure MMIO init from VRAM checkout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b86c7b5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/guc: Use GuC ID Manager in submission code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4db529a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/kunit: Add basic tests for GuC context ID Manager (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 75f45ee
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/guc: Introduce GuC context ID Manager (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7d048f5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/guc: Move GUC_ID_MAX definition to GuC ABI header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3473b7e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/guc: Fix include guard for SR-IOV ABI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 95fff0a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Move HW GGTT definitions to dedicated file (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a956de4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Create a helper function to init job's user fence (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c428f1c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/guc: Remove explicit shutdown of SLPC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3368284
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Add new PCI IDs to DG2 platform (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7abcf91
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Use FIELD_PREP for lrc descriptor (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8d78ba7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Remove redundant functions to get xe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bbca41e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/guc: Add some failure checks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8a162ed
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Nuke EXEC_QUEUE_FLAG_PERSISTENT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7c33db6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/devcoredump: Print errno if VM snapshot was not captured (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7ec0eec
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Make devcoredump VM error state print consistent (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5950683
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Add debug messages for MMU notifier and VMA invalidate (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3995099
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Use USEC_PER_MSEC rather than the hard coding (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b284abb
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/bb: assert width in xe_bb_create_migration_job() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 51c2104
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/bb: assert width in xe_bb_create_job() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c977c51
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/uc: Use u64 for offsets for which we use upper_32_bits() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8fc93b1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Always check force_wake_get return code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 78faa15
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/xelpg: Add Wa_14020495402 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4d5b2f9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/gt: Remove continue statement which has no effect (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 61dfe7d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/display: fix type of intel_uncore_read*() functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 691bb39
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Move xe_ggtt_invalidate out from ggtt->lock (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 67cfb41
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Add XE_BO_GGTT_INVALIDATE flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3d62706
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Drop ggtt invalidate from display code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0a9d2d8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Add a NULL check in xe_ttm_stolen_mgr_init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 718d1c8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Use correct function pointer type (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5ca2195
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Streamline exec queue freeing path (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4649c7f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Separate out sched/deregister_done handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e88a34a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/guc: Don't support older GuC 70.x releases (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f71f8a5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Add dbg messages on the suspend resume functions. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 299e3ca
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Convert gt suspend/resume messages to debug (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 820f7b5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/vm : Remove duplicate assignment of XE_VM_FLAG_LR_MODE flag. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 17bc09e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/display: Mark dpt and related vma as uncached (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d419e06
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/display: mark DPT with XE_BO_PAGETABLE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 38f90f1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Remove usage of unsafe strcpy (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ba561af
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Drop bogus vma NULL check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0ab6634
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Fix potential integer overflow in page size calculation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c604d6f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/vm: fix xe_assert() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 503eeee
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/client: drop bogus bo NULL check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f703db
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/client: remove bogus rcu list usage (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 06e3743
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/pf: Always select Multi-Level LMTT for platforms 12.60+ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cc300c7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/pf: Request 64K aligned allocations for LMTT PD (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a6fbc12
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Allow VRAM BO allocations aligned to 64K (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0fc9735
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Make xe_mmio_read|write() functions non-inline (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1168f42
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Mark VF accessible interrupt registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 52be605
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Mark VF accessible global registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1965429
* Wed Oct 23 2024 oneukum@suse.com
- media: v4l: async: Clean up error handling in
  v4l2_async_match_notify (jsc#PED-10837).
- commit ebafa31
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Mark VF accessible GuC registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 46964f5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Define XE_REG_OPTION_VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b1abc52
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Assert size of the struct xe_reg (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 705a4d7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Add helper macro to loop each DSS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4ce4f1a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/mocs: Clarify which GT is being operated on (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 41056c7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/mocs: Determine MCR separately for primary/media GT in kunit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1fb5226
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/gsc: Handle GSCCS ER interrupt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f0eed7c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Use xe_assert in xe_device_assert_mem_access (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1fc3872
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/xe_exec : In xe_exec_ioctl remove deadcode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e0332a6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/xe_tracer: Align fence output format in ftrace log (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b0dbfa6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Group live kunit tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2213313
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/uapi: Add IP version and stepping to GT list query (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 94addab
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/hdcp: Fix condition for hdcp gsc cs requirement (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4d1b3a8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/pvc: Fix WA 18020744125 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 81db1a1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Remove unused FF_SLICE_CS_CHICKEN2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a97f2b7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/gsc: Fix kernel doc for xe_gsc_create_host_session_id (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 85db53a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Fix NULL check in xe_ggtt_init() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5bb7ebf
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Declare __xe_lrc_*_ggtt_addr with __maybe__unused (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d6af58
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Remove unused 'create' parameter from queue property logic (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 29bbfe7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Drop WA 16015675438 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b8944b6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/hdcp: Enable HDCP for XE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 680a580
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Use gsc_proxy_init_done to check proxy status (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a1c6cbf
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/hdcp: Use xe_device struct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8923cb0
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/hdcp: Move intel_hdcp_gsc_message def away from header file (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2ec44f1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Do not grab forcewakes when issuing GGTT TLB invalidation via (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3cd0fe4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/arl: Add Arrow Lake H support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f15f182
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/xelpg: Extend some workarounds to graphics version 12.74 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3f42411
* Wed Oct 23 2024 oneukum@suse.com
- media: v4l: async: Simplify async sub-device fwnode matching
  (jsc#PED-10837).
- commit a84cf2a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/xelpg: Recognize graphics version 12.74 as Xe_LPG (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5dae4a2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Pipeline evict / restore of pinned BOs during suspend / (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 209edeb
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Convert xe_pm_runtime_{get, put} to void and protect from (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 58f23c6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Create a xe_pm_runtime_resume_and_get variant for display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d2426d4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Fix display runtime_pm handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9703167
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Implement capture of HWSP and HWCTX (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5cdb163
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Add infrastructure for delayed LRC capture (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 36e30ec
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Move lrc snapshot capturing to xe_lrc.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cc4ea47
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/mocs: Fix DG2 kunit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7448d21
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/mocs: Allow odd number of entries on test (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3ee884e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/mocs: Move warn/assertion up (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ecef667
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/mocs: Be explicit when logging number of entries (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit de37d1c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/mocs: Refactor mocs/l3cc loop (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb3794b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Fix build error in xe_ggtt.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ba9156e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Add LRC parsing for more GPU instructions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fbb4760
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/guc: Handle timing out of signaled jobs gracefully (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7c16a79
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Extend uAPI to query HuC micro-controler firmware version (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 898f242
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Remove useless mem_access on PAT dumps (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4a91c79
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Convert gt_reset from mem_access to xe_pm_runtime (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3d9678c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Remove mem_access from suspend and resume functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 31e4320
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Convert gsc_work from mem_access to xe_pm_runtime (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 366db48
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Remove useless mem_access protection for query ioctls (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 220a363
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Convert hwmon from mem_access to xe_pm_runtime calls (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f82d16c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Replace dma_buf mem_access per direct xe_pm_runtime calls (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ba42075
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Runtime PM wake on every debugfs call (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3db0bc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Remove mem_access from guc_pc calls (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a4523c3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Runtime PM wake on every sysfs call (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2aabc2e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Convert kunit tests from mem_access to xe_pm_runtime (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 454c6c4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Runtime PM wake on every IOCTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 632bbac
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Convert mem_access assertion towards the runtime_pm state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6180860
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Document Xe PM component (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 83b3ea1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe: Cleanup some layering in GGTT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 386d87c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mipi-dsi: add mipi_dsi_compression_mode_ext() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit be93f8d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mipi-dsi: use correct return type for the DSC functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b674e41
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/vkms: Use drm_crtc_vblank_crtc() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b4859e0
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/nouveau: Use drm_crtc_vblank_crtc() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7fb93c7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/vblank: Introduce drm_crtc_vblank_crtc() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 765e150
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel: simple: Add Innolux G121XCE-L01 LVDS display support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9fa31a6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel: simple: Convert Innolux G121X1-L03 to display_timing (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8791758
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/edid: make drm_edid_are_equal() more convenient for its single (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f95ec12
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/edid: make drm_edid_are_equal() static (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2a05352
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/edid: avoid drm_edid_find_extension() internally (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ed000b6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/edid: rename drm_find_edid_extension() to (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3fe46a5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/edid: group struct drm_edid based declarations together (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 080fa09
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/edid: move all internal declarations to drm_crtc_internal.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2510234
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/displayid: move drm_displayid.h to drm_displayd_internal.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6b8b49c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/fb_dma: Fix parameter name in htmldocs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 137d213
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel: truly-nt35597: Don't log an error when DSI host can't be (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3a3e7f9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/vmwgfx: Implement virtual crc generation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bdf96fe
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/vmwgfx: Implement virtual kms (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9d759cd
* Wed Oct 23 2024 pjakobsson@suse.de
- dma-buf: Do not build debugfs related code when !CONFIG_DEBUG_FS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 05515a1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/fb_dma: (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cf1f822
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ast: Add drm_panic support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 73aa199
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/imx: Add drm_panic support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 78351c0
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mgag200: Add drm_panic support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 20fef15
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/simpledrm: Add drm_panic support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9dc2403
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/fb_dma: Add generic get_scanout_buffer() for drm_panic (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 709b59f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panic: Add debugfs entry to test without triggering panic. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9354eb5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panic: Add support for color format conversion (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb41ae9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panic: Add a drm panic handler (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0b9f131
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panic: Add drm panic locking (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2876c22
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: prefer DRM_MODE_FMT/ARG over drm_mode_debug_printmodeline() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3069ca5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/crtc-helper: switch to drm device based logging and warns (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d65a474
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/crtc: switch to drm device based logging (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9eb2935
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/client: switch to drm device based logging, and more (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1f84b4b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/sysfs: switch to drm device based logging (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 42b2946
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/modes: switch to drm device based error logging (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2957b94
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/probe-helper: switch to drm device based logging (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0a36e96
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/bios: return drm_edid_product_id from get_lvds_pnp_id() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fd087aa
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/bios: switch to struct drm_edid and struct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 81bebca
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/edid: add drm_edid_print_product_id() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 613a045
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/edid: add drm_edid_get_product_id() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c3f3685
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: fix DRM_DISPLAY_DP_HELPER dependencies, part 2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d8c0e94
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: Document requirements for driver-specific KMS props in new (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8e08f86
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/lima: fix void pointer to enum lima_gpu_id cast warning (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 99a1826
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/lima: include pp bcast irq in timeout handler check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4c4a875
* Wed Oct 23 2024 pjakobsson@suse.de
- accel/qaic: mark debugfs stub functions as static inline (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dbfab2e
* Wed Oct 23 2024 pjakobsson@suse.de
- accel/qaic: Add Sahara implementation for firmware loading (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7104e86
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Add SIZE_HINTS property for cursors (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a2cb451
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: Introduce plane SIZE_HINTS property (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5db8f62
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ttm: remove unused paramter (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6de5edd
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ast: Define struct ast_ddc in ast_ddc.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 12f79ad
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ast: Group DDC init code by data structure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3f61a27
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ast: Set DDC timeout in milliseconds (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 957ad16
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/bridge: imx8mp-hdmi-tx: Convert to platform remove callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 195229d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: remove virt_init_data_exchange from poison consumption (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3435ba8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Change AID detection logic (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aab8369
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: enable redirection of irq's for IH V6.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f53ba1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Skip the coredump collection on reset during driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4d30e62
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: enable redirection of irq's for IH V6.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0d10c43
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add IH_RING1_CFG headers for IH v6.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cff7b45
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Use driver mode reset for data poison (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c427410
* Wed Oct 23 2024 pjakobsson@suse.de
- drm:amdgpu: enable IH ring1 for IH v6.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6365e07
* Wed Oct 23 2024 pjakobsson@suse.de
- drm:amdgpu: enable IH RB ring1 for IH v6.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d46bbde
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/swsmu: support smu block discovery for smu v14 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a5e34b1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/swsmu: support SMU_14_0_2 ppt_funcs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d3c7364
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/swsmu: add smu v14_0_2 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 252a122
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/swsmu: add pptable header for smu v14_0_2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 13e61f8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/swsmu: add smu v14_0_2 ppsmc file (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fcafa56
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/swsmu: add smu14 driver if file (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d3203ef
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/swsmu: add smu14 ip support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1f9adf3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: rename DBG_DRV to HAD_DRV for psp v14 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c6dd4e8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: refactoring the runtime pm mode detection code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 803c2f2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Load ipkeymgr drv for psp v14 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 02b1258
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Add missing space to DRM_WARN() message (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fffbff2
* Wed Oct 23 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Enable cur_rom_en even if cursor degamma is (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 57fa2db
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Fix discovery initialization failure during pci rescan (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 485f04e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add new aca smu callback func parse_error_code() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit efc22c4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.281 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9bb942f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add missing replay field (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 603f45b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add missing callback for init_watermarks in DCN 301 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3ed493
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Update DCN201 link encoder registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7747e0f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Move REG sequence from program ogam to idle before (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5887545
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Rework dcn10_stream_encoder header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 670a6ad
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Update FMT settings for 4:2:0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7efbd6e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: increase mes submission timeout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 89942d4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Remove unnecessary code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e291e6d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Update some comments to improve the code readability (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 011148a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Replace int with unsigned int (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 084820a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Group scl_data together in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 53ef2b5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Fix PSR command version passed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 945746d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Improve the log precision (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6eed202
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Adjust headers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cf87d5d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Use dce_version instead of chip_id (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 24963aa
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Expand dmub_cmd operations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c8e33f2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add missing vbios version from devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7b959e5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu/gfx11: properly handle regGRBM_GFX_CNTL in soft reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7560799
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Rework power sequence and resource allocation logic (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 30b0f25
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Enable Z10 flag for IPS FSM (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 878dfb2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Fix incorrect pointer assignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0001387
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Pass sequential ONO bit to DMCUB boot options (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 68c521e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: add support for chroma offset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ba543b1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: limit the code change to ips enabled asic (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 86f624c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Modify resource allocation logic (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 54f4fdb
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: tie DMC wakelock to DC5/6 state transitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit beacc5f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: add module parameter to enable DMC wakelock (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f75d106
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: don't allow DMC wakelock on older hardware (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6a218e8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: add support for DMC wakelocks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3fb2c2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Allow bigjoiner for MST (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8cd2286
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/mst: Add bigjoiner handling to MST modeset sequence (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0044e03
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Handle joined pipes inside hsw_crtc_enable() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 06f83c1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Handle joined pipes inside hsw_crtc_disable() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 95d239a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Utilize intel_crtc_joined_pipe_mask() more (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 83c4d10
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Extract intel_ddi_post_disable_hdmi_or_sst() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit af128e2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/psr: Use crtc_state->port_clock instead of (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 51b97a4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/mtl: Add DP FEC BS jitter WA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 786d70b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/mtl+: Disable DP/DSC SF insertion at EOL WA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c374c62
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/adlp+: Add DSC early pixel count scaling WA (Wa_1409098942) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d0b15b7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/adlp: Add DP MST DPT/DPTP alignment WA (Wa_14014143976) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa97f74
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/adlp: Add MST short HBlank WA (Wa_14014143976) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3af099
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/adlp: Add MST FEC BS jitter WA (Wa_14013163432) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 858fd50
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/pps: move pps debugfs file to intel_pps.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 46c2370
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Introduce intel_crtc_joined_pipe_mask() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f47a546
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Pass connector to intel_dp_need_bigjoiner() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3a8e752
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/mst: Check intel_dp_joiner_needs_dsc() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fdc03bb
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Extract intel_dp_joiner_needs_dsc() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4b12ffb
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: s/intel_dp_can_bigjoiner()/intel_dp_has_bigjoiner()/ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4ebbed2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: use check_add_overflow() and drop local variants (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit db073dc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: move pipestat_irq_mask to display substruct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1ca398d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: move de_irq_mask to display substruct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f8bc99e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: move display_irqs_enabled to display substruct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6fdb499
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: move vblank_enabled to display substruct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cd7c86a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: move max_dotclk_freq to display substruct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2669444
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: move skl_preferred_vco_freq to display substruct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7aa8428
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/gt: drop display clock info from gt debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f5dfe3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Update pipes in reverse order for bigjoiner (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 71813ba
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Fix intel_modeset_pipe_config_late() for bigjoiner (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dda81c2
* Wed Oct 23 2024 oneukum@suse.com
- media: v4l: async: Rename v4l2_async_subdev as
  v4l2_async_connection (jsc#PED-10837).
- Refresh
  patches.suse/media-cadence-csi2rx-Unregister-v4l2-async-notifier.patch.
- Refresh
  patches.suse/media-sun4i_csi-Implement-link-validate-for-sun4i_cs.patch.
- commit 3a5b0a7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/display: clean up compat i915_vgpu.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9922628
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/display: remove compat i915_gem.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ea47831
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/display: clean up a lot of cruft from compat i915_drv.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c9022be
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: move i915_fixed.h to display/intel_fixed.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5e91713
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dmc: define firmware URL locally (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c3ca3e9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: use IS_JASPERLAKE()/IS_ELKHARTLAKE() instead of (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d10a3af
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/psr: Panel replay has to be enabled before link training (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 09bdca4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/psr: Unify panel replay enable/disable sink (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 926dd76
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/psr: Do not write registers/bits not applicable for panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aef6c17
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/psr: Check possible errors for panel replay as well (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 24a2321
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/psr: Do not update phy power state in case of non-eDP panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3cd041
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/psr: Intel_psr_pause/resume needs to support panel replay (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b5853e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/psr: Set intel_crtc_state->has_psr on panel replay as well (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dc8b5f1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/psr: Add some documentation of variables used in psr code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f5715b7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Fix i915_display_info output when connectors are not active (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2113a8b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: Initialize capability variables (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b198451
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Optimize out redundant dbuf slice updates (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ff96d86
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Use a plain old int for the cdclk/mdclk ratio (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d70df0
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Implement vblank synchronized MBUS join changes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 719eabc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Use the correct mdclk/cdclk ratio in MBUS updates (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c709f84
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Use old mbus_join value when increasing CDCLK (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c719662
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Add debugs for mbus joining and dbuf ratio programming (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b03369b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Extract intel_dbuf_mdclk_min_tracker_update() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit abb4951
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Extract intel_dbuf_mbus_join_update() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5e449ea
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Relocate intel_mbus_dbox_update() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aefb8db
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Loop over all active pipes in intel_mbus_dbox_update (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cbbde2b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/cdclk: Indicate whether CDCLK change happens during pre or (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1696932
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/cdclk: Drop tgl/dg2 cdclk bump hacks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e5a9396
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: Read/Write Adaptive Sync SDP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 50f99b4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: Compute vrr_vsync params (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 253f3eb
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: Add state checker for Adaptive Sync SDP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 24af506
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: Compute AS SDP parameters (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f6c5108
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dp: Add wrapper function to check AS SDP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d0e62bb
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dp: Add Read/Write support for Adaptive Sync SDP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c1d4f5a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: Add crtc state dump for Adaptive Sync SDP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 050d5ae
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/dp: Add Adaptive Sync SDP logging (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cb5f893
* Wed Oct 23 2024 oneukum@suse.com
- media: Documentation: v4l: Document v4l2_async_nf_cleanup
  (jsc#PED-10837).
- media: Documentation: v4l: Document missing async subdev
  function (jsc#PED-10837).
- media: Documentation: v4l: Fix async sensor subdev helper
  documentation (jsc#PED-10837).
- media: Documentation: v4l: Add section titles for async
  (jsc#PED-10837).
- media: Documentation: v4l: Fix async notifier registration
  example (jsc#PED-10837).
- commit 5732a01
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/dp: Add support to indicate if sink supports AS SDP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ae72a88
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Extract glk_need_scaler_clock_gating_wa() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a17b34c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Clean up glk_pipe_scaler_clock_gating_wa() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ede3131
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Shuffle DP .mode_valid() checks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 99daa8d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Remove DRM_MODE_FLAG_DBLSCAN checks from .mode_valid() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 63534de
* Wed Oct 23 2024 pjakobsson@suse.de
- Revert "drm/i915/display: move dmc_firmware_path to display params" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4ab3b8b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/psr: Do not write ALPM configuration for PSR1 or DP2.0 Panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 59be4e1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/psr: Enable ALPM on source side for eDP Panel replay (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7fcca26
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/psr: Silence period and lfps half cycle (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0ab2ba0
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/psr: Calculate aux less wake time (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d4a35dc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/psr: Add missing ALPM AUX-Less register definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6261dad
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: move dmc_firmware_path to display params (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c838fce
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: use fine grained -Woverride-init disable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c37ed29
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: Implement Wa_16021440873 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ff00ff9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: Add definition for MCURSOR_MODE_64_2B (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5d1d7fe
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Add new PCI IDs to DG2 platform in driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8c007bc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Delete stray .rej file (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3509804
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/backlight: Do not bump min brightness to max on enable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 163de2f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/bios: Use the platform's port_mask when there is no VBT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 73e7152
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: prefer intel_de_wait*() functions over uncore ones (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5e89710
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/de: register wait function renames (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 472bea3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Remove special handling for !RCS_MASK() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 84a067a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Drop dead code for pvc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a276a42
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Update IP_VER(12, 50) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9e8da78
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Stop inheriting IP_VER(12, 50) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f2b37ef
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Remove XEHP_FWRANGES() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 58c6650
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Drop dead code for xehpsdv (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b579025
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/bios: Pimp the VBT backlight data BDB version comments (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 86111e6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/bios: Define the (obsolete) backlight i2c VBT stuff (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a605506
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/bios: Add the old DPST field into VBT LFP power block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 176d410
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/bios: Update VBT driver feature block version numbers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6bcadb8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/bios: s/dpfs/dfps/ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e6ed1e2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/cx0: pass encoder instead of i915 and port around (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 651e3d1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/cx0: remove the unused intel_is_c10phy() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 275ac00
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: use intel_encoder_is/to_* functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 56bcab4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: add intel_encoder_is_*() and _to_*() functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3e9ebac
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/snps: pass encoder to (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cbe98ab
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/ddi: pass encoder to intel_wait_ddi_buf_active() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 84f2bbe
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/hdmi: convert *_port_to_ddc_pin() to *_encoder_to_ddc_pin() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7af1e54
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/mst: enable MST mode for 128b/132b single-stream sideband (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 417da35
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/mst: add intel_dp_mst_disconnect() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 15bc4b4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/mst: use the MST mode detected previously (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a602718
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/mst: abstract choosing the MST mode to use (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9bdc8dc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/mst: improve debug logging of DP MST mode detect (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b12c596
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/mst: read sideband messaging cap (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7328694
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Rename ICL_PORT_TX_DW6 bits (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e151f9a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/scaler: Update Pipe src size check in skl_update_scaler (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 97c96a8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Create the printer only once in intel_pipe_config_compare() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f656f2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Reuse pipe_config_mismatch() more (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1e63298
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Relocate pipe_config_mismatch() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6897966
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Skip intel_crtc_state_dump() if debugs aren't enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 39a3322
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Convert the remaining state dump to drm_printer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 30d38ae
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Use drm_printer more extensively in intel_crtc_state_dump() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 64522fa
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Convert intel_dpll_dump_hw_state() to drm_printer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eae70d0
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Convert pipe_config_buffer_mismatch() to drm_printer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3a12499
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Convert pipe_config_infoframe_mismatch() to drm_printer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e740723
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Include CRTC info in VSC SDP mismatch prints (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a31f843
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Include CRTC info in infoframe mismatch prints (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fcf5543
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Indicate which pipe failed the fastset check overall (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit be6630f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Drop pointless (void*) cast (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2afe965
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Use container_of_const() for states (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7a5f0c3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Don't cast away const (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 43ff7fc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dsi: Use enc_to_intel_dsi() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1449568
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: Increase number of fast wake precharge pulses (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7ff091a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/psr: Calculate IO wake and fast wake lines for DISPLAY_VER < (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 44f760b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/psr: Improve fast and IO wake lines calculation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5796c92
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: Make intel_dp_aux_fw_sync_len available for PSR (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 092dfa9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dp: Increase idle pattern wait timeout to 2ms (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b205f7d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/xe/lnl: Enable display support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ce740a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: Load DMC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e3bc3e7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: Support MDCLK:CDCLK ratio changes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1ecae8b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Add mdclk_cdclk_ratio to intel_dbuf_state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ff22c5b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Extract intel_dbuf_mdclk_cdclk_ratio_update() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0f68b24
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/cdclk: Only compute squash waveform when necessary (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 19e355c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/cdclk: Add and use mdclk_source_is_cdclk_pll() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 89f8b3c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/cdclk: Rename lnl_cdclk_table to xe2lpd_cdclk_table (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e04c097
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/opregion: add intel_opregion_vbt_present() stub for ACPI=n (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8e1ebdb
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Reuse RPLU cdclk fns for MTL+ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9f6065c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Show bios vbt when read from firmware/spi/oprom (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a497c42
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Duplicate opregion vbt memory (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 08a958c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Extract opregion vbt presence check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a7554c0
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Move vbt read from firmware to intel_bios.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 17a5784
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Pass size to spi_oprom_get_vbt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f989df4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Pass size to oprom_get_vbt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a513d51
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Simplify intel_old_crtc_state_disables() calling convention (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e71b6e2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Disable planes more atomically during modesets (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d50d8f3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Precompute disable_pipes bitmask in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9265448
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/fbc: Move DPFC_CHICKEN programming into (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2af55ba
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/fbc: Don't use a fence for a plane if FBC is not possible (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1f854ba
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Streamline eDP handling in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0b233ea
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Use pw_idx to derive PHY for ICL_LANE_ENABLE_AUX override (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2025c99
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Use REG_BIT() & co. in intel_combo_phy_regs.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 629f38a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Rename ICL_AUX_ANAOVRD1 to ICL_PORT_TX_DW6_AUX (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e970dda
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dsb: Always set DSB_SKIP_WAITS_EN (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c62916d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/dp: Fix documentation of DP tunnel functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f5f1141
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/overlay: Remove redundant drm_rect_visible() use (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 87e0488
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Add missing doc for drm_i915_reset_stats (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 855609f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: Simplify aux_ch_to_digital_port() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e990d9c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/display: Save a few bytes of memory in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 847f560
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/bios: abstract child device expected size (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5ef9222
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/bios: abstract child device size check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ec71f04
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/bios: bump expected child device size (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3c97f2d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/cdclk: Document CDCLK components (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bc6a273
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/cdclk: Rename intel_cdclk_needs_modeset to (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fbf5ac7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/dp: Fix spelling mistake "redect" -> "reject" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dbb6143
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add a function for checking tmds mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6c76494
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Modify power sequence (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f46c755
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.280 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 657fb72
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Reorganize dwb header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 301244b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Change DPCD address range (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d0b8424
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add fallback configuration for set DRR in DCN10 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f003532
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add fallback configuration when set DRR (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c35eead
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Update DCN10 resource (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b31a203
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Disable P010 Support of DCN 1.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9200985
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Update resource capabilities and debug struct for (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0e5693b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Drop legacy code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5cd5123
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Adjust some includes used by display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 151efa7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add comments to improve the code readability (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 40e41fc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu/sdma6: set sdma hang watchdog (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b11328f
* Wed Oct 23 2024 oneukum@suse.com
- staging: media: tegra-video: include video.h header
  (jsc#PED-10837).
- commit a3c58c9
* Wed Oct 23 2024 oneukum@suse.com
- staging: media: tegra-video: add support for Tegra20 parallel
  input (jsc#PED-10837).
- commit f71b54f
* Wed Oct 23 2024 nik.borisov@suse.com
- x86/tdx: Fix "in-kernel MMIO" check (bsc#1232116 CVE-2024-47727).
- commit 9b65946
* Wed Oct 23 2024 oneukum@suse.com
- staging: media: tegra-video: add H/V flip controls
  (jsc#PED-10837).
- staging: media: tegra-video: add hooks for planar YUV and H/V
  flip (jsc#PED-10837).
- staging: media: tegra-video: add syncpts for Tegra20 to struct
  tegra_vi (jsc#PED-10837).
- staging: media: tegra-video: move syncpt init/free to a per-soc
  op (jsc#PED-10837).
- commit 65e74bb
* Wed Oct 23 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add test for sign extension in
  coerce_subreg_to_size_sx() (git-fixes).
- selftests/bpf: Add test for truncation after sign extension
  in coerce_reg_to_size_sx() (git-fixes).
- bpf: Fix truncation bug in coerce_reg_to_size_sx() (git-fixes).
- selftests/bpf: Add test for sign extension in
  coerce_subreg_to_size_sx() (git-fixes).
- selftests/bpf: Add test for truncation after sign extension
  in coerce_reg_to_size_sx() (git-fixes).
- bpf: Fix truncation bug in coerce_reg_to_size_sx() (git-fixes).
- commit 34bee66
* Wed Oct 23 2024 oneukum@suse.com
- staging: media: tegra-video: add a per-soc enable/disable op
  (jsc#PED-10837).
- commit e70f605
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/amdgpu: Update PF2VF Header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-amd-amdgpu-Properly-tune-the-size-of-struct.patch.
- commit 6d882e9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: delete the redundant initialization in dcn3_51_soc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb0abe7
* Wed Oct 23 2024 pjakobsson@suse.de
- Documentation/gpu: correct path of reference (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c3ad80c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add V_TOTAL_REGS to dcn10 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit df04241
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.212.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bef5d76
* Wed Oct 23 2024 ailiop@suse.com
- xfs: fix freeing speculative preallocations for preallocated
  files (git-fixes).
- commit 80e4f70
* Wed Oct 23 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Enabling urgent latency adjustment for (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1c5a248
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Rebuild test pattern params for (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 56ed28b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: add dwb support to dml2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 48d6c1b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: refactor vpg.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8dedbea
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: expand the non standard link rate for testing (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ff8a72e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add driver support for future FAMS versions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f94d50e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/pm: Allow setting soft max frequency in VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 80827a7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: fix an incorrect ODM policy assigned for subvp (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4a61bbf
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add option to configure mapping policy for edp0 on (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit df4c216
* Wed Oct 23 2024 pjakobsson@suse.de
- amd/amdgpu: improve VF recover time (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f835a79
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/pm: Categorize RAS messages on SMUv13.0.6 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 019fa07
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/pm: Add special handling for RAS messages (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5be4ad9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/pm: Add PMFW message and capability flags (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2aef7a6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Set fatal errror detected flag earlier (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e162cd2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add missing parameter desc in dc_commit_streams (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 68bfa51
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/pm: Update uclk/sclk limit report format (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6af4859
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/pm: Report uclk/sclk current limits (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d7708b9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: retire UMC v12 mca_addr_to_pa (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 64bd5d1
* Wed Oct 23 2024 oneukum@suse.com
- staging: media: tegra-video: move MIPI calibration calls from
  VI to CSI (jsc#PED-10837).
- staging: media: tegra-video: move default format to soc-specific
  data (jsc#PED-10837).
- commit 98f376a
* Wed Oct 23 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add test for lsm tail call (CVE-2024-50063).
- commit 810e00e
* Wed Oct 23 2024 ailiop@suse.com
- xfs: make sure sb_fdblocks is non-negative (git-fixes).
- commit 258a678
* Wed Oct 23 2024 ailiop@suse.com
- xfs: remove a racy if_bytes check in xfs_reflink_end_cow_extent
  (git-fixes).
- commit 4ab4091
* Wed Oct 23 2024 ailiop@suse.com
- xfs: convert delayed extents to unwritten when zeroing post
  eof blocks (git-fixes).
- commit 6f12db2
* Wed Oct 23 2024 ailiop@suse.com
- xfs: make xfs_bmapi_convert_delalloc() to allocate the target
  offset (git-fixes).
- commit 9f0f731
* Wed Oct 23 2024 ailiop@suse.com
- xfs: make the seq argument to xfs_bmapi_convert_delalloc()
  optional (git-fixes).
- commit 504e0bc
* Wed Oct 23 2024 ailiop@suse.com
- xfs: validate recovered name buffers when recovering xattr items
  (git-fixes).
- commit a53fc5e
* Wed Oct 23 2024 oneukum@suse.com
- staging: media: tegra-video: move tegra_channel_fmt_align to
  a per-soc op (jsc#PED-10837).
- commit 5ea99e6
* Wed Oct 23 2024 ailiop@suse.com
- xfs: check shortform attr entry flags specifically (git-fixes).
- commit 621ec11
* Wed Oct 23 2024 shung-hsi.yu@suse.com
- kABI: bpf: struct bpf_map kABI workaround (CVE-2024-50063).
- bpf: Prevent tail call between progs attached to different hooks
  (CVE-2024-50063).
- commit cef79ef
* Wed Oct 23 2024 ailiop@suse.com
- xfs: check opcode and iovec count match in
  xlog_recover_attri_commit_pass2 (git-fixes).
- commit 2398ba4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/amdgpu: support MES command SET_HW_RESOURCE1 in sriov (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-amd-amdgpu-Properly-tune-the-size-of-struct.patch.
- Refresh patches.suse/drm-amdgpu-avoid-reading-vf2pf-info-size-from-FB.patch.
- commit a3018de
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: update check condition for XGMI ACA UE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit db9dc8d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/pm: update XGMI RAS UE criteria for sum v13.0.6 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7d53cb0
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu/pm: Check AMDGPU_RUNPM_BAMACO when setting baco state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 26a8576
* Wed Oct 23 2024 ailiop@suse.com
- fat: fix uninitialized variable (git-fixes).
- commit 77f5dad
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Add support for BAMACO mode checking (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7561148
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/pm: centralize all pp_dpm_xxx attribute nodes update cb (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d0869d9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Bypass asd if display hw is not available (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 54ad7e1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu/pm: Add support for MACO flag checking (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 696cef9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu/pm: Change the member function name in pp_hwmgr_func and (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 76ae475
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Add a new runtime mode definition (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8bdf0f8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Enable FGCG for DCN351 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c0f395f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add color logs for dcn20 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 83ee359
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Includes adjustments (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b78d76
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add code comments clock and encode code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit af6a708
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add WBSCL ram coefficient for writeback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 06ba9fe
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Fix MPCC DTN logging (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 65ef299
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Initialize debug variable data (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd2a0d3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add missing SFB and OPP_SF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c07d8c6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Remove redundant RESERVE0 and RESERVE1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d8140af
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add missing registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a79645b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Drop legacy code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 56852cd
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Update DSC compute parameter calculation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6844b63
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add some missing debug registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 823d68d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Enable cur_rom_en even if cursor degamma is not (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 97d86bb
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Set alpha enable to 0 for some specific formats (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cc77268
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Initialize DP ref clk with the correct clock (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c3ab321
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.279 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9d37c2d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Allow RCG for Static Screen + LVP for DCN35 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a0a9de4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Fix compiler warnings on high compiler warning (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b43aa00
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: move build test pattern params as part of pipe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c5e9b60
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add handling for DC power mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5214288
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: remove context->dml2 dependency from DML21 wrapper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d769b61
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add extra DMUB logging to track message timeout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b19591
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: add root clock control function pointer to fix (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 11be70e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Disable Z8 minimum stutter period check for DCN35 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ed84844
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add extra logging for HUBP and OTG (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5365092
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add OTG check for set AV mute (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 895e83b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Allow HPO PG for DCN35 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f5a7323
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Enable RCO for HDMISTREAMCLK in DCN35 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5791cae
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add dummy interface for tracing DCN32 SMU messages (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5c7a2f5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Enable DTBCLK DTO earlier in the sequence (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f926bf
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: update pipe topology log to support subvp (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 07b52cf
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add dmub additional interface support for FAMS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b5732dc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: use vm_update_mode=0 as default in sriov for gfx10.3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3d2eda6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/amdgpu: add pipe1 hardware support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b452593
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: select HDP ref/mask according to gfx ring pipe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 166df37
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: handle invalid connector indices (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fd6ef69
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: FEC overhead should be checked once for mst slot (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 74af08a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Expand supported Replay residency mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b43e3dc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Toggle additional RCO options in DCN35 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b7a8597
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: optimize dml2 pipe resource allocation order (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4593bc5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: fix underflow in some two display subvp/non-subvp (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 12f1451
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add timing pixel encoding for mst mode validation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 029e932
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Fix compiler redefinition warnings for certain (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2e66667
* Wed Oct 23 2024 pjakobsson@suse.de
- Documentation: add a page on amdgpu debugging (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b2a2fde
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/pm: fixes a random hang in S4 for SMU v13.0.4/11 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bda67a9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: refine function signature of amdgpu_aca_get_error_data() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f750770
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add IP's FW information to devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7e55b66
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: make amdgpu device attr_update() function more efficient (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 945e959
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.278 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2f67c58
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.210.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 541d499
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Modify DHCUB waterwark structures and functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c8bff8f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Remove plane and stream pointers from dc scratch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7ca920b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Increase number of hpo dp link encoders (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 08de4a6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Increase clock table size (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c0519bc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Allow Z8 when stutter threshold is not met for dcn35 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a859467
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Allow Z8 when stutter threshold is not met (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6b0e936
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add new IPS config mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd36641
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: build scaling params when a new plane is appended (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit efb4d4b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: fix nonseamless transition from ODM + MPO to ODM + (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f1e4f0b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Added missing null checks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5dad9e7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Refactor DML2 interfaces (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2686556
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Expand DML2 callbacks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f5099a1
* Wed Oct 23 2024 oneukum@suse.com
- staging: media: tegra-video: Kconfig: allow TPG only on Tegra210
  (jsc#PED-10837).
- commit 8391eb8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Remove read/write to external register (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4118b56
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Consolidate HPO enable/disable and restrict only to (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3e5e444
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Allow idle opts for no flip case on PSR panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7a1671b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Fix truncations in gfx_v11_0_init_microcode() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8d827b2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Fix truncation in smu_v11_0_init_microcode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d7ac2f9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: simplify convert_error_address interface for UMC v12 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 10cd5f1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Fix truncation issues in gfx_v9_0.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bf12a9e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Fix truncation in gfx_v10_0_init_microcode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2e9b318
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Fix 'fw_name' buffer size to prevent truncations in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c523f57
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Fix format character cut-off issues in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0c53b46
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add socket id parameter for psp query address cmd (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 29bbee6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdkfd: Cleanup workqueue during module unload (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e087eed
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Add a NULL check for freeing root PT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 381938e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: refactor code to split devcoredump code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b76dc4b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.277 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 094d20f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add TB_BORROWED_MAX definition (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2f3fdbc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: fix a bug to dereference already freed old current (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 193d6bc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/pm set pp_dpm_*clk as read only for SRIOV one VF mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ce5725
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Enable reallow for idle on DCN35 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8b61b51
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Enable new interface design for alternate scrambling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e6a7c39
* Wed Oct 23 2024 oneukum@suse.com
- staging: media: tegra-video: remove unneeded include
  (jsc#PED-10837).
- commit 48de39e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Remove unnecessary hard coded DPM states (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 489e1f5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add optional optimization for IPS handshake (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 209e61e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Detect and disallow idle reallow during reentrancy (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3dcbfde
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: change aux_init to apu version (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a34a362
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add ras event id support for ACA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9ee25d1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: avoid update aca bank multi times during ras isr (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e3080ef
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: retrieve umc odecc error count for aca umc v12.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 09b94d1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Added debug prints for zstate_support and (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 946e740
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Power on VPG memory unconditionally if off (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0a70c80
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: fix debug key not working on dml2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2de63a0
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add VCN sensor value for SMU 14.0.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b8b1c84
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: sync page table freeing with tlb flush (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9c9e2fc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Enable smuio v14_0_2 callbacks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ac9ed5f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Add smuio callback to get gpu clk counter (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2b3a684
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Add smuio v14_0_2 ip block support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a635ee5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Add smuio v14_0_2 ip headers (v4) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 62370fc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add umc v12.0.0 deferred error support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f1aee0e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add aca deferred error type support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b3abd31
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add VCN sensor value for SMU 13.0.5 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 93074bc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: make reset method configurable for RAS poison (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b21e6a8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: retire unused aca_bank_report data structure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 24a22ed
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add VCN sensor value for yellow carp (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3726627
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Update setting EEPROM table version (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 685159c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.276 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bc1c6be
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.208.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 63407ad
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: refine aca error cache for umc v12.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9514241
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: refine aca error cache for sdma v4.4.2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5fde6cb
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: refine aca error cache for xgmi v6.4.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0544671
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: support utcl2 RAS poison query for mmhub (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c7f1253
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add utcl2 RAS poison query for mmhub (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c55a162
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add VCN sensor value for Vangogh (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 515e42b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: clear mpc_tree in init_pipes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d08c147
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: refine aca error cache for mmhub v1.8 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9e2dbcf
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Program pixclk according to dcn revision (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6923940
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: add stream clock source to DP DTO params (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 214bd9b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: implement TLB flush fence (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1ba6761
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: refine aca error cache for gfx v9.4.3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 32caa2d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add new api to save error count into aca cache (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 11db163
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add new aca_smu_type support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b0443ba
* Wed Oct 23 2024 oneukum@suse.com
- staging: media: tegra-video: move tegra210_csi_soc to C file
  (jsc#PED-10837).
- commit b1a1ff5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Address kdoc for (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 52adbfd
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Fix truncation issues in smu_v13_0_init_microcode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d3297ef
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: remove the adev check for NULL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2e743f5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add support for atom fw version v3_5 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fb47071
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Apply retry to IP discovery v2 and v4 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e81b0d8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add ras event id support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c4d244c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add debug option for idle reg checks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d349302
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: trigger flr_work if reading pf2vf data failed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0cd8a63
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/admgpu: add vclk and dclk sysfs node for some ASICs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3eadcbb
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add VCN sensor value for SMU 13.0.4 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit de62c24
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: skip forcing odm in minimal transition (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3611f21
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add missing registers and offset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4f0f522
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Comments adjustments (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 09fef28
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: correct hostvm flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 098fff7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Remove legacy code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d973213
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Enable fast update for DCN314 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5b3ba5e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Move define to the proper header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1cb4c7d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdkfd: Check preemption status on all XCDs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1bbdcb8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdkfd: Rename read_doorbell_id in MQD functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 158b46a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/pm: Use metric table for pcie speed/width (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e921abc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/pm: Update SMUv13.0.6 PMFW headers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9da89b3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add the MALL size in the fallback function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 53d049d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Correct indentations and spaces (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f68b26d
* Wed Oct 23 2024 oneukum@suse.com
- staging: media: tegra-video: improve documentation of
  tegra_video_format fields (jsc#PED-10837).
- commit 612ca3e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Delete duplicated function prototypes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 190e5c1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Enable 2to1 ODM policy for DCN35 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8deb060
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Remove wrong signal from vrr calculation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8bce12a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Remove code duplication (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8e41045
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add the hw_ip version of all IP's (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b4a88a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Revert "Set the power_down_on_boot function pointer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6386377
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Set the power_down_on_boot function pointer to null (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a32c080
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.275 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2f691eb
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Backup and restore only on full updates (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f824e8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Implement update_planes_and_stream_v3 sequence (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4199db1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Skip virt_exchange_init on SDMA poison consumption (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f05d15b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: Do a basic health check before reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 18b1e15
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add comments to v_total calculation and drop legacy (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 130a115
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Update DMUB flags and definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9526f35
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add the sensor value of VCN activity (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 04dc5c1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Refactor DPP into a component directory (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0afe7cc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add debug counters to IPS exit prints (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6b06e22
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Guard cursor idle reallow by DC debug option (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 46c8db6
* Wed Oct 23 2024 oneukum@suse.com
- staging: media: tegra-video: move private struct declaration
  to C file (jsc#PED-10837).
- commit 6f9ce14
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add guards for idle on reg read/write (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6afb5e9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: cleanup unused variable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 29de2a9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Support long vblank feature (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b6413b3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.274 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit caee1ce
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add entry and exit counters (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d4ec19d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add debug prints for IPS testing (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eeb4342
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add debug key to allow disabling dtbclk (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a250c51
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: skip GFX FED error in page fault handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f0a8df
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: retire gfx ras query_utcl2_poison_status (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 71eb74f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add ring buffer information in devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 10f0dd0
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Fix function banner for amdgpu_dm_psr_disable_all() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 96b74ee
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add vm fault information to devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 73dde4f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add utcl2 poison query for gfxhub (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e980f91
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add new bit definitions for GC 9.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 36bc6ff
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add DML2 folder to include path (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bfbb714
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: add recent pagefault info in vm_manager (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 47f8531
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add some forward declarations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a39e0ab
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Revert Add left edge pixel + ODM pipe split (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 355ee3e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amd/display: Add left edge pixel for YCbCr422/420 + ODM pipe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 71bdd8e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/bridge: imx8mp-hdmi-pvi: Convert to platform remove callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 79dbf41
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: tilcdc: don't use devm_pinctrl_get_select_default() in probe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 958e8be
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/omap: dmm_tiler: drop driver owner assignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2c0d0d4
* Wed Oct 23 2024 oneukum@suse.com
- staging: media: tegra-video: slightly simplify cleanup on errors
  (jsc#PED-10837).
- commit 096baae
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: xlnx: db: fix a memory leak in probe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit adb067e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: remove unused header gma_drm.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4b340c8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm-panel: If drm_panel_dp_aux_backlight() fails, don't fail panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 551fbe2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel-edp: If we fail to powerup/get EDID, use conservative (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 22ec1ed
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel-edp: Abstract out function to set conservative timings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d1ed09d
* Wed Oct 23 2024 pjakobsson@suse.de
- accel/qaic: Add fifo queued debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 07a2099
* Wed Oct 23 2024 pjakobsson@suse.de
- accel/qaic: Add fifo size debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb15162
* Wed Oct 23 2024 pjakobsson@suse.de
- accel/qaic: Add bootlog debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e254c95
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/display: Select DRM_KMS_HELPER for DP helpers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bdf9f08
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: fix DRM_DISPLAY_DP_HELPER dependencies (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2546fb6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/bridge: adv7511: Allow IRQ to share GPIO pins (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2b20d00
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Don't return NULL from panthor_vm_get_heap_pool() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b4ba95b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Fix NULL vs IS_ERR() bug in panthor_probe() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3fee037
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Fix off by one in panthor_fw_get_cs_iface() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 91df6cc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Fix error code in panthor_gpu_init() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a7f4a4a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Fix a couple -ENOMEM error codes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e7cf5d1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Fix some kerneldoc warnings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f82f5a2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Cleanup unused variable 'cookie' (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b131f41
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ast: Automatically clean up poll helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 85d0d80
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ast: Implement polling for VGA and SIL164 connectors (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8be878e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ast: Use drm_connector_helper_get_modes() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3bb42c8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ast: Acquire I/O-register lock in DDC code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 469c687
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ast: Rename struct i2c_algo_bit_data callbacks and their (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9848545
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ast: Store AST device in struct ast_ddc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4a96043
* Wed Oct 23 2024 oneukum@suse.com
- media: omap3isp: Move link creation to bound callback
  (jsc#PED-10837).
- staging: media: tegra-video: improve error messages
  (jsc#PED-10837).
- staging: media: tegra-video: fix typos in comment
  (jsc#PED-10837).
- staging: media: tegra-video: document
  tegra_channel_get_remote_source_subdev (jsc#PED-10837).
- commit 86e4c4b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ast: Pass AST device to ast_ddc_create() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 51eb978
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ast: Rename struct ast_i2c_chan to struct ast_ddc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3e81ce4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ast: Move DDC code to ast_ddc.{c,h} (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f49e751
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ast: Allocate instance of struct ast_i2c_chan with managed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a33e4c1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ast: Remove struct ast_{vga,sil165}_connector (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f212a48
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ast: Fail probing if DDC channel could not be initialized (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e0fd9c4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ast: Include <linux/of.h> where necessary (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit baeb97c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Fix clang -Wunused-but-set-variable in tick_ctx_apply() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 961be97
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Drop the dev_enter/exit() sections in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d39f72a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Fix ordering in _irq_suspend() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f129941
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Fix IO-page mmap() for 32-bit userspace on 64-bit kernel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 11c2dee
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel: st7703: Add GameForce Chi Panel Support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7ddc8fb
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/vmwgfx: Remove unused code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 60a3775
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: DRM_WERROR should depend on DRM (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e35c532
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/bridge: it6505: Remove useless select (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5280cc1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: Switch DRM_DISPLAY_HDMI_HELPER to depends on (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9a3b059
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: Switch DRM_DISPLAY_HDCP_HELPER to depends on (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fc11870
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: Switch DRM_DISPLAY_DP_HELPER to depends on (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 857d790
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: Switch DRM_DISPLAY_DP_AUX_BUS to depends on (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ce50435
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/display: Make DisplayPort tunnel debug Kconfig name consistent (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a67408c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/dp: Clarify that wait_hpd_asserted() is not optional for panels (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 379483f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Fix spelling mistake "readyness" -> "readiness" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2630548
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Fix wrong kernel-doc format in the uAPI header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 726e6f7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel-edp: Add AUO B120XAN01.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c868fc5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panfrost: Only display fdinfo's engine and cycle tags when (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 28333ca
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/imagination: avoid -Woverflow warning (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b550a44
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Don't use virt_to_pfn() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 478c0d6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Fix the CONFIG_PM=n case (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b38a434
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel: atna33xc20: Fix unbalanced regulator in the case HPD (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9c504d5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ttm: warn when resv objs are mixed in a bulk_move (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aeaf633
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel: simple: Add POWERTIP PH128800T006-ZHC01 panel entry (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2f3ed11
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: bridge: thc63lvd1024: Print error message when DT parsing fails (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 029e689
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: bridge: thc63lvd1024: Switch to use of_graph_get_remote_node() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aa485da
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/bridge: it66121: Remove a duplicated invoke of (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 38e5e4c
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: bridge: dw_hdmi: Switch to of_graph_get_remote_node() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fae467b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/bridge: ite66121: Register HPD interrupt handler only when (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bf8b121
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel: ilitek-ili9881c: Add Startek KD050HDFIA020-C020A support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bea92bd
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/omapdrm: Fix console with deferred ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 19a51f1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel-edp: Fix AUO 0x405c panel naming and add a variant (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e17c742
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel-edp: Match edp_panels with panel identity (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f45f5dc
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/edid: Match edid quirks with identity (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0ed0257
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/edid: Add a function to match EDID with identity (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b55b337
* Wed Oct 23 2024 pjakobsson@suse.de
- drm_edid: Add a function to get EDID base block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 836eaad
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel: simple: add CMT430B19N00 LCD panel support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d1eea27
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/shmem-helper: Remove duplicate include (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 01fbc3e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/qxl: Do not pin buffer objects for vmap (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 906378b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/gem-vram: Do not pin buffer objects for vmap (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 21dc103
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/client: Pin vmap'ed GEM buffers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c922df3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/fbdev-generic: Fix locking with drm_client_buffer_vmap_local() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cf97ddd
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/gem: Acquire reservation lock in drm_gem_{pin/unpin}() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0fe72b7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/qxl: Acquire reservation lock in GEM pin/unpin callbacks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 41a35d3
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/qxl: Provide qxl_bo_{pin,unpin}_locked() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ebe4ce6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/nouveau: Acquire reservation lock in GEM pin/unpin callbacks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 97422a5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/nouveau: Provide nouveau_bo_{pin,unpin}_locked() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ec84b6d
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: Acquire reservation lock in GEM pin/unpin callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 411f5bf
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/msm: Provide msm_gem_get_pages_locked() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3ca5d99
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/gem-vram: Acquire reservation lock in GEM pin/unpin callbacks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3d55b70
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/gem-shmem: Acquire reservation lock in GEM pin/unpin callbacks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 235a38a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i2c: silence ch7006.h and sil164.h kernel-doc warnings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 074384b
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panfrost: Replace fdinfo's profiling debugfs knob with sysfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ca70a7b
* Wed Oct 23 2024 pjakobsson@suse.de
- Revert "drm/panthor: Fix undefined panthor_device_suspend/resume (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 697cfe7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Fix undefined panthor_device_suspend/resume symbol issue (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f6d11ed
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Explicitly include mm.h for the {virt, __phys)_to_pfn() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aff3fb1
* Wed Oct 23 2024 oneukum@suse.com
- media: platform: ti: Use
  devm_platform_get_and_ioremap_resource() (jsc#PED-10837).
- commit caae2f2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Fix panthor_devfreq kerneldoc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7875e81
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: avoid includes in drm_crtc_helper_internal.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a1e9a7e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/dp_mst: avoid includes in drm_dp_mst_topology_internal.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ae5379
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ttm: make ttm_pool.h self-contained (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 340b628
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ttm: fix ttm_kmap_iter.h kernel-doc warnings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3d2eaa4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ttm: fix ttm_execbuf_util.h kernel-doc warnings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3bca0b5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ttm: make ttm_caching.h self-contained (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e1d84e0
* Wed Oct 23 2024 osalvador@suse.de
- drm/amd/display: Add null check for head_pipe in
  dcn201_acquire_free_pipe_for_layer (CVE-2024-49919 bsc#1231968).
- commit ff31b31
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ttm: fix ttm_bo.h kernel-doc warnings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 66e4ff5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/pxp: fix i915_pxp_tee_interface.h kernel-doc warnings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d6e9df2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915/hdcp: fix i915_hdcp_interface.h kernel-doc warnings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 35bdfa7
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/i915: fix i915_gsc_proxy_mei_interface.h kernel-doc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3482af9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/encoder: improve drm_encoder_slave.h kernel-doc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ecf6dfa
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: add missing header guards to drm_crtc_helper_internal.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6dabf60
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: add missing header guards to drm_crtc_internal.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ea1683
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/gma500: Remove unused intel-mid.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fbced28
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel-edp: Add BOE NT116WHM-N44 and CMN N116BCA-EA1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f1f9bf9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/suballoc: fix drm_suballoc.h kernel-doc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4fa7d51
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/of: make drm_of.h self-contained (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 003effa
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: fix drm_gem_vram_helper.h kernel-doc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a04597e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/lease: make drm_lease.h self-contained (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 98a633a
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: fix drm_format_helper.h kernel-doc warnings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 186bb81
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/crc: make drm_debugfs_crc.h self-contained and fix kernel-doc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c1854a5
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/dp_mst: fix drm_dp_mst_helper.h kernel-doc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit becfb44
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: bridge: samsung-dsim: make samsung-dsim.h self-contained (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6dd14b2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: make amd_asic_type.h self-contained (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aa6511e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/kunit: fix drm_kunit_helpers.h kernel-doc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4647035
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: add missing header guards to drm_internal.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d980789
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/crtc: make drm_crtc_internal.h self-contained (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d5304e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: enable (most) W=1 warnings by default across the subsystem (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 741c49f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/nouveau: move more missing UAPI bits (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a9db667
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/bridge: Document bridge init order with pre_enable_prev_first (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 523a40e
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/tidss: Use dev_err_probe() over dev_dbg() when failing to probe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 26dd6f0
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panel-edp: Add prepare_to_enable to 200ms for MNC207QS1-1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a95e3d6
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/amdgpu: use GTT only as fallback for VRAM|GTT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 409f8d9
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/ttm: improve idle/busy handling v5 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fd73dc1
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Add the driver frontend block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 92cb97f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Add the scheduler logical block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aa824ea
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Add the heap logical block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 08fe6d2
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Add the FW logical block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2fccd09
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Add the MMU/VM logical block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a229f8f
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Add the devfreq logical block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2fc6752
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Add GEM logical block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1f259a8
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Add the GPU logical block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7b28691
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Add the device logical block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb4ffb0
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Add GPU register definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d7a9d79
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/panthor: Add uAPI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 54158c4
* Wed Oct 23 2024 pjakobsson@suse.de
- drm: xlnx: dp: Reset DisplayPort IP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fb59a9e
* Wed Oct 23 2024 pjakobsson@suse.de
- gpu: host1x: Add Tegra SE to SID table (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f9aaffe
* Wed Oct 23 2024 pjakobsson@suse.de
- dma-buf: handle testing kthreads creation failure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b0c3b40
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/nouveau/nvif: Avoid build error due to potential integer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 65b9baf
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/tests/buddy: stop using PAGE_SIZE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6a74056
* Wed Oct 23 2024 pjakobsson@suse.de
- drm/buddy: stop using PAGE_SIZE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 53349eb
* Wed Oct 23 2024 pjakobsson@suse.de
- PCI: Rename PCI_IRQ_LEGACY to PCI_IRQ_INTX (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7521973
* Wed Oct 23 2024 pjakobsson@suse.de
- seq_buf: Make DECLARE_SEQ_BUF() usable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 71ed65e
* Wed Oct 23 2024 pjakobsson@suse.de
- seq_buf: Introduce DECLARE_SEQ_BUF and seq_buf_str() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ebc8d9c
* Wed Oct 23 2024 pjakobsson@suse.de
- tracing: Move readpos from seq_buf to trace_seq (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f792dfc
* Wed Oct 23 2024 pjakobsson@suse.de
- powerpc: Remove initialisation of readpos (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e2565c9
* Wed Oct 23 2024 pjakobsson@suse.de
- devcoredump: Add dev_coredump_put() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ad7e728
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-atomfirmware-silence-UBSAN-warning.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0cbcc18
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-array-index-out-of-bounds-in-dml.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d0195df
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Update-efficiency-bandwidth-for-dcn3.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 39500c4
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-refresh-rate-range-for-some-pane.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e113d37
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Account-for-cursor-prefetch-BW-in-DM.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cb635bd
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-refresh-rate-range-check.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aa6effc
* Wed Oct 23 2024 oneukum@suse.com
- media: xilinx-vipp: Clean up bound async notifier callback
  (jsc#PED-10837).
- commit 3b86c81
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-ttm-Always-take-the-bo-delayed-cleanup-path-for-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9baa576
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-fbdev-generic-Fix-framebuffer-on-big-endian-devi.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit beae101
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-orientation-quirks-Add-quirk-for-Valve-Gal.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a985301
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-drm_file-Fix-pid-refcounting-race.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 71959ca
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Fix-potential-UAF-by-revoke-of-fence-reg.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 39a6c16
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-avoid-using-null-object-of-framebuffer.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b68e091
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Send-DP_TOTAL_LTTPR_CNT-during-detec.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f600ab2
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-pci-state-save-during-mode-1-reset.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f2378c8
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-atomfirmware-fix-parsing-of-vram_info.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5dd67a0
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-simple-Add-missing-display-timing-flags-fo.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 16bbf87
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-fbdev-dma-Only-set-smem_start-is-enable-per-modu.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0d7f084
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-vmwgfx-Fix-missing-HYPERVISOR_GUEST-dependency.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0ad7850
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-change-dram_clock_latency-to-34us-fo.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 658f810
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Indicate-CU-havest-info-to-CP.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9b834c4
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-locking-scope-when-flushing-tlb.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 766e6ca
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-mso-using-joiner-is-not-possible-with-eDP-M.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a2572db
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/mei-me-release-irq-in-mei_me_pci_resume-error-path.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bff5ecc
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/mei-demote-client-disconnect-warning-on-suspend-to-d.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5fdd265
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-exynos-dp-drop-driver-owner-initialization.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 21b7357
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-exynos-hdmi-report-safe-640x480-mode-as-a-fallba.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b1df911
* Wed Oct 23 2024 pjakobsson@suse.de
- Delete patches.suse/drm-amd-Fix-shutdown-again-on-some-SMU-v13.0.4-11-pl.patch.
- commit 38fc27c
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amdkfd-fix-gfx_target_version-for-certain.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9720ca8
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-silence-UBSAN-warning.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3f5968e
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Enable-colorspace-property-for-MST-c.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 50c60c7
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Fix-audio-component-initialization.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 37f94c4
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dpt-Make-DPT-object-unshrinkable.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 66ec127
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Fix-CCS-id-s-calculation-for-CCS-mode-se.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 859b1bc
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-guc-avoid-FIELD_PREP-warning.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8208631
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Disarm-breadcrumbs-if-engines-are-alread.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dcd2651
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Call-drm_atomic_helper_shutdown-at-shut.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit af3dfae
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-panel-Fix-runtime-warning-on-panel-bridge.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8d141c7
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-orientation-quirks-Add-quirk-for-Aya-Neo-K.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b6e1297
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-vmwgfx-Don-t-memcmp-equivalent-pointers.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e4d8141
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-vmwgfx-3D-disabled-should-not-effect-STDU-memory.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1576454
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-sitronix-st7789v-Add-check-for-of_drm_get_.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1cfb0a7
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-sitronix-st7789v-fix-display-size-for-jt24.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c7bbff3
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-sitronix-st7789v-tweak-timing-for-jt240mhq.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e1cc63f
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-sitronix-st7789v-fix-timing-for-jt240mhqs_.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cd80c21
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/0001-drm-mst-Fix-NULL-pointer-dereference-at-drm_dp_add_p.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 505d054
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-atomfirmware-add-intergrated-info-v2.3-ta.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 219b98b
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Let-VRAM-allocations-go-to-GTT-domain-on-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 01bf8fe
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-sh7760fb-allow-modular-build.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5b7d9b1
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-sisfb-hide-unused-variables.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9d5a7c6
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-shmobile-fix-snprintf-truncation.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 56e39ba
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-zynqmp_dpsub-Always-register-bridge.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f0f2807
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-bridge-ti-sn65dsi83-Fix-enable-error-path.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b1956ac
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-fbdev-generic-Do-not-set-physical-framebuffer-ad.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ae8e9bf
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-a6xx-Avoid-a-nullptr-dereference-when-speedb.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d432bd
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-adreno-fix-CP-cycles-stat-retrieval-on-a7xx.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ab16154
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Always-flush-the-slave-INTF-on-the-CTL.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 887cb3d
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dsi-Print-dual-DSI-adjusted-pclk-instead-of-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d438503
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dp-Avoid-a-long-timeout-for-AUX-transfer-if-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0b5ca90
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dp-allow-voltage-swing-pre-emphasis-of-3.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 701bb1c
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-the-warning-about-the-expression-int-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2ba1d25
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-uninitialized-scalar-variable-warning.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d59db95
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-uninitialized-variables-in-DM.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 99ee3eb
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Check-pipe-offset-before-setting-vbl.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 03ed0cc
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-buffer-size-in-gfx_v9_4_3_init_-cp_co.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e5112cc
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/0001-drm-amd-display-Add-NULL-pointer-check-for-kzalloc.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4d6ec9b
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Initialize-timestamp-for-some-legacy-SOCs.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f7c117b
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-division-by-zero-in-setup_dsc_co.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 742f9af
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-uninitialized-variable-warnings.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ec9011a
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-init-microcode-chip-name-from-ip-versions.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2765b72
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-dp-Fix-mtk_dp_aux_transfer-return-value.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4cd40f0
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Init-ddp_comp-with-devm_kcalloc.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e9aab3c
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358775-fix-support-for-jeida-18-and-jei.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8e7993c
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-meson-gate-px_clk-when-setting-rate.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 20abbd6
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-vop2-Do-not-divide-height-twice-for-YUV.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6058eb3
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-hwmon-Get-rid-of-devm.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d1be9d5
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-simple-Add-missing-Innolux-G121X1-L03-form.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bfc4198
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-anx7625-Update-audio-status-while-detecti.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0cae7f9
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-novatek-nt35950-Don-t-log-an-error-when-DS.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8b640a1
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-dpc3433-Don-t-log-an-error-when-DSI-host-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6147eb0
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358775-Don-t-log-an-error-when-DSI-host.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 562bfb3
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-lt9611uxc-Don-t-log-an-error-when-DSI-hos.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b9978b7
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-lt9611-Don-t-log-an-error-when-DSI-host-c.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f89acc8
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-lt8912b-Don-t-log-an-error-when-DSI-host-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e27d2aa
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-icn6211-Don-t-log-an-error-when-DSI-host-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c329509
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-anx7625-Don-t-log-an-error-when-DSI-host-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0679dbf
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-lima-fix-shared-irq-handling-on-driver-remove.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9e94fdd
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-lima-mask-irqs-in-timeout-path-before-hard-reset.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8bc5660
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-lima-add-mask-irq-callback-to-gp-and-pp.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit afa2844
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-radeon_display-Decrease-the-size-of-alloc.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit be7a1cb
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Workaround-register-access-in-idle-r.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6bf3742
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Remove-redundant-condition-in-dcn35_.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b20f725
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-potential-index-out-of-bounds-in.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit baae1ea
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-cdns-mhdp8546-Fix-possible-null-pointer-d.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3954ca
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-meson-vclk-fix-calculation-of-59.94-fractional-r.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5e768d5
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-ltk050h3146w-drop-duplicate-commands-from-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d5c451e
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-ltk050h3146w-add-MIPI_DSI_MODE_VIDEO-to-LT.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9ad30cb
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-lcdif-Do-not-disable-clocks-on-already-suspended.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0e699cd
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-omapdrm-Fix-console-by-implementing-fb_dirty.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 877ce36
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-dp-Fix-incorrect-return-code-in-r535_dp_.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 06282a2
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-ci-update-device-type-for-volteer-devices.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5443b51
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-Fix-improper-bridge-init-order-with-pre_e.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2f92df6
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/dma-buf-sw-sync-don-t-enable-IRQ-from-sync_print_obj.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022 git-fixes CVE-2024-38780 bsc#1226886)
- commit 7cd824d
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-shmem-helper-Fix-BUG_ON-on-mmap-PROT_WRITE-MAP_P.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022 git-fixes CVE-2024-39497 bsc#1227722)
- commit f7ef170
* Wed Oct 23 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-use-tile_mode-and-pte_kind-for-VM_BIND-b.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5c51b72
* Wed Oct 23 2024 pjakobsson@suse.de
- blacklist.conf: Unblacklist patches for DRM v6.10 backport
- commit b41e9af
* Wed Oct 23 2024 tbogendoerfer@suse.de
- slip: make slhc_remember() more robust against malicious packets
  (CVE-2024-50033 bsc#1231914).
- i40e: Fix macvlan leak by synchronizing access to
  mac_filter_hash (CVE-2024-50041 bsc#1231907).
- ice: Fix increasing MSI-X on VF (CVE-2024-50042 bsc#1231906).
- commit a1fb8a8
* Wed Oct 23 2024 tiwai@suse.de
- i2c: xgene-slimpro: Migrate to use generic PCC shmem related
  macros (jsc#PED-11164).
- commit a4f2b1c
* Wed Oct 23 2024 tiwai@suse.de
- pinctrl: ocelot: fix system hang on level based interrupts
  (stable-fixes).
- tty: n_gsm: Fix use-after-free in gsm_cleanup_mux
  (stable-fixes).
- USB: serial: option: add Telit FN920C04 MBIM compositions
  (stable-fixes).
- USB: serial: option: add support for Quectel EG916Q-GL
  (stable-fixes).
- drm/vmwgfx: Handle surface check failure correctly (git-fixes).
- drm/amdgpu/swsmu: Only force workload setup on init (git-fixes).
- drm/radeon: Fix encoder->possible_clones (git-fixes).
- commit 4fdf5d1
* Wed Oct 23 2024 tiwai@suse.de
- thermal: core: Reference count the zone in
  thermal_zone_get_by_id() (CVE-2024-50028 bsc#1231950).
- commit a5813a1
* Wed Oct 23 2024 shung-hsi.yu@suse.com
- bpf: Fix a sdiv overflow issue (CVE-2024-49888 bsc#1232208).
- commit ce8f994
* Tue Oct 22 2024 ailiop@suse.com
- kabi fix for NFSv4: Prevent NULL-pointer dereference in
  nfs42_complete_copies() (bsc#1231902 CVE-2024-50046).
- NFSv4: Prevent NULL-pointer dereference in
  nfs42_complete_copies() (bsc#1231902 CVE-2024-50046).
- commit e5e1a89
* Tue Oct 22 2024 oneukum@suse.com
- media: AV1: Make sure that bit depth in correctly initialize
  (jsc#PED-10837).
- commit a1adf00
* Tue Oct 22 2024 dfaggioli@suse.com
- kvm: replace __KVM_HAVE_READONLY_MEM with Kconfig symbol (bsc#1231519).
- Refresh
  patches.suse/KVM-x86-Disallow-read-only-memslots-for-SEV-ES-and-S.patch.
- Update config files
- commit 31024bd
* Tue Oct 22 2024 vbabka@suse.cz
- zram: don't free statically defined names (CVE-2024-50064
  bsc#1231901).
- commit 645eb93
* Tue Oct 22 2024 vbabka@suse.cz
- zram: free secondary algorithms names (CVE-2024-50064
  bsc#1231901).
- commit 293822f
* Tue Oct 22 2024 tiwai@suse.de
- pinctrl: intel: platform: fix error path in
  device_for_each_child_node() (git-fixes).
- device property: Introduce device_for_each_child_node_scoped()
  (stable-fixes).
- commit eb9067b
* Tue Oct 22 2024 lhenriques@suse.de
- block: fix potential invalid pointer dereference in
  blk_add_partition (bsc#1231872 CVE-2024-47705).
- block: print symbolic error name instead of error code
  (bsc#1231872).
- commit fcde2ed
* Tue Oct 22 2024 ddiss@suse.de
- nfsd: return -EINVAL when namelen is 0 (CVE-2024-47692
  bsc#1231857).
- commit 9ee6831
* Tue Oct 22 2024 jslaby@suse.cz
- PCI: Fix pci_enable_acs() support for the ACS quirks (bsc#1229019).
- commit 1bd1860
* Tue Oct 22 2024 ailiop@suse.com
- nilfs2: fix kernel bug due to missing clearing of buffer delay
  flag (git-fixes).
- commit 472d949
* Tue Oct 22 2024 oneukum@suse.com
- media: v4l: async: Clean up list heads and entries
  (jsc#PED-10837).
- commit ab5d476
* Tue Oct 22 2024 oneukum@suse.com
- media: v4l: async: Only pass match information for async subdev
  validation (jsc#PED-10837).
- commit 5f8f910
* Tue Oct 22 2024 oneukum@suse.com
- media: v4l: async: Don't check whether asd is NULL in validity
  check (jsc#PED-10837).
- Refresh
  patches.suse/media-v4l-async-Make-V4L2-async-match-information-a-.patch.
- Refresh
  patches.suse/media-v4l-async-Rename-V4L2_ASYNC_MATCH_-macros-add-.patch.
- commit caaae51
* Mon Oct 21 2024 jroedel@suse.de
- blacklist.conf: Add "iommufd/selftest: Check the bus type during probe"
- commit 62cf3fa
* Mon Oct 21 2024 jroedel@suse.de
- iommu: Restore lost return in iommu_report_device_fault()
  (jsc#PED-10539).
- Refresh
  patches.suse/iommu-Handle-iommu-faults-for-a-bad-iopf-setup.
- commit 3606b56
* Mon Oct 21 2024 jroedel@suse.de
- iommu/vt-d: Fix missed device TLB cache tag (jsc#PED-10539).
- Refresh patches.suse/iommu-vt-d-Cleanup-si_domain.
- commit 7a96040
* Mon Oct 21 2024 jroedel@suse.de
- iommu/amd: Invalidate cache before removing device from domain
  list (jsc#PED-10539).
- Refresh
  patches.suse/iommu-amd-Make-amd_iommu_dev_update_dte-static.
- commit 9d89821
* Mon Oct 21 2024 jgross@suse.com
- Update
  patches.suse/xen-move-max_pfn-in-xen_memory_setup-out-of-function.patch
  (bsc#1226003 bsc#1231828).
- commit ec3e6a6
* Mon Oct 21 2024 jroedel@suse.de
- iommu/amd: Fix Invalid wait context issue (jsc#PED-10539).
- Refresh
  patches.suse/iommu-amd-Make-amd_iommu_dev_update_dte-static.
- Refresh
  patches.suse/iommu-amd-Store-the-nid-in-io_pgtable_cfg-instead-of-the-domain.
- commit 96c2af4
* Mon Oct 21 2024 jroedel@suse.de
- Documentation: qat: fix auto_reset attribute details
  (jsc#PED-10539).
- vfio/pci: Init the count variable in collecting hot-reset
  devices (jsc#PED-10539).
- iommu/amd: Fix GT feature enablement again (jsc#PED-10539).
- iommu/amd: Check EFR bit before enabling PPR (jsc#PED-10539).
- iommu/amd: Fix workqueue name (jsc#PED-10539).
- iommu/dma: Fix domain init (jsc#PED-10539).
- virtio: uapi: Drop __packed attribute in linux/virtio_pci.h
  (jsc#PED-10539).
- Documentation: qat: fix auto_reset section (jsc#PED-10539).
- commit 15c0374
* Mon Oct 21 2024 jlee@suse.com
- thermal: gov_power_allocator: Return early in manage if trip_max is NULL (jsc#PED-11164).
- thermal: core: Change PM notifier priority to the minimum (jsc#PED-11164).
- thermal: gov_power_allocator: Use .manage() callback instead of .throttle() (jsc#PED-11164).
- commit 85870c1
* Mon Oct 21 2024 jroedel@suse.de
- iommu/amd: Rename struct amd_io_pgtable iopt to pgtbl (jsc#PED-10539).
- Refresh patches.suse/iommu-amd-Fix-typo-of-instead-of.patch.
- commit b9497a9
* Mon Oct 21 2024 jroedel@suse.de
- iommu/arm-smmu-v3: Add in-kernel support for NVIDIA Tegra241
  (Grace) CMDQV (jsc#PED-10539).
- Update config files.
- commit 7e1ba3f
* Mon Oct 21 2024 jroedel@suse.de
- iommu/vt-d: Fix incorrect pci_for_each_dma_alias() for non-PCI
  devices (jsc#PED-10539).
- iommu/arm-smmu-v3: Convert comma to semicolon (jsc#PED-10539).
- iommu/arm-smmu-v3: Fix last_sid_idx calculation for sid_bits==32
  (jsc#PED-10539).
- iommu/arm-smmu: Clarify MMU-500 CPRE workaround (jsc#PED-10539).
- vfio/pci: clean up a type in
  vfio_pci_ioctl_pci_hot_reset_groups() (jsc#PED-10539).
- vfio/mdev: Constify struct kobj_type (jsc#PED-10539).
- vfio: mdev: Remove unused function declarations (jsc#PED-10539).
- vfio/fsl-mc: Remove unused variable 'hwirq' (jsc#PED-10539).
- vfio/pci: Remove unused struct 'vfio_pci_mmap_vma'
  (jsc#PED-10539).
- iommu: Set iommu_attach_handle->domain in core (jsc#PED-10539).
- iommufd: Avoid duplicated __iommu_group_set_core_domain() call
  (jsc#PED-10539).
- iommufd: Reorder struct forward declarations (jsc#PED-10539).
- iommufd/device: Enforce reserved IOVA also when attached to
  hwpt_nested (jsc#PED-10539).
- iommufd: Reorder include files (jsc#PED-10539).
- iommu: Use of_property_present() (jsc#PED-10539).
- iommu/io-pgtable-arm: Optimise non-coherent unmap
  (jsc#PED-10539).
- iommu: Allow ATS to work on VFs when the PF uses IDENTITY
  (jsc#PED-10539).
- iommu/amd: Test for PAGING domains before freeing a domain
  (jsc#PED-10539).
- iommu/amd: Add kernel parameters to limit V1 page-sizes
  (jsc#PED-10539).
- iommu/amd: Correct the reported page sizes from the V1 table
  (jsc#PED-10539).
- iommu/amd: Remove the confusing dummy iommu_flush_ops tlb ops
  (jsc#PED-10539).
- iommu/amd: Remove conditions from domain free paths
  (jsc#PED-10539).
- iommu/amd: Narrow the use of struct protection_domain to
  invalidation (jsc#PED-10539).
- iommu/amd: Store the nid in io_pgtable_cfg instead of the domain
  (jsc#PED-10539).
- iommu/amd: Remove amd_io_pgtable::pgtbl_cfg (jsc#PED-10539).
- iommu/amd: Remove the amd_iommu_domain_set_pt_root() and related
  (jsc#PED-10539).
- iommu/amd: Remove amd_iommu_domain_update() from page table
  freeing (jsc#PED-10539).
- iommu/amd: Set the pgsize_bitmap correctly (jsc#PED-10539).
- iommu/amd: Move allocation of the top table into
  v1_alloc_pgtable (jsc#PED-10539).
- iommu/amd: Make amd_iommu_dev_update_dte() static
  (jsc#PED-10539).
- iommu/amd: Rework amd_iommu_update_and_flush_device_table()
  (jsc#PED-10539).
- iommu/amd: Make amd_iommu_domain_flush_complete() static
  (jsc#PED-10539).
- iommu/amd: Make amd_iommu_dev_flush_pasid_all() static
  (jsc#PED-10539).
- iommu/amd: Handle error path in amd_iommu_probe_device()
  (jsc#PED-10539).
- iommu/amd: Remove unused DTE_GCR3_INDEX_* macros
  (jsc#PED-10539).
- iommu/amd: Make amd_iommu_is_attach_deferred() static
  (jsc#PED-10539).
- iommu/amd: Update event log pointer as soon as processing is
  complete (jsc#PED-10539).
- iommu/amd: Update PASID, GATS, GLX, SNPAVICSUP feature related
  macros (jsc#PED-10539).
- iommu/amd: Add blocked domain support (jsc#PED-10539).
- iommu/vt-d: Introduce batched cache invalidation
  (jsc#PED-10539).
- iommu/vt-d: Add qi_batch for dmar_domain (jsc#PED-10539).
- iommu/vt-d: Refactor IOTLB and Dev-IOTLB flush for batching
  (jsc#PED-10539).
- iommu/vt-d: Factor out invalidation descriptor composition
  (jsc#PED-10539).
- iommu/vt-d: Unconditionally flush device TLB for pasid table
  updates (jsc#PED-10539).
- iommu/vt-d: Move PCI PASID enablement to probe path
  (jsc#PED-10539).
- iommu/vt-d: Fix potential lockup if qi_submit_sync called with
  0 count (jsc#PED-10539).
- iommu/vt-d: Cleanup si_domain (jsc#PED-10539).
- iommu/vt-d: Add support for static identity domain
  (jsc#PED-10539).
- iommu/vt-d: Factor out helpers from domain_context_mapping_one()
  (jsc#PED-10539).
- iommu/vt-d: Remove has_iotlb_device flag (jsc#PED-10539).
- iommu/vt-d: Always reserve a domain ID for identity setup
  (jsc#PED-10539).
- iommu/vt-d: Remove identity mappings from si_domain
  (jsc#PED-10539).
- iommu/vt-d: Require DMA domain if hardware not support
  passthrough (jsc#PED-10539).
- dt-bindings: arm-smmu: Add compatible for QCS8300 SoC
  (jsc#PED-10539).
- dt-bindings: arm-smmu: document the support on SA8255p
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Reorganize struct arm_smmu_ctx_desc_cfg
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Add types for each level of the CD table
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Shrink the cdtab l1_desc array
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Do not use devm for the cd table allocations
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Remove strtab_base/cfg (jsc#PED-10539).
- iommu/arm-smmu-v3: Reorganize struct arm_smmu_strtab_cfg
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Add types for each level of the 2 level
  stream table (jsc#PED-10539).
- iommu/arm-smmu-v3: Add arm_smmu_strtab_l1/2_idx()
  (jsc#PED-10539).
- iommu/arm-smmu-qcom: apply num_context_bank fixes for SDM630 /
  SDM660 (jsc#PED-10539).
- iommu/arm-smmu-v3: Use the new rb tree helpers (jsc#PED-10539).
- iommu/tegra241-cmdqv: Do not allocate vcmdq until
  dma_set_mask_and_coherent (jsc#PED-10539).
- iommu/tegra241-cmdqv: Drop static at local variable
  (jsc#PED-10539).
- iommu/tegra241-cmdqv: Fix ioremap() error handling in probe()
  (jsc#PED-10539).
- iommu/tegra241-cmdqv: Fix -Wformat-truncation warnings in
  lvcmdq_error_header (jsc#PED-10539).
- iommu/arm-smmu-v3-test: Test masters with stall enabled
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Match Stall behaviour for S2 (jsc#PED-10539).
- iommu/tegra241-cmdqv: Limit CMDs for VCMDQs of a guest owned
  VINTF (jsc#PED-10539).
- iommu/arm-smmu-v3: Start a new batch if new command is not
  supported (jsc#PED-10539).
- iommu/arm-smmu-v3: Add struct arm_smmu_impl_ops (jsc#PED-10539).
- iommu/arm-smmu-v3: Add acpi_smmu_iort_probe_model for impl
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Add ARM_SMMU_OPT_TEGRA241_CMDQV
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Make symbols public for CONFIG_TEGRA241_CMDQV
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Pass in cmdq pointer to arm_smmu_cmdq_init
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Pass in cmdq pointer to
  arm_smmu_cmdq_build_sync_cmd (jsc#PED-10539).
- iommu/arm-smmu-v3: Issue a batch of commands to the same cmdq
  (jsc#PED-10539).
- iommu/arm-smmu-qcom: Work around SDM845 Adreno SMMU w/ 16K pages
  (jsc#PED-10539).
- iommu/arm-smmu-qcom: hide last LPASS SMMU context bank from
  linux (jsc#PED-10539).
- iommu/arm-smmu-v3: Fix a NULL vs IS_ERR() check (jsc#PED-10539).
- iommu/arm-smmu-v3: Remove the unused empty definition
  (jsc#PED-10539).
- iommu/arm-smmu: Un-demote unhandled-fault msg (jsc#PED-10539).
- iommu/amd: Fix argument order in amd_iommu_dev_flush_pasid_all()
  (jsc#PED-10539).
- commit bdc165e
* Mon Oct 21 2024 oneukum@suse.com
- media: atomisp: Register only 1 /dev/video# node
  (jsc#PED-10837).
- commit a873077
* Mon Oct 21 2024 oneukum@suse.com
- media: atomisp: Drop atomisp_get_css_buf_type() (jsc#PED-10837).
- commit b3b1ee8
* Mon Oct 21 2024 oneukum@suse.com
- media: atomisp: Remove isp->need_gfx_throttle field
  (jsc#PED-10837).
- commit c45f623
* Mon Oct 21 2024 oneukum@suse.com
- media: atomisp: Remove res_overflow parameter from
  atomisp_try_fmt() (jsc#PED-10837).
- commit 3e50694
* Mon Oct 21 2024 oneukum@suse.com
- media: atomisp: sh_css_mipi: Remove #ifdef ISP2401
  (jsc#PED-10837).
- commit 78a16bf
* Mon Oct 21 2024 jroedel@suse.de
- iommufd/iova_bitmap: Check iova_bitmap_done() after set ahead (jsc#PED-10539).
- commit 8cdf473
* Mon Oct 21 2024 nik.borisov@suse.com
- x86/sev: Check for MWAITX and MONITORX opcodes in the #VC handler (git-fixes).
- commit 23789e3
* Mon Oct 21 2024 nik.borisov@suse.com
- x86/apic: Make x2apic_disable() work correctly (git-fixes).
- commit 546101e
* Mon Oct 21 2024 nik.borisov@suse.com
- x86/entry: Remove unwanted instrumentation in common_interrupt() (git-fixes).
- commit 846156b
* Mon Oct 21 2024 pjakobsson@suse.de
- blacklist.conf: Blacklist git-fixes for DRM v6.9 backport
- commit 6adfc8d
* Mon Oct 21 2024 jlee@suse.com
- blacklist.conf: For backporting to SLE15-SP7 in batches, d2278f3533a8 add to blacklist temporarily
- commit a32459b
* Mon Oct 21 2024 nik.borisov@suse.com
- x86/mm: Use IPIs to synchronize LAM enablement (git-fixes).
- commit 8a7a0be
* Mon Oct 21 2024 nik.borisov@suse.com
- x86/amd_nb: Add new PCI IDs for AMD family 1Ah model 60h (git-fixes).
- commit 60a5f34
* Mon Oct 21 2024 jlee@suse.com
- thermal/debugfs: Print initial trip temperature and hysteresis in tze_seq_show() (jsc#PED-11164).
- commit bd09eda
* Mon Oct 21 2024 jroedel@suse.de
- iommufd: Associate fault object with iommufd_hw_pgtable
  (jsc#PED-10539).
- Refresh
  patches.suse/iommufd-Check-the-domain-owner-of-the-parent-before-.patch.
- commit 722fe2a
* Mon Oct 21 2024 nik.borisov@suse.com
- x86/PCI: Check pcie_find_root_port() return for NULL (git-fixes).
- commit 7c1cc11
* Mon Oct 21 2024 oneukum@suse.com
- media: atomisp: sh_css_firmware: determine firmware version
  at runtime (jsc#PED-10837).
- commit e081854
* Mon Oct 21 2024 oneukum@suse.com
- media: atomisp: sh_css_sp: Remove #ifdef ISP2401
  (jsc#PED-10837).
- commit bf8a925
* Mon Oct 21 2024 oneukum@suse.com
- media: atomisp: runtime: frame: remove #ifdef ISP2401
  (jsc#PED-10837).
- commit a8d9320
* Mon Oct 21 2024 oneukum@suse.com
- media: atomisp: sh_css: Remove #ifdef ISP2401 (jsc#PED-10837).
- commit 089bc66
* Mon Oct 21 2024 vbabka@suse.cz
- maple_tree: correct tree corruption on spanning store
  (git-fixes).
- commit 2b034f1
* Mon Oct 21 2024 nik.borisov@suse.com
- x86/resctrl: Avoid overflow in MB settings in bw_validate() (git-fixes).
- commit b2f0d6d
* Mon Oct 21 2024 nik.borisov@suse.com
- x86/resctrl: Annotate get_mem_config() functions as __init (git-fixes).
- commit 7e80f38
* Mon Oct 21 2024 oneukum@suse.com
- media: atomisp: Replace source-pad checks with run-mode checks
  (jsc#PED-10837).
- commit 767bdec
* Mon Oct 21 2024 jroedel@suse.de
- iommu: Do not return 0 from map_pages if it doesn't do anything
  (jsc#PED-10539).
- iommufd: Do not allow creating areas without READ or WRITE
  (jsc#PED-10539).
- iommu/vt-d: Fix incorrect domain ID in context flush helper
  (jsc#PED-10539).
- iommu: Handle iommu faults for a bad iopf setup (jsc#PED-10539).
- iommu: arm-smmu: Fix Tegra workaround for PAGE_SIZE mappings
  (jsc#PED-10539).
- vfio-mdev: add missing MODULE_DESCRIPTION() macros
  (jsc#PED-10539).
- vfio/pci: Fix typo in macro to declare accessors
  (jsc#PED-10539).
- vfio/pci: Support 8-byte PCI loads and stores (jsc#PED-10539).
- vfio/pci: Extract duplicated code into macro (jsc#PED-10539).
- RDMA/usnic: Use iommu_paging_domain_alloc() (jsc#PED-10539).
- wifi: ath11k: Use iommu_paging_domain_alloc() (jsc#PED-10539).
- wifi: ath10k: Use iommu_paging_domain_alloc() (jsc#PED-10539).
- drm/msm: Use iommu_paging_domain_alloc() (jsc#PED-10539).
- vhost-vdpa: Use iommu_paging_domain_alloc() (jsc#PED-10539).
- vfio/type1: Use iommu_paging_domain_alloc() (jsc#PED-10539).
- iommufd: Use iommu_paging_domain_alloc() (jsc#PED-10539).
- iommu: Add iommu_paging_domain_alloc() interface
  (jsc#PED-10539).
- arm64: dts: fvp: Enable PCIe ATS for Base RevC FVP
  (jsc#PED-10539).
- iommu/of: Support ats-supported device-tree property
  (jsc#PED-10539).
- dt-bindings: PCI: generic: Add ats-supported property
  (jsc#PED-10539).
- iommu: Remove iommu_fwspec ops (jsc#PED-10539).
- OF: Simplify of_iommu_configure() (jsc#PED-10539).
- ACPI: Retire acpi_iommu_fwspec_ops() (jsc#PED-10539).
- iommu: Resolve fwspec ops automatically (jsc#PED-10539).
- iommu/mediatek-v1: Clean up redundant fwspec checks
  (jsc#PED-10539).
- docs: iommu: Remove outdated
  Documentation/userspace-api/iommu.rst (jsc#PED-10539).
- iommufd: Use atomic_long_try_cmpxchg() in incr_user_locked_vm()
  (jsc#PED-10539).
- iommu/iova: Add missing MODULE_DESCRIPTION() macro
  (jsc#PED-10539).
- iommu/dma: Prune redundant pgprot arguments (jsc#PED-10539).
- iommu: Make iommu_sva_domain_alloc() static (jsc#PED-10539).
- dt-bindings: iommu: Convert msm,iommu-v0 to yaml
  (jsc#PED-10539).
- dt-bindings: iommu: qcom,iommu: Add MSM8953 GPU IOMMU to SMMUv2
  compatibles (jsc#PED-10539).
- iommu/tegra-smmu: Pass correct fwnode to iommu_fwspec_init()
  (jsc#PED-10539).
- iommu/vt-d: Fix aligned pages in calculate_psi_aligned_address()
  (jsc#PED-10539).
- iommu/vt-d: Limit max address mask to MAX_AGAW_PFN_WIDTH
  (jsc#PED-10539).
- iommu/vt-d: Refactor PCI PRI enabling/disabling callbacks
  (jsc#PED-10539).
- iommu/vt-d: Add helper to flush caches for context change
  (jsc#PED-10539).
- iommu/vt-d: Add helper to allocate paging domain
  (jsc#PED-10539).
- iommu/vt-d: Downgrade warning for pre-enabled IR
  (jsc#PED-10539).
- iommu/vt-d: Remove control over Execute-Requested requests
  (jsc#PED-10539).
- iommu/vt-d: Remove comment for def_domain_type (jsc#PED-10539).
- iommu/vt-d: Handle volatile descriptor status read
  (jsc#PED-10539).
- iommu/vt-d: Use try_cmpxchg64() in intel_pasid_get_entry()
  (jsc#PED-10539).
- iommu: Move IOMMU_DIRTY_NO_CLEAR define (jsc#PED-10539).
- iommu/arm-smmu-qcom: Register the TBU driver in
  qcom_smmu_impl_init (jsc#PED-10539).
- iommu/arm-smmu-v3: Enable HTTU for stage1 with io-pgtable
  mapping (jsc#PED-10539).
- iommu/arm-smmu-v3: Add support for dirty tracking in domain
  alloc (jsc#PED-10539).
- iommu/io-pgtable-arm: Add read_and_clear_dirty() support
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Add feature detection for HTTU
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Add support for domain_alloc_user fn
  (jsc#PED-10539).
- iommu/arm-smmu-qcom: record reason for deferring probe
  (jsc#PED-10539).
- iommu/arm-smmu: Pretty-print context fault related regs
  (jsc#PED-10539).
- iommu/arm-smmu-qcom-debug: Do not print for handled faults
  (jsc#PED-10539).
- iommu/arm-smmu: Add CB prefix to register bitfields
  (jsc#PED-10539).
- iommu/arm-smmu-v3: add missing MODULE_DESCRIPTION() macro
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Shrink the strtab l1_desc array
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Do not zero the strtab twice (jsc#PED-10539).
- iommu/arm-smmu-v3: Allow setting a S1 domain to a PASID
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Allow a PASID to be set when RID is
  IDENTITY/BLOCKED (jsc#PED-10539).
- iommu/arm-smmu-v3: Test the STE S1DSS functionality
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Allow IDENTITY/BLOCKED to be set while
  PASID is used (jsc#PED-10539).
- iommu/arm-smmu-v3: Put the SVA mmu notifier in the smmu_domain
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Keep track of arm_smmu_master_domain for SVA
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Make SVA allocate a normal arm_smmu_domain
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Thread SSID through the arm_smmu_attach_*()
  interface (jsc#PED-10539).
- iommu/arm-smmu-v3: Do not use master->sva_enable to restrict
  attaches (jsc#PED-10539).
- iommu/arm-smmu-v3: Add ssid to struct arm_smmu_master_domain
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Make changing domains be hitless for ATS
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Make smmu_domain->devices into an allocated
  list (jsc#PED-10539).
- iommu/arm-smmu-v3: Start building a generic PASID layer
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Convert to domain_alloc_sva()
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Use *-y instead of *-objs in Makefile
  (jsc#PED-10539).
- iommu/arm-smmu-v3: Avoid uninitialized asid in case of error
  (jsc#PED-10539).
- dt-bindings: arm-smmu: Add X1E80100 GPU SMMU (jsc#PED-10539).
- dt-bindings: arm-smmu: Fix Qualcomm SC8180X binding
  (jsc#PED-10539).
- iommu/amd: Use try_cmpxchg64() in v2_alloc_pte()
  (jsc#PED-10539).
- iommu: sun50i: Add H616 compatible string (jsc#PED-10539).
- dt-bindings: iommu: add new compatible strings (jsc#PED-10539).
- iommu: sun50i: allocate page tables from below 4 GiB
  (jsc#PED-10539).
- iommu: sun50i: clear bypass register (jsc#PED-10539).
- iommufd: Put constants for all the uAPI enums (jsc#PED-10539).
- iommufd: Fix error pointer checking (jsc#PED-10539).
- iommufd: Add check on user response code (jsc#PED-10539).
- iommufd: Remove IOMMUFD_PAGE_RESP_FAILURE (jsc#PED-10539).
- iommufd: Require drivers to supply the cache_invalidate_user
  ops (jsc#PED-10539).
- iommufd: Fault-capable hwpt attach/detach/replace
  (jsc#PED-10539).
- iommufd: Add iommufd fault object (jsc#PED-10539).
- iommufd: Add fault and response message definitions
  (jsc#PED-10539).
- iommu: Extend domain attach group with handle support
  (jsc#PED-10539).
- iommu: Add attach handle to struct iopf_group (jsc#PED-10539).
- iommu: Remove sva handle list (jsc#PED-10539).
- iommu: Introduce domain attachment handle (jsc#PED-10539).
- iommufd/iova_bitmap: Remove iterator logic (jsc#PED-10539).
- iommufd/iova_bitmap: Dynamic pinning on iova_bitmap_set()
  (jsc#PED-10539).
- iommufd/iova_bitmap: Consolidate iova_bitmap_set exit
  conditionals (jsc#PED-10539).
- iommufd/iova_bitmap: Move initial pinning to
  iova_bitmap_for_each() (jsc#PED-10539).
- iommufd/iova_bitmap: Cache mapped length in iova_bitmap_map
  struct (jsc#PED-10539).
- commit d9d8a71
* Mon Oct 21 2024 nik.borisov@suse.com
- x86/apic: Always explicitly disarm TSC-deadline timer (git-fixes).
- commit 312d3e7
* Mon Oct 21 2024 oneukum@suse.com
- media: atomisp: Remove Continuous capture and SDV run-modes
  (jsc#PED-10837).
- commit 8f2a038
* Mon Oct 21 2024 nik.borisov@suse.com
- x86/CPU/AMD: Only apply Zenbleed fix for Zen2 during late microcode  load (git-fixes).
- commit 0cb125d
* Mon Oct 21 2024 davide.benini@suse.com
- ethtool: fail closed if we can't get max channel used in
  indirection tables (CVE-2024-46834 bsc#1231096).
- commit 5cacc93
* Mon Oct 21 2024 oneukum@suse.com
- Bluetooth: btusb: Fix not being able to reconnect after suspend
  (git-fixes).
- commit c84ecb4
* Mon Oct 21 2024 pjakobsson@suse.de
- drm/panel: ili9341: Correct use of device property APIs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit e4f8577
* Mon Oct 21 2024 pjakobsson@suse.de
- backlight: Add Kinetic KTD2801 Backlight support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 0585437
* Mon Oct 21 2024 pjakobsson@suse.de
- drm/i915/dp: Add support for DP tunnel BW allocation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit e793cd3
* Mon Oct 21 2024 pjakobsson@suse.de
- drm/panel: Add driver for DJN HX83112A LCD panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 388de60
* Mon Oct 21 2024 pjakobsson@suse.de
- video: Add helpers for decoding screen_info (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit acc80a2
* Mon Oct 21 2024 pjakobsson@suse.de
- drm/panel: re-alphabetize the menu list (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 638824c
* Mon Oct 21 2024 pjakobsson@suse.de
- drm/bridge: imx: add bridge wrapper driver for i.MX8MP DWC HDMI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit fbb2d5c
* Mon Oct 21 2024 pjakobsson@suse.de
- drm/bridge: imx: add driver for HDMI TX Parallel Video Interface (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 23fe898
* Mon Oct 21 2024 pjakobsson@suse.de
- video/nomodeset: Select nomodeset= parameter with CONFIG_VIDEO (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 38fe641
* Mon Oct 21 2024 jroedel@suse.de
- iommu: Validate that devices match domains (jsc#PED-10968).
- commit b5a591b
* Mon Oct 21 2024 pjakobsson@suse.de
- video/cmdline: Introduce CONFIG_VIDEO for video= parameter (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 91b8a6e
* Mon Oct 21 2024 jroedel@suse.de
- cdx: Convert to platform remove callback returning void
  (jsc#PED-10968).
- cdx: add MSI support for CDX bus (jsc#PED-10968).
- cdx: Unlock on error path in rescan_store() (jsc#PED-10968).
- cdx: call of_node_put() on error path (jsc#PED-10968).
- cdx: Create resource debugfs file for cdx device
  (jsc#PED-10968).
- cdx: create sysfs bin files for cdx resources (jsc#PED-10968).
- cdx: Explicitly include correct DT includes, again
  (jsc#PED-10968).
- cdx: add sysfs for subsystem, class and revision
  (jsc#PED-10968).
- cdx: add sysfs for bus reset (jsc#PED-10968).
- cdx: add support for bus enable and disable (jsc#PED-10968).
- cdx: Register cdx bus as a device on cdx subsystem
  (jsc#PED-10968).
- cdx: Create symbol namespaces for cdx subsystem (jsc#PED-10968).
- cdx: Introduce lock to protect controller ops (jsc#PED-10968).
- cdx: Remove cdx controller list from cdx bus system
  (jsc#PED-10968).
- cdx: Explicitly include correct DT includes (jsc#PED-10968).
- cdx: Replace custom mcdi logging with print_hex_dump_debug()
  (jsc#PED-10968).
- commit 6ebf24a
* Mon Oct 21 2024 pjakobsson@suse.de
- drm/mm: Allow CONFIG_DRM_MM_DEBUG with DRM=m (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 82a632a
* Mon Oct 21 2024 pjakobsson@suse.de
- drm/panel: Add support for Novatek NT36672E panel driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 434c9f3
* Mon Oct 21 2024 pjakobsson@suse.de
- drm/panel: Add driver for BOE TH101MB31IG002-28A panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Update config files.
- commit 50b5899
* Mon Oct 21 2024 tiwai@suse.de
- Bluetooth: btusb: Fix regression with fake CSR controllers
  0a12:0001 (git-fixes).
- Bluetooth: bnep: fix wild-memory-access in proto_unregister
  (git-fixes).
- Bluetooth: Remove debugfs directory on module init failure
  (git-fixes).
- Bluetooth: Call iso_exit() on module unload (git-fixes).
- Bluetooth: ISO: Fix multiple init when debugfs is disabled
  (git-fixes).
- pinctrl: apple: check devm_kasprintf() returned value
  (git-fixes).
- parport: Proper fix for array out-of-bounds access (git-fixes).
- iio: frequency: admv4420: fix missing select REMAP_SPI in
  Kconfig (git-fixes).
- iio: adc: ti-ads8688: add missing select IIO_(TRIGGERED_)BUFFER
  in Kconfig (git-fixes).
- iio: hid-sensors: Fix an error handling path in
  _hid_sensor_set_report_latency() (git-fixes).
- iio: dac: stm32-dac-core: add missing select REGMAP_MMIO in
  Kconfig (git-fixes).
- iio: dac: ltc1660: add missing select REGMAP_SPI in Kconfig
  (git-fixes).
- iio: dac: ad5770r: add missing select REGMAP_SPI in Kconfig
  (git-fixes).
- iio: amplifiers: ada4250: add missing select REGMAP_SPI in
  Kconfig (git-fixes).
- iio: frequency: adf4377: add missing select REMAP_SPI in Kconfig
  (git-fixes).
- iio: proximity: mb1232: add missing select
  IIO_(TRIGGERED_)BUFFER in Kconfig (git-fixes).
- iio: dac: ad5766: add missing select IIO_(TRIGGERED_)BUFFER
  in Kconfig (git-fixes).
- iio: dac: ad3552r: add missing select IIO_(TRIGGERED_)BUFFER
  in Kconfig (git-fixes).
- iio: adc: ti-lmp92064: add missing select REGMAP_SPI in Kconfig
  (git-fixes).
- iio: adc: ti-ads124s08: add missing select
  IIO_(TRIGGERED_)BUFFER in Kconfig (git-fixes).
- iio: accel: kx022a: add missing select IIO_(TRIGGERED_)BUFFER
  in Kconfig (git-fixes).
- iio: light: veml6030: fix ALS sensor resolution (git-fixes).
- iio: light: opt3001: add missing full-scale range value
  (git-fixes).
- iio: light: veml6030: fix IIO device retrieval from embedded
  device (git-fixes).
- iio: accel: bma400: Fix uninitialized variable field_value in
  tap event handling (git-fixes).
- serial: imx: Update mctrl old_status on RTSD interrupt
  (git-fixes).
- vt: prevent kernel-infoleak in con_font_get() (git-fixes).
- xhci: Mitigate failed set dequeue pointer commands (git-fixes).
- xhci: Fix incorrect stream context type macro (git-fixes).
- xhci: tegra: fix checked USB2 port number (git-fixes).
- usb: dwc3: Wait for EndXfer completion before restoring
  GUSB2PHYCFG (git-fixes).
- usb: typec: altmode should keep reference to parent (git-fixes).
- commit 5e08e81
* Mon Oct 21 2024 pjakobsson@suse.de
- Refresh patches.suse/1839-drm-xe-display-Implement-display-support.patch.
- commit 0c93e2b
* Mon Oct 21 2024 pjakobsson@suse.de
- kbuild: make -Woverride-init warnings more consistent (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 29bd61c
* Mon Oct 21 2024 jlee@suse.com
- blacklist.conf: For backporting to SLE15-SP7 in batches, bd700ba9adef add to blacklist temporarily
- commit 537e385
* Sat Oct 19 2024 mfranc@suse.cz
- supported.conf: mark nhpoly1305 module as supported (bsc#1231035)
  In 59d03d7c990c, we marked adiantum as a supported module, I'm afraid
  we need to mark nhpoly1305 as supported too (as a dependecy) if we
  want adiantum to work.
  This makes tcrypt test case 219 (adiantum) pass on SLE15-SP6 (tested
  on z15 VM).
- commit 01d2906
* Fri Oct 18 2024 tbogendoerfer@suse.de
- vmxnet3: Fix packet corruption in vmxnet3_xdp_xmit_frame
  (bsc#1226498).
- vmxnet3: Fix missing reserved tailroom (bsc#1226498).
- commit 1bd55aa
* Fri Oct 18 2024 jroedel@suse.de
- arm64: Properly clean up iommu-dma remnants (jsc#PED-10968).
- Update config files.
- commit bf553c6
* Fri Oct 18 2024 tbogendoerfer@suse.de
- vmxnet3: update to version 9 (bsc#1226498).
- vmxnet3: add command to allow disabling of offloads
  (bsc#1226498).
- vmxnet3: add latency measurement support in vmxnet3
  (bsc#1226498).
- vmxnet3: prepare for version 9 changes (bsc#1226498).
- vmxnet3: Add XDP support (bsc#1226498).
- commit 3fdc8e3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Fix comparison in amdgpu_res_cpu_visible (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 54b6835
* Fri Oct 18 2024 pjakobsson@suse.de
- Revert "drm/amdkfd: Add partition id field to location_id" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ae0ecaa
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: MST DSC check for older devices (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bcd9f72
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Fix idle optimization checks for multi-display and (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2a69bfb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Fix DSC-re-computing (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 59b7c50
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Enable urgent latency adjustments for DCN35 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d72e54c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Use ordered WQ for G2H handler (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2c622a5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Check error code when initializing the CT mutex (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit efbe491
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/ads: Use flexible-array (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3ca0e63
* Fri Oct 18 2024 pjakobsson@suse.de
- mei: pxp: match against PCI_CLASS_DISPLAY_OTHER (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6879287
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/nouveau/gsp: Use the sg allocator for level 2 of radix3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5eab1bb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/imagination: Ensure PVR_MIPS_PT_PAGE_COUNT is never zero (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ce7470
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/ttm: Print the memory decryption status just once (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d5e4cab
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/display: Fix ADL-N detection (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d7be2f0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/vm: prevent UAF in rebind_work_func() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fd5f5fe
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Disable panel replay by default for now (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 23d00e4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: fix doorbell regression (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a7fb571
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Ensure that dmcub support flag is set for DCN20 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 18f5b6c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Fix arguments passed to relay G2H handlers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2224d6c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: call free_gsc_pkt only once on action add failure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d1abb2a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Remove sysfs only once on action add failure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9840497
* Fri Oct 18 2024 pjakobsson@suse.de
- Revert "drm/etnaviv: Expose a few more chipspecs to userspace" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8e535c7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/atomic-helper: fix parameter order in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0ea8e89
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/umsch: don't execute umsch test when GPU is in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa9311f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdkfd: Fix rescheduling of restore worker (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 61ab284
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/vpe: fix vpe dpm setup failed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eaf0cb2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/pm: Remove gpu_od if it's an empty directory (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9c0a578
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdkfd: make sure VM is ready for updating operations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 81e9721
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdkfd: Fix eviction fence handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 450d954
* Fri Oct 18 2024 pjakobsson@suse.de
- mei: vsc: Unregister interrupt handler for system suspend (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3521b00
* Fri Oct 18 2024 pjakobsson@suse.de
- Revert "mei: vsc: Call wake_up() in the threaded IRQ handler" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7a2e1c0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/vm: prevent UAF with asid based lookup (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8540be2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Fix bo leak in intel_fb_bo_framebuffer_init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5aea63c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/panel: novatek-nt36682e: don't unregister DSI device (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f0cf2b7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/nouveau/kms/nv50-: Disable AUX bus for disconnected DP ports (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-nouveau-dp-Don-t-probe-eDP-ports-twice-harder.patch.
- commit ac284a0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/v3d: Don't increment `enabled_ns` twice (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6c45c95
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: fix visible VRAM handling during faults (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7eda090
* Fri Oct 18 2024 pjakobsson@suse.de
- Revert "drm/amd/display: fix USB-C flag update after enc10 feature (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022 stable-fixes)
- commit 7e51bbe
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/adreno: Set highest_bank_bit for A619 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 637e8d5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm: fix the `CRASHDUMP_READ` target of `a6xx_get_shader_block()` (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1239032
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: assign correct DP controller ID to x1e80100 interface (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f44ef2b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: fix runtime PM leak on connect failure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 10da0f3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: fix runtime PM leak on disconnect (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 68b5313
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Label RING_CONTEXT_CONTROL as masked (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 967ed49
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/xe_migrate: Cast to output precision before multiplying (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b053a47
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/hwmon: Cast result to output precision on left shift of (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f6c254f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/display: Fix double mutex initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c42e7fb
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/ivpu: Fix missed error message after VPU rename (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1ffa469
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/ivpu: Return max freq for DRM_IVPU_PARAM_CORE_CLOCK_RATE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2aeb484
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/ivpu: Improve clarity of MMU error messages (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8c1c0b9
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/ivpu: Put NPU back to D3hot after failed resume (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2597765
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/ivpu: Fix PCI D0 state entry in resume (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 01f39a0
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/ivpu: Remove d3hot_after_power_off WA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e39d792
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/ivpu: Check return code of ipc->lock init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ff2a1fe
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: differentiate external rev id for gfx 11.5.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b5110ef
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Adjust dprefclk by down spread percentage. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe063d2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: always reset ODM mode in context when adding first (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 216f377
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Return max resolution supported by DWB (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b19ac76
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: clear set_q_mode_offs when VM changed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2a1bf6f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/pm: fix the high voltage issue after unload (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f39ca8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add smu 14.0.1 discovery support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4aa4186
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/swsmu: Update smu v14.0.0 headers to be 14.0.1 compatible (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b96926e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu : Increase the mes log buffer size as per new MES FW (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aefafb5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu : Add mes_log_enable to control mes log feature (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b915dc5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: add DCN 351 version for microcode load (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4eca798
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/umsch: reinitialize write pointer in hw init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 84810d6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/psr: Disable PSR when bigjoiner is used (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 11f5a00
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/guc: Fix the fix for reset lock confusion (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e8a56ef
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/hdcp: Fix get remote hdcp capability function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9b6b8c7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/cdclk: Fix voltage_level programming edge case (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4adafeb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/gt: Limit the reserved VM space to only the platforms that (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 96dcf0c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/psr: Fix intel_psr2_sel_fetch_et_alignment usage (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit df91b64
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/psr: Move writing early transport pipe src (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cbd3f76
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/psr: Calculate PIPE_SRCSZ_ERLY_TPT value (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b1aa6c5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dp: Fix DSC state HW readout for SST connectors (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f0d94c9
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Use ordered wq for preempt fence waiting (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 51ac0ee
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Move vma rebinding to the drm_exec locking loop (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 051642a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Make TLB invalidation fences unordered (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1b82706
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Rework rebinding (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5ba57da
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Use ring ops TLB invalidation for rebinds (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dfa359e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/nouveau/gr/gf100: Remove second semicolon (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 652503c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/vma: Fix UAF on destroy against retire race (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 44dbfa5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Do not print 'pxp init failed with 0' when it succeed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 882a04b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/display/debugfs: Fix duplicate checks in i915_drrs_status (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit efd086a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/drrs: Refactor CPU transcoder DRRS check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a20fcbd
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/mtl: Update workaround 14018575942 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 299b540
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/display: Disable AuxCCS framebuffers if built for Xe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 22f4d0c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Stop doing double audio enable/disable on SDVO and g4x+ DP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 96eea60
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Add includes for BUG_ON/BUILD_BUG_ON in i915_memcpy.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 08f9ef4
* Fri Oct 18 2024 pjakobsson@suse.de
- fbdev: Select I/O-memory framebuffer ops for SBus (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dc8c12f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/dp: Fix divide-by-zero regression on DP MST unplug with nouveau (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c89d4e5
* Fri Oct 18 2024 pjakobsson@suse.de
- Revert "drm/bridge: Select DRM_KMS_HELPER for DRM_PANEL_BRIDGE" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 30fb38d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: Select DRM_KMS_HELPER for DRM_PANEL_BRIDGE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 46d00e6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: add bug.h include to i915_memcpy.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dccc7e7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: enable UMSCH 4.0.6 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 71adad3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/umsch: update UMSCH 4.0 FW interface (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bdbb37f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: fix a dereference of a NULL pointer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3d91940
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Send DTBCLK disable message on first commit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6d80f26
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Update dcn351 to latest dcn35 config (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e36300c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: fix IPX enablement (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aaa2259
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/vpe: power on vpe when hw_init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8310370
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: increase bb clock for DCN351 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4da0090
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Prevent crash when disable stream (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f061495
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Increase Z8 watermark times. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 25a7ea9
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/swsmu: add smu 14.0.1 vcn and jpeg msg (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2463f98
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Fix END redefinition (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 845c8b8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/query: fix gt_id bounds check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 447e862
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/device: fix XE_MAX_TILES_PER_DEVICE check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dd91cdd
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/device: fix XE_MAX_GT_PER_TILE check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 531ce18
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/queue: fix engine_class bounds check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 434126d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc_submit: use jiffies for job timeout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9be80f6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Remove unused xe_bo->props struct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 14030df
* Fri Oct 18 2024 pjakobsson@suse.de
- fbdev: panel-tpo-td043mtea1: Convert sprintf() to sysfs_emit() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7b3c70d
* Fri Oct 18 2024 pjakobsson@suse.de
- fbcon: Increase maximum font width x height to 64 x 128 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7abf782
* Fri Oct 18 2024 pjakobsson@suse.de
- fbdev: mb862xxfb: Fix defined but not used error (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e7a221a
* Fri Oct 18 2024 pjakobsson@suse.de
- fbdev: uvesafb: Convert sprintf/snprintf to sysfs_emit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb04c01
* Fri Oct 18 2024 pjakobsson@suse.de
- fbdev: Restrict FB_SH_MOBILE_LCDC to SuperH (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f4e240f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/pm: Don't use OD table on Arcturus (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7f606dd
* Fri Oct 18 2024 pjakobsson@suse.de
- Revert "drm/amdgpu/vpe: don't emit cond exec command under (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 093a805
* Fri Oct 18 2024 pjakobsson@suse.de
- Revert "drm/amd/amdgpu: Fix potential ioremap() memory leaks in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022 stable-fixes)
- commit b81741b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Add a dc_state NULL check in dc_state_release (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 10e43ef
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Implement wait_for_odm_update_pending_complete (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a23f3eb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Lock all enabled otg pipes even with no planes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 939fc31
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Amend coasting vtotal for replay low hz (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1621a97
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Override min required DCFCLK in dml1_validate (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb6b903
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Bypass display ta if display hw is not available (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f148dbd
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: correct the KGQ fallback message (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 18357fa
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Skip access PF-only registers on gfx10/gfxhub2_1 under (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0f4c381
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Init zone device and drm client after mode-1 reset on (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a64beb3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/vcn: enable vcn1 fw load for VCN 4_0_6 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d45aa37
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Enable DML2 debug flags (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1459f1b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Reset IH OVERFLOW_EN bit for IH 7.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c785e20
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: fix mmhub client id out-of-bounds access (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022 git-fixes CVE-2024-27029 bsc#1223789)
- commit 5d138ed
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Handle duplicate BOs during process restore (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dffa12f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/tests: Build KMS helpers when DRM_KUNIT_TEST_HELPERS is enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cad52bc
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: correct DRM_BRIDGE_OP_EDID documentation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5975c3f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/sun4i: hdmi: Fix u64 div on 32bit arch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 40d1164
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/exynos: simplify the return value handling in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7b5d375
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: lt9611uxc: use int for holding number of modes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a8d5337
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: lt8912b: do not return negative values from .get_modes() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5377ac5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/nouveau: fix kerneldoc warnings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dc2ac33
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Skip VMAs pin when requesting signal to the last XE_EXEC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 19072a6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Return if kobj creation is failed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 86763f2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Invalidate userptr VMA on page pin fault (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0c571a6
* Fri Oct 18 2024 pjakobsson@suse.de
- mei: vsc: Convert to platform remove callback returning void (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 24d3484
* Fri Oct 18 2024 pjakobsson@suse.de
- mei: vsc: Assign pinfo fields in variable declaration (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 21ce33f
* Fri Oct 18 2024 pjakobsson@suse.de
- mei: vsc: Don't use sleeping condition in wait_event_timeout() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7cfc008
* Fri Oct 18 2024 pjakobsson@suse.de
- mei: vsc: Call wake_up() in the threaded IRQ handler (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8a965a9
* Fri Oct 18 2024 pjakobsson@suse.de
- mei: me: remove unnecessary NULL pointer checks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1b017da
* Fri Oct 18 2024 pjakobsson@suse.de
- mei: txe: remove unnecessary NULL pointer checks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0808f67
* Fri Oct 18 2024 pjakobsson@suse.de
- mei: gsc: remove unnecessary NULL pointer checks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c52270b
* Fri Oct 18 2024 pjakobsson@suse.de
- mei: pxp: add dependency on Xe driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f0113d
* Fri Oct 18 2024 pjakobsson@suse.de
- mei: hdcp: add dependency on Xe driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ac1d1e0
* Fri Oct 18 2024 pjakobsson@suse.de
- mei: pxp: match without driver name (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d5da602
* Fri Oct 18 2024 pjakobsson@suse.de
- mei: hdcp: match without driver name (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a40f2c8
* Fri Oct 18 2024 pjakobsson@suse.de
- mei: gsc: add support for auxiliary device created by Xe driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 24ea8dc
* Fri Oct 18 2024 pjakobsson@suse.de
- fbcon: remove fbcon_getxy() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2a080c9
* Fri Oct 18 2024 pjakobsson@suse.de
- fbcon: remove consw::con_screen_pos() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 97f43da
* Fri Oct 18 2024 pjakobsson@suse.de
- fbdev/core: simplify cursor_state setting in fbcon_ops::cursor() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4e5e296
* Fri Oct 18 2024 pjakobsson@suse.de
- fbcon: make display_desc a static array in fbcon_startup() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e6cfcaf
* Fri Oct 18 2024 pjakobsson@suse.de
- vgacon: inline vc_scrolldelta_helper() into vgacon_scrolldelta() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa0f960
* Fri Oct 18 2024 pjakobsson@suse.de
- Normalise "name (ad@dr)" MODULE_AUTHORs to "name <ad@dr>" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f43f615
* Fri Oct 18 2024 pjakobsson@suse.de
- treewide: update LLVM Bugzilla links (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bc79a7c
* Fri Oct 18 2024 pjakobsson@suse.de
- backlight: pandora_bl: Drop unneeded ENOMEM error message (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e7d48f8
* Fri Oct 18 2024 pjakobsson@suse.de
- backlight: lm3630a_bl: Simplify probe return on gpio request error (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9e67f6d
* Fri Oct 18 2024 pjakobsson@suse.de
- backlight: lm3630a_bl: Handle deferred probe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8bb179d
* Fri Oct 18 2024 pjakobsson@suse.de
- backlight: as3711_bl: Handle deferred probe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f1ac2a4
* Fri Oct 18 2024 pjakobsson@suse.de
- backlight: bd6107: Handle deferred probe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 55e6c82
* Fri Oct 18 2024 pjakobsson@suse.de
- backlight: l4f00242t03: Simplify with dev_err_probe() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f29ab80
* Fri Oct 18 2024 pjakobsson@suse.de
- backlight: gpio: Simplify with dev_err_probe() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 56999f4
* Fri Oct 18 2024 pjakobsson@suse.de
- backlight: lm3630a: Use backlight_get_brightness helper in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c0f5050
* Fri Oct 18 2024 pjakobsson@suse.de
- backlight: mp3309c: Fully initialize backlight_properties during (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b9624f6
* Fri Oct 18 2024 pjakobsson@suse.de
- backlight: mp3309c: Utilise temporary variable for struct device (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4f4d4e8
* Fri Oct 18 2024 pjakobsson@suse.de
- backlight: mp3309c: Use dev_err_probe() instead of dev_err() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 264a551
* Fri Oct 18 2024 pjakobsson@suse.de
- backlight: mp3309c: Make use of device properties (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6d8ba18
* Fri Oct 18 2024 pjakobsson@suse.de
- backlight: hx8357: Utilise temporary variable for struct device (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 62c251c
* Fri Oct 18 2024 pjakobsson@suse.de
- backlight: hx8357: Make use of dev_err_probe() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f82e837
* Fri Oct 18 2024 pjakobsson@suse.de
- backlight: hx8357: Move OF table closer to its consumer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6615a0f
* Fri Oct 18 2024 pjakobsson@suse.de
- backlight: hx8357: Make use of device properties (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f1fe0ca
* Fri Oct 18 2024 pjakobsson@suse.de
- backlight: mp3309c: Use pwm_apply_might_sleep() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 17c1b3e
* Fri Oct 18 2024 pjakobsson@suse.de
- backlight: ktd2801: Make timing struct static (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8f7d549
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Removed redundant @ symbol to fix kernel-doc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5db90eb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/pm: wait for completion of the EnableGfxImu message (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a465978
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/soc21: add mode2 asic reset for SMU IP v14.0.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 083503c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add smu 14.0.1 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit db788f3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add VPE 6.1.1 discovery support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 37cd82b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/vpe: add VPE 6.1.1 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 096e2e4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/vpe: don't emit cond exec command under collaborate mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1a5fdd8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/vpe: add collaborate mode support for VPE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 05edece
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/vpe: add PRED_EXE and COLLAB_SYNC OPCODE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 46adf60
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/vpe: add multi instance VPE support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 79753bd
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/discovery: add nbif v6_3_1 ip block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f148584
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Add nbif v6_3_1 ip block support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit af657cf
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Add pcie v6_1_0 ip headers (v5) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0298dc0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Add nbif v6_3_1 ip headers (v5) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ef788b3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdkfd: make kfd_class constant (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 568fd81
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add ring timeout information in devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2098ecd
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add dcn3.5.1 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bf776e8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdkfd: Use SQC when TCP would fail in gfx10.1 context save (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a6b2b13
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdkfd: Increase the size of the memory reserved for the TBA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2a691d8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: disable ring_muxer if mcbp is off (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a137a35
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/pm: disable pp_dpm_dcefclk node for gfx 11.0.3 sriov (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d5f66b3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: remove unused code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fcf3bf6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: workaround to avoid SET_Q_MODE packets v2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cf6d577
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: cleanup conditional execution (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 19a6d87
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Use rpm_mode flag instead of checking it again for rpm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0194256
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: change vm->task_info handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5ff26c4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: add amdgpu_dm support for DCN351 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit 16d0558
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: add DC changes for DCN351 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a100279
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: add DCN351 IRQ changes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bd5a422
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: add DMUB source files and changes for DCN351 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f63760a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd: add register headers for DCN351 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 13dfe25
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: add DCN351 version identifiers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b2bee8e
* Fri Oct 18 2024 pjakobsson@suse.de
- Revert "drm/amdgpu: remove vm sanity check from (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 354fc3f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dpu: make "vblank timeout" more useful (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5162404
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: allow YUV420 mode for DP connector when CDM available (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2405b7a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dpu: reserve CDM blocks for DP if mode is YUV420 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e8348fc
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dpu: modify timing engine programming for YUV420 over DP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a7c9eb5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dpu: modify encoder programming for CDM over DP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 59c0c7c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: enable SDP and SDE periph flush update (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d46c1ad
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dpu: add support of new peripheral flush mechanism (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7a6fd96
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: add VSC SDP support for YUV420 over DP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3dd23f1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: move parity calculation to dp_utils (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 929e53c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: change clock related programming for YUV420 over DP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0234ef8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: program config ctrl for YUV420 over DP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a88fe1d
* Fri Oct 18 2024 jroedel@suse.de
- iommu/amd: use page allocation function provided by
  iommu-pages.h (jsc#PED-10968).
- Refresh
  patches.suse/iommu-amd-Allocate-the-page-table-root-using-GFP_KER.patch.
- commit 5186587
* Fri Oct 18 2024 jroedel@suse.de
- iommu/vt-d: add wrapper functions for page allocations
  (jsc#PED-10968).
- Refresh patches.suse/Revert-iommu-vt-d-Enable-PCI-IMS.patch.
- commit 12bcf2f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dpu: move widebus logic to its own API (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-msm-dpu-capture-snapshot-on-the-first-commit_don.patch.
- Refresh patches.suse/drm-msm-dpu-move-dpu_encoder-s-connector-assignment-.patch.
- commit 3b366ed
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: check if VSC SDP is supported in DP programming (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3e9efb7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: store mode YUV420 information to be used by rest of DP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 076dd43
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: rename wide_bus_en to wide_bus_supported (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5c39a0f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dpu: move dpu_encoder_helper_phys_setup_cdm to dpu_encoder (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0d6603f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dpu: allow dpu_encoder_helper_phys_setup_cdm to work for DP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 47cdb7e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dpu: pass mode dimensions instead of fb size in CDM setup (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ee0ada7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dpu: allow certain formats for CDM for DP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b73afb6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/etnaviv: add sensitive state for PE_RT_ADDR_4_PIPE(3, 0|1) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f312465
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/etnaviv: Expose a few more chipspecs to userspace (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7992383
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/etnaviv: disable MLCG and pulse eater on GPU reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d1e69d5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/etnaviv: Drop the 'len' parameter of etnaviv_iommu_map() function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fbfbfe7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/etnaviv: Clean up etnaviv_gem_get_pages (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 21dd184
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/etnaviv: Add a helper to get the first available GPU device node (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bab38ec
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/etnaviv: Add helper functions to create and destroy platform (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ffb9b1f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/etnaviv: Fix coding style (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e754e74
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/etnaviv: Drop the second argument of the etnaviv_gem_new_impl() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 609dac4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/etnaviv: Replace strncpy with strscpy_pad (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8099e8c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Replace 'grouped target' in Makefile with pattern rule (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ca452d1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Fix ref counting leak on page fault (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 871234f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Remove obsolete async_ops from struct xe_vm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d1d819a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Fix missing topology init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 98809ab
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/xe2: fix 64-bit division in pte_update_size (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 28d2316
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/kunit: fix link failure with built-in xe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9407af8
* Fri Oct 18 2024 pjakobsson@suse.de
- fbdev/chipsfb: Include <linux/backlight.h> (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d680b02
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: fix applying placement flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dcda027
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: remove misleading amdgpu_pmops_runtime_idle() comment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4e7edd6
* Fri Oct 18 2024 pjakobsson@suse.de
- Reapply "Revert drm/amd/display: Enable Freesync Video Mode by (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8f579a7
* Fri Oct 18 2024 pjakobsson@suse.de
- Revert "drm/amd: Remove freesync video mode amdgpu parameter" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0cb7488
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add deferred error check for UMC v12 address query (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d95ef78
* Fri Oct 18 2024 pjakobsson@suse.de
- amd/amdkfd: remove unused parameter (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3403727
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/pm: Skip reporting pcie width/speed on vfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c3382d1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: enable pp_od_clk_voltage for gfx 9.4.3 SRIOV (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fdbaa89
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/pm: Increase SMUv13.0.6 mode-2 reset time (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit efe24a4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd: Drop abm_level property (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 53ca1b7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdkfd: Add partition id field to location_id (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cf551ba
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: reserve more memory for MES runtime DRAM (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ce14d4c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Enable gpu reset for S3 abort cases on Raven series (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cad8ce7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Do not program SQ_TIMEOUT_CONFIG in SRIOV (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 85c609e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Fix ineffective ras_mask settings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 20f0cca
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdkfd: Skip packet submission on fatal error (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit afab887
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Add fatal error detected flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a7e170a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add vcn 4.0.6 discovery support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5fa30aa
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Use RMW accessors for changing LNKCTL2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e22a250
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Simplify the allocation of sync slab caches (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c4aa37c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/soc21: Enabling PG and CG flags for VCN 4.0.6 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 960a311
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Use RMW accessors for changing LNKCTL2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9d3f217
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Use kcalloc() instead of kzalloc() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e6ee520
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Simplify the allocation of mux_chunk slab caches (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 966f1d6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Simplify the allocation of fence slab caches (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aad72b5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/soc21: Added Video Capabilities for VCN 406 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ec37c43
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/vcn: Enable VCN 4.0.6 Support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 33823bc
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/jpeg: add support for jpeg multi instance (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dc4d53e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdkfd: fix process reference drop on debug ioctl (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 857d7a7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Use correct SRIOV macro for (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8c13c3e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Do not program IH_CHICKEN in vega20_ih.c under SRIOV (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6fbb64e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Improve error checking in amdgpu_virt_rlcg_reg_rw (v2) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4cf1d93
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: enable MES discovery for GC 11.5.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6c1ad45
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add GC 11.5.1 discovery support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c192bba
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdkfd: add KFD support for GC 11.5.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1e86778
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: enable CGPG for GFX ip v11.5.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a02478c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: initialize gfx11.5.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5b80421
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add mes firmware support for GC 11.5.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 809f643
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add imu firmware support for GC 11.5.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ce618e8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add firmware for GC 11.5.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 80c370b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add GC 11.5.1 to GC 11.5.0 family (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e17d936
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: enable soc21 discovery support for GC 11.5.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 43c160e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add initial GC 11.5.1 soc21 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b3bd2b0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: enable gmc11 discovery support for GC 11.5.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1bc5f4b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd: Update atomfirmware.h for DCN401 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d41402f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.273 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b959c7a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Drop unnecessary header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a38fe22
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: reenable windowed mpo odm support on dcn32 and (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa29bf8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Only log during optimize_bandwidth call (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e7939ee
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: fix input states translation error for dcn35 & (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4e36522
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Generalize new minimal transition path (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 59434ba
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Check DP Alt mode DPCS state via DMUB (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 712e667
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Remove pcie bw sys entry (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8a90e74
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Fix S4 hang polling on HW power up done for VBIOS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bfa11d7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Drop redundant parameter in amdgpu_gfx_kiq_init_ring (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb97ab7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Remove redundant FPU guard (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a6d57fe
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Add SMU timeout check and retry (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 512391a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Remove unused file (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 523e4a6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Initialize variable with default value (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6bc8485
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add tmz support for GC IP v11.5.1 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 74ff910
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Do not toggle bif ras irq from guest (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6d4ad4d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add GFXHUB 11.5.1 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5e3cdf5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/imx/dcss: fix resource size calculation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ce93973
* Fri Oct 18 2024 pjakobsson@suse.de
- firmware/sysfb: fix an error code in sysfb_init() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3279c4e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Fix possible null pointer dereference after drm_dbg_printer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d95f378
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/adreno: Add A702 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 74645c4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm: Fix page fault client detection on a660 family and a7xx (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5635dba
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm: More fully implement devcoredump for a7xx (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 72fe41f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm: Fix snapshotting a7xx indexed regs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2e67774
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm: Import a7xx crashdump register lists from kgsl (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 939cc84
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm: add support for A750 GPU (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f693b08
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/adreno: Add A305B support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5e3ca83
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/adreno: Update generated headers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 577db08
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/adreno: Add support for SM7150 SoC machine (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ce64395
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/a6xx: specify UBWC config for sc7180 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2f641b6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dpu: Add X1E80100 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d482ea0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm: mdss: Add X1E80100 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d801e40
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/mdp5: drop global_state_lock (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c4631be
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/mdp5: migrate SMP dumping to using atomic_print_state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e4ed6ca
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dpu: drop global_state_lock (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6b9ea5a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dpu: add support for SDM660 and SDM630 platforms (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c8a7266
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm: add a kernel param to select between MDP5 and DPU drivers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 55d36a5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dpu: support binding to the mdp5 devices (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 11ddf50
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/mdss: generate MDSS data for MDP5 platforms (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3dbdb76
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: Fix spelling mistake "enale" -> "enable" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d98d4cf
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dsi: Document DSC related pclk_rate and hdisplay calculations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 14f7f42
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dpu: drop dpu_encoder_phys_ops::atomic_check() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9924b84
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dpu: move writeback's atomic_check to dpu_writeback.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3627da
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dpu: drop dpu_encoder_phys_ops.atomic_mode_set (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9ade913
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dpu: split _dpu_encoder_resource_control_helper() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 77a3061
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dpu: split irq_control into irq_enable and _disable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 18ce667
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dsi: Replace dsi_get_bpp() with mipi_dsi header function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 12d8fd8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: drop dp_parser (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ad76171
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: move next_bridge handling to dp_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7e1cc3f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: move link property handling to dp_panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 79e528f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: move all IO handling to dp_catalog (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 393df40
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: handle PHY directly in dp_ctrl (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e4431b2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: remove PHY handling from dp_catalog.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a558c18
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: move phy_configure_opts to dp_ctrl (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3013961
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: split dp_ctrl_clk_enable into four functuions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4a6e9a8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: stop parsing clock names from DT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7ae82c8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: simplify stream clocks handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2337b4f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: fold dp_power into dp_ctrl module (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bdd12c7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: inline dp_power_(de)init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4a4532a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: parse DT from dp_parser_get (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 81b0cb2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: drop unused fields from dp_power_private (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 332fa09
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: drop unused parser definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8c03ffe
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dp: remove mdss_dp_test_bit_depth_to_bpc() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 316d29b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/mdp5: drop split display support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b151a83
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dsi: remove msm_dsi::encoder (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1e6e589
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dsi: stop calling set_split_display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 03c3f32
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dsi: drop msm_dsi_device_connected() function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 09315f6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/dsi: do not store internal bridge pointer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a81a888
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/mediatek: Filter modes according to hardware capability (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6277834
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/mediatek: dsi: Use mipi_dsi_pixel_format_to_bpp() helper function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a816b5a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/mediatek: dsi: Compress of_device_id entries and add sentinel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7f8a35e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/mediatek: dsi: Simplify with dev_err_probe and remove gotos (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8f37210
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/mediatek: dsi: Register DSI host after acquiring clocks and PHY (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 175734f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/mediatek: dsi: Replace open-coded instance of HZ_PER_MHZ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3802c2c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/mediatek: dsi: Use bitfield macros where useful (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ea79ffa
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/mediatek: dsi: Cleanup functions mtk_dsi_ps_control{_vact}() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2b671a4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/mediatek: dsi: Use GENMASK() for register mask definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-mediatek-dsi-Fix-DSI-RGB666-formats-and-definiti.patch.
- commit 1dd51c5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/mediatek: Support MT8188 VDOSYS1 in display driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-mediatek-Set-DRM-mode-configs-accordingly.patch.
- commit 09398bb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/mediatek: Add Padding to OVL adaptor (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 617d6e4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/sun4i: hdmi: Add missing drm_atomic header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 052e218
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/dp: Don't attempt AUX transfers when eDP panels are not powered (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f431c39
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/tests: connector: Add tests for drmm_connector_init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 08a9e81
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/tests: Add helper to create mock crtc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e2c4a0f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/tests: Add helper to create mock plane (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7bce435
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/tests: helpers: Add atomic helpers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2d0cbf4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/scheduler: Simplify the allocation of slab caches in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3d7a11f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: Remove drm_num_crtcs() helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c010acc
* Fri Oct 18 2024 pjakobsson@suse.de
- fbdev: Clean up include statements in header file (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b9312af
* Fri Oct 18 2024 pjakobsson@suse.de
- fbdev: Clean up forward declarations in header file (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e75efbb
* Fri Oct 18 2024 pjakobsson@suse.de
- fbdev: Do not include <linux/slab.h> in header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9e3f4cc
* Fri Oct 18 2024 pjakobsson@suse.de
- fbdev: Do not include <linux/notifier.h> in header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit beba0f8
* Fri Oct 18 2024 pjakobsson@suse.de
- fbdev: Do not include <linux/fs.h> in header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 48cd2bc
* Fri Oct 18 2024 pjakobsson@suse.de
- fbdev: Do not include <linux/backlight.h> in header (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e183ee2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/nouveau: Include <linux/backlight.h> (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c45c71a
* Fri Oct 18 2024 pjakobsson@suse.de
- backlight/corgi-lcd: Include <linux/backlight.h> (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 914d241
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/mgag200: Add a workaround for low-latency (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 985aa75
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/edid/firmware: Remove built-in EDIDs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3320b4c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/sun4i: hdmi: Consolidate atomic_check and mode_valid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1fa326c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/sun4i: hdmi: Switch to container_of_const (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ae6fc55
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: lcdif: Switch to drmm_mode_config_init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 11c5663
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/mxsfb: Switch to drmm_mode_config_init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit df55722
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/v3d: Enable V3D to use different PAGE_SIZE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f5b7a4c
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/qaic: Constify aic100_channels (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d26f6cc
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/dp: add an API to indicate if sink supports VSC SDP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d48cb41
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/dp: drop the size parameter from drm_dp_vsc_sdp_pack() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8e3e1ad
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/dp: move intel_dp_vsc_sdp_pack() to generic helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 428c912
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Add some boring kerneldoc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 96682ca
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dp: Enable DP tunnel BW allocation mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 85ed3b3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dp: Read DPRX for all long HPD pulses (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b951203
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dp: Suspend/resume DP tunnels (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b13326e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dp: Call intel_dp_sync_state() always for DDI DP encoders (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 609c464
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dp: Handle DP tunnel IRQs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4e8e885
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dp: Allocate/free DP tunnel BW during modeset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2a5ccf5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dp: Compute DP tunnel BW during encoder state computation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9daa324
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dp: Account for tunnel BW limit in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a34d155
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dp: Add DP tunnel atomic state and check BW limit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 857c035
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dp: Sync instead of try-sync commits when getting active (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8b7f366
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dp: Add intel_dp_max_link_data_rate() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1ab1c2a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dp: Factor out intel_dp_read_dprx_caps() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8de250c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dp: Factor out intel_dp_update_sink_caps() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6893dd7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dp: Export intel_dp_max_common_rate/lane_count() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 563cedb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dp: Factor out intel_dp_config_required_rate() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3faaff0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dp: Use drm_dp_max_dprx_data_rate() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2f81119
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dp: Add support to notify MST connectors to retry modesets (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cce064b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Fix display bpp limit computation during system resume (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2fab481
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/dp: Add support for DP tunneling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ac8ed8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/dp: Add drm_dp_max_dprx_data_rate() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2394ce2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/hdcp: Read Rxcaps for robustibility (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b0ba6d4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/hdcp: Allocate stream id after HDCP AKE stage (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 956e6f9
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/hdcp: Don't enable HDCP1.4 directly from check_link (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 371409b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/hdcp: Don't enable HDCP2.2 directly from check_link (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b2260c9
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/hdcp: HDCP Capability for the downstream device (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 617124d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/hdcp: Add new remote capability check shim function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb08b87
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/hdcp: Rename hdcp capable functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c39b126
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/hdcp: Pass drm_dp_aux to read_bcaps function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1344893
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/hdcp: Refactor intel_dp_hdcp2_capable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a14cbfb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/hdcp: Move source hdcp2 checks into its own function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b7c34d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/display/debugfs: New entry "DRRS capable" to (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f703bbe
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Fix doc build issue on intel_cdclk.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7a39e29
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/lnl: Program PKGC_LATENCY register (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d6b4fc1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/lnl: Add pkgc related register (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dccb73e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: remove intel_memory_region_ops::flags (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2dcb594
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: remove i915_vma::obj_hash (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit af871f6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: remove execute_cb::signal (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ff4bb34
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: remove intel_gvt_irq::pending_events (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f26d39d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: remove intel_gvt_event_info::policy (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d6fc881
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: remove intel_gvt_irq_info::warned (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cde5513
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: remove gvt_mmio_block::device (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 68cb5b5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: remove intel_vgpu::intx_trigger (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 50fb9b4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: remove intel_vgpu_opregion::mapped (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c948ac9
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: remove intel_vgpu_fence::base (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6ba9db1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: remove intel_vgpu_gtt::active_ppgtt_mm_bitmap (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4239fa6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: remove i915_perf_stream::size_exponent (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 06ee584
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: remove i915_drm_client::id (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fb41184
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: remove intel_guc::ads_engine_usage_size (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1a9ebc7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: remove intel_vbt_panel_data::edp::initialized (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit df453e4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: remove intel_vgpu_workload::{ring_context, restore_inhibit} (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9fb48df
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: remove intel_gvt_mmio_info::{device, addr_range} (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit edf8d31
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: remove intel_gvt_gtt::{mm_alloc_page_table, (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 847637c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: remove intel_dsi::{port_bits,hs} (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4adf096
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: remove structs intel_vgpu_pipe_format and (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 588ca43
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: remove unused intel_dvo_dev_ops hooks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 655f842
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/cdclk: Document CDCLK update methods (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 69f616b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/cdclk: Remove the hardcoded divider from (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7faa53c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/cdclk: Squash waveform is 16 bits (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 463295f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/cdclk: Extract cdclk_divider() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 23124d1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Enable fastboot across the board (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d0d3e7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Add PLL .compare_hw_state() vfunc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 70ff15a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Reuse ibx_dump_hw_state() for gmch platforms (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 041b12f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Include the CRTC name in the ELD buffer mismatch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 673e8a3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Fix PLL state check for gmch platforms (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f68130e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Update ADL-N PCI IDs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7e2790e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/display: update pll values in sync with Bspec for MTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 65c9213
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Prevent HW access during init from connector get_modes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 439924b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Prevent HW access during init from SDVO TV get_modes hook (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 188e936
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Use debugfs_create_bool() for "i915_bigjoiner_force_enable" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a114c3a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Add bigjoiner force enable option to debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 493ad39
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dvo: Use sizeof(*variable) instead of sizeof(type) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fcbb8b8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dvo/ns2501: Nuke pointless casts (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 33d0479
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/wm: Use per-device debugs ilk wm code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bf3e2fb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/wm: Use per-device debugs in pre-ilk wm code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ab33a0a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/wm: Pass the whole i915 to intel_get_cxsr_latency() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c5405dc
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/hdcp: Use per-device debugs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 44058e1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/bios: Use per-device debugs for VBT related stuff (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f39be6d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/bios: Switch to kms debugs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8762339
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/fb: Use per-device debugs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0430a85
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/color: Use per-device debugs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 52ea9e7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/sdvo: Fix up code alignment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c520067
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/sdvo: Convert to per-device debugs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 22b6ccb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Correct for_each_old_global_obj_in_state() arguments (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5c36183
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/display: On Xe2 always enable decompression with tile4 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ca5d1fc
* Fri Oct 18 2024 pjakobsson@suse.de
- accel: constify the struct device_type usage (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 12c9699
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs: modify pci health check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a56f048
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs: keep explicit size of reserved memory for FW (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1fbf8b8
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs: handle reserved memory request when working with (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f048560
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs/hwmon: rate limit errors user can generate (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3556cf8
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: drain event lacks rd/wr indication (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a5aa9ed
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs: fix error print (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b666a70
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs: initialize maybe-uninitialized variables (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bbee661
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs: fix debugfs files permissions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 95de200
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs: fix glbl error cause handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fde2e2f
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: check extended errors according to PCIe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e8f544a
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs: modify print for skip loading linux FW to debug log (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ea0fc6a
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs: remove hop size from asic properties (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f15ef3a
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs: use kcalloc() instead of kzalloc() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 69eb1d4
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs/goya: remove redundant assignment to pointer 'input' (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fd84368
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: fail memory memset when failing to copy QM (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2a3c9d2
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs: remove call to deprecated function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 08794bc
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs: Remove unnecessary braces from if statement (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6cbc001
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: move HMMU page tables to device memory (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1fd5a80
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs: abort device reset for consecutive heartbeat (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bea36af
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs: fix DRAM BAR base address calculation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 95c555d
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs: increase HL_MAX_STR to 64 bytes to avoid warnings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6995d53
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: add interrupt affinity for user interrupts (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2010eeb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Prefer struct_size over open coded arithmetic (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5696fb3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Do not include current dir for generated/xe_wa_oob.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 77dabfb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Add debug prints for skipping rebinds (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 161ca04
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Implement VM snapshot support for BO's and userptr (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f10c291
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Add vm snapshot mutex for easily taking a vm snapshot during (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1ae2c3c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Annotate each dumpable vma as such (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2ffdb24
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Clear all snapshot members after deleting coredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bc13200
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/snapshot: Remove drm_err on guc alloc failures (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f2a318d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Remove usage of the deprecated ida_simple_xx() API (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ad96dc0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Initialize GuC earlier during probe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f429714
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Move GuC power control init to "post-hwconfig" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bcd14cf
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/huc: Realloc HuC FW in vram for post-hwconfig (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9f293af
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Allocate GuC data structures in system memory for initial (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 881b9a7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Remove exec queue bind.fence_* (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c725b11
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Add uAPI to query GuC firmware submission version (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0e0c19c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/vf: Don't support MCR registers if VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 52c25a5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/vf: Don't program PAT if VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 181a2d1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/vf: Don't enable hwmon if VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c4e6c1c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/vf: Don't check if LMEM is initialized if VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7bce16e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/vf: Don't initialize stolen memory manager if VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4e7f77a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/vf: Don't program MOCS if VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c284220
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/vf: Don't try to capture engine data unavailable to VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 395440c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/vf: Assume fixed GSM size if VF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 20ba926
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: use drm based debugging instead of dev (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1b51c60
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/irq: allocate all possible msix interrupts (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2258ffe
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Avoid cryptic message when there's no GuC definition (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb38fb4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Always allow to override firmware (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1a6238c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/pm: add debug logs for D3cold (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5386c4e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/hwmon: Refactor xe hwmon (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b56e55
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/query: Use kzalloc for drm_xe_query_engines (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d854541
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Add support for LNL firmware (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dfd1dee
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Update to GuC firmware 70.19.2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c6c8b5d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/uc: Include patch version in expectations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d9faef8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Drop rebind argument from xe_pt_prepare_bind (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 142417d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/gsc: Add status check during gsc header readout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 49a2483
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Convert job timeouts from assert to warning (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2d9c8e0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: drop display/ subdir from include directories (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1a6ecc3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: move xe_display.[ch] under display/ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cb26a14
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Add batch buffer addresses to devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b8444ff
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Add functions to convert regular address to canonical address (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5e11a34
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Use function to emit PIPE_CONTROL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7211ccb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Reduce a print from warn to debug (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 87801fe
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/xe2: Enable has_usm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e19a841
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: correct the assertion for number of PTEs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cdf9885
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Flush G2H handler when turning off CTs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 26634b5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Move TLB invalidation reset before HW reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b4b4ea0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Add more GuC CT states (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 610c6a9
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: don't build debugfs files when CONFIG_DEBUG_FS=n (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a272d22
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Remove additional spaces in devcoredump HW Engines section (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a03f6f2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Print registers spread in 2 u32 as u64 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3e9c603
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Print more device information in devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9570263
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Stash GMD_ID value in xe_gt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 18dd822
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Nuke xe from xe_devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a003284
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Change devcoredump functions parameters to xe_sched_job (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b4544b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Remove double new lines in devcoredump (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b4e9bce
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Document nested struct members according to guidelines (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 811a9ca
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/xe2_lpg: Introduce performance guide changes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 79b66eb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Fix typo in vram frequency sysfs documentation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 91f4cdf
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Enable 32bits build (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 24acb25
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Do not flood dmesg with guc log (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 791e498
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/xe_debugfs: Print skip_guc_pc in xe info (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 954d4f6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: constify engine class sysfs attributes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f60498e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: make gpuvm_ops const (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 50dbce6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: make hwmon_info const (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7d80e77
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: make heci_gsc_irq_chip const (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 95c67d0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: make xe_ttm_funcs const (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 923acd3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Modify the cfb size to be page size aligned for FBC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d3334f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: correct the calculation of remaining size (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a8e3077
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/gsc: add support for GSC proxy interrupt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 959834d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/gsc: Initialize GSC proxy (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f6a7666
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Add kernel-doc for xe_guc_ct_send_recv() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 523022d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Return CTB HXG response DATA0 if no buffer provided (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 051adc3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Mark internal gmdid mappings as const (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5cbc38c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Enable WA 14018913170 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1b93d33
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Group normal kunit tests in a single module (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f9ff31f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Use kstrdup while creating snapshot (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 24788f4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/migrate: Cap PTEs written by MI_STORE_DATA_IMM to 510 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9509299
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Fix potential deadlock in __fini_dbm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7fdd703
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Allow to exclude part of GGTT from allocations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 37a9f71
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Use HXG definitions on HXG messages (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0c8c941
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Return CTB response length (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8f9ca58
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Treat non-response message after BUSY as unexpected (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dfbe49e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Split GuC communication initialization (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d0716e0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Invert access counter queue head / tail (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8886c67
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Add build on bug to assert access counter queue works (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f0a3ca8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Invert page fault queue head / tail (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ef5a87a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Add build on bug to assert page fault queue works (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 156fb06
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Remove set_job_timeout_ms() from exec_queue_ops (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cf3a9ed
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Finish refactoring of exec_queue_create (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 29f8eb3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Add exec_queue.sched_props.job_timeout_ms (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 04b4b59
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Refactor __xe_exec_queue_create() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3eb811e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Add vram frequency sysfs attributes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 30c599d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/xe2_lpg: Add Wa_16018610683 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2af0815
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Only take actions in CT irq handler if CTs are enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 100b34d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/exec: reserve fence slot for CPU bind (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit 62900e6
* Fri Oct 18 2024 jroedel@suse.de
- vfio/pci: Insert full vma on mmap'd MMIO fault (jsc#PED-10968).
- vfio/pci: Use unmap_mapping_range() (jsc#PED-10968).
- vfio: Create vfio_fs_type with inode per device (jsc#PED-10968).
- vfio/pci: Restore zero affected bus reset devices warning
  (jsc#PED-10968).
- vfio: remove an extra semicolon (jsc#PED-10968).
- vfio/pci: Collect hot-reset devices to local buffer
  (jsc#PED-10968).
- vfio/cdx: add interrupt support (jsc#PED-10968).
- genirq/msi: Add MSI allocation helper and export MSI functions
  (jsc#PED-10968).
- vfio/pci: Pass eventfd context object through irqfd
  (jsc#PED-10968).
- vfio/pci: Pass eventfd context to IRQ handler (jsc#PED-10968).
- iommu/vt-d: Decouple igfx_off from graphic identity mapping
  (jsc#PED-10968).
- iommu/vt-d: Remove struct intel_svm (jsc#PED-10968).
- iommu: Add ops->domain_alloc_sva() (jsc#PED-10968).
- iommu/vt-d: Remove intel_svm_dev (jsc#PED-10968).
- iommu/vt-d: Use cache helpers in arch_invalidate_secondary_tlbs
  (jsc#PED-10968).
- iommu/vt-d: Use cache_tag_flush_range() in cache_invalidate_user
  (jsc#PED-10968).
- iommu/vt-d: Cleanup use of iommu_flush_iotlb_psi()
  (jsc#PED-10968).
- iommu/vt-d: Use cache_tag_flush_range_np() in iotlb_sync_map
  (jsc#PED-10968).
- iommu/vt-d: Use cache_tag_flush_range() in tlb_sync
  (jsc#PED-10968).
- iommu/vt-d: Use cache_tag_flush_all() in flush_iotlb_all
  (jsc#PED-10968).
- iommu/vt-d: Add trace events for cache tag interface
  (jsc#PED-10968).
- iommu/vt-d: Add cache tag invalidation helpers (jsc#PED-10968).
- iommu/vt-d: Add cache tag assignment interface (jsc#PED-10968).
- iommu/vt-d: Remove caching mode check before device TLB flush
  (jsc#PED-10968).
- iommu/vt-d: Remove private data use in fault message
  (jsc#PED-10968).
- iommu/vt-d: Remove debugfs use of private data field
  (jsc#PED-10968).
- iommu/vt-d: Use try_cmpxchg64{,_local}() in iommu.c
  (jsc#PED-10968).
- iommu/vt-d: Remove redundant assignment to variable err
  (jsc#PED-10968).
- dma-mapping: Simplify arch_setup_dma_ops() (jsc#PED-10968).
- iommu/dma: Centralise iommu_setup_dma_ops() (jsc#PED-10968).
- iommu/dma: Make limit checks self-contained (jsc#PED-10968).
- dma-mapping: Add helpers for dma_range_map bounds
  (jsc#PED-10968).
- ACPI/IORT: Handle memory address size limits as limits
  (jsc#PED-10968).
- OF: Simplify DMA range calculations (jsc#PED-10968).
- OF: Retire dma-ranges mask workaround (jsc#PED-10968).
- iommu: Pass domain to remove_dev_pasid() op (jsc#PED-10968).
- iommu/amd: Enable Guest Translation after reading IOMMU feature
  register (jsc#PED-10968).
- iommu/amd: Fix compilation error (jsc#PED-10968).
- iommu: account IOMMU allocated memory (jsc#PED-10968).
- iommu: observability of the IOMMU allocations (jsc#PED-10968).
- iommu/tegra-smmu: use page allocation function provided by
  iommu-pages.h (jsc#PED-10968).
- iommu/sun50i: use page allocation function provided by
  iommu-pages.h (jsc#PED-10968).
- iommu/rockchip: use page allocation function provided by
  iommu-pages.h (jsc#PED-10968).
- iommu/exynos: use page allocation function provided by
  iommu-pages.h (jsc#PED-10968).
- iommu/io-pgtable-dart: use page allocation function provided
  by iommu-pages.h (jsc#PED-10968).
- iommu/io-pgtable-arm: use page allocation function provided
  by iommu-pages.h (jsc#PED-10968).
- iommu/dma: use iommu_put_pages_list() to releae freelist
  (jsc#PED-10968).
- iommu/amd: Add SVA domain support (jsc#PED-10968).
- iommu/amd: Initial SVA support for AMD IOMMU (jsc#PED-10968).
- iommu/amd: Add support for enable/disable IOPF (jsc#PED-10968).
- iommu/amd: Add IO page fault notifier handler (jsc#PED-10968).
- iommu/amd: Add support for page response (jsc#PED-10968).
- iommu/amd: Define per-IOMMU iopf_queue (jsc#PED-10968).
- iommu/amd: Enable PCI features based on attached domain
  capability (jsc#PED-10968).
- iommu/amd: Setup GCR3 table in advance if domain is SVA capable
  (jsc#PED-10968).
- iommu/amd: Introduce iommu_dev_data.max_pasids (jsc#PED-10968).
- iommu/amd: Fix PPR interrupt processing logic (jsc#PED-10968).
- iommu/amd: Move PPR-related functions into ppr.c
  (jsc#PED-10968).
- iommu/amd: Add support for enabling/disabling IOMMU features
  (jsc#PED-10968).
- iommu/amd: Introduce per device DTE update function
  (jsc#PED-10968).
- iommu/amd: Rename amd_iommu_v2_supported() as
  amd_iommu_pasid_supported() (jsc#PED-10968).
- iommu/arm-smmu-v3: Make the kunit into a module (jsc#PED-10968).
- iommu/arm-smmu-v3: Add unit tests for arm_smmu_write_entry
  (jsc#PED-10968).
- iommu/arm-smmu-v3: Build the whole CD in arm_smmu_make_s1_cd()
  (jsc#PED-10968).
- iommu/arm-smmu-v3: Move the CD generation for SVA into a
  function (jsc#PED-10968).
- iommu/arm-smmu-v3: Allocate the CD table entry in advance
  (jsc#PED-10968).
- iommu/arm-smmu-v3: Make arm_smmu_alloc_cd_ptr() (jsc#PED-10968).
- iommu/arm-smmu-v3: Consolidate clearing a CD table entry
  (jsc#PED-10968).
- iommu/arm-smmu-v3: Move the CD generation for S1 domains into
  a function (jsc#PED-10968).
- iommu/arm-smmu-v3: Make CD programming use
  arm_smmu_write_entry() (jsc#PED-10968).
- iommu/arm-smmu-v3: Add an ops indirection to the STE code
  (jsc#PED-10968).
- iommu/arm-smmu-qcom: Don't build debug features as a kernel
  module (jsc#PED-10968).
- iommu/arm-smmu-qcom: Use the custom fault handler on more
  platforms (jsc#PED-10968).
- iommu/arm-smmu-qcom: Use a custom context fault handler for
  sdm845 (jsc#PED-10968).
- iommu/arm-smmu: Allow using a threaded handler for context
  interrupts (jsc#PED-10968).
- iommu/arm-smmu-qcom-debug: Add support for TBUs (jsc#PED-10968).
- dt-bindings: iommu: Add Qualcomm TBU (jsc#PED-10968).
- iommu/arm-smmu-v3: Add a type for the CD entry (jsc#PED-10968).
- iommu/arm-smmu-v3: Do not ATC invalidate the entire domain
  (jsc#PED-10968).
- iommu/arm-smmu-v3: Do not allow a SVA domain to be set on the
  wrong PASID (jsc#PED-10968).
- iommu/arm-smmu-v3: Retire disable_bypass parameter
  (jsc#PED-10968).
- dt-bindings: iommu: renesas,ipmmu-vmsa: add r8a779h0 support
  (jsc#PED-10968).
- commit abd2dfc
* Fri Oct 18 2024 ailiop@suse.com
- SUNRPC: Fix integer overflow in decode_rc_list() (git-fixes).
- commit 15be003
* Fri Oct 18 2024 ailiop@suse.com
- NFSD: Mark filecache "down" if init fails (git-fixes).
- commit ceca4b8
* Fri Oct 18 2024 ailiop@suse.com
- SUNRPC: clnt.c: Remove misleading comment (git-fixes).
- commit 2e12710
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/exec: move fence reservation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit ad0345a
* Fri Oct 18 2024 ailiop@suse.com
- nfs: fix memory leak in error path of nfs4_do_reclaim
  (git-fixes).
- commit 1994ef6
* Fri Oct 18 2024 ailiop@suse.com
- nfsd: fix delegation_blocked() to block correctly for at least
  30 seconds (git-fixes).
- commit f66078d
* Fri Oct 18 2024 ailiop@suse.com
- nfsd: return -EINVAL when namelen is 0 (git-fixes).
- commit 1bc1c36
* Fri Oct 18 2024 ailiop@suse.com
- nfsd: call cache_put if xdr_reserve_space returns NULL
  (git-fixes).
- commit 003f784
* Fri Oct 18 2024 ailiop@suse.com
- nfsd: map the EBADMSG to nfserr_io to avoid warning (git-fixes).
- commit 5b8020a
* Fri Oct 18 2024 ailiop@suse.com
- NFSD: Fix NFSv4's PUTPUBFH operation (git-fixes).
- commit 88290fb
* Fri Oct 18 2024 ailiop@suse.com
- nfsd: fix refcount leak when file is unhashed after being found
  (git-fixes).
- commit 5a551a1
* Fri Oct 18 2024 ailiop@suse.com
- nfsd: remove unneeded EEXIST error check in nfsd_do_file_acquire
  (git-fixes).
- commit 6d18e0e
* Fri Oct 18 2024 ailiop@suse.com
- NFS: Avoid unnecessary rescanning of the per-server delegation
  list (git-fixes).
- commit e5841ef
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/dgfx: Release mmap mappings on rpm suspend (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1ba68a4
* Fri Oct 18 2024 ailiop@suse.com
- NFSv4: Fix clearing of layout segments in layoutreturn
  (git-fixes).
- commit ec4c812
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/xe2: synchronise CS_CHICKEN1 with WMTP support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9d52a7c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/kunit: Drop xe_wa tests for pre-production DG2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3e2b1fd
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Fix spelling mistake "gueue" -> "queue" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 021d032
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Fix compilation without CONFIG_KUNIT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6b7c623
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Add mocs reset kunit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 595a747
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Start handling GuC Relay event messages (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1946e6e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/kunit: Add GuC Relay kunit tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d88ae41
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/kunit: Allow to replace xe_guc_ct_send_recv() with stub (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e64c6a9
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Introduce Relay Communication for SR-IOV (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f66d31
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Add Relay Communication ABI definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d83ccbf
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Update few GuC CTB ABI definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c5464d3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Add helpers for HXG messages (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d6abc3f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Introduce GT-oriented SR-IOV logging macros (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 47b7483
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Define Virtual Function Identifier (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d2ed054
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Allocate dedicated workqueue for SR-IOV workers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 720cbf6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Use intel_wakeref_t in intel_runtime_pm functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 72ae0c0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/xe2: Add workaround 16020183090 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5374357
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/guc: Use FAST_REQUEST for non-blocking H2G messages (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 355a379
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/xelpg: Extend Wa_14019877138 for Graphics 12.70/71 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9d9ef5d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/kunit: Add GuC Doorbells Manager tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 56f60ba
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/kunit: Enable CONFIG_LOCKDEP in tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 22a1ea8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/kunit: Use xe kunit helper in WA test (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ff156a6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/kunit: Use xe kunit helper in RTP test (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bff2754
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/kunit: Restore test->priv when done with fake xe device (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 78d87e8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/kunit: Define helper functions to allocate fake xe device (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 03d424a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/kunit: Set SR-IOV mode of the fake device (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3c39485
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Introduce GuC Doorbells Manager (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6bf89ef
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Report TLB timeout using GT oriented functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f05c747
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Add GT oriented drm_printers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0865fd5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/vf: Add VF specific interrupt handler (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7b24670
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/vf: Setup memory based interrupts in GuC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 94cfffa
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/vf: Update LRC with memory based interrupts data (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4c308fc
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/vf: Introduce Memory Based Interrupts Handler (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 24287e4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Add XE_BO_NEEDS_UC flag to force UC mode instead WB (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7e09445
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Define IRQ offsets used by HW engines (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dab5166
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Update definition of GT_INTR_DW (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f43379b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Update LRC context layout definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3d9599
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Define registers used by memory based irq processing (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a93cf85
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Add command MI_LOAD_REGISTER_MEM (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2ab6808
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/dg2: Drop pre-production workarounds (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9e16c3a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: renesas: rz-du: Fix redefinition errors related to (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 009586a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/syncobj: call might_sleep before waiting for fence submission (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 71e207b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/syncobj: reject invalid flags in drm_syncobj_find_fence (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 130a8aa
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: renesas: Add RZ/G2L DU Support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 879c082
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/ci: mark universal-plane-sanity as failing on SC7180 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2031ef4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/ci: update msm-apq8096-fails list (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 25c7423
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/ci: update IGT test names (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fc8355c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/ci: skip suspend tests for both msm-sc7180 machines (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3eeef78
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/panel: simple: Add BOE BP082WX1-100 8.2" panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a41f1d7
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/ivpu: Rename VPU to NPU in message strings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7edcf32
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/ivpu: Refactor BO creation functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c5cc245
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/ivpu: Fix ivpu_reset_engine_fn merge issue (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit becc67c
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/ivpu: Use lazy allocation for doorbell IDs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/accel-ivpu-Fix-deadlock-in-context_xa.patch.
- commit 6e79b56
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/ivpu: Add support for FW boot param system_time_us (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 11fb9f6
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/ivpu: Update FW API headers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8b41f4d
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/ivpu: Remove legacy firmware name (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cfc0dff
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/ivpu: Rename TILE_SKU_BOTH_MTL to TILE_SKU_BOTH (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8934139
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/meson: improve encoder probe / initialization error handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 10026bc
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/panel: ltk500hd1829: add panel type for ltk101b4029w (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 575f405
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/panel: ltk500hd1829: make room for more similar panels (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 66c610b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: bridge: dw_hdmi: Set DRM bridge type (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 622cd8a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Update shared stats to use the new gem helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3edb52a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Update shared stats to use the new gem helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit afa573f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add shared fdinfo stats (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2678520
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: update drm_show_memory_stats() for dma-bufs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9a4696e
* Fri Oct 18 2024 pjakobsson@suse.de
- Documentation/gpu: Update documentation on drm-shared-* (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8acc356
* Fri Oct 18 2024 pjakobsson@suse.de
- gpu: host1x: remove redundant assignment to variable space (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f706fb2
* Fri Oct 18 2024 pjakobsson@suse.de
- Revert "drm/panel-edp: Add auo_b116xa3_mode" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c7e201a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: Spelling s/hardward/hardware/g (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c9577b4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add MMHUB 3.3.1 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6d6f27b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Remove break after return (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8e5d571
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd: Change `jpeg_v4_0_5_start_dpg_mode()` to void (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 191d94f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Fix missing parameter descriptions in ih_v7_0.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0cafcaf
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add SDMA 6.1.1 discovery support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0168886
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add sdma 6.1.1 firmware (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c100cba
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add psp 14.0.1 discovery support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 91ff1a0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add PSP 14.0.1 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 19a08d8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add smuio 14.0.1 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4a124f2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add nbio 7.11.1 discovery support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 115a129
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/nbio: Add NBIO 7.11.1 Support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3a30370
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdkfd: Relocate TBA/TMA to opposite side of VM hole (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a2400fe
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.272 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b0d0621
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: support psp ip block discovery for psp v14 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ab55721
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add psp_timeout to limit PSP related operation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 98c0408
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/psp: set boot_time_tmr flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2eb9124
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/psp: handle TMR type via flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a74653a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/psp: set autoload support by default (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e08fccb
* Fri Oct 18 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Add left edge pixel for YCbCr422/420 + ODM (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 04bcd19
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: support psp ip block for psp v14 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5db8dc0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: use spirom update wait_for helper for psp v14 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ce7f464
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/pm: Allow setting max UCLK on SMU v13.0.6 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8494a81
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Reduce VA_RESERVED_BOTTOM to 64KB (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3d66b03
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Add psp v14_0 ip block support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1555b73
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Add mp v14_0_2 ip headers (v5) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a7b7460
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: should support dmub hw lock on Replay (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b07e7ee
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: allow psr-su/replay for z8 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4cfccc4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Add shared firmware state for DMUB IPS handshake (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f625756
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Update FIXED_VS Retimer HWSS Test Pattern Sequences (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe69bbe
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: enable fgcg by default (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3ee3191
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: treat plane clip size change as MED update type (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6463e9b
* Fri Oct 18 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Send DTBCLK disable message on first commit" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8a969a4
* Fri Oct 18 2024 pjakobsson@suse.de
- Revert "drm/amd/display: increased min_dcfclk_mhz and min_fclk_mhz" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6aecfa5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/psp: update define to better align with its meaning (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5f68bb7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: respect the abmlevel module parameter value if it is set (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit afa5a59
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Add jpeg_v5_0_0 ip block support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2ed55b3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/jpeg5: Enable doorbell (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit acde816
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/jpeg5: add power gating support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8a8d84a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Add JPEG5 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7e8330c
* Fri Oct 18 2024 pjakobsson@suse.de
- amdgpu/drm: Add vcn_v5_0_0_ip_block support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 13c6e30
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add VCN_5_0_0 IP block support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2d2c098
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add VCN_5_0_0 firmware support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ccb7606
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Add vcn v5_0_0 ip headers (v5) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0c60364
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/discovery: Add hdp v7_0 ip block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 185cd10
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Add hdp v7_0 ip block support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 153b9fa
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Add hdp v7_0_0 ip headers (v3) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 53487c8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/discovery: Add ih v7_0 ip block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 68599b4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Add ih v7_0 ip block support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4f1fa00
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/jpeg: add support for jpeg DPG mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4b2f4d2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add ucode id for jpeg DPG support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f514ec7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Add osssys v7_0_0 ip headers (v4) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b6075b3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/discovery: Add lsdma v7_0 ip block (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c1e6871
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Add lsdma v7_0 ip block support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c6dd6be
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Add lsdma v7_0_0 ip headers (v3) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2d311f0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: send smu rma reason event in ras eeprom driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3e00cc9
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: implement smu send rma reason for smu v13.0.6 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f0f10f6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Add athub v4_1_0 ip block support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d7fb600
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Add athub v4_1_0 ip headers (v5) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8776342
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: support rlc auotload type set (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 87ac4ae
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: skip ucode bo reserve for RLC AUTOLOAD (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b8c91c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/swsmu: add judgement for vcn jpeg dpm set (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 92597d1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdkfd: pass debug exceptions to second-level trap handler (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c984911
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdkfd: fill in data for control stack header for gfx10 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit af74ff9
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: drm_crtc: correct some comments (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 07e6cbf
* Fri Oct 18 2024 pjakobsson@suse.de
- fbdev/efifb: Remove framebuffer relocation tracking (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 30dfa57
* Fri Oct 18 2024 pjakobsson@suse.de
- firmware/sysfb: Update screen_info for relocated EFI framebuffers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9018aa4
* Fri Oct 18 2024 pjakobsson@suse.de
- fbdev/efifb: Do not track parent device status (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d1e3e9f
* Fri Oct 18 2024 pjakobsson@suse.de
- firmware/sysfb: Create firmware device only for enabled PCI devices (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b52aba1
* Fri Oct 18 2024 pjakobsson@suse.de
- fbdev/efifb: Remove PM for parent device (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e75579c
* Fri Oct 18 2024 pjakobsson@suse.de
- firmware/sysfb: Set firmware-framebuffer parent device (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drivers-firmware-skip-simpledrm-if-nvidia-drm.modese.patch.
- commit c59d548
* Fri Oct 18 2024 pjakobsson@suse.de
- video: Provide screen_info_get_pci_dev() to find screen_info's PCI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 28a7a71
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/panel: st7703: Add Panel Rotation Support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit edd80ff
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/panel: st7703: Add Powkiddy RGB10MAX3 Panel Support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 31d7549
* Fri Oct 18 2024 pjakobsson@suse.de
- gpu: host1x: bus: make host1x_bus_type const (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b9ecd68
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: fix arguments to drm_err_printer() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 47d6c05
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: Fix a missing argument to drm_err_printer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 418a5d7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/tests: mm: Convert to drm_dbg_printer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c068247
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/lima: standardize debug messages by ip name (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 58b9b6a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/lima: increase default job timeout to 10s (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit faab9d0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/lima: remove guilty drm_sched context handling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 160770c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/lima: handle spurious timeouts due to high irq latency (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-lima-mask-irqs-in-timeout-path-before-hard-reset.patch.
- commit 9255515
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/lima: set pp bus_stop bit before hard reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 08e820c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/lima: reset async_reset on gp hard reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a407d97
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/lima: reset async_reset on pp hard reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3039ace
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: remove drm_debug_printer in favor of drm_dbg_printer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d85242f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe: switch from drm_debug_printer() to device specific (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 421d867
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: use drm_printf() with the drm_err_printer intead of (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5932523
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: switch from drm_debug_printer() to device specific (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 45c6305
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/dp: switch drm_dp_vsc_sdp_log() to struct drm_printer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3125ca6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/mode: switch from drm_debug_printer() to device specific (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c0943a0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/dp_mst: switch from drm_debug_printer() to device specific (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3e65471
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/print: add drm_dbg_printer() for drm device specific printer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2cfe324
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/print: move enum drm_debug_category etc. earlier in drm_print.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 56a746c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/print: make drm_err_printer() device specific by using drm_err() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4dcb29b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: remove ->get_edid callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ba54460
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: ti-sn65dsi86: switch to ->edid_read callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7829763
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: tc358767: switch to ->edid_read callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f453c6e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: tc358767: update the EDID property (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b2c789d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: bridge: dw_hdmi: clear the EDID property and CEC address on (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d580cf4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: bridge: dw_hdmi: switch to ->edid_read callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2c44dcc
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: adv7511: switch to ->edid_read callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a5c7122
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: xlnx: zynqmp_dpsub: switch to ->edid_read callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cd06a58
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/omap/hdmi5: switch to ->edid_read callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bef4210
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/omap/hdmi4: switch to ->edid_read callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3a1e298
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/hdmi: switch to ->edid_read callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 30a5421
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/msm/hdmi: fix indent (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bff725b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/mediatek/hdmi: switch to ->edid_read callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d983f2b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/mediatek/dp: switch to ->edid_read callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Delete patches.suse/drm-mediatek-dp-Fix-spurious-kfree.patch.
- commit 1052e39
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: sii902x: switch to ->edid_read callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 50a3552
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: sii902x: use display info is_hdmi (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 24769b2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: nxp-ptn3460: switch to ->edid_read callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9370b95
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: megachips: switch to ->edid_read callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0742f3b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: lt9611uxc: switch to ->edid_read callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f77378a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: lt9611: switch to ->edid_read callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9b4d535
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: bridge: it66121: switch to ->edid_read callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8476cd0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: it6505: switch to ->edid_read callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 39e8aeb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: display-connector: switch to ->edid_read callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 86a1644
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: cdns-mhdp8546: clear the EDID property on failures (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 40cbb20
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: cdns-mhdp8546: switch to ->edid_read callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 45de40d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: anx7625: switch to ->edid_read callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-bridge-anx7625-Update-audio-status-while-detecti.patch.
- commit eea8281
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/gt: Restart the heartbeat timer when forcing a pulse (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1c20b58
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Add GuC submission interface version query (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f631c4a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/selftests: Increasing the sleep time for live_rc6_manual (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7665584
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Add flex arrays to struct i915_syncmap (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f29d09b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/gt: Reflect the true and current status of rc6_enable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d99d765
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/mtl: Wake GT before sending H2G message (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e735f9b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/xelpg: Extend some workarounds/tuning to gfx version 12.74 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9935a05
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/xelpg: Extend driver code of Xe_LPG to Xe_LPG+ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 760af80
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/gt: Use rc6.supported flag from intel_gt for rc6_enable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2822e25
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/guc: Avoid circular locking issue on busyness flush (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4507aa5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/guc: Close deregister-context race against CT-loss (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3390670
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/guc: Flush context destruction worker at suspend (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9952cb0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/huc: Allow for very slow HuC loading (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 49c4653
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/xelpg: Add workaround 14019877138 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa5390e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/guc: Change wa and EU_PERF_CNTL registers to MCR type (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d7cbfd8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/gem: Atomically invalidate userptr on mmu-notifier (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0ec1b49
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/alpm: Alpm aux wake configuration for lnl (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 97e60d4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/alpm: Calculate ALPM Entry check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5a450ee
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/psr: Add alpm_parameters struct (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 495c2de
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/alpm: Add ALPM register definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6335db5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Annotate more of the BIOS fb takeover failure paths (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 394fd8d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Try to relocate the BIOS fb to the start of ggtt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit be60581
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Tweak BIOS fb reuse check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bf62eff
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/fbdev: Fix smem_start for LMEMBAR stolen objects (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ae742ab
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Simplify intel_initial_plane_config() calling convention (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6867801
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Split the smem and lmem plane readout apart (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d888f24
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: s/phys_base/dma_addr/ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f3ed285
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Fix MTL initial plane readout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 00a8e68
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Fix region start during initial plane readout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3ca1cd7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Fix PTE decode during initial plane readout (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 630b476
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Rename the DSM/GSM registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fc859c5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Disable the "binder" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 29bd4d0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Bypass LMEMBAR/GTTMMADR for MTL stolen memory access (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c96c5c3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Remove ad-hoc lmem/stolen debugs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 66e69b5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Print memory region info during probe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bcd4eb7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Use struct resource for memory region IO as well (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f0a8fcd
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/hdcp: Pin the hdcp gsc message high in ggtt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3abb4ab
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/hdcp: Do intel_hdcp_component_init() much later during init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0e6ff2a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/fbc: Allow FBC with CCS modifiers on SKL+ (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 64771ba
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Extract intel_atomic_swap_state() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9a390d3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Rework global state serializaiton (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cb3e19a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Compute use_sagv_wm differently (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 303c69b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/display: Include debugfs.h in intel_display_debugfs_params.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 425d352
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: Move registers to PICA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a6e71a4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: Move D2D enable/disable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 82064f7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Convert PLL flags to booleans (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 28f1525
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Perform vblank evasion around legacy cursor updates (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb7cb87
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Move intel_vblank_evade() & co. into intel_vblank.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 774c356
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Move the min/max scanline sanity check into (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3aed823
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Extract intel_vblank_evade() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 529b21a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Include need_vlv_dsi_wa in intel_vblank_evade_ctx (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7b1ad2b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Introduce struct intel_vblank_evade_ctx (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8e44a64
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Reorder drm_vblank_put() vs. need_vlv_dsi_wa (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e0fc55d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Decouple intel_crtc_vblank_evade_scanlines() from atomic (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 08c293b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Add additional ARL PCI IDs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 04c10f1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/opregion: remove unused lid_state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d0229f8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/opregion: make struct intel_opregion opaque (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e2c8092
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/gvt: use local INTEL_GVT_OPREGION_SIZE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3f4a7af
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/opregion: abstract ASLE presence check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7debd52
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/opregion: abstract getting the opregion VBT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c3d6214
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/opregion: move i915_opregion debugfs to intel_opregion.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e9e553a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/bios: move i915_vbt debugfs to intel_bios.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8a893b8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/psr: CAN_PSR and CAN_PANEL_REPLAY can be now local defines (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7df80b2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/display: No need for full modeset due to psr (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8579a87
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/psr: Disable early transport by default (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0d4b69b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/psr: Enable psr2 early transport as possible (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 377dec5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/psr: Configure PIPE_SRCSZ_ERLY_TPT for psr2 early transport (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c9b4b96
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/psr: Calculate and configure CUR_POS_ERLY_TPT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d75384a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/psr: Carry su area in crtc_state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d543256
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/psr: Extend SU area to cover cursor fully if needed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0b9bf80
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: Add eDP 1.5 early transport definition (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3e266ab
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/cdclk: Re-use bxt_cdclk_ctl() when sanitizing (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 185ac02
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/cdclk: Reorder bxt_sanitize_cdclk() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 83b6204
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/cdclk: Extract bxt_cdclk_ctl() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c1b3a6d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: Update bxt_sanitize_cdclk() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 66bfd56
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dp: Abort AUX on disconnected native DP ports (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 42efae8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Filter out glitches on HPD lines during hotplug detection (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit da7dbe3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Add intel_digital_port lock/unlock hooks (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a5935d1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Disable hotplug detection handlers during driver (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e3c3f0d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Disable hotplug detection works during driver init/shutdown (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7f4325e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Prevent modesets during driver init/shutdown (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-i915-Fix-audio-component-initialization.patch.
- commit 962c49e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Suspend the framebuffer console earlier during system (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb93e94
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Suspend the framebuffer console during driver shutdown (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 54e015f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Disable intel HPD poll after DRM poll init/enable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 98736a1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Move audio deinit after disabling polling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 663599f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Keep the connector polled state disabled after storm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2c8dbe4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Init DRM connector polled field early (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ba7d921
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/display: Use helper to select C20 MPLLA/B (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f5dcd60
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Disable DSB in Xe KMD (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1f26e15
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/tv: use DISPLAY_VER instead of GRAPHICS_VER (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 859db5b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/display: use IS_DISPLAY_VER instead of IS_GRAPHICS_VER (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 35323cf
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/hdcp: use DISPLAY_VER instead of GRAPHICS_VER (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-i915-hdcp-Fix-HDCP2_STREAM_STATUS-macro.patch.
- commit 8aba6e0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dmc: use DISPLAY_VER instead of GRAPHICS_VER (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e89661b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/irq: use DISPLAY_VER instead of GRAPHICS_VER (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 46c02f0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/display: Skip C10 state verification in case of fastset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 765cee4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/display: Cleanup mplla/mpllb selection (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e95591a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/display: Store hw clock for C20 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cc4df0d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/mtl: Add fake PCH for Meteor Lake (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 88a9d51
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/bios: remove some unused leftover declarations (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e5f08c2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/display: Take care of VSC select field in video dip ctl (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa8aa6d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/display: Read PSR configuration before VSC SDP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 185ad02
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/display: Ignore only psr specific part of vsc sdp (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a2fc044
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/display: Fix vsc_sdp computation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6cb061d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/display: Unify VSC SPD preparation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e1ad3a4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/display: Move colorimetry_support from intel_psr to intel_dp (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 89e2124
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/display: Remove intel_crtc_state->psr_vsc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d8f22c4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/hdcp: Fail Repeater authentication if Type1 device not (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 48d8e86
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/cdclk: Remove divider field from tables (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 944d9b5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dp: Add TPS4 PHY test pattern support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 256ace0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/dp: Use LINK_QUAL_PATTERN_* Phy test pattern names (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ba8638a
* Fri Oct 18 2024 pjakobsson@suse.de
- Refresh patches.suse/2402-Revert-drm-amd-display-initialize-all-the-dpm-level-.patch.
  Alt-commit
- commit 4b9bca5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915: Ratelimit debug log in vm_fault_ttm (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit 0eb6f76
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/print: Add drm_dbg_ratelimited (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0d92558
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/hdcp: fix intel_hdcp_get_repeater_ctl() error return value (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4399c41
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/i915/hdcp: unify connector logging format (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c6c9997
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Simplify the calculation of variables (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8479f5f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.271 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d3353e1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Drop some unnecessary guards (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dbc00fc
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Trivial code style adjustment (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f44be18
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Drop legacy code (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5b8fc24
* Fri Oct 18 2024 pjakobsson@suse.de
- Revert "drm/amd/display: For FPO and SubVP/DRR configs program (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 675b594
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Adjust set_p_state calls to fix logging (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 224f6f5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Add delay before logging clks from hw (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e4b8541
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: correct comment in set_default_brightness_aux() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0630bcf
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Add left edge pixel for YCbCr422/420 + ODM pipe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b708cfd
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Add debug option to force 1-tap chroma subsampling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 468710a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Disable idle reallow as part of command/gpint (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 317449b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Disable timeout in more places for dc_dmub_srv (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2be37df
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/pm: Retrieve UMC ODECC error count from aca bank (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7d65353
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Add more checks for exiting idle in DC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1ef1744
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: correct static screen event mask (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cbf5094
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: reset gpu for s3 suspend abort case (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9b1b45c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Don't perform rate toggle on DP2-capable FIXED_VS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6012727
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdkfd: Add cache line sizes to KFD topology (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4993f86
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Remove Legacy FIXED_VS Transparent LT Sequence (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b47b5fa
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: add panel_power_savings sysfs entry to eDP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aaf31da
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Clear the hotplug interrupt ack bit before hpd (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eeb57eb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: fix typo in parameter description (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ae0b003
* Fri Oct 18 2024 tiwai@suse.de
- ALSA: scarlett2: Add error check after retrieving PEQ filter
  values (git-fixes).
- commit 20e9844
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Only create mes event log debugfs when mes is enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bd673c7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: use PSP address query command (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1b781cc
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add PSP RAS address query command (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ecc32b3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Need to resume ras during gpu reset for gfx v9_4_3 sriov (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f620297
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: disable RAS feature when fini (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 024629c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Update boot time errors polling sequence (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e4f0f7f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: use helper macro HW_ERR instead of Hardware error string (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 52a9c74
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/pm: Use macro definitions in the smu IH process function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 99c27ce
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.270 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b352371
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.202.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9d63f0b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Populate invalid split index to be 0xF (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4d1033e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: clkmgr unittest with removal of warn & rename DCN35 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6b39efe
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: fix DP audio settings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ed75d2f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: use correct phantom pipe when populating subvp pipe (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 96782c4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: fix invalid reg access on DCN35 FPGA (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c35901e
* Fri Oct 18 2024 tiwai@suse.de
- ALSA: hda/conexant - Use cached pin control for Node 0x1d on
  HP EliteOne 1000 G2 (git-fixes).
- ALSA/hda: intel-sdw-acpi: simplify sdw-master-count property
  read (stable-fixes).
- ALSA/hda: intel-sdw-acpi: fetch fwnode once in
  sdw_intel_scan_controller() (stable-fixes).
- ALSA/hda: intel-sdw-acpi: cleanup sdw_intel_scan_controller
  (stable-fixes).
- ALSA: hda/tas2781: Add new quirk for Lenovo, ASUS, Dell projects
  (stable-fixes).
- ALSA: line6: update contact information (stable-fixes).
- ALSA: hda/conexant - Fix audio routing for HP EliteOne 1000 G2
  (stable-fixes).
- ALSA: hda: Sound support for HP Spectre x360 16 inch model 2024
  (stable-fixes).
- commit fb6c2ec
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: refine code for dmcub inbox1 ring buffer debug (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2676b17
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Send DTBCLK disable message on first commit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2393730
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: add debugfs disallow edp psr (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d8af3a4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: For FPO and SubVP/DRR configs program vmin/max sel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4aa3947
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Unify optimize_required flags and VRR adjustments (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b54c76c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: increased min_dcfclk_mhz and min_fclk_mhz (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 24ea587
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Wait for mailbox ready when powering up DMCUB (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 50b8dbf
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Wait before sending idle allow and after idle (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 238d5a1
* Fri Oct 18 2024 tiwai@suse.de
- firmware: arm_scmi: Fix the double free in
  scmi_debugfs_common_setup() (git-fixes).
- ALSA: hda/cs8409: Fix possible NULL dereference (git-fixes).
- netdevsim: use cond_resched() in nsim_dev_trap_report_work()
  (git-fixes).
- macsec: don't increment counters for an unrelated SA
  (git-fixes).
- net: usb: usbnet: fix race in probe failure (git-fixes).
- HID: plantronics: Workaround for an unexcepted opposite volume
  key (stable-fixes).
- usb: xhci: Fix problem with xhci resume from suspend
  (stable-fixes).
- usb: storage: ignore bogus device raised by JieLi BR21 USB
  sound chip (stable-fixes).
- net: phy: Remove LED entry from LEDs list on unregister
  (git-fixes).
- net: phy: bcm84881: Fix some error handling paths (git-fixes).
- net: phy: dp83869: fix memory corruption when enabling fiber
  (git-fixes).
- kthread: unpark only parked kthread (git-fixes).
- unicode: Don't special case ignorable code points
  (stable-fixes).
- fbdev: sisfb: Fix strbuf array overflow (stable-fixes).
- fbcon: Fix a NULL pointer dereference issue in fbcon_putcs
  (stable-fixes).
- drm/amd/display: Check null pointer before dereferencing se
  (stable-fixes).
- driver core: bus: Fix double free in driver API bus_register()
  (stable-fixes).
- driver core: bus: Return -EIO instead of 0 when show/store
  invalid bus attribute (stable-fixes).
- comedi: ni_routing: tools: Check when the file could not be
  opened (stable-fixes).
- serial: protect uart_port_dtr_rts() in uart_shutdown() too
  (stable-fixes).
- usb: dwc2: Adjust the timing of USB Driver Interrupt
  Registration in the Crashkernel Scenario (stable-fixes).
- usb: chipidea: udc: enable suspend interrupt after usb reset
  (stable-fixes).
- i3c: master: cdns: Fix use after free vulnerability in
  cdns_i3c_master Driver Due to Race Condition (stable-fixes).
- media: videobuf2-core: clear memory related fields in
  __vb2_plane_dmabuf_put() (stable-fixes).
- clk: imx: Remove CLK_SET_PARENT_GATE for DRAM mux for i.MX7D
  (stable-fixes).
- clk: bcm: bcm53573: fix OF node leak in init (stable-fixes).
- i2c: i801: Use a different adapter-name for IDF adapters
  (stable-fixes).
- mfd: intel_soc_pmic_chtwc: Make Lenovo Yoga Tab 3 X90F DMI
  match less strict (stable-fixes).
- soundwire: intel_bus_common: enable interrupts before exiting
  reset (stable-fixes).
- PCI: Mark Creative Labs EMU20k2 INTx masking as broken
  (stable-fixes).
- PCI: Add ACS quirk for Qualcomm SA8775P (stable-fixes).
- PCI: Add function 0 DMA alias quirk for Glenfly Arise chip
  (stable-fixes).
- drm/amd/display: Revert "Check HDCP returned status"
  (stable-fixes).
- HID: multitouch: Add support for lenovo Y9000P Touchpad
  (stable-fixes).
- drm/amd/display: Remove a redundant check in authenticated_dp
  (stable-fixes).
- HID: i2c-hid: Remove I2C_HID_QUIRK_SET_PWR_WAKEUP_DEV quirk
  (stable-fixes).
- commit f829d20
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Fix static screen event mask definition change (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 37cf722
* Fri Oct 18 2024 pjakobsson@suse.de
- Documentation/gpu: Introduce a simple contribution list for display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 52cff8d
* Fri Oct 18 2024 pjakobsson@suse.de
- Documentation/gpu: Add an explanation about the DC weekly patches (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 52292b5
* Fri Oct 18 2024 pjakobsson@suse.de
- Documentation/gpu: Add entry for the DIO component (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 137c070
* Fri Oct 18 2024 pjakobsson@suse.de
- Documentation/gpu: Add entry for OPP in the kernel doc (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 06f0070
* Fri Oct 18 2024 pjakobsson@suse.de
- Documentation/gpu: Add kernel doc entry for MPC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dcd5478
* Fri Oct 18 2024 pjakobsson@suse.de
- Documentation/gpu: Add kernel doc entry for DPP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ea5ac2d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/include: Add missing registers/mask for DCN316 and 350 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 382ad9c
* Fri Oct 18 2024 pjakobsson@suse.de
- Documentation/gpu: Add simple doc page for DCHUBBUB (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 98507e7
* Fri Oct 18 2024 pjakobsson@suse.de
- Documentation/gpu: Add basic page for HUBP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ccf887e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: update documentation on new chips (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7c71806
* Fri Oct 18 2024 pjakobsson@suse.de
- amdgpu/drm: Use vram manager for virtualization page retirement (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 60f9eb1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Add RAS_POISON_READY host response message (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d8ce1d8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Support passing poison consumption ras block to SRIOV (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 15f59cd
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: adjust aca init/fini sequence to match gpu reset (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 320e6c5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add aca sysfs remove support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5a976fb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Fix module unload hang with RAS enabled (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1b0b390
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/pm: Add default case for smu IH process func (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4332d63
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: convert some variable sized arrays to [] style (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a5dee25
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Fix return type in 'aca_bank_hwip_is_matched()' (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b1f062b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu/pptable: convert some variable sized arrays to [] style (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b2944a0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: hook up DCN20 color blocks data to DTN log (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f1ecefb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: add DPP and MPC color caps to DTN log (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b52f243
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Address kdoc for eDP Panel Replay feature in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eacf2a5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: hook up DCN30 color blocks data to DTN log (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9f74dde
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: skip call ras_late_init if ras block is not supported (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ae6b42
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Promote DAL to 3.2.269 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 26565a3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.201.0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f9cbcee
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: turn off windowed Mpo ODM feature for dcn321 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aad7a2c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Add GART memory support for dmcub (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0aeff0d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Revert "Rework DC Z10 restore" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 54ed7a3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: add power_state and pme_pending flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 783e3f8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Add NULL-checks in dml2 assigned pipe search (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c51b220
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Add usb4_bw_alloc_support flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b357785
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Promote DAL to 3.2.268 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ad5f030
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: create DCN3-specific log for MPC state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-amd-display-Remove-MPC-rate-control-logic-from-D.patch.
- commit 6fde884
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Fix timing bandwidth calculation for HDMI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4b1ce5f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: add get_gamut_remap helper for MPC3 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e86a98d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: fill up DCN3 DPP color state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 57733f2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: read gamut remap matrix in fixed-point 31.32 format (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0de5241
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Add dpp_get_gamut_remap functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8eaa5bb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: decouple color state from hw state log (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 223a41d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: update check condition of query for ras page retire (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 50cf555
* Fri Oct 18 2024 pjakobsson@suse.de
- Revert "drm/amd/pm: smu v13_0_6 supports ecc info by default" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4fa9314
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Drop kdoc markers for some Panel Replay functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1017371
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Cleanup inconsistent indenting in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1bae349
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu:Support retiring multiple MCA error address pages (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3716eca
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add interface to check mca umc status (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9a133e2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Use asynchronous polling to handle umc_v12_0 poisoning (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1235358
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Fix ras features value calltrace (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b2d97ff
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Prepare for asynchronous processing of umc page (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2be3dbd
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Add log info for umc_v12_0 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 32ce968
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: fix wrong sizeof argument (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dcb8046
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Enable seq64 manager and fix bugs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0872356
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/pm: enable amdgpu smu send message log (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 00de7b8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: update error condition check for (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cc5b7a4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Show deferred error count for UMC (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1089919
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: fix UBSAN array-index-out-of-bounds for (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ef2d4c8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/amdgpu: Update RLC_SPM_MC_CNT by ring wreg in guest (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8391674
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Remove unnecessary NULL check (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 956f44a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Remove usage of the deprecated ida_simple_xx() API (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7aabfe1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon/ni_dpm: Clean up errors in nislands_smc.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 681a910
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in si.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ce282ba
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in radeon.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9b1b093
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in ci_dpm.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 279dfa5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon/dpm: Clean up errors in evergreen_smc.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 50bbae2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in clearstate_cayman.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit acc3439
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in clearstate_ci.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0df01c7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon/kms: Clean up errors in radeon_pm.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 264e3c4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon/kms: Clean up errors in smu7.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 83a9eb4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon/kms: Clean up errors in smu7_fusion.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 00929b0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in r600_dpm.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 78e2528
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in rv515.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fca39c6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in radeon_mode.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0e69f90
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in evergreen_reg.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f40c40d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in kv_smc.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1f42f97
* Fri Oct 18 2024 pjakobsson@suse.de
- gpu/drm/radeon: Clean up errors in evergreen.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 56a6449
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in evergreen.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cd801c4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in rv770_smc.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 27a2eda
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon/ci_dpm: Clean up errors in ci_dpm.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7393685
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in r600.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d5e77f0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in rs600.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4a96cee
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in si_dpm.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f52b255
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in radeon_audio.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cc8e6b0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in rs400.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b5826ce
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in radeon_audio.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f533023
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in uvd_v1_0.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 730a652
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in radeon_asic.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6737002
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon/kms: Clean up errors in rv6xx_dpm.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 31393d2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon/btc_dpm: Clean up errors in btc_dpm.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6c8c149
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon/dpm: Clean up errors in trinity_dpm.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8b733c1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon/rv770: Clean up errors in rv770_dpm.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c5d58c2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in smu7_discrete.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e08b434
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in ni_dpm.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit edd9208
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon/ni_dpm: Clean up errors in ni_dpm.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3674832
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon/dpm: Clean up errors in sumo_dpm.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit df25214
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in ni.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9948ca6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in r600_dpm.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1dabf74
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon/r100: Clean up errors in r100.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4aa1bad
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in radeon_atpx_handler.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d92c843
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in trinity_dpm.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5a2ed68
* Fri Oct 18 2024 jlee@suse.com
- thermal/debugfs: Avoid excessive updates of trip point statistics (jsc#PED-11164).
- thermal/drivers/mediatek/lvts_thermal: Add coeff for mt8192 (jsc#PED-11164).
- thermal/debugfs: Fix two locking issues with thermal zone debug (jsc#PED-11164).
- thermal/debugfs: Free all thermal zone debug memory on zone removal (jsc#PED-11164).
- thermal/debugfs: Add missing count increment to thermal_debug_tz_trip_up() (jsc#PED-11164).
- thermal: gov_power_allocator: Allow binding without trip points (jsc#PED-11164).
- thermal: gov_power_allocator: Allow binding without cooling devices (jsc#PED-11164).
- thermal: loongson2: Replace of_device.h with explicit includes (jsc#PED-11164).
- commit f75f430
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon/trinity_dpm: Clean up errors in trinity_dpm.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8ea093b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: Clean up errors in si_dpm.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 25512e4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/include/vega20_ip_offset: Clean up errors in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6728c6e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Clean up errors in renoir_ip_offset.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fbdb72c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/amdgpu: Clean up errors in beige_goby_ip_offset.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f54dbcf
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in v10_structs.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4f621de
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/include/navi14_ip_offset: Clean up errors in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b0cef59
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in cgs_common.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d4672cb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/include/sienna_cichlid_ip_offset: Clean up errors in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5b466c2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/include/vangogh_ip_offset: Clean up errors in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4ec2ed9
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in dimgrey_cavefish_ip_offset.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 38890b7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/pp: Clean up errors in dm_pp_interface.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e6c5121
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd: Clean up errors in vega10_ip_offset.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7fa4855
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/include/vega10_ip_offset:Clean up errors in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb398e3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in kgd_pp_interface.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7aec7e0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in navi12_ip_offset.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d9d28fa
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in atom-bits.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d13eae
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/include: Clean up errors in arct_ip_offset.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa54243
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in umc_v6_0.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2baa920
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in clearstate_si.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 765b220
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in amdgpu.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb6db5b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in amdgpu_gmc.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4586380
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in jpeg_v2_5.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e4eb82c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in gfx_v9_4.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1a15947
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in amdgpu_drv.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2ad5fda
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd: Clean up errors in amdgpu_vkms.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 26d3b5f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Centralize ras cap query to amdgpu_ras_check_supported (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ce797fd
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Query ras capablity from psp v2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 01d49bd
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.267 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e5bbf9f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Allow Z8 for multiplane configurations on DCN35 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 48e50fb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Set default Z8 minimum residency for DCN35 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 908668c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Rework DC Z10 restore (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8e47bc8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Enable Panel Replay for static screen use case (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit 08dadec
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Add DP audio BW validation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ec35a92
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Fix dml2 assigned pipe search (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b11c0f3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Ensure populate uclk in bb construction (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f286fbb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Update P010 scaling cap (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 490b597
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/display: Floor to mhz when requesting dpp disp clock changes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 87ea8d2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in amdgpu_rlc.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f95bdfb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd: Clean up errors in sdma_v2_4.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 937d47f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/amdgpu: Clean up errors in amdgpu_umr.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aa41f26
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in amdgpu_atomfirmware.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6bec404
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in clearstate_gfx9.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 598da0d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Clean up errors in navi10_ih.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit da17e66
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/radeon: check PS, WS index (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 91aa77b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: check PS, WS index (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 915ca89
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdkfd: Fix variable dereferenced before NULL check in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 25cb91e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Align ras block enum with firmware (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7ebcd97
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: replace MCA macro with ACA for XGMI (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aee7c06
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Log deferred error separately (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 72d7860
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Do bad page retirement for deferred errors (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 10188f6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add xgmi v6.4.0 ACA support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 47c3be8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add mmhub v1.8 ACA support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 204ada1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add sdma v4.4.2 ACA support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cdf1e31
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add gfx v9.4.3 ACA support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 282b628
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Check extended configuration space register when system (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 61da9e7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add umc v12.0 ACA support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9035e5a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add aca sysfs support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c3828b0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add amdgpu ras aca query interface (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2ce117b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amd/pm: add aca smu backend support for smu v13.0.6 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f7d3749
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: move kiq_reg_write_reg_wait() out of amdgpu_virt.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6897ee1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add new INFO IOCTL query for input power (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b72049b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Query boot status if boot failed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit acf7426
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add ACA bank dump debugfs support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0d7237f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: add ACA kernel hardware error log support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4ac1485
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Query boot status if discovery failed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0eeaf4d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Add ras helper to query boot errors v2 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 58bd276
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: implement RAS ACA driver framework (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 24f7462
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Init pcie_index/data address as fallback (v2) (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3a0d58e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: drop psp v13 query_boot_status implementation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ef3840d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Replace DRM_* with dev_* in amdgpu_psp.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5ea271f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdkfd: Bump KFD ioctl version (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f7706c6
* Fri Oct 18 2024 jlee@suse.com
- thermal/debugfs: Unlock on error path in thermal_debug_tz_trip_up() (jsc#PED-11164).
- thermal: gov_power_allocator: avoid inability to reset a cdev (jsc#PED-11164).
- thermal: helpers: Rearrange thermal_cdev_set_cur_state() (jsc#PED-11164).
- thermal: netlink: Rework notify API for cooling devices (jsc#PED-11164).
- thermal/debugfs: Add thermal debugfs information for mitigation episodes (jsc#PED-11164).
  Refresh
  patches.suse/thermal-debugfs-Pass-cooling-device-state-to-thermal.patch.
- thermal: netlink: Pass thermal zone pointer to notify routines (jsc#PED-11164).
- thermal: netlink: Drop thermal_notify_tz_trip_add/delete() (jsc#PED-11164).
- thermal: netlink: Pass pointers to thermal_notify_tz_trip_up/down() (jsc#PED-11164).
- thermal: netlink: Pass pointers to thermal_notify_tz_trip_change() (jsc#PED-11164).
- thermal/drivers/exynos: Use set_trips ops (jsc#PED-11164).
- thermal/drivers/exynos: Use BIT wherever possible (jsc#PED-11164).
- thermal/drivers/exynos: Split initialization of TMU and the thermal zone (jsc#PED-11164).
- thermal/drivers/exynos: Stop using the threshold mechanism on Exynos 4210 (jsc#PED-11164).
- thermal/drivers/exynos: Simplify regulator (de)initialization (jsc#PED-11164).
- thermal/drivers/exynos: Handle devm_regulator_get_optional return value correctly (jsc#PED-11164).
- thermal/drivers/exynos: Wwitch from workqueue-driven interrupt handling to threaded interrupts (jsc#PED-11164).
- thermal/drivers/exynos: Drop id field (jsc#PED-11164).
- thermal/drivers/exynos: Remove an unnecessary field description (jsc#PED-11164).
- thermal/drivers/sun8i: Add D1/T113s THS controller support (jsc#PED-11164).
- thermal: amlogic: Use DEFINE_SIMPLE_DEV_PM_OPS for PM functions (jsc#PED-11164).
- thermal: amlogic: Make amlogic_thermal_disable() return void (jsc#PED-11164).
- thermal/thermal_of: Allow rebooting after critical temp (jsc#PED-11164).
- reboot: Introduce thermal_zone_device_critical_reboot() (jsc#PED-11164).
- thermal/core: Prepare for introduction of thermal reboot (jsc#PED-11164).
- drivers/thermal/loongson2_thermal: Fix incorrect PTR_ERR() judgment (jsc#PED-11164).
- thermal/drivers/loongson-2: Add thermal management support (jsc#PED-11164).
- commit 663016a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: Auto-validate DMABuf imports in compute VMs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-amdgpu-reset-vm-state-machine-after-gpu-reset-vr.patch.
- commit 5e289f4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: remove drm_bridge_get_edid() in favour of (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f32ea3c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/meson: switch to drm_bridge_edid_read() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa5927e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: tfp410: clear the EDID property on failures (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 300e039
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: tfp410: use drm_bridge_edid_read() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2936313
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: bridge: simple-bridge: clear the EDID property on failures (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2345d34
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: bridge: simple-bridge: use drm_bridge_edid_read() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 144c41b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: lt9611uxc: use drm_bridge_edid_read() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 217c46d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: lt8912b: use ->edid_read callback (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a3b2664
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: lt8912b: clear the EDID property on failures (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d023aa8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: lt8912b: use drm_bridge_edid_read() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-bridge-lontium-lt8912b-Validate-mode-in-drm_brid.patch.
- commit 7ac78df
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: chrontel-ch7033: switch to drm_bridge_edid_read() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 48dc524
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: switch to drm_bridge_edid_read() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fa60eb5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: add ->edid_read hook and drm_bridge_edid_read() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 460c3a2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: xlnx: zynqmp_dpsub: Filter interrupts against mask (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f797265
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: xlnx: zynqmp_dpsub: Clear status register ASAP (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9eba99c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: xlnx: zynqmp_dpsub: Fix timing for live mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8f2ce5f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: xlnx: zynqmp_dpsub: Make drm bridge discoverable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f1de1f5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: mipi-dsi: make mipi_dsi_bus_type const (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0c85760
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: display: make dp_aux_bus_type const (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ab7e11c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: imx8mp-hdmi-pvi: Fix build warnings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8114f91
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/panel: simple: push blanking limit on RK32FN48H (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 398713b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/panel: simple: fix flags on RK043FN48H (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cc3a217
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/panel: visionox-r66451: Set prepare_prev_first flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 17de9be
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rect: fix kernel-doc typos (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d3b860
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/panel: visionox-vtdr6130: Set prepare_prev_first flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2230dc6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/panel: novatek-nt36523: Set prepare_prev_first (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 89cc6f2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/imx/dcss: have all init functions use devres (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c9119e4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/imx/dcss: request memory region (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 24a092a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/nouveau/svm: remove unused but set variables (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4175392
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/nouveau/acr/ga102: remove unused but set variable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0283f91
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/imx: prefer snprintf over sprintf (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2da5fa7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/amdgpu: prefer snprintf over sprintf (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fb7001e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/vmwgfx: Add SPDX header to vmwgfx_drm.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e01c8a8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/vmwgfx: Make all surfaces shareable (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 827eed8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/vmwgfx: Refactor drm connector probing for display modes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Delete patches.suse/drm-vmwgfx-Filter-modes-which-exceed-graphics-memory.patch.
- commit 0aa0e27
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/panel: simple: Add EDT ETML1010G3DRA panel (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a850baf
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/loongson: Error out if no VRAM detected (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 408905a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/ttm: Make sure the mapped tt pages are decrypted when needed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f811a56
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/vmwgfx: Add SVGA_3D_CMD_DEFINE_GB_SURFACE_V4 to command array. (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit be105ab
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/ttm: replace busy placement with flags v6 (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8a3f665
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: tc358767: Limit the Pixel PLL input range (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 340d14e
* Fri Oct 18 2024 pjakobsson@suse.de
- video/cmdline: Hide __video_get_options() behind CONFIG_FB_CORE (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit adb8bd8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/exec, drm/gpuvm: Prefer u32 over uint32_t (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c80ab7e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: bridge: samsung-dsim: complete the CLKLANE_STOP setting (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9d30fca
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: bridge: samsung-dsim: enter display mode in the enable() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 838c342
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/vmwgfx: remove vmw_vram_gmr_placement (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f0e8667
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/doc/rfc: Removing missing reference to xe.rst (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f0a994
* Fri Oct 18 2024 pjakobsson@suse.de
- Documentation/gpu: Reference articles on Linux graphics stack (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a80ebc7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/panel: novatek-nt36672e: Include <linux/of.h> (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f46deff
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/tests: managed: Add a simple test for drmm_managed_release (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6632d02
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/tests: managed: Extract device initialization into test init (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d32dfc2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/tests: managed: Add comments about test intent (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e857ece
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/tests: managed: Rename the suite name to match other DRM tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1823b18
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/managed: Add drmm_release_action (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ceb2f4e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Explicitly include drm_atomic.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cdf14d8
* Fri Oct 18 2024 pjakobsson@suse.de
- ASoC: hdmi-codec: drop drm/drm_edid.h include (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d1e9c89
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/ci: add sc7180-trogdor-kingoftown (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9f3023c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/ci: uprev mesa version: fix kdl commit fetch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fe61acb
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/ci: Update xfails for newly added msm tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0e884c1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/ci: Add msm tests (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7da9338
* Fri Oct 18 2024 pjakobsson@suse.de
- dma-buf/dma-fence: fix spelling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3a67482
* Fri Oct 18 2024 pjakobsson@suse.de
- dma-buf/dma-resv: fix spelling (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4fcc83f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/doc: internals: remove section on PCI legacy support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ae78555
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: Clean-up superfluously selecting VT_HW_CONSOLE_BINDING (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f35f7ec
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/panel: Simplify with dev_err_probe() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4ee13e8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: panel: simple: convert LG LB070WV8 fixed mode into display (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5ab44b0
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/v3d: Show the memory-management stats on debugfs (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dcc22e5
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/ttm/tests: Fix argument in ttm_tt_kunit_init() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb114a8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/edid: Clean up errors in drm_edid.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 564d80b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/doc/rfc: Remove Xe's pre-merge plan (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d8edd1a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/hisilicon: include drm/drm_edid.h only where needed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5667f2f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/nouveau: include drm/drm_edid.h only where needed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c06c021
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/nouveau/disp: switch to use kmemdup() helper (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6db5c5f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: Fixed a DP link training bug (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Delete patches.suse/drm-bridge-it6505-fix-hibernate-to-resume-no-display.patch.
- commit b9e2cd7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/panel: nt35510: support FRIDA FRD400B25025-A-CTK (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2c82827
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/panel: nt35510: move hardwired parameters to configuration (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a020d4e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/nouveau: uapi: fix kerneldoc warnings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a4c84b8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/nouveau/volt/gk20a: don't misuse kernel-doc comments (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 03b5d78
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/nouveau/gr/gf100: don't misuse kernel-doc comments (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6d5fd07
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/nouveau: don't misuse kernel-doc comments (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2742b28
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/nouveau/disp: don't misuse kernel-doc comments (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1e175b1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/nouveau/bios/init: drop kernel-doc notation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ebcc8b8
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/probe-helper: remove unused (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 92a6d24
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/mgag200: convert get modes to struct drm_edid (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6013788
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/mgag200: Fix caching setup for remapped video memory (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 94688b3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/sched: Return an error code only as a constant in (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b214160
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/sched: One function call less in drm_sched_init() after error (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3c0b77a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm: Move drm_set_preferred_mode() helper from drm_edid to drm_modes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b82c273
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/edid: prefer forward declarations over includes in drm_edid.h (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5634186
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/panel: ltk050h3146w: use dev_err_probe wherever possible (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 73ceae9
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/panel: ltk050h3146w: only print message when GPIO getting is not (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 95d6a5d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Drop custom fill_modes hook (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cb2be93
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Add basic mode validation (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a7d1696
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Add RK3128 support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6b99235
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Add variant support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4fc7809
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: analogix_dp: get encoder port ID from DT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4c5eb74
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/vmwgfx: fix kernel-doc Excess struct member 'base' (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d8599d6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/vmwgfx: fix all kernel-doc warnings in stdu (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c3b9a3a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/vmwgfx: Fix typos in vmwgfx_execbuf.c (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b5c506e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/virtio: Spelling fixes (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b0d111a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/debugfs: drop unneeded DEBUG_FS guard (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit da232db
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/vkms: Create separate Kconfig file for VKMS (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ea822f3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/vc4: plane: check drm_gem_plane_helper_prepare_fb() return value (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- Refresh patches.suse/drm-vc4-don-t-check-if-plane-state-fb-state-fb.patch.
- commit 455f81e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/ssd130x: Add support for the SSD133x OLED controller family (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6b85b2d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Split power mode setting (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ed789b7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Don't power up the phy after resetting (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0fc9035
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Correctly setup HDMI quantization range (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 898950e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Subclass connector state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9247457
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Remove useless include (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 670c6a3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Drop irq struct member (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b3d0507
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Remove unused drm device pointer (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0fa6321
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Switch to infoframe type (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2e4232d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Move infoframe disable to separate function (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 777898e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Drop HDMI Vendor Infoframe support (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb3ea3a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Remove tmds rate from structure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 860928d
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Remove YUV-based csc coefficents (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit edc7faf
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Remove useless input format (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 726825b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Remove unneeded has audio flag (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4ce460e
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: no need to store vic (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c377517
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Get rid of mode_set (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 785b91c
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Switch encoder hooks to atomic (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bcb83ed
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Remove useless copy of drm_display_mode (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 98103df
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: inno_hdmi: Remove useless mode_fixup (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 262941f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/rockchip: vop: Add output selection registers for RK312x (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5b9db3b
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/tilcdc: request and mapp iomem with devres (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f2eb1d0
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/qaic: Order pci_remove() operations in reverse of probe() (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fd641d2
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/qaic: Leverage DRM managed APIs to release resources (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c1e47f1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/panel-edp: Add several generic edp panels (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dacef29
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/panel-edp: Add some panels with conservative timings (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4f033de
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/edp-panel: Add panels delay entries (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d805f3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/panel-edp: Add powered_on_to_enable delay (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f0af9d3
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/todo: Add entry to rename drm_atomic_state (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit eb68853
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/atomic: Make the drm_atomic_state documentation less ambiguous (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit facfbb4
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/atomic: Rework the object doc a bit (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8bf6d8a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/atomic: Remove inexistent reference (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9dae332
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/atomic: Move the drm_atomic_state field doc inline (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f5bd960
* Fri Oct 18 2024 pjakobsson@suse.de
- fbdev/vesafb: Use screen_info pointer from device (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit efb4c47
* Fri Oct 18 2024 pjakobsson@suse.de
- fbdev/vesafb: Replace references to global screen_info by local (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8241272
* Fri Oct 18 2024 pjakobsson@suse.de
- fbdev/efifb: Use screen_info pointer from device (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 855dbf5
* Fri Oct 18 2024 pjakobsson@suse.de
- fbdev/efifb: Replace references to global screen_info by local (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1f76a0d
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/qaic: Call drm_gem_create_mmap_offset() once for each BO (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 238c6f0
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/qaic: Drop the reference to BO in error path of create BO IOCTL (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bdb2c35
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/qaic: Fix MHI channel struct field order (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2d884b4
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/qaic: Remove bo->queued field (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c86d2dc
* Fri Oct 18 2024 pjakobsson@suse.de
- accel/qaic: Deprecate ->size field from attach slice IOCTL structure (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7d78897
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: samsung-dsim: check the return value only if necessary (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 69aad53
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: tc358767: Add descriptions to register definitions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f75e53
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: tc358767: Add precious register SYSSTAT (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e032aa7
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: tc358767: Add more volatile registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 39e5aa6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: tc358767: Sort volatile registers according to address (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c274e62
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: tc358767: Add more registers to non-writeable range (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e36cee9
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: tc358767: Fix order of register defines (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8962098
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/bridge: tc358767: Use regmap_access_table for writeable registers (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1c829d6
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/tegra: include drm/drm_edid.h only where needed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2ed1481
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/ioc32: replace __attribute__((packed)) with __packed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e48986f
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/edid: replace __attribute__((packed)) with __packed (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 65063bc
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/ttm/tests: Add tests for ttm_bo functions (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 913c359
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/ttm/tests: Add tests for ttm_tt (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6bb24b1
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/ttm/tests: Add tests for ttm_resource and ttm_sys_man (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a9e6cbc
* Fri Oct 18 2024 pjakobsson@suse.de
- fbdev/simplefb: change loglevel when the power domains cannot be (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dbd5453
* Fri Oct 18 2024 pjakobsson@suse.de
- video: fbdev: mmp: Follow renaming of SPI "master" to "controller" (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 96210d2
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/vram-helper: Fix 'multi-line' kernel-doc comments (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5bfec3a
* Fri Oct 18 2024 pjakobsson@suse.de
- drm/xe/tests: Fix printf format specifiers in xe_migrate test (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 86d45fe
* Fri Oct 18 2024 nmorey@suse.com
- RDMA/mlx5: Enforce umem boundaries for explicit ODP page faults (git-fixes)
- commit b9b835e
* Fri Oct 18 2024 nmorey@suse.com
- RDMA/rtrs-srv: Avoid null pointer deref during path establishment (git-fixes)
- commit cf9eccb
* Fri Oct 18 2024 nmorey@suse.com
- RDMA/mad: Improve handling of timed out WRs of mad agent (git-fixes)
- commit 72bef76
* Fri Oct 18 2024 jlee@suse.com
- thermal: gov_power_allocator: Support new update callback of weights (jsc#PED-11164).
- thermal: gov_power_allocator: Simplify checks for valid power actor (jsc#PED-11164).
- thermal: gov_power_allocator: Move memory allocation out of throttle() (jsc#PED-11164).
- thermal: gov_power_allocator: Change trace functions (jsc#PED-11164).
- thermal: gov_power_allocator: Refactor checks in divvy_up_power() (jsc#PED-11164).
- thermal: gov_power_allocator: Refactor check_power_actors() (jsc#PED-11164).
- commit 27b8762
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-nouveau-firmware-Fix-SG_DEBUG-error-with-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d01755f
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-connector-Add-n-to-message-about-demoting-connec.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c60aa87
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-meson-dw-hdmi-add-bandgap-setting-for-g12.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6dd44f1
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-meson-dw-hdmi-power-up-phy-on-device-init.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a8c49e8
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/dm-amd-pm-Fix-problems-with-reboot-shutdown-for-some.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2904aa9
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-bios-Fix-parsing-backlight-BDB-data.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2a8b2f6
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-audio-Fix-audio-time-stamp-programming-for-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ab6f4de
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Automate-CCS-Mode-setting-during-engine-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1fdfb5d
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/Reapply-drm-qxl-simplify-qxl_fence_wait.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 975842d
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/mei-me-add-lunar-lake-point-M-DID.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c279116
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-ili9341-Use-predefined-error-codes.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2c85708
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-ili9341-Respect-deferred-probe.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e400be8
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-vmwgfx-Fix-invalid-reads-in-fence-signaled-event.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8478597
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-firmware-Fix-SG_DEBUG-error-with-nvkm_fi.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ebb018d
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-vmwgfx-Fix-Legacy-Display-Unit.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a2bca88
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Flush-the-process-wq-before-creating-a-kf.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 708cab3
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Disable-seamless-boot-on-128b-132b-e.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 475b447
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-DC-mode-screen-flickering-on-DCN.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9ccdc43
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-VCO-speed-parameter-for-DCN31-FP.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2cb87ed
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-once-more-fix-the-call-oder-in-amdgpu_ttm.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8c830a0
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Allocate-zero-bw-after-bw-alloc-enab.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9c95445
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-incorrect-DSC-instance-for-MST.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 21b9709
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Atom-Integrated-System-Info-v2_2-for.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d730534
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-dtbclk-access-to-dcn315.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ab99cac
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Handle-Y-carry-over-in-VCP-X.Y-calcu.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f39f335
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-VRAM-memory-accounting.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7532563
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-etnaviv-fix-tx-clock-gating-on-some-GC7000-varia.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b4acb55
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-fix-incorrect-address-computation-in-deferred-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d4af252
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-gma500-Remove-lid-code.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bfca830
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-mes-fix-use-after-free-issue.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bb3296b
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-sdma5.2-use-legacy-HDP-flush-for-SDMA2-3.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4720020
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-the-ring-buffer-size-for-queue-VM-flu.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f9f1ff2
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Add-VRAM-accounting-for-SVM-migration.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3b34947
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-Restore-config-space-after-reset.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 907da1d
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Update-BO-eviction-priorities.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b9b07d0
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Assign-correct-bits-for-SDMA-HDP-flush.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 158949c
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-leak-when-GPU-memory-allocation-fails.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 83acc73
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Set-color_mgmt_changed-to-true-on-un.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ec48fa3
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/mei-me-disable-RPL-S-on-SPS-and-IGN-firmwares.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5da10d6
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-visionox-rm69299-don-t-unregister-DSI-devi.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c59cf9c
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-dp-Don-t-probe-eDP-ports-twice-harder.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022 stable-fixes).
- commit 10fafcb
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-vmwgfx-Sort-primary-plane-formats-by-order-of-pr.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0fb1e63
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-vmwgfx-Fix-crtc-s-atomic-check-conditional.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2bb0c09
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-vmwgfx-Fix-prime-import-export.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit aed85aa
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-ttm-stop-pooling-cached-NUMA-pages-v2.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 55fb73e
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-fix-instmem-race-condition-around-ptr-stores.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9e07bcb
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-silence-UBSAN-warning-v3.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ca9f80f
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-make-fstrict-flex-arrays-3-happy.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e3dbb3a
* Thu Oct 17 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amdgpu-once-more-fix-the-call-oder-in-amdgpu_ttm.patch.
- Delete patches.suse/drm-amdgpu-Fix-comparison-in-amdgpu_res_cpu_visible.patch.
- Delete patches.suse/drm-amdgpu-fix-doorbell-regression.patch.
- Delete patches.suse/drm-amdgpu-fix-visible-VRAM-handling-during-faults.patch.
- commit a629e31
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-validate-the-parameters-of-bo-mapping-ope.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4db8e73
* Thu Oct 17 2024 pjakobsson@suse.de
- Delete patches.suse/Revert-drm-amd-display-fix-USB-C-flag-update-after-e.patch.
- commit ee60c68
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-remove-invalid-resource-start-check-v2.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9ea4873
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dp-fix-typo-in-dp_display_handle_port_status.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 41cf0a6
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-make-error-messages-at-dpu_core_irq_regi.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3401e19
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-don-t-allow-overriding-data-from-catalog.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9a94e22
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-Add-newlines-to-some-debug-prints.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d82d222
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-vmwgfx-Enable-DMA-mappings-with-SEV.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6ade919
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/gpu-host1x-Do-not-setup-DMA-for-virtual-devices.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 40d5e93
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/accel-ivpu-Fix-deadlock-in-context_xa.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022 git-fixes CVE-2024-35953 bsc#1224704).
- commit 419d525
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-fix-function-cast-warning.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bc4083e
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-gsp-Avoid-addressing-beyond-end-of-rpc-entri.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e9ec734
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-qxl-simplify-qxl_fence_wait.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8a6501f
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-ast-Fix-soft-lockup.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b2e51e4
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Set-VSC-SDP-Colorimetry-same-way-for.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8591dcc
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Program-VSC-SDP-colorimetry-for-all-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3ee2924
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-disable-otg-wa-logic-in-DCN316.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5a1f483
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Do-not-recursively-call-manual-trigg.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c920759
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-incorrect-number-of-active-RBs-for-gf.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3f0ebc7
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-VCN-allocation-in-CPX-partition.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 45373c3
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Skip-on-writeback-when-it-s-not-appl.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 858af4f
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-implement-IRQ_STATE_ENABLE-for-SDMA-v4.4..patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ca730db
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Reset-dGPU-if-suspend-got-aborted.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2876ea3
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Refine-IB-schedule-error-logging.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4ff1c4b
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-always-force-full-reset-for-SOC21.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 35a3421
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Reset-GPU-on-queue-preemption-failure.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 048fb1b
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-vrr-Disable-VRR-when-using-bigjoiner.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6221fa2
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Disable-live-M-N-updates-when-using-bigjoin.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0208d1b
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Disable-port-sync-when-bigjoiner-is-used.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 520263e
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-cdclk-Fix-CDCLK-programming-order-when-pipe.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 49c68c4
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-fix-devinit-paths-to-only-handle-display-on-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0532aeb
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-mst-Reject-FEC-MST-on-ICL.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0b68f8d
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-mst-Limit-MST-DSC-to-TGL.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 9a14551
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dp-Fix-the-computation-for-compressed_bpp-f.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5859bbc
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Enable-only-one-CCS-for-compute-workload.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6a9219e
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Do-not-generate-the-command-streamer-for.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d7f0332
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Disable-HW-load-balancing-for-CCS.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ad9f991
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dp-Remove-support-for-UHBR13.5.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2644f86
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-display-fix-typo.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5a1739b
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-prime-Unbreak-virtgpu-dma-buf-export.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c4642f1
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-panfrost-fix-power-transition-timeout-warnings.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 72dddcf
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-bios-Tolerate-devdata-NULL-in-intel_bios_en.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit f5165d0
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Pre-populate-the-cursor-physical-dma-addres.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 81ba4d6
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Reset-queue_priority_hint-on-parking.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b845fff
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Do-not-match-JSL-in-ehl_combo_pll_div_frac_.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1cee320
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-hwmon-Fix-locking-inversion-in-sysfs-getter.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1de10de
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dsb-Fix-DSB-vblank-waits-when-using-VRR.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 283db96
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-vrr-Generate-VRR-safe-window-for-DSB.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 737ca7e
* Thu Oct 17 2024 pjakobsson@suse.de
- Delete patches.suse/drm-i915-mtl-Update-workaround-14018575942.patch.
- commit 7ef8aef
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dsi-Go-back-to-the-previous-INIT_OTP-DISPLA.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3cb42a1
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-qxl-remove-unused-variable-from-qxl_process_sing.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ca37a31
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-qxl-remove-unused-count-variable-from-qxl_surfac.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1d36a28
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-vmwgfx-Create-debugfs-ttm_resource_manager-entry.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit dea444a
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-vop2-Remove-AR30-and-AB30-format-suppor.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 13fdd12
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-sched-fix-null-ptr-deref-in-init-entity.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 68e5bb0
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-deadlock-while-reading-mqd-from-debug.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a69895a
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Set-DCN351-BB-and-IP-the-same-as-DCN.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit da561eb
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-bounds-check-for-dcn35-DcfClocks.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fc97802
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Remove-MPC-rate-control-logic-from-D.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022 stable-fixes).
- commit 14570fe
* Thu Oct 17 2024 pjakobsson@suse.de
- Delete patches.suse/drm-amd-display-Send-DTBCLK-disable-message-on-first.patch.
- commit 458f564
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Flush-GFXOFF-requests-in-prepare-stage.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 20e8fdf
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-range-check-cp-bad-op-exception-interrupt.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fd37fe1
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amd-display-Fix-sending-VSC-colorimetry-p.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit fc02466
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-fix-TLB-flush-after-unmap-for-GFX9.4.2.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1379a64
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Check-cgroup-when-returning-DMABuf-info.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 135321f
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-viafb-fix-typo-in-hw_bitblt_1-and-hw_bitblt_2.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 19de030
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-drop-setting-buffer-funcs-in-sdma442.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1cb91a5
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-noise-issue-on-HDMI-AV-mute.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8b2b9c2
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Revert-Remove-pixle-rate-limit-for-s.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c638a99
* Thu Oct 17 2024 pjakobsson@suse.de
- Delete patches.suse/Revert-drm-amd-amdgpu-Fix-potential-ioremap-memory-l.patch.
- commit d014766
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Return-the-correct-HDCP-error-code.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cd2d47e
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-idle-check-for-shared-firmware-s.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7f44490
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Update-odm-when-ODM-combine-is-chang.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ac30b88
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Init-DPPCLK-from-SMU-on-dcn32.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a08045d
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Allow-dirty-rects-to-be-sent-to-dmub.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 054a4ca
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-pm-Check-the-validity-of-overdiver-power-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1b97fc1
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-pm-Fix-NULL-pointer-dereference-when-get-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 08ea7dd
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-amdgpu_ttm_gart_bind-set-gtt-bound-flag.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bc8c4d9
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Change-default-size-for-dummy-plane-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 231d28a
* Thu Oct 17 2024 pjakobsson@suse.de
- Delete patches.suse/drm-amdgpu-fix-mmhub-client-id-out-of-bounds-access.patch.
- commit 86495c1
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-use-after-free-bug.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ff9ebf9
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Use-freesync-when-DRM_EDID_FEATURE_C.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 57fbb1d
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-gsp-don-t-check-devinit-disable-on-GSP.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b7b9c6d
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-Fix-drm_fixp2int_round-making-it-add-0.5.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 47d8411
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-vc4-hdmi-do-not-return-negative-values-from-.get.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ab99162
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-imx-ipuv3-do-not-return-negative-values-from-.ge.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 05b98e4
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-exynos-do-not-return-negative-values-from-.get_m.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a5c0c77
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-do-not-return-negative-error-codes-from-dr.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit afb174b
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-probe-helper-warn-about-negative-.get_modes.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 157f038
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-reset-the-bo-resource-bus-info-after-an-evic.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 494b2fc
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Add-missing-to-__assign_str-macros-in-trace.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 936cf35
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/backlight-lp8788-Fully-initialize-backlight_properti.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e26529a
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/backlight-lm3639-Fully-initialize-backlight_properti.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a05363b
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/backlight-da9052-Fully-initialize-backlight_properti.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d5d3fe9
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/backlight-lm3630a-Don-t-set-bl-props.brightness-in-g.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 896d875
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/backlight-lm3630a-Initialize-backlight_properties-on.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8e240f6
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/backlight-ktz8866-Correct-the-check-for-of_property_.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e7c4527
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-capture-snapshot-on-the-first-commit_don.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022 stable-fixes).
- commit 29aece0
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-split-dpu_encoder_wait_for_event-into-tw.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit edcfabc
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-add-division-of-drm_display_mode-s-hskew.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b878180
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-etnaviv-Restore-some-id-values.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 06cfdd6
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-Fix-esm-reg-mask-use-to-get-pcie-speed.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 80d684d
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-missing-break-in-ATOM_ARG_IMM-Case-of.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1dea9ee
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-display-Address-kdoc-for-is_psr_su-in-fil.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6f1735f
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-nanosec-stat-overflow.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit ec8e973
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Remove-pixle-rate-limit-for-subvp.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6654f34
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amdgpu-Add-pcie-usage-callback-to-nbio.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4e358dc
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amdgpu-Add-pci-usage-to-nbio-v7.9.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3435de8
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-a7xx-Fix-LLC-typo.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 76c541a
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-finalise-global-state-object.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0103268
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Only-enable-DSC_MODE_MULTIPLEX-if-dsc_me.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit bab8532
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-fix-the-programming-of-INTF_CFG2_DATA_HC.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5bb9247
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-improve-DSC-allocation.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 38b7e31
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-a-null-pointer-crash-in-mtk_drm_crt.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 426d3a4
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-dsi-Fix-DSI-RGB666-formats-and-definiti.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022).
- commit 21438c5
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-tests-helpers-Include-missing-drm_drv-header.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3f6ae39
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-Check-polling-initialized-before-enabling-in-drm.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4d58b3c
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-sun4i-hdmi-Move-mode_set-into-enable.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 8769ec6
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-sun4i-hdmi-Convert-encoder-to-atomic.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0c8f729
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-tidss-Fix-sync-lost-issue-with-two-displays.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit cc5a014
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-tidss-Fix-initial-plane-zpos-values.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d635b34
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-tegra-put-drm_gem_object-ref-on-error-in-tegra_f.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 7ac88f1
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-adv7511-fix-crash-on-irq-during-probe.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit b107caa
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-boe-tv101wum-nl6-make-use-of-prepare_prev_.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 144b0ec
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-add-drm_gem_object_is_shared_for_memory_stats-he.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d9475ae
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-replay-NULL-check-in-edp_set_rep.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 96fe911
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-NULL-checks-for-adev-dm.dc-in-am.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 3fe369e
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-ni-Fix-wrong-firmware-size-logging-in-ni_.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 33e4479
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-ci-use-clk_ignore_unused-for-apq8016.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2e050b3
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-lima-set-gp-bus_stop-bit-before-hard-reset.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 410a16d
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Suppress-old-PLL-pipe_mask-checks-for-MG-TC.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 29e0b9d
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Include-the-PLL-name-in-the-debug-messages.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e6d3a00
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Try-to-preserve-the-current-shared_dpll-for.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 2b2e6f8
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-i915-xe2lpd-Treat-cursor-plane-as-regular.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 19cce86
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Replace-a-memset-with-zero-initialization.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1bf2f68
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-a-potential-buffer-overflow-in-d.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5ebb8a5
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-ni_dpm-remove-redundant-NULL-check.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 31397cf
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-remove-dead-code-in-ni_mc_load_microcode.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 93b8f45
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Skip-do-PCI-error-slot-reset-during-RAS-r.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 4d52ac7
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-vmwgfx-Fix-vmw_du_get_cursor_mob-fencing-of-newl.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 0f789d2
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-ttm-return-ENOSPC-from-ttm_bo_mem_space-v3.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 11705b5
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-orientation-quirks-Add-quirk-for-GPD-Win-M.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit e06353d
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-nt36523-Set-120Hz-fps-for-xiaomi-elish-pan.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 44ce60c
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-vc4-don-t-check-if-plane-state-fb-state-fb.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022 stable-fixes CVE-2024-35932 bsc#1224650).
- commit 156e544
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-edp-use-put_sync-in-unprepare.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 1e1cd9f
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-lvds-do-not-print-scary-message-when-pr.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 494bbd7
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-lvds-do-not-overwrite-error-code.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit d359732
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-Don-t-treat-0-as-1-in-drm_fixp2int_ceil.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit a6e4319
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-inno_hdmi-Fix-video-timing.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 73f27d4
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-tegra-output-Fix-missing-i2c_put_adapter-in-the-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 6880e7e
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-tegra-rgb-Fix-some-error-handling-paths-in-tegra.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 97f8d95
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-tegra-hdmi-Fix-some-error-handling-paths-in-tegr.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 653031b
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-tegra-dsi-Fix-missing-pm_runtime_disable-in-the-.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit c622fad
* Thu Oct 17 2024 pjakobsson@suse.de
- Update patches.suse/drm-tegra-dsi-Fix-some-error-handling-paths-in-tegra.patch (jsc#PED-9898 jsc#PED-10191 jsc#PED-10197 jsc#PED-10226 jsc#PED-10237 jsc#PED-10340 jsc#PED-10852 jsc#PED-11022)
- commit 5a60ea3
* Thu Oct 17 2024 pjakobsson@suse.de
- blacklist.conf: Unblacklist patches for DRM v6.9 backport
- commit 6789f6f
* Thu Oct 17 2024 ohering@suse.de
- tools/hv: Add memory allocation check in hv_fcopy_start (git-fixes).
- x86/hyperv: use helpers to read control registers in hv_snp_boot_ap() (git-fixes).
- Drivers: hv: vmbus: Optimize boot time by concurrent execution of hv_synic_init() (git-fixes).
- clockevents/drivers/i8253: Fix stop sequence for timer 0 (git-fixes).
- net: netvsc: Update default VMBus channels (git-fixes).
- hv: vmbus: Constify struct kobj_type and struct attribute_group (git-fixes).
- tools: hv: lsvmbus: change shebang to use python3 (git-fixes).
- clocksource: hyper-v: Use lapic timer in a TDX VM without paravisor (git-fixes).
- Drivers: hv: Remove deprecated hv_fcopy declarations (git-fixes).
- RDMA/mana_ib: Set correct device into ib (git-fixes).
- RDMA/mana_ib: Process QP error events in mana_ib (git-fixes).
- RDMA/mana_ib: extend query device (git-fixes).
- RDMA/mana_ib: set node_guid (git-fixes).
- RDMA/mana_ib: Modify QP state (git-fixes).
- RDMA/mana_ib: Implement uapi to create and destroy RC QP (git-fixes).
- RDMA/mana_ib: Create and destroy RC QP (git-fixes).
- net: mana: Use mana_cleanup_port_context() for rxq cleanup (git-fixes).
- net: mana: Allow variable size indirection table (git-fixes).
- Drivers: hv: Cosmetic changes for hv.c and balloon.c (git-fixes).
- tools: hv: suppress the invalid warning for packed member alignment (git-fixes).
- hv_balloon: Enable hot-add for memblock sizes > 128 MiB (git-fixes).
- hv_balloon: Use kernel macros to simplify open coded sequences (git-fixes).
- uio_hv_generic: Remove use of PAGE_SIZE (git-fixes).
- Drivers: hv: Remove fcopy driver (git-fixes).
- tools: hv: Add new fcopy application based on uio driver (git-fixes).
- tools: hv: Add vmbus_bufring (git-fixes).
- uio_hv_generic: Enable interrupt for low speed VMBus devices (git-fixes).
- uio_hv_generic: Query the ringbuffer size for device (git-fixes).
- Drivers: hv: vmbus: Add utility function for querying ring size (git-fixes).
- RDMA/mana_ib: implement uapi for creation of rnic cq (git-fixes).
- RDMA/mana_ib: boundary check before installing cq callbacks (git-fixes).
- RDMA/mana_ib: introduce a helper to remove cq callbacks (git-fixes).
- RDMA/mana_ib: create and destroy RNIC cqs (git-fixes).
- RDMA/mana_ib: create EQs for RNIC CQs (git-fixes).
- RDMA/mana_ib: Fix missing ret value (git-fixes).
- RDMA/mana_ib: Configure mac address in RNIC (git-fixes).
- RDMA/mana_ib: Adding and deleting GIDs (git-fixes).
- RDMA/mana_ib: Enable RoCE on port 1 (git-fixes).
- RDMA/mana_ib: Implement port parameters (git-fixes).
- RDMA/mana_ib: Create and destroy rnic adapter (git-fixes).
- RDMA/mana_ib: Add EQ creation for rnic adapter (git-fixes).
- RDMA/mana_ib: Use num_comp_vectors of ib_device (git-fixes).
- RDMA/mana_ib: remove useless return values from dbg prints (git-fixes).
- RDMA/mana_ib: Use struct mana_ib_queue for RAW QPs (git-fixes).
- RDMA/mana_ib: Use struct mana_ib_queue for WQs (git-fixes).
- RDMA/mana_ib: Use struct mana_ib_queue for CQs (git-fixes).
- RDMA/mana_ib: Introduce helpers to create and destroy mana queues (git-fixes).
- net: mana: Avoid open coded arithmetic (git-fixes).
- RDMA/mana_ib: Prefer struct_size over open coded arithmetic (git-fixes).
- net: mana: Add flex array to struct mana_cfg_rx_steer_req_v2 (git-fixes).
- hv/hv_kvp_daemon: Handle IPv4 and Ipv6 combination for keyfile format (git-fixes).
- hv: vmbus: Convert sprintf() family to sysfs_emit() family (git-fixes).
- mshyperv: Introduce hv_numa_node_to_pxm_info() (git-fixes).
- x86/hyperv: Cosmetic changes for hv_apic.c (git-fixes).
- x86/hyperv: Use Hyper-V entropy to seed guest random number generator (git-fixes).
- x86/hyperv: Cosmetic changes for hv_spinlock.c (git-fixes).
- hyperv-tlfs: Rename some HV_REGISTER_* defines for consistency (git-fixes).
- mshyperv: Introduce hv_get_hypervisor_version function (git-fixes).
- hyperv-tlfs: Change prefix of generic HV_REGISTER_* MSRs to HV_MSR_* (git-fixes).
- RDMA/mana_ib: Introduce mana_ib_install_cq_cb helper function (git-fixes).
- RDMA/mana_ib: Introduce mana_ib_get_netdev helper function (git-fixes).
- RDMA/mana_ib: Introduce mdev_to_gc helper function (git-fixes).
- net: mana: Assigning IRQ affinity on HT cores (git-fixes).
- net: mana: add a function to spread IRQs per CPUs (git-fixes).
- cpumask: define cleanup function for cpumasks (git-fixes).
- cpumask: add cpumask_weight_andnot() (git-fixes).
- Drivers: hv: vmbus: make hv_bus const (git-fixes).
- x86/hyperv: Make encrypted/decrypted changes safe for load_unaligned_zeropad() (git-fixes).
- x86/mm: Regularize set_memory_p() parameters and make non-static (git-fixes).
- x86/hyperv: Use slow_virt_to_phys() in page transition hypervisor callback (git-fixes).
- x86/apic: Drop apic::delivery_mode (git-fixes).
- PCI: hv: Annotate struct hv_dr_state with __counted_by (git-fixes).
- net: mana: Use xdp_set_features_flag instead of direct assignment (git-fixes).
- net: mana: Annotate struct hwc_dma_buf with __counted_by (git-fixes).
- net: mana: Annotate struct mana_rxq with __counted_by (git-fixes).
- hv_balloon: Update the balloon driver to use the SBRM API (git-fixes).
- clocksource: hyper-v: Provide noinstr sched_clock() (git-fixes).
- commit 96a4519
* Thu Oct 17 2024 jlee@suse.com
- thermal: core: Do not fail cdev registration because of invalid initial state (jsc#PED-11164).
- commit 2f669d1
* Thu Oct 17 2024 jroedel@suse.de
- Refresh
  patches.suse/iommu-arm-smmu-Convert-to-domain_alloc_paging.
- commit 559fa76
* Thu Oct 17 2024 jroedel@suse.de
- crypto: qat - add heartbeat error simulator (jsc#PED-9963).
- Update config files.
- commit 40c188c
* Thu Oct 17 2024 jroedel@suse.de
- crypto: qat - add support for 420xx devices (jsc#PED-9963).
- Update config files.
- supported.conf: Add additional QAT module
- commit c848fc2
* Thu Oct 17 2024 jroedel@suse.de
- crypto: qat - Remove trailing space after \n newline
  (jsc#PED-9963).
- crypto: qat - fix "Full Going True" macro definition
  (jsc#PED-9963).
- crypto: qat - Use static_assert() to check struct sizes
  (jsc#PED-9963).
- crypto: qat - allow disabling SR-IOV VFs (jsc#PED-9963).
- crypto: qat - ensure correct order in VF restarting handler
  (jsc#PED-9963).
- crypto: qat - fix recovery flow for VFs (jsc#PED-9963).
- crypto: qat - disable IOV in adf_dev_stop() (jsc#PED-9963).
- crypto: qat - preserve ADF_GENERAL_SEC (jsc#PED-9963).
- crypto: qat - initialize user_input.lock for rate_limiting
  (jsc#PED-9963).
- crypto: qat - make adf_ctl_class constant (jsc#PED-9963).
- crypto: qat - Fix typo (jsc#PED-9963).
- crypto: qat - fix linking errors when PCI_IOV is disabled
  (jsc#PED-9963).
- crypto: qat - validate slices count returned by FW
  (jsc#PED-9963).
- crypto: qat - improve error message in adf_get_arbiter_mapping()
  (jsc#PED-9963).
- crypto: qat - implement dh fallback for primes > 4K
  (jsc#PED-9963).
- crypto: qat - Fix spelling mistake "Invalide" -> "Invalid"
  (jsc#PED-9963).
- crypto: qat - Avoid -Wflex-array-member-not-at-end warnings
  (jsc#PED-9963).
- crypto: qat - implement interface for live migration
  (jsc#PED-9963).
- crypto: qat - add interface for live migration (jsc#PED-9963).
- crypto: qat - add bank save and restore flows (jsc#PED-9963).
- crypto: qat - expand CSR operations for QAT GEN4 devices
  (jsc#PED-9963).
- crypto: qat - rename get_sla_arr_of_type() (jsc#PED-9963).
- crypto: qat - relocate CSR access code (jsc#PED-9963).
- crypto: qat - move PFVF compat checker to a function
  (jsc#PED-9963).
- crypto: qat - relocate and rename 4xxx PF2VM definitions
  (jsc#PED-9963).
- crypto: qat - adf_get_etr_base() helper (jsc#PED-9963).
- crypto: qat - make ring to service map common for QAT GEN4
  (jsc#PED-9963).
- crypto: qat - fix ring to service map for dcc in 420xx
  (jsc#PED-9963).
- crypto: qat - fix comment structure (jsc#PED-9963).
- crypto: qat - remove unnecessary description from comment
  (jsc#PED-9963).
- crypto: qat - uninitialized variable in
  adf_hb_error_inject_write() (jsc#PED-9963).
- crypto: qat - improve aer error reset handling (jsc#PED-9963).
- crypto: qat - limit heartbeat notifications (jsc#PED-9963).
- crypto: qat - add auto reset on error (jsc#PED-9963).
- crypto: qat - add fatal error notification (jsc#PED-9963).
- crypto: qat - re-enable sriov after pf reset (jsc#PED-9963).
- crypto: qat - update PFVF protocol for recovery (jsc#PED-9963).
- crypto: qat - disable arbitration before reset (jsc#PED-9963).
- crypto: qat - add fatal error notify method (jsc#PED-9963).
- crypto: qat - use kcalloc_node() instead of kzalloc_node()
  (jsc#PED-9963).
- crypto: qat - avoid memcpy() overflow warning (jsc#PED-9963).
- crypto: qat - fix arbiter mapping generation algorithm for
  QAT 402xx (jsc#PED-9963).
- crypto: qat - generate dynamically arbiter mappings
  (jsc#PED-9963).
- crypto: qat - add support for ring pair level telemetry
  (jsc#PED-9963).
- crypto: qat - add support for device telemetry (jsc#PED-9963).
- crypto: qat - add admin msgs for telemetry (jsc#PED-9963).
- crypto: qat - include pci.h for GET_DEV() (jsc#PED-9963).
- crypto: qat - move fw config related structures (jsc#PED-9963).
- crypto: qat - relocate portions of qat_4xxx code (jsc#PED-9963).
- crypto: qat - change signature of uof_get_num_objs()
  (jsc#PED-9963).
- seq_file: add helper macro to define attribute for rw file
  (jsc#PED-9963).
- commit ec26923
* Thu Oct 17 2024 tiwai@suse.de
- dmaengine: avoid non-constant format string (jsc#PED-10356).
- commit 19ec5b4
* Thu Oct 17 2024 tiwai@suse.de
- Update patch reference for Intel MFD patch (jsc#PED-10104 jsc#PED-10230)
- commit cb36d79
* Thu Oct 17 2024 tiwai@suse.de
- dmaengine: idxd: Add new DSA and IAA device IDs for Diamond
  Rapids platform (jsc#PED-10356).
- dmaengine: idxd: Add a new DSA device ID for Granite Rapids-D
  platform (jsc#PED-10356).
- dmaengine: idxd: Convert comma to semicolon (jsc#PED-10356).
- commit 2aedf4e
* Thu Oct 17 2024 tiwai@suse.de
- mfd: intel-lpss: Add Intel Panther Lake LPSS PCI IDs
  (jsc#PED-10104).
- mfd: intel-lpss: Add Intel Arrow Lake-H LPSS PCI IDs
  (jsc#PED-10104).
- mfd: intel-lpss: Rename SPI intel_lpss_platform_info structs
  (jsc#PED-10104).
- mfd: intel-lpss: Switch over to MSI interrupts (jsc#PED-10104).
- mfd: intel-lpss: Introduce QUIRK_CLOCK_DIVIDER_UNITY for XPS
  9530 (jsc#PED-10104).
- mfd: intel-lpss: Switch to generalized quirk table
  (jsc#PED-10104).
- mfd: intel-lpss: Don't fail probe on success of
  pci_alloc_irq_vectors() (jsc#PED-10104).
- mfd: intel-lpss: Use device_get_match_data() (jsc#PED-10104).
- commit aa36b3c
* Thu Oct 17 2024 krisman@suse.de
- io_uring/sqpoll: do not put cpumask on stack (git-fixes).
- io_uring/sqpoll: retain test for whether the CPU is valid
  (git-fixes).
- commit ff84c2d
* Thu Oct 17 2024 tiwai@suse.de
- mfd: intel-lpss: Use PCI APIs instead of dereferencing
  (jsc#PED-10104).
- Refresh
  patches.suse/mfd-intel-lpss-Revert-Add-missing-check-for-platform.patch.
- commit d5b14ab
* Thu Oct 17 2024 rgoldwyn@suse.com
- config: Disable security/landlock
  References: jsc#PED-10440
- commit 2d816c5
* Thu Oct 17 2024 jroedel@suse.de
- vfio/nvgrace-gpu: Add vfio pci variant module for grace hopper
  (jsc#PED-10968).
- Update config files.
- supported.conf: Mark grace hopper vfio pci module unsupported
- commit c530dba
* Thu Oct 17 2024 jlee@suse.com
- thermal: core: Resume thermal zones asynchronously (jsc#PED-11164).
- thermal: netlink: Use for_each_trip() in thermal_genl_cmd_tz_get_trip() (jsc#PED-11164).
- thermal: trip: Use for_each_trip() in __thermal_zone_set_trips() (jsc#PED-11164).
  Refresh
  patches.suse/Revert-thermal-core-Don-t-update-trip-points-inside-.patch.
- thermal: gov_power_allocator: Rearrange initialization of local variables (jsc#PED-11164).
- thermal: gov_power_allocator: Remove excessive local variables (jsc#PED-11164).
- thermal: gov_power_allocator: Use shorter paths to access data when possible (jsc#PED-11164).
- thermal: gov_power_allocator: Rearrange local variables (jsc#PED-11164).
- thermal: gov_power_allocator: Check the cooling devices only for trip_max (jsc#PED-11164).
- thermal: gov_power_allocator: Set up trip points earlier (jsc#PED-11164).
- thermal: gov_power_allocator: Rename trip_max_desired_temperature (jsc#PED-11164).
- thermal: core: Add trip thresholds for trip crossing detection (jsc#PED-11164).
  Refresh
  patches.suse/thermal-core-Fix-thermal-zone-suspend-resume-synchro.patch.
- thermal/drivers/mediatek/lvts_thermal: Update calibration data documentation (jsc#PED-11164).
- thermal/drivers/mediatek/lvts_thermal: Add mt8192 support (jsc#PED-11164).
- thermal/drivers/mediatek/lvts_thermal: Add suspend and resume (jsc#PED-11164).
- thermal/drivers/max77620: Remove duplicate error message (jsc#PED-11164).
- thermal/drivers/mediatek/lvts_thermal: Fix error check in lvts_debugfs_init() (jsc#PED-11164).
- thermal/drivers/imx8mm_thermal: Fix function pointer declaration by adding identifier name (jsc#PED-11164).
- thermal/drivers/mediatek/lvts_thermal: Add mt7988 support (jsc#PED-11164).
- thermal/drivers/mediatek/lvts_thermal: Make coeff configurable (jsc#PED-11164).
  Refresh
  patches.suse/thermal-drivers-mediatek-lvts_thermal-Return-error-i.patch.
- thermal: int340x: processor_thermal: Enable power floor support (jsc#PED-11164).
  Refresh
  patches.suse/thermal-int340x-processor_thermal-Add-Lunar-Lake-M-P.patch.
  patches.suse/thermal-intel-int340x-Add-DLVR-support-for-Lunar-Lak.patch.
  patches.suse/thermal-intel-int340x-Support-MSI-interrupt-for-Luna.patch.
  patches.suse/thermal-intel-int340x-Enable-WLT-and-power-floor-sup.patch.
- thermal: core: Pass trip pointer to governor throttle callback (jsc#PED-11164).
  Refresh
  patches.suse/thermal-core-Fix-thermal-zone-suspend-resume-synchro.patch.
  patches.suse/thermal-core-Add-governor-callback-for-thermal-zone-.patch.
- thermal: gov_step_wise: Fold update_passive_instance() into its caller (jsc#PED-11164).
- thermal: gov_power_allocator: Use trip pointers instead of trip indices (jsc#PED-11164).
- thermal: gov_fair_share: Rearrange get_trip_level() (jsc#PED-11164).
- thermal: core: Drop thermal_zone_device_exec() (jsc#PED-11164).
  Refresh
  patches.suse/thermal-core-Initialize-poll_queue-in-thermal_zone_d.patch.
- thermal: amlogic: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: uniphier: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: ti-bandgap: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: tegra-bpmp: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: soctherm: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: stm: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: sprd: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: spear: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: exynos_tmu: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: rzg2l: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: rockchip: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: rcar: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: rcar_gen3: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: tsens: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: lvts: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: kirkwood: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: k3_j72xx_bandgap: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: k3_bandgap: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: imx: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: imx8mm: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: hisi: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: dove: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: da9062: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: ns: Convert to platform remove callback returning void (jsc#PED-11164).
- thermal: armada: Convert to platform remove callback returning void (jsc#PED-11164).
- drivers: thermal: tsens: Annotate struct tsens_priv with __counted_by (jsc#PED-11164).
- commit 312ab8f
* Thu Oct 17 2024 tiwai@suse.de
- blacklist.conf: Move DRM entries to SP7 section
- commit 407e362
* Thu Oct 17 2024 jlee@suse.com
- thermal/debugfs: Fix the NULL vs IS_ERR() confusion in debugfs_create_dir() (jsc#PED-11164).
- commit 05f6516
* Thu Oct 17 2024 nmorey@suse.com
- IB/hfi1: Constify struct flag_table (jsc#PED-9948)
- commit a77f63d
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/hfi1: Constify struct mmu_rb_ops (jsc#PED-9948)
- commit 85c28f0
* Thu Oct 17 2024 nmorey@suse.com
- IB/hfi1: Do not use custom stat allocator (jsc#PED-9948)
- commit bc1aa5d
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/hfi1: Use RMW accessors for changing LNKCTL2 (jsc#PED-9948)
- commit 24f0928
* Thu Oct 17 2024 nmorey@suse.com
- IB/hfi1: allocate dummy net_device dynamically (jsc#PED-9948)
- commit 2d3356d
* Thu Oct 17 2024 nmorey@suse.com
- IB/hfi1: fix spellos and kernel-doc (jsc#PED-9948)
- commit 0189799
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/ocrdma: Don't inline statistics functions (jsc#PED-9949)
- commit d7adc79
* Thu Oct 17 2024 nmorey@suse.com
- vsock/virtio: use GFP_ATOMIC under RCU read lock (jsc#PED-11028)
- commit a44d114
* Thu Oct 17 2024 nmorey@suse.com
- vsock/virtio: avoid queuing packets when intermediate queue is empty (jsc#PED-11028)
- commit ed2d9ff
* Thu Oct 17 2024 nmorey@suse.com
- vsock/virtio: refactor virtio_transport_send_pkt_work (jsc#PED-11028)
- commit d899b3e
* Thu Oct 17 2024 jroedel@suse.de
- vfio/platform: Disable virqfds on cleanup (jsc#PED-10968).
- Refresh
  patches.suse/vfio-platform-Create-persistent-IRQ-handlers.
- commit 425114d
* Thu Oct 17 2024 nmorey@suse.com
- vsock: fix recursive ->recvmsg calls (jsc#PED-11028)
- commit 8cf1ab4
* Thu Oct 17 2024 jroedel@suse.de
- iommu: Separate SVA and IOPF (jsc#PED-10968).
- Update config files.
- commit 751b76b
* Thu Oct 17 2024 nmorey@suse.com
- vsock/virtio: add SIOCOUTQ support for all virtio based transports (jsc#PED-11028)
- commit be9806d
* Thu Oct 17 2024 vbabka@suse.cz
- mm: avoid leaving partial pfn mappings around in error case
  (CVE-2024-47674 bsc#1231673).
- commit 83d1625
* Thu Oct 17 2024 nmorey@suse.com
- vsock: add support for SIOCOUTQ ioctl (jsc#PED-11028)
- commit 5dfa556
* Thu Oct 17 2024 jroedel@suse.de
- iommu/amd: Refactor helper function for setting / clearing GCR3
  (jsc#PED-10968).
- Refresh
  patches.suse/iommu-amd-Allocate-the-page-table-root-using-GFP_KER.patch.
- commit c5162ca
* Thu Oct 17 2024 jroedel@suse.de
- iommu/arm-smmu: Use the correct type in
  nvidia_smmu_context_fault() (jsc#PED-10968).
- iommufd: Add config needed for iommufd_fail_nth (jsc#PED-10968).
- iommu/amd: Change log message severity (jsc#PED-10968).
- iommu/amd: Do not enable SNP when V2 page table is enabled
  (jsc#PED-10968).
- iommu/amd: Fix possible irq lock inversion dependency issue
  (jsc#PED-10968).
- iommu: Validate the PASID in iommu_attach_device_pasid()
  (jsc#PED-10968).
- iommu/arm-smmu-v3: Fix access for STE.SHCFG (jsc#PED-10968).
- iommu/arm-smmu-v3: Add cpu_to_le64() around STRTAB_STE_0_V
  (jsc#PED-10968).
- vfio/pci: Lock external INTx masking ops (jsc#PED-10968).
- vfio/pds: Refactor/simplify reset logic (jsc#PED-10968).
- vfio/pds: Make sure migration file isn't accessed after reset
  (jsc#PED-10968).
- vfio/platform: Convert to platform remove callback returning
  void (jsc#PED-10968).
- vfio/mlx5: Enforce PRE_COPY support (jsc#PED-10968).
- vfio/mbochs: make mbochs_class constant (jsc#PED-10968).
- vfio/mdpy: make mdpy_class constant (jsc#PED-10968).
- hisi_acc_vfio_pci: Remove the deferred_reset logic
  (jsc#PED-10968).
- Revert "vfio/type1: Unpin zero pages" (jsc#PED-10968).
- vfio/nvgrace-gpu: Convey kvm to map device memory region as
  noncached (jsc#PED-10968).
- vfio: amba: Rename pl330_ids to vfio_amba_ids[] (jsc#PED-10968).
- vfio/pds: Always clear the save/restore FDs on reset
  (jsc#PED-10968).
- vfio/pci: rename and export range_intersect_range
  (jsc#PED-10968).
- vfio/pci: rename and export do_io_rw() (jsc#PED-10968).
- MAINTAINERS: Re-alphabetize VFIO (jsc#PED-10968).
- vfio/mlx5: Let firmware knows upon leaving PRE_COPY back to
  RUNNING (jsc#PED-10968).
- vfio/mlx5: Block incremental query upon migf state error
  (jsc#PED-10968).
- vfio/mlx5: Handle the EREMOTEIO error upon the SAVE command
  (jsc#PED-10968).
- vfio/mlx5: Add support for tracker object change event
  (jsc#PED-10968).
- net/mlx5: Add the IFC related bits for query tracker
  (jsc#PED-10968).
- vfio/pci: WARN_ON driver_override kasprintf failure
  (jsc#PED-10968).
- vfio: Convey kvm that the vfio-pci device is wc safe
  (jsc#PED-10968).
- KVM: arm64: Set io memory s2 pte as normalnc for vfio pci device
  (jsc#PED-10968).
- mm: Introduce new flag to indicate wc safe (jsc#PED-10968).
- KVM: arm64: Introduce new flag for non-cacheable IO memory
  (jsc#PED-10968).
- iommu/dma: Document min_align_mask assumption (jsc#PED-10968).
- iommu: re-use local fwnode variable in iommu_ops_from_fwnode()
  (jsc#PED-10968).
- iommu: constify fwnode in iommu_ops_from_fwnode()
  (jsc#PED-10968).
- iommu: constify of_phandle_args in xlate (jsc#PED-10968).
- iommu: constify pointer to bus_type (jsc#PED-10968).
- iommu: Make iommu_report_device_fault() return void
  (jsc#PED-10968).
- iommu: Make iopf_group_response() return void (jsc#PED-10968).
- iommu: Track iopf group instead of last fault (jsc#PED-10968).
- iommu: Improve iopf_queue_remove_device() (jsc#PED-10968).
- iommu: Use refcount for fault data access (jsc#PED-10968).
- iommu: Refine locking for per-device fault data management
  (jsc#PED-10968).
- iommu: Make iommu_queue_iopf() more generic (jsc#PED-10968).
- iommu: Prepare for separating SVA and IOPF (jsc#PED-10968).
- iommu: Merge iommu_fault_event and iopf_fault (jsc#PED-10968).
- iommu: Remove iommu_register_device_fault_handler()
  (jsc#PED-10968).
- iommu: Merge iopf_device_param into iommu_fault_param
  (jsc#PED-10968).
- iommu: Cleanup iopf data structure definitions (jsc#PED-10968).
- iommu: Remove unrecoverable fault data (jsc#PED-10968).
- iommu/arm-smmu-v3: Remove unrecoverable faults reporting
  (jsc#PED-10968).
- iommu: Move iommu fault data to linux/iommu.h (jsc#PED-10968).
- iommu/iova: use named kmem_cache for iova magazines
  (jsc#PED-10968).
- iommu/iova: Reorganise some code (jsc#PED-10968).
- iommu/iova: Tidy up iova_cache_get() failure (jsc#PED-10968).
- iommu/amd: Fix sleeping in atomic context (jsc#PED-10968).
- iommu/amd: Introduce per-device domain ID to fix potential
  TLB aliasing issue (jsc#PED-10968).
- iommu/amd: Remove unused GCR3 table parameters from struct
  protection_domain (jsc#PED-10968).
- iommu/amd: Rearrange device flush code (jsc#PED-10968).
- iommu/amd: Remove unused flush pasid functions (jsc#PED-10968).
- iommu/amd: Refactor GCR3 table helper functions (jsc#PED-10968).
- iommu/amd: Refactor protection_domain helper functions
  (jsc#PED-10968).
- iommu/amd: Refactor attaching / detaching device functions
  (jsc#PED-10968).
- iommu: Introduce iommu_group_mutex_assert() (jsc#PED-10968).
- iommu/amd: Rearrange GCR3 table setup code (jsc#PED-10968).
- iommu/amd: Add support for device based TLB invalidation
  (jsc#PED-10968).
- iommu/amd: Use protection_domain.flags to check page table mode
  (jsc#PED-10968).
- iommu/amd: Introduce per-device GCR3 table (jsc#PED-10968).
- iommu/amd: Introduce struct protection_domain.pd_mode
  (jsc#PED-10968).
- iommu/amd: Introduce get_amd_iommu_from_dev() (jsc#PED-10968).
- iommu/amd: Enable Guest Translation before registering devices
  (jsc#PED-10968).
- iommu/amd: Pass struct iommu_dev_data to set_dte_entry()
  (jsc#PED-10968).
- iommu/amd: Remove EXPORT_SYMBOL for perf counter related
  functions (jsc#PED-10968).
- iommu/amd: Remove redundant error check in
  amd_iommu_probe_device() (jsc#PED-10968).
- iommu/amd: Remove duplicate function declarations from
  amd_iommu.h (jsc#PED-10968).
- iommu/amd: Remove unused APERTURE_* macros (jsc#PED-10968).
- iommu/amd: Remove unused IOVA_* macro (jsc#PED-10968).
- iommu/amd: Remove unused PPR_* macros (jsc#PED-10968).
- iommu/vt-d: Remove scalabe mode in domain_context_clear_one()
  (jsc#PED-10968).
- iommu/vt-d: Remove scalable mode context entry setup from
  attach_dev (jsc#PED-10968).
- iommu/vt-d: Setup scalable mode context entry in probe path
  (jsc#PED-10968).
- iommu/vt-d: Merge intel_svm_bind_mm() into its caller
  (jsc#PED-10968).
- iommu/vt-d: Remove initialization for dynamically heap-allocated
  rcu_head (jsc#PED-10968).
- iommu/vt-d: Remove treatment for revoking PASIDs with pending
  page faults (jsc#PED-10968).
- iommu/vt-d: Add the document for Intel IOMMU debugfs
  (jsc#PED-10968).
- iommu/vt-d: Use kcalloc() instead of kzalloc() (jsc#PED-10968).
- iommu/vt-d: Remove INTEL_IOMMU_BROKEN_GFX_WA (jsc#PED-10968).
- iommu/arm-smmu-v3: Convert to domain_alloc_paging()
  (jsc#PED-10968).
- iommu/arm-smmu-v3: Pass arm_smmu_domain and arm_smmu_device
  to finalize (jsc#PED-10968).
- iommu/arm-smmu-v3: Use the identity/blocked domain during
  release (jsc#PED-10968).
- iommu/arm-smmu-v3: Add a global static BLOCKED domain
  (jsc#PED-10968).
- iommu/arm-smmu-v3: Add a global static IDENTITY domain
  (jsc#PED-10968).
- iommu/arm-smmu-v3: Remove arm_smmu_master->domain
  (jsc#PED-10968).
- iommu/arm-smmu-v3: Pass smmu_domain to arm_enable/disable_ats()
  (jsc#PED-10968).
- iommu/arm-smmu-v3: Put writing the context descriptor in the
  right order (jsc#PED-10968).
- iommu/arm-smmu-v3: Do not change the STE twice during
  arm_smmu_attach_dev() (jsc#PED-10968).
- iommu/arm-smmu-v3: Compute the STE only once for each master
  (jsc#PED-10968).
- iommu/arm-smmu-v3: Hold arm_smmu_asid_lock during all of
  attach_dev (jsc#PED-10968).
- iommu/arm-smmu-v3: Build the whole STE in
  arm_smmu_make_s2_domain_ste() (jsc#PED-10968).
- iommu/arm-smmu-v3: Move the STE generation for S1 and S2
  domains into functions (jsc#PED-10968).
- iommu/arm-smmu-v3: Consolidate the STE generation for
  abort/bypass (jsc#PED-10968).
- iommu/arm-smmu-v3: Make STE programming independent of the
  callers (jsc#PED-10968).
- dt-bindings: arm-smmu: Document SM8650 GPU SMMU (jsc#PED-10968).
- dt-bindings: arm-smmu: Fix SM850 GPU SMMU 'if' condition
  (jsc#PED-10968).
- dt-bindings: arm-smmu: Add QCM2290 GPU SMMU (jsc#PED-10968).
- iommu/arm-smmu-qcom: Add X1E80100 MDSS compatible
  (jsc#PED-10968).
- iommu/ipmmu-vmsa: Minor cleanups (jsc#PED-10968).
- iommu/mtk_iommu: Use devm_kcalloc() instead of devm_kzalloc()
  (jsc#PED-10968).
- commit 350b5a9
* Thu Oct 17 2024 jlee@suse.com
- thermal/debugfs: Pass cooling device state to thermal_debug_cdev_add() (jsc#PED-11164).
- thermal/debugfs: Create records for cdev states as they get used (jsc#PED-11164).
- thermal/debugfs: Prevent use-after-free from occurring after cdev removal (jsc#PED-11164).
- thermal: core: Move initial num_trips assignment before memcpy() (jsc#PED-11164).
- ACPI: property: Polish ignoring bad data nodes (jsc#PED-11164).
  Refresh
  patches.suse/ACPI-scan-Ignore-camera-graph-port-nodes-on-all-Dell.patch.
- commit e2b6ac4
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Avoid CPU lockups due fifo occupancy check loop (git-fixes)
- commit 21fb93d
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix the GID table length (git-fixes)
- commit 6a0779e
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix a bug while setting up Level-2 PBL pages (git-fixes)
- commit d91ede3
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Change the sequence of updating the CQ toggle value (git-fixes)
- commit 414cbde
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Return more meaningful error (git-fixes)
- commit 6755798
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix incorrect dereference of srq in async event (git-fixes)
- commit 4e1ef61
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix out of bound check (git-fixes)
- commit d8d1339
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix the max CQ WQEs for older adapters (git-fixes)
- commit 598626b
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/srpt: Make slab cache names unique (git-fixes)
- commit 29c0fcb
* Thu Oct 17 2024 pjakobsson@suse.de
- drm/xe: Use DRM GPUVM helpers for external- and evicted objects (drm-backport-placeholder).
- commit 5268d6f
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/irdma: Fix misspelling of "accept*" (git-fixes)
- commit 2566da7
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/cxgb4: Fix RDMA_CM_EVENT_UNREACHABLE error for iWARP (git-fixes)
- commit 89fa27f
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/core: Fix ENODEV error for iWARP test over vlan (git-fixes)
- commit 4c15511
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Add a check for memory allocation (git-fixes)
- commit abea295
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix incorrect AVID type in WQE structure (git-fixes)
- commit ae91db1
* Thu Oct 17 2024 nmorey@suse.com
- RDMA/bnxt_re: Fix a possible memory leak (git-fixes)
- commit 77c3f34
* Thu Oct 17 2024 pjakobsson@suse.de
- drm/xe: Convert remaining instances of ttm_eu_reserve_buffers to drm_exec (drm-backport-placeholder).
- commit 74f3a99
* Thu Oct 17 2024 jlee@suse.com
- thermal: core: Store zone trips table in struct thermal_zone_device (jsc#PED-11164).
- thermal/debugfs: Add thermal cooling device debugfs information (jsc#PED-11164).
  Update config files.
  CONFIG_THERMAL_DEBUGFS is not set
- commit 5d4b39f
* Thu Oct 17 2024 jlee@suse.com
- platform/x86: ideapad-laptop: Make the scope_guard() clear of its scope (jsc#PED-11164).
- ACPI: scan: Ignore camera graph port nodes on all Dell Tiger, Alder and Raptor Lake models (jsc#PED-11164).
- ACPI: thermal: Register thermal zones without valid trip points (jsc#PED-11164).
- ACPI: property: Ignore bad graph port nodes on Dell XPS 9315 (jsc#PED-11164).
- ACPI: utils: Make acpi_handle_path() not static (jsc#PED-11164).
- commit 42c06ee
* Wed Oct 16 2024 krisman@suse.de
- io_uring/rw: fix cflags posting for single issue multishot read
  (git-fixes).
- commit 320c7ee
* Wed Oct 16 2024 krisman@suse.de
- io_uring/net: harden multishot termination case for recv
  (git-fixes).
- commit 6529e65
* Wed Oct 16 2024 krisman@suse.de
- blacklist.conf: Disable IORING_OP_FUTEX fix
  We do not support this io_uring operation.
- commit add0e5f
* Wed Oct 16 2024 krisman@suse.de
- io_uring: check for presence of task_work rather than
  TIF_NOTIFY_SIGNAL (git-fixes).
- commit 5b92400
* Wed Oct 16 2024 krisman@suse.de
- io_uring/io-wq: inherit cpuset of cgroup in io worker
  (git-fixes).
- commit 474a07e
* Wed Oct 16 2024 krisman@suse.de
- io_uring/io-wq: do not allow pinning outside of cpuset
  (git-fixes).
- commit e99d8a8
* Wed Oct 16 2024 krisman@suse.de
- io_uring/rw: treat -EOPNOTSUPP for IOCB_NOWAIT like -EAGAIN
  (git-fixes).
- io_uring/sqpoll: do not allow pinning outside of cpuset
  (git-fixes).
- commit 37d0dce
* Wed Oct 16 2024 pjakobsson@suse.de
- Delete patches.suse/0001-drm-amd-display-Disable-DMCUB-timeout-for-DCN35.patch.
- Delete patches.suse/0001-drm-amd-display-Disable-idle-reallow-as-part-of-comm.patch.
- Delete patches.suse/drm-amd-display-Wake-DMCUB-before-executing-GPINT-co.patch.
- commit b9dabc6
* Wed Oct 16 2024 krisman@suse.de
- io_uring/eventfd: move to more idiomatic RCU free usage
  (git-fixes).
- commit 4e262c3
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 7a51a2aa2384 drm/i915/dp: Fix DSC state HW readout for SST connectors
- commit 641ba13
* Wed Oct 16 2024 jack@suse.cz
- udf: Avoid excessive partition lengths (bsc#1230773
  CVE-2024-46777).
- commit ec61258
* Wed Oct 16 2024 jack@suse.cz
- fsnotify: clear PARENT_WATCHED flags lazily (bsc#1231439
  CVE-2024-47660).
- commit 133a7e9
* Wed Oct 16 2024 oneukum@suse.com
- media: ipu3-cio2: rename ipu3-cio2-main.c back to ipu3-cio2.c
  (jsc#PED-10837).
- Refresh patches.suse/media-ipu3-cio2-Request-IRQ-earlier.patch.
- Refresh patches.suse/media-pci-ipu3-cio2-Initialise-timing-struct-to-avoi.patch
- commit 7b45c98
* Wed Oct 16 2024 oneukum@suse.com
- media: ipu-bridge: use IPU_MAX_PORTS for bridge instead of
  CIO2_NUM_PORTS (jsc#PED-10837).
- commit bdf3f5f
* Wed Oct 16 2024 davide.benini@suse.com
- netem: fix return value if duplicate enqueue fails
  (CVE-2024-45016 bsc#1230429).
- commit 8c9c269
* Wed Oct 16 2024 oneukum@suse.com
- media: ipu3-cio2: Fix container_of() macro wrapper arguments
  (jsc#PED-10837).
- commit 30ac6b4
* Wed Oct 16 2024 oneukum@suse.com
- media: pci: ipu3-cio2: Obtain remote pad from endpoint
  (jsc#PED-10837).
- commit 1f8b97d
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 42465603a310 drm/xe/guc_submit: fix xa_store() error checking
- blacklist.conf: e863781abe4f drm/xe/ct: fix xa_store() error checking
- commit c4511f8
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: db7f92af6261 drm/xe/ct: prevent UAF in send_recv()
- blacklist.conf: d7d7b947a4fa drm/amdkfd: Fix an eviction fence leak
- commit 70f0241
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 7257d9c9a3c6 drm/xe: Prevent null pointer access in xe_migrate_copy
- commit 438e015
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 74231870cf49 drm/xe/vm: move xa_alloc to prevent UAF
- blacklist.conf: 1b30f87e088b drm/xe: Resume TDR after GT reset
- commit bf5abb7
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 2d2be279f1ca drm/xe: fix UAF around queue destruction
- blacklist.conf: cffa8e83df9f drm/xe: Restore pci state upon resume
- commit e36253b
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 440d52b370b0 drm/sched: Fix dynamic job-flow control race
- commit 6144c9a
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 69bbe3adf36d drm/xe/client: add missing bo locking in show_meminfo()
- blacklist.conf: 99b1f7493bfa drm/xe/client: fix deadlock in show_meminfo()
- commit e542474
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: ec2231b8dd2d drm/i915/dp: Fix AUX IO power enabling for eDP PSR
- blacklist.conf: 94c4aa266111 drm/xe/client: add missing bo locking in show_meminfo()
- commit ffeddb9
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 9bd7ff293fc8 drm/xe/client: fix deadlock in show_meminfo()
- commit 3b70916
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: dd10595c3232 drm/xe/display: fix compat IS_DISPLAY_STEP() range end
- blacklist.conf: fe13fd683375 drm/xe/pcode: Treat pcode as per-tile rather than per-GT
- commit 3ed2b85
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 529bf8d1118b drm/xe/gsc: Do not attempt to load the GSC multiple times
- blacklist.conf: 3f6b2f60b463 drm/imagination: Free pvr_vm_gpuva after unlink
- commit 9a15fe3
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: bf758226c7e6 drm/xe: Invalidate media_gt TLBs in PT code
- commit 1b4a4e5
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 3034cc8107b8 drm/xe/pcode: Treat pcode as per-tile rather than per-GT
- blacklist.conf: 2160f6f6e3cf drm/xe/gsc: Do not attempt to load the GSC multiple times
- commit 918b8d1
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 59d237c8a241 drm/xe/hwmon: Fix WRITE_I1 param from u32 to u16
- commit 34e768f
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: a7f657097e96 drm/xe/hwmon: Fix WRITE_I1 param from u32 to u16
- commit f358afa
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 01cc7b2e8a59 Revert "drm/panel-edp: Add SDC ATNA45AF01"
- commit 71ba08b
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 1eb52589a299 drm/xe: Invalidate media_gt TLBs
- commit f20f9e6
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 453afb1a4399 drm/xe/display: fix compat IS_DISPLAY_STEP() range end
- commit c1ed5d3
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 77cc3f6c58b1 drm/xe: Invalidate media_gt TLBs
- blacklist.conf: 9e7f30563677 drm/xe: Free job before xe_exec_queue_put
- commit 0408b40
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: dd3e840a33b5 drm/xe: Drop HW fence pointer to HW fence ctx
- blacklist.conf: a6f78359ac75 drm/xe: Fix missing workqueue destroy in xe_gt_pagefault
- commit 2f39db2
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 32a42c93b74c drm/xe: Free job before xe_exec_queue_put
- commit daa68fa
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 60db6f540af9 drm/xe: Drop HW fence pointer to HW fence ctx
- blacklist.conf: 7586fc52b14e drm/xe: Fix missing workqueue destroy in xe_gt_pagefault
- commit 0468fa7
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: ddf6492e0e50 drm/xe/display: Make display suspend/resume work on discrete
- blacklist.conf: 730b72480e29 drm/xe: prevent UAF around preempt fence
- commit 7a0b9f7
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 15939ca77d44 drm/xe: Fix tile fini sequence
- commit a1f1e4e
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 7090d7fc969f drm/xe: Move VM dma-resv lock from xe_exec_queue_create to __xe_exec_queue_init
- blacklist.conf: f4b2a0ae1a31 drm/xe: Fix opregion leak
- commit 5a3d3db
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: cb8f81c17531 drm/xe/display: Make display suspend/resume work on discrete
- blacklist.conf: 7116c35aaced drm/xe: prevent UAF around preempt fence
- commit 84e84e8
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 852856e3b6f6 drm/xe: Use reserved copy engine for user binds on faulting devices
- commit e05d33b
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 3396900aa273 drm/xe: Fix tile fini sequence
- blacklist.conf: f002702290fc drm/xe: Hold a PM ref when GT TLB invalidations are inflight
- commit 5309ab5
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 55ea73aacfb9 drm/xe: Build PM into GuC CT layer
- blacklist.conf: ddeb7989a98f drm/xe: Validate user fence during creation
- commit 1f5a78c
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 497d370a644d drm/v3d: Fix out-of-bounds read in
- commit 4fcd586
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 549dd786b61c drm/xe: Move VM dma-resv lock from xe_exec_queue_create to __xe_exec_queue_init
- blacklist.conf: ac3191c5cf47 drm/xe/hwmon: Fix PL1 disable flow in xe_hwmon_power_max_write
- commit 2908dc3
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 4f854a8b1b85 drm/xe: Use dma_fence_chain_free in chain fence unused as a sync
- blacklist.conf: ae02c7b7fea3 drm/xe/rtp: Fix off-by-one when processing rules
- commit 05c8d65
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 929725bd7eb4 drm/atomic: allow no-op FB_ID updates for async flips
- commit c52a86b
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 62b45bab010d drm/test: fix the gem shmem test to map the sg table.
- blacklist.conf: 146458645e50 drm/xe/hwmon: Fix PL1 disable flow in xe_hwmon_power_max_write
- commit a7ca615
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: f85de245c6a8 drm/atomic: Allow userspace to use damage clips with async flips
- blacklist.conf: e0fa4132bfae drm/atomic: Allow userspace to use explicit sync with atomic async flips
- commit 5130580
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 7f7a2da3bf8b drm/xe: Use dma_fence_chain_free in chain fence unused as a sync
- commit 33cf851
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 6f4e43a2f771 drm/xe: Fix opregion leak
- blacklist.conf: fd6797ec50c5 drm/xe/rtp: Fix off-by-one when processing rules
- commit d1c36a1
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: d930c19fdff3 drm/xe: Build PM into GuC CT layer
- blacklist.conf: 0a382f9bc5dc drm/xe: Hold a PM ref when GT TLB invalidations are inflight
- commit 0bb061b
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 0fde907da2d5 drm/xe: Validate user fence during creation
- commit 24d0dd6
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 408c2f14a5d3 drm/xe/exec: Fix minor bug related to xe_sync_entry_cleanup
- commit e50c7d9
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 4ecc24a84d7e drm/v3d: Validate passed in drm syncobj handles in the performance extension
- commit fb68abf
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 023d22e8bb0c drm/v3d: Validate passed in drm syncobj handles in the timestamp extension
- commit a3bcd6d
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 32df4abc44f2 drm/v3d: Fix potential memory leak in the performance extension
- commit 91975ac
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 0e50fcc20bd8 drm/v3d: Fix potential memory leak in the timestamp extension
- blacklist.conf: 6ce9efd12ae8 drm/v3d: Prevent out of bounds access in performance query extensions
- commit f20f468
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 1fe1c66274fb drm/v3d: Fix Indirect Dispatch configuration for V3D 7.1.6 and later
- commit 5a598ae
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: a546b7e4d73c drm/v3d: Validate passed in drm syncobj handles in the performance extension
- blacklist.conf: 8d1276d1b8f7 drm/v3d: Validate passed in drm syncobj handles in the timestamp extension
- commit 611e8e3
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 484de39fa5f5 drm/v3d: Fix potential memory leak in the performance extension
- commit 0751b7e
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 753ce4fea621 drm/v3d: Fix potential memory leak in the timestamp extension
- blacklist.conf: f32b5128d2c4 drm/v3d: Prevent out of bounds access in performance query extensions
- commit 0f2c5fe
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 43a6faa6d9b5 drm/xe/exec: Fix minor bug related to xe_sync_entry_cleanup
- blacklist.conf: 5207c393d3e7 drm/xe: Use write-back caching mode for system memory on DGFX
- commit 2a97f4b
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 01e0cfc994be drm/xe: Use write-back caching mode for system memory on DGFX
- commit d36653a
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 43407254b8a3 mei: vsc: Enhance SPI transfer of IVSC ROM
- blacklist.conf: a896a8a127f4 mei: vsc: Utilize the appropriate byte order swap function
- commit 0842c0a
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: a9e8fe38195a mei: vsc: Prevent timeout error with added delay post-firmware download
- blacklist.conf: 07de60a46ae9 mei: vsc: Enhance IVSC chipset stability during warm reboot
- commit fd8b4b1
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 1f0064702845 drm/xe/mcr: Avoid clobbering DSS steering
- commit dd46a16
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: fc932f519266 drm/xe: fix error handling in xe_migrate_update_pgtables
- blacklist.conf: 4f82ac610278 drm/xe/mcr: Avoid clobbering DSS steering
- commit 2d8aa0b
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: c96140000915 drm/amd/display: Add null check before access structs
- blacklist.conf: ce6b63336f79 drm/xe: fix error handling in xe_migrate_update_pgtables
- commit e1dcae0
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: e2654a4453ba drm/amd/display: Remove redundant idle optimization check
- commit 0959766
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 2470b141bfae drm/xe: move disable_c6 call
- blacklist.conf: b5e3a9b83f35 drm/xe: flush engine buffers before signalling user fence on all engines
- commit 4d11d54
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 7c877115da41 drm/xe/xe_gt_idle: use GT forcewake domain assertion
- blacklist.conf: 51ee1f29a9ac drm/i915/psr: Print Panel Replay status instead of frame lock status
- commit 014fee3
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 6800e63cf97b drm/xe: move disable_c6 call
- commit 693ef8a
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 21b708554648 drm/xe/xe_gt_idle: use GT forcewake domain assertion
- blacklist.conf: aeacc39e2088 drm/msm/dp: fix runtime_pm handling in dp_wait_hpd_asserted
- commit 6407418
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 6ed817592638 drm/msm/dpu: drop duplicate drm formats from wb2_formats arrays
- blacklist.conf: 3ad7d18c5dad drm/xe: flush engine buffers before signalling user fence on all engines
- commit 6416733
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: af076156ec6d mei: vsc: Fix wrong invocation of ACPI SID method
- commit 69abdb6
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: ba46b3bda296 drm/amdgpu: Adjust logic in amdgpu_device_partner_bandwidth()
- blacklist.conf: 6c5cd0807c79 drm/xe: Properly handle alloc_guc_id() failure
- commit e4bc16c
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: c8ea2c31f5ea drm/xe: Only use reserved BCS instances for usm migrate exec queue
- blacklist.conf: 77b79df0268b drm/xe: Change pcode timeout to 50msec while polling again
- commit d986cd7
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 40672b792a36 drm/xe: Properly handle alloc_guc_id() failure
- commit 8b925f4
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 5745cb2da6fe drm/amd/display: Remove redundant idle optimization check
- commit 50af36c
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: c606043ddbf0 drm/v3d: Different V3D versions can have different number of perfcnt
- blacklist.conf: 04f4a70a183a drm/xe: Only use reserved BCS instances for usm migrate exec queue
- commit e7807cf
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: c81858eb5226 drm/xe: Change pcode timeout to 50msec while polling again
- blacklist.conf: 51474ab44abf drm/bridge: aux-hpd-bridge: correct devm_drm_dp_hpd_bridge_add() stub
- commit 09246dc
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: d69c3d4b5382 drm/xe/ads: Use flexible-array
- commit 40d48be
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 2d9c72f676e6 drm/xe: Use ordered WQ for G2H handler
- blacklist.conf: c002bfe644a2 drm/xe: Use ordered WQ for G2H handler
- commit ff34d17
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 2d4b74a619de drm/xe/ads: Use flexible-array
- commit bb28efa
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: ee7284230644 drm/xe/ads: Use flexible-array
- blacklist.conf: ef283674a17e drm/uapi: Move drm_color_ctm_3x4 out from drm_mode.h
- commit 83062b3
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 50aec9665e0b drm/xe: Use ordered WQ for G2H handler
- commit cc9e4a7
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: c528aaa36db0 Revert "drm/i915/dgfx: DGFX uses direct VBT pin mapping"
- commit 1439c3d
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: df04b152fca2 drm/xe/display: Fix ADL-N detection
- commit 630d9a7
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 28d21e3e66c5 drm/xe/vm: prevent UAF in rebind_work_func()
- commit ee29c81
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 98957360563e drm/xe/vm: prevent UAF in rebind_work_func()
- commit 4d37d24
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: e4236b14fe32 drm/imagination: Ensure PVR_MIPS_PT_PAGE_COUNT is never zero
- commit 291c896
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: f989ecccdf6b drm/amdkfd: Fix rescheduling of restore worker
- commit 8f943c1
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 3d44d67c441a drm/xe/vm: prevent UAF in rebind_work_func()
- commit 0e6af50
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: f38c4d224aa3 drm/xe: call free_gsc_pkt only once on action add failure
- commit 80157bc
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: d6dab9017b7c drm/xe: Remove sysfs only once on action add failure
- commit 19fcf74
* Wed Oct 16 2024 jlee@suse.com
- ACPI: resource: Remove duplicate Asus E1504GAB IRQ override (jsc#PED-11164).
- memory tiers: use default_dram_perf_ref_source in log message (jsc#PED-11164).
- platform/x86: ideapad-laptop: add a mutex to synchronize VPC commands (jsc#PED-11164).
- platform/x86: ideapad-laptop: move ymc_trigger_ec from lenovo-ymc (jsc#PED-11164).
  Refresh
  patches.suse/platform-x86-lenovo-ymc-Ignore-the-0x0-state.patch.
- platform/x86: ideapad-laptop: introduce a generic notification chain (jsc#PED-11164).
- platform/x86: intel-vbtn: Protect ACPI notify handler against recursion (jsc#PED-11164).
- genirq: Set IRQF_COND_ONESHOT in request_irq() (jsc#PED-11164).
- locking/mutex: Introduce devm_mutex_init() (jsc#PED-11164).
- commit 6430d49
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: e26305f369ed drm/amdkfd: Fix rescheduling of restore worker
- commit 911b110
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 37865e02e6cc drm/amdkfd: Fix eviction fence handling
- commit 83b13b9
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 6abe93b621ab drm/v3d: Fix race-condition between sysfs/fdinfo and interrupt handler
- commit c220e19
* Wed Oct 16 2024 oneukum@suse.com
- blacklist.conf: false positive
- commit be20945
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: a386c3041045 drm/atomic-helper: fix parameter order in drm_format_conv_state_copy() call
- commit ed6f91c
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 7e38ccb5276f drm/amdkfd: Fix eviction fence handling
- commit 8163348
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 22bf0bc04d27 drm/xe: call free_gsc_pkt only once on action add failure
- commit 6dbc93d
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: a99641e38704 drm/xe: Remove sysfs only once on action add failure
- commit 7a6bfd8
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: ca7c52ac7ad3 drm/xe/vm: prevent UAF with asid based lookup
- commit 7d3db71
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 652ead9b746a drm/xe: Fix bo leak in intel_fb_bo_framebuffer_init
- commit 4df7d87
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 83967c57320d drm/xe/vm: prevent UAF with asid based lookup
- commit f70d009
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 35f4f8c9fc97 drm/v3d: Don't increment  twice
- commit 8362ad5
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: a2f3d731be38 drm/xe: Fix bo leak in intel_fb_bo_framebuffer_init
- commit 85cc793
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: a8ad8715472b drm/xe/hwmon: Cast result to output precision on left shift of operand
- commit 3f9976c
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 50a9b7fc151e drm/xe/display: Fix double mutex initialization
- commit 9b45dcf
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: f6085a96c973 mei: vsc: Unregister interrupt handler for system suspend
- commit 4264fca
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 883232b47b81 drm/xe/hwmon: Cast result to output precision on left shift of operand
- commit e325132
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: c8520d5e5d8f drm/msm/dp: Account for the timeout in wait_hpd_asserted() callback
- commit 41dbd4f
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 117de185edf2 drm/xe/display: Fix double mutex initialization
- commit ac815f1
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 875bc9cd1b33 accel/ivpu: Put NPU back to D3hot after failed resume
- commit 27333e5
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 3534eacbf101 accel/ivpu: Fix PCI D0 state entry in resume
- commit e7a925e
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 77a011012d7d drm/xe: Use ordered wq for preempt fence waiting
- commit fd06449
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 3edd52bead30 drm/xe: Move vma rebinding to the drm_exec locking loop
- commit 7aa4d1b
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: fd1c8085113f drm/xe: Make TLB invalidation fences unordered
- commit f8747b2
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: a00e7e3fb4b9 drm/xe: Rework rebinding
- commit 0be0385
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 3c88b8f471ee drm/xe: Use ring ops TLB invalidation for rebinds
- commit 605a03e
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 94bf3e60e1a6 drm/i915/gt: Limit the reserved VM space to only the platforms that need it
- commit de6b015
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 37c15c4aae1f drm/xe: Use ordered wq for preempt fence waiting
- commit 6f11968
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: d725ce9d7c78 drm/i915/dp: Fix DSC state HW readout for SST connectors
- commit aa68cbf
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: e86750b01a15 drm/msm/dp: fix runtime PM leak on connect failure
- commit c9ea520
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 0640f47b7426 drm/msm/dp: fix runtime PM leak on disconnect
- commit cbb002e
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 9721634441d5 drm/i915/gt: Limit the reserved VM space to only the platforms that need it
- commit 7c1df5f
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: d392e1b9c2e8 drm/i915: Do not print 'pxp init failed with 0' when it succeed
- commit 0e57c76
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: cf48bddd31de drm/i915/display: Disable AuxCCS framebuffers if built for Xe
- commit 9229164
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: f378ab787004 drm/i915: Stop doing double audio enable/disable on SDVO and g4x+ DP
- commit 93d470e
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 7ee7dd6f3013 drm/xe: Move vma rebinding to the drm_exec locking loop
- commit 2b5d107
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 0453f1757501 drm/xe: Make TLB invalidation fences unordered
- commit 9f09a34
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 5a091aff50b7 drm/xe: Rework rebinding
- commit 394bbf7
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 4fc4899e86f7 drm/xe: Use ring ops TLB invalidation for rebinds
- commit 7440dba
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: a8eb93b42d7e fbdev: Select I/O-memory framebuffer ops for SBus
- commit 72dbbdc
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 45c30b2923e5 drm/xe/query: fix gt_id bounds check
- commit 534c95e
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: b45f20fa69ce drm/xe/device: fix XE_MAX_TILES_PER_DEVICE check
- commit b282d62
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 23e1ee3a2317 drm/xe/device: fix XE_MAX_GT_PER_TILE check
- commit 94b0325
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: b7dce525c4fc drm/xe/queue: fix engine_class bounds check
- commit e0b85a0
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 9c1256369c10 drm/xe/guc_submit: use jiffies for job timeout
- commit cedd7c3
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: fd00fe8cdbb2 drm/xe: Remove unused xe_bo->props struct
- commit deaa0e1
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 07b9d0144fff drm/imagination: avoid -Woverflow warning
- commit f8baafd
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 4b275f502a0d drm/xe/query: fix gt_id bounds check
- commit 6469f78
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: d437099ab21c drm/i915: Do not print 'pxp init failed with 0' when it succeed
- commit 633d897
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: a96cd71ec7be drm/xe/device: fix XE_MAX_TILES_PER_DEVICE check
- commit c562ac6
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: a5ef563b1d67 drm/xe/device: fix XE_MAX_GT_PER_TILE check
- commit a251b97
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: fe87b7dfcb20 drm/xe/queue: fix engine_class bounds check
- commit 3b34f3e
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 9cbd1dae8427 drm/dp: Fix divide-by-zero regression on DP MST unplug with nouveau
- commit 41a403f
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: dd8a07f06dfd drm/xe: Skip VMAs pin when requesting signal to the last XE_EXEC
- commit 5705f0a
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 386021394394 drm/xe: Invalidate userptr VMA on page pin fault
- commit 023aa5c
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 2c5b70f74d61 drm/xe/guc_submit: use jiffies for job timeout
- commit bbff3f8
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 002d8f0b4f76 drm/xe: Remove unused xe_bo->props struct
- commit e1828e6
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 58480c1c912f drm/xe: Skip VMAs pin when requesting signal to the last XE_EXEC
- commit 30f4899
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 521db22a1d70 drm/xe: Invalidate userptr VMA on page pin fault
- commit 985fad3
* Wed Oct 16 2024 oneukum@suse.com
- blacklist.conf: kABI
- commit 542a4a6
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2562-drm-xe-Return-immediately-on-tile_init-failure.patch (git-fixes)
  Alt-commit
- commit dfd974f
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: b7232a730fbf drm/i915/display: Disable AuxCCS framebuffers if built for Xe
- commit 07ba573
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 315bd0a08257 drm/i915: Stop doing double audio enable/disable on SDVO and g4x+ DP
- commit c69d8e0
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2560-drm-i915-dp-Fix-connector-DSC-HW-state-readout.patch (git-fixes)
  Alt-commit
- commit 63619b9
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: b8b19acfafde mei: vsc: Don't use sleeping condition in wait_event_timeout()
- commit 865a8ea
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: e62d2e00780b drm/xe: Replace 'grouped target' in Makefile with pattern rule
- commit f4ef5c8
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: f7da398935f7 drm/xe: Fix ref counting leak on page fault
- commit ec9db7b
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: c6f6750bd256 drm/xe: Remove obsolete async_ops from struct xe_vm
- commit e300597
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 5224ed586ba7 drm/xe: Replace 'grouped target' in Makefile with pattern rule
- commit 22e4871
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 32b6ff95b912 drm/msm/dpu: allow certain formats for CDM for DP
- commit 8a5e8f6
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 27b5a3f237fe drm/xe: Fix ref counting leak on page fault
- commit 11c778e
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2561-drm-i915-panelreplay-Move-out-psr_init_dpcd-from-ini.patch (git-fixes)
  Alt-commit
- commit a840333
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: e5f276dc1e4c drm/xe: Remove obsolete async_ops from struct xe_vm
- commit f2bd6df
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2539-drm-xe-mmio-fix-build-warning-for-BAR-resize-on-32-b.patch (git-fixes)
  Alt-commit
- commit 41f592b
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 689a930b93c5 drm/xe/tests: Fix printf format specifiers in xe_migrate test
- commit edb7cea
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2538-drm-xe-get-rid-of-MAX_BINDS.patch (git-fixes)
  Alt-commit
- commit c28847a
* Wed Oct 16 2024 jlee@suse.com
- ACPI: bus: allow _UID matching for integer zero (jsc#PED-11164).
- genirq: Introduce IRQF_COND_ONESHOT and use it in pinctrl-amd (jsc#PED-11164).
- ACPI: HMAT: Remove register of memory node for generic target (jsc#PED-11164).
- thermal: ACPI: Discard trips table after zone registration (jsc#PED-11164).
- Revert "ACPI: EC: Use a spin lock without disabing interrupts" (jsc#PED-11164).
  Refresh
  patches.suse/ACPI-EC-Do-not-release-locks-during-operation-region.patch.
- platform/x86: intel: int0002_vgpio: Pass IRQF_ONESHOT to request_irq() (jsc#PED-11164).
- pinctrl: amd: Add IRQF_ONESHOT to the interrupt request (jsc#PED-11164).
- commit 7a9b5ef
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2537-drm-xe-Use-vmalloc-for-array-of-bind-allocation-in-b.patch (git-fixes)
  Alt-commit
- commit 91a82ad
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 0d7dfc79fb9b drm/msm/a6xx: specify UBWC config for sc7180
- commit de1b862
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2536-drm-xe-Don-t-support-execlists-in-xe_gt_tlb_invalida.patch (git-fixes)
  Alt-commit
- commit b683a88
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2535-drm-xe-Fix-execlist-splat.patch (git-fixes)
  Alt-commit
- commit 6c0784f
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2534-drm-xe-uapi-Remove-unused-flags.patch (git-fixes)
  Alt-commit
- commit 5cce846
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2520-drm-xe-Fix-modpost-warning-on-xe_mocs-kunit-module.patch (git-fixes)
  Alt-commit
- commit 2e2f1df
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2519-drm-xe-xe_gt_idle-Drop-redundant-newline-in-name.patch (git-fixes)
  Alt-commit
- commit 1a57e53
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2518-drm-xe-Return-2MB-page-size-for-compact-64k-PTEs.patch (git-fixes)
  Alt-commit
- commit 903db2a
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2517-drm-xe-Add-XE_VMA_PTE_64K-VMA-flag.patch (git-fixes)
  Alt-commit
- commit b9a9272
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2516-drm-xe-Fix-xe_vma_set_pte_size.patch (git-fixes)
  Alt-commit
- commit 24ce7ba
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2515-drm-xe-uapi-Remove-support-for-persistent-exec_queue.patch (git-fixes)
  Alt-commit
- commit 26ecc17
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 1a5e81de180e Revert "drm/panel-edp: Add auo_b116xa3_mode"
- commit 49060b0
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2475-drm-xe-avoid-function-cast-warnings.patch (git-fixes)
  Alt-commit
- commit f7ffd0b
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2474-drm-xe-pt-Allow-for-stricter-type-and-range-checking.patch (git-fixes)
  Alt-commit
- commit 865a31d
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2473-drm-xe-display-fix-i915_gem_object_is_shmem-wrapper.patch (git-fixes)
  Alt-commit
- commit 967fdef
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2472-drm-xe-vm-Avoid-reserving-zero-fences.patch (git-fixes)
  Alt-commit
- commit 91f86e2
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2453-drm-amd-display-Clear-phantom-stream-count-and-plane.patch (git-fixes)
  Alt-commit
- commit b92f735
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 0701117efd1e Revert "drm/amd/display: For FPO and SubVP/DRR configs program vmin/max sel"
- commit b0175f7
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2438-drm-xe-Remove-TEST_VM_ASYNC_OPS_ERROR.patch (git-fixes)
  Alt-commit
- commit d2c8b67
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2437-drm-xe-vm-don-t-ignore-error-when-in_kthread.patch (git-fixes)
  Alt-commit
- commit d8bf627
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2436-drm-xe-Assume-large-page-size-if-VMA-not-yet-bound.patch (git-fixes)
  Alt-commit
- commit 0500224
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2435-drm-xe-display-Fix-memleak-in-display-initialization.patch (git-fixes)
  Alt-commit
- commit 9536c31
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2434-drm-xe-Map-both-mem.kernel_bb_pool-and-usm.bb_pool.patch (git-fixes)
  Alt-commit
- commit 9df6224
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2433-drm-xe-circumvent-bogus-stringop-overflow-warning.patch (git-fixes)
  Alt-commit
- commit 2885799
* Wed Oct 16 2024 oneukum@suse.com
- media: pci: ipu3-cio2: Initialise timing struct to avoid a
  compiler warning (git-fixes).
- commit c21df3e
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2432-drm-xe-Pick-correct-userptr-VMA-to-repin-on-REMAP-op.patch (git-fixes)
  Alt-commit
- commit 086f2db
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2431-drm-xe-Take-a-reference-in-xe_exec_queue_last_fence_.patch (git-fixes)
  Alt-commit
- commit 0ad65e9
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2430-drm-xe-Fix-loop-in-vm_bind_ioctl_ops_unwind.patch (git-fixes)
  Alt-commit
- commit 7d7a075
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 5f16ee27cd5a drm/hwmon: Fix abi doc warnings
- commit 698a5ae
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2395-drm-xe-vm-Subclass-userptr-vmas.patch (git-fixes)
  Alt-commit
- commit b97846c
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2394-drm-xe-Use-LRC-prefix-rather-than-CTX-prefix-in-lrc-.patch (git-fixes)
  Alt-commit
- commit 5f4c34c
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2396-drm-xe-Make-all-GuC-ABI-shift-values-unsigned.patch (git-fixes)
  Alt-commit
- commit c5618e7
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2393-drm-xe-Don-t-use-__user-error-pointers.patch (git-fixes)
  Alt-commit
- commit 23cd686
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2392-drm-xe-Annotate-mcr_-un-lock.patch (git-fixes)
  Alt-commit
- commit 39f9b99
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2391-drm-xe-Only-allow-1-ufence-per-exec-bind-IOCTL.patch (git-fixes)
  Alt-commit
- commit 40780dc
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 20485e3a810c drm/hwmon: Fix abi doc warnings
- commit 9fbfe59
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2399-drm-amdkfd-Correct-partial-migration-virtual-addr.patch (git-fixes)
  Alt-commit
- commit b09195d
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2398-drm-amdgpu-move-the-drm-client-creation-behind-drm-d.patch (git-fixes)
  Alt-commit
- commit 4de1d49
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2390-drm-xe-Grab-mem_access-when-disabling-C6-on-skip_guc.patch (git-fixes)
  Alt-commit
- commit 4b57af9
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2389-drm-xe-Fix-crash-in-trace_dma_fence_init.patch (git-fixes)
  Alt-commit
- commit 5f6c8fd
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2337-drm-xe-Remove-PVC-from-xe_wa-kunit-tests.patch (git-fixes)
  Alt-commit
- commit 971b7ca
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 18d71047922e Revert "drm/amd/pm: smu v13_0_6 supports ecc info by default"
- commit 7b06e82
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: e8cc57a96cb0 drm/amd/display: Drop kdoc markers for some Panel Replay functions
- commit 4b512e4
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2336-drm-xe-vm-bugfix-in-xe_vm_create_ioctl.patch (git-fixes)
  Alt-commit
- commit 8d4113e
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2335-drm-xe-xe2-Use-XE_CACHE_WB-pat-index.patch (git-fixes)
  Alt-commit
- commit 31f9514
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2334-drm-xe-display-Avoid-calling-readq.patch (git-fixes)
  Alt-commit
- commit ff2eb3a
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2333-drm-xe-mmio-Cast-to-u64-when-printing.patch (git-fixes)
  Alt-commit
- commit 1f1560b
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2332-drm-xe-Use-_ULL-for-u64-division.patch (git-fixes)
  Alt-commit
- commit 02b61ab
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2295-drm-amdkfd-init-drm_client-with-funcs-hook.patch (git-fixes)
  Alt-commit
- commit b322d50
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2331-drm-xe-Use-a-NULL-pointer-instead-of-0.patch (git-fixes)
  Alt-commit
- commit fcfa22e
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2330-drm-xe-dmabuf-Make-xe_dmabuf_ops-static.patch (git-fixes)
  Alt-commit
- commit 7aa3d80
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2318-drm-ttm-fix-ttm-pool-initialization-for-no-dma-devic.patch (git-fixes)
  Alt-commit
- commit c4f4d6e
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2315-drm-xe-Fix-bounds-checking-in-__xe_bo_placement_for_.patch (git-fixes)
  Alt-commit
- commit 571a1dd
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: a7983eefb642 drm/doc: internals: remove section on PCI legacy support
- commit 3d6b517
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2314-drm-xe-migrate-Fix-CCS-copy-for-small-VRAM-copy-chun.patch (git-fixes)
  Alt-commit
- commit c51491b
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2313-drm-xe-unlock-on-error-path-in-xe_vm_add_compute_exe.patch (git-fixes)
  Alt-commit
- commit 670176d
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2312-drm-xe-selftests-Fix-an-error-pointer-dereference-bu.patch (git-fixes)
  Alt-commit
- commit 3d68454
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2311-drm-xe-device-clean-up-on-error-in-probe.patch (git-fixes)
  Alt-commit
- commit a0523a1
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2310-drm-xe-Fix-build-bug-for-GCC-11.patch (git-fixes)
  Alt-commit
- commit f139882
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2309-drm-xe-Check-skip_guc_pc-before-setting-SLPC-flag.patch (git-fixes)
  Alt-commit
- commit 7eeb5f3
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2308-drm-xe-Fix-modifying-exec_queue-priority-in-xe_migra.patch (git-fixes)
  Alt-commit
- commit 7dfe9b3
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2307-drm-xe-Fix-guc_exec_queue_set_priority.patch (git-fixes)
  Alt-commit
- commit 696eecb
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2306-drm-xe-Annotate-xe_ttm_stolen_mgr-mapping-with-__iom.patch (git-fixes)
  Alt-commit
- commit b3e6fac
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2305-drm-xe-Annotate-multiple-mmio-pointers-with-__iomem.patch (git-fixes)
  Alt-commit
- commit 0e8097b
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2304-drm-xe-Annotate-xe_mem_region-mapping-with-__iomem.patch (git-fixes)
  Alt-commit
- commit 95b4a8d
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2303-drm-xe-Use-__iomem-for-the-regs-pointer.patch (git-fixes)
  Alt-commit
- commit 2d45d30
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2302-drm-xe-vm-Fix-an-error-path.patch (git-fixes)
  Alt-commit
- commit 311dfb7
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2301-drm-xe-Fix-exec-IOCTL-long-running-exec-queue-ring-f.patch (git-fixes)
  Alt-commit
- commit 6018e30
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2218-drm-i915-don-t-make-assumptions-about-intel_wakeref_.patch (git-fixes)
  Alt-commit
- commit 75a798c
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2300-drm-xe-Fix-definition-of-intel_wakeref_t.patch (git-fixes)
  Alt-commit
- commit 93bca8a
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2218-drm-i915-don-t-make-assumptions-about-intel_wakeref_.patch (git-fixes)
  Alt-commit
- commit d57b94d
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2217-drm-i915-dp-Fix-the-PSR-debugfs-entries-wrt.-MST-con.patch (git-fixes)
  Alt-commit
- commit dd233bc
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2216-drm-i915-display-Fix-C20-pll-selection-for-state-ver.patch (git-fixes)
  Alt-commit
- commit 9eef926
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2533-drm-xe-uapi-Remove-DRM_XE_VM_BIND_FLAG_ASYNC-comment.patch (git-fixes)
  Alt-commit
- commit 9fbe50c
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2079-drm-xe-Fix-warning-on-impossible-condition.patch (git-fixes)
  Alt-commit
- commit 2a140e1
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2078-drm-xe-Fix-UBSAN-splat-in-add_preempt_fences.patch (git-fixes)
  Alt-commit
- commit a348560
* Wed Oct 16 2024 pjakobsson@suse.de
- Refresh patches.suse/2051-drm-xe-Disable-32bits-build.patch (git-fixes)
  Alt-commit
- commit 5819b3e
* Wed Oct 16 2024 pjakobsson@suse.de
- blacklist.conf: 4350aa21cca4 fbdev/simplefb: change loglevel when the power domains cannot be parsed
- commit b11738c
* Wed Oct 16 2024 pjakobsson@suse.de
- supported.conf: Added new drivers from the DRM v6.8 backport
- commit b274fd9
* Wed Oct 16 2024 oneukum@suse.com
- wifi: rtw88: Fix USB/SDIO devices not transmitting beacons
  (git-fixes).
- commit d46bb93
* Wed Oct 16 2024 pjakobsson@suse.de
- drm/xe: Internally change the compute_mode and no_dma_fence mode naming (drm-backport-placeholder).
- commit c17d9ff
* Wed Oct 16 2024 oneukum@suse.com
- blacklist.conf: kABI
- commit 69a972d
* Wed Oct 16 2024 oneukum@suse.com
- blacklist.conf: cleanup with no code change
- commit 17d2ae5
* Wed Oct 16 2024 oneukum@suse.com
- blacklist.conf: false positive
- commit 26080b4
* Wed Oct 16 2024 pjakobsson@suse.de
- drm/xe: Use Xe assert macros instead of XE_WARN_ON macro (drm-backport-placeholder).
- commit 58225ba
* Wed Oct 16 2024 jlee@suse.com
- acpi: numa: Add helper function to retrieve the performance attributes (jsc#PED-11164).
- acpi: numa: Add setting of generic port system locality attributes (jsc#PED-11164).
- acpi: Break out nesting for hmat_parse_locality() (jsc#PED-11164).
- acpi: numa: Create enum for memory_target access coordinates indexing (jsc#PED-11164).
  Refresh
  patches.suse/acpi-numa-Add-genport-target-allocation-to-the-HMAT-.patch.
- base/node / acpi: Change 'node_hmem_attrs' to 'access_coordinates' (jsc#PED-11164).
  Refresh
  patches.suse/acpi-numa-Add-genport-target-allocation-to-the-HMAT-.patch.
- dax, kmem: calculate abstract distance with general interface (jsc#PED-11164).
  Refresh
  patches.suse/dax-kmem-allow-kmem-to-add-memory-with-memmap_on_mem-4eca.patch.
- acpi, hmat: calculate abstract distance with HMAT (jsc#PED-11164).
  Refresh
  patches.suse/acpi-hmat-calculate-abstract-distance-with-HMAT.patch.
- acpi, hmat: refactor hmat_register_target_initiators() (jsc#PED-11164).
- memory tiering: add abstract distance calculation algorithms management (jsc#PED-11164).
  Refresh
  patches.suse/memory-tiering-add-abstract-distance-calculation-alg.patch.
- memory tier: rename destroy_memory_type() to put_memory_type() (jsc#PED-11164).
- memory tier: use helper function destroy_memory_type() (jsc#PED-11164).
- base/node: Use 'property' to identify an access parameter (jsc#PED-11164).
- commit 5c450a7
* Wed Oct 16 2024 msuchanek@suse.de
- crypto: powerpc/p10-aes-gcm - Add dependency on CRYPTO_SIMD and
  re-enable CRYPTO_AES_GCM_P10 (bsc#1230501 ltc#208632).
  - Update config files.
- crypto: powerpc/p10-aes-gcm - Register modules as SIMD
  (bsc#1230501 ltc#208632).
- crypto: powerpc/p10-aes-gcm - Re-write AES/GCM stitched
  implementation (bsc#1230501 ltc#208632).
- crypto: powerpc/p10-aes-gcm - Disable CRYPTO_AES_GCM_P10
  (bsc#1230501 ltc#208632).
- powerpc/crypto: don't build aes-gcm-p10 by default (bsc#1230501
  ltc#208632).
- powerpc/crypto: fix missing skcipher dependency for aes-gcm-p10
  (bsc#1230501 ltc#208632).
- commit a579f42
* Wed Oct 16 2024 pjakobsson@suse.de
- drm/xe: Rework xe_exec and the VM rebind worker to use the drm_exec helper (drm-backport-placeholder).
- commit 30a0ac1
* Wed Oct 16 2024 jlee@suse.com
- acpi: numa: Add genport target allocation to the HMAT parsing (jsc#PED-11164).
- lib/firmware_table: tables: Add CDAT table parsing support (jsc#PED-11164).
- ACPI: Move ACPI_HOTPLUG_CPU to be disabled on arm64 and riscv (jsc#PED-11164).
  Update config files.
  Removed CONFIG_ACPI_HOTPLUG_CPU=y from config/arm64/default
- commit 9fd1cee
* Wed Oct 16 2024 pjakobsson@suse.de
- drm/amd/display: For FPO and SubVP/DRR configs program vmin/max sel (drm-backport-placeholder).
- Delete patches.suse/drm-amd-display-Override-min-required-DCFCLK-in-dml1.patch.
- commit b25e072
* Wed Oct 16 2024 jlee@suse.com
- x86/pci: Add MCFG debug logging (jsc#PED-11164).
- ACPICA: MADT: Add new MADT GICC/GICR/ITS non-coherent flags handling (jsc#PED-11164).
- ACPICA: MADT: Add GICC online capable bit handling (jsc#PED-11164).
- ACPI: resource: Skip IRQ override on ASUS ExpertBook B1502CGA (jsc#PED-11164).
- ACPI: resource: Add DMI quirks for ASUS Vivobook E1504GA and E1504GAB (jsc#PED-11164).
- acpi/nfit: Use sysfs_emit() for all attributes (jsc#PED-11164).
- ACPI: NFIT: Use cleanup.h helpers instead of devm_*() (jsc#PED-11164).
- dma-mapping: don't store redundant offsets (jsc#PED-11164).
- ACPI: scan: Add LNXVIDEO HID to ignore_serial_bus_ids (jsc#PED-11164).
- thermal: trip: Send trip change notifications on all trip updates (jsc#PED-11164).
- ACPI: watchdog: fix kernel-doc warnings (jsc#PED-11164).
- ACPI: NUMA: Optimize the check for the availability of node values (jsc#PED-11164).
- ACPI: NUMA: Remove unnecessary check in acpi_parse_gi_affinity() (jsc#PED-11164).
- ACPI: APEI: EINJ: Add support for vendor defined error types (jsc#PED-11164).
- ACPI: APEI: EINJ: Refactor available_error_type_show() (jsc#PED-11164).
- ACPI: video: Drop should_check_lcd_flag() (jsc#PED-11164).
- ACPI: video: Add comment about acpi_video_backlight_use_native() usage (jsc#PED-11164).
- ACPI: thermal_lib: include "internal.h" for function prototypes (jsc#PED-11164).
- ACPI: thermal: Use library functions to obtain trip point temperature values (jsc#PED-11164).
- ACPI: thermal_lib: Add functions returning temperature in deci-Kelvin (jsc#PED-11164).
- commit 41824e5
* Wed Oct 16 2024 jlee@suse.com
- ACPI: utils: Introduce helper for _DEP list lookup (jsc#PED-11164).
- ACPI: utils: Refine acpi_handle_list_equal() slightly (jsc#PED-11164).
- ACPI: utils: Return bool from acpi_evaluate_reference() (jsc#PED-11164).
- ACPI: utils: Rearrange in acpi_evaluate_reference() (jsc#PED-11164).
- ACPI: LPSS: use acpi_dev_uid_match() for matching _UID (jsc#PED-11164).
- ACPI: bus: update acpi_dev_hid_uid_match() to support multiple types (jsc#PED-11164).
- ACPI: bus: update acpi_dev_uid_match() to support multiple types (jsc#PED-11164).
- ACPI: Run USB4 _OSC() first with query bit set (jsc#PED-11164).
- ACPI: EC: Use a spin lock without disabing interrupts (jsc#PED-11164).
  Refresh
  patches.suse/ACPI-EC-Do-not-release-locks-during-operation-region.patch.
- ACPI: EC: Use a threaded handler for dedicated IRQ (jsc#PED-11164).
- ACPI: OSL: Use spin locks without disabling interrupts (jsc#PED-11164).
- ACPI: OSL: Allow Notify () handlers to run on all CPUs (jsc#PED-11164).
- ACPI: OSL: Rearrange workqueue selection in acpi_os_execute() (jsc#PED-11164).
- ACPI: OSL: Rework error handling in acpi_os_execute() (jsc#PED-11164).
- ACPI: OSL: Use a threaded interrupt handler for SCI (jsc#PED-11164).
- ACPI: processor: Provide empty stub of acpi_proc_quirk_mwait_check() (jsc#PED-11164).
- ACPI: scan: Fix an error message in DisCo for Imaging support (jsc#PED-11164).
- ACPI: property: Replicate DT-aligned u32 properties from DisCo for Imaging (jsc#PED-11164).
- ACPI: property: Dig "rotation" property for devices with CSI2 _CRS (jsc#PED-11164).
- ACPI: scan: Extract MIPI DisCo for Imaging data into swnodes (jsc#PED-11164).
- ACPI: scan: Extract _CRS CSI-2 connection information into swnodes (jsc#PED-11164).
- ACPI: scan: Extract CSI-2 connection graph from _CRS (jsc#PED-11164).
- ACPI: property: Support using strings in reference properties (jsc#PED-11164).
  Refresh
  patches.suse/acpi-property-Let-args-be-NULL-in-__acpi_node_get_pr.patch.
- ACPI: button: trigger wakeup key events (jsc#PED-11164).
- cpufreq/cppc: Move and rename cppc_cpufreq_{perf_to_khz|khz_to_perf}() (jsc#PED-11164).
- commit 3d6ebb4
* Wed Oct 16 2024 jlee@suse.com
- ACPI: utils: Fix white space in struct acpi_handle_list definition (jsc#PED-11164).
- x86/acpi: Handle bogus MADT APIC tables gracefully (jsc#PED-11164).
- x86, kexec: fix the wrong ifdeffery CONFIG_KEXEC (jsc#PED-11164).
- ACPI: utils: Fix error path in acpi_evaluate_reference() (jsc#PED-11164).
- ACPI: Fix ARM32 platforms compile issue introduced by fw_table changes (jsc#PED-11164).
- commit bc66031
* Tue Oct 15 2024 jlee@suse.com
- x86/acpi: Ignore invalid x2APIC entries (jsc#PED-11164).
- lib/fw_table: Remove acpi_parse_entries_array() export (jsc#PED-11164).
- acpi: Move common tables helper functions to common lib (jsc#PED-11164).
  Update config files. Add CONFIG_FIRMWARE_TABLE=y
- acpi,mm: fix typo sibiling -> sibling (jsc#PED-11164).
- arm64, irqchip/gic-v3, ACPI: Move MADT GICC enabled check into a helper (jsc#PED-11164).
- amba: bus: balance firmware node reference counting (jsc#PED-11164).
- of/platform: increase refcount of fwnode (jsc#PED-11164).
- of/platform: Propagate firmware node by calling device_set_node() (jsc#PED-11164).
- commit 8419ebf
* Tue Oct 15 2024 oneukum@suse.com
- powercap: intel_rapl: Fix off by one in get_rpi() (git-fixes).
- commit 6c73c0c
* Tue Oct 15 2024 jlee@suse.com
- ACPI: acpi_pad: Rename ACPI device from device to adev (jsc#PED-11164).
- ACPI: acpi_pad: Use dev groups for sysfs (jsc#PED-11164).
- ACPI: acpi_pad: Replace acpi_driver with platform_driver (jsc#PED-11164).
  Refresh
  patches.suse/ACPI-acpi_pad-Do-not-launch-acpi_pad-threads-on-idle-cpus.patch.
- ACPI: AC: Rename ACPI device from device to adev (jsc#PED-11164).
- ACPI: AC: Replace acpi_driver with platform_driver (jsc#PED-11164).
- ACPI: AC: Use string_choices API instead of ternary operator (jsc#PED-11164).
- ACPI: AC: Remove redundant checks (jsc#PED-11164).
- ACPI: bus: Add context argument to acpi_dev_install_notify_handler() (jsc#PED-11164).
- ACPI: x86: use acpi_dev_uid_match() for matching _UID (jsc#PED-11164).
- ACPI: utils: use acpi_dev_uid_match() for matching _UID (jsc#PED-11164).
- ACPI: utils: Introduce acpi_dev_uid_match() for matching _UID (jsc#PED-11164).
- ACPI: sysfs: use acpi_device_uid() for fetching _UID (jsc#PED-11164).
- ACPI: x86: s2idle: Switch to use acpi_evaluate_dsm_typed() (jsc#PED-11164).
- ACPI: PCI: Switch to use acpi_evaluate_dsm_typed() (jsc#PED-11164).
- ACPI: sysfs: Clean up create_pnp_modalias() and create_of_modalias() (jsc#PED-11164).
- ACPI: PCC: Add PCC shared memory region command and status bitfields (jsc#PED-11164).
- ACPI: APEI: Use ERST timeout for slow devices (jsc#PED-11164).
- ACPI: PRM: Annotate struct prm_module_info with __counted_by (jsc#PED-11164).
- ACPI: video: Add "vendor" quirks for 3 Lenovo x86 Android tablets (jsc#PED-11164).
- ACPI: video: Move Xiaomi Mi Pad 2 quirk to its own section (jsc#PED-11164).
- ACPI: LPSS: drop BayTrail and Lynxpoint pinctrl HIDs (jsc#PED-11164).
- ACPI: property: Document the _DSD data buffer GUID (jsc#PED-11164).
- ACPI: resource: Drop .ident values from dmi_system_id tables (jsc#PED-11164).
  Refresh
  patches.suse/ACPI-resource-Skip-IRQ-override-on-ASUS-ExpertBook-B-bd91148.patch.
  patches.suse/ACPI-resource-Add-Asus-Vivobook-X1704VAP-to-irq1_lev.patch.
- commit b89b450
* Tue Oct 15 2024 oneukum@suse.com
- blacklist.conf: irrelevant in our configs
- commit 6fcd0e2
* Tue Oct 15 2024 tzimmermann@suse.com
- drm/amd/display: Disable DMCUB timeout for DCN35 (bsc#1231435 CVE-2024-46870)
- commit 0a39326
* Tue Oct 15 2024 pjakobsson@suse.de
- sizes.h: Add entries between SZ_32G and SZ_64T (drm-backport-placeholder)
- commit d2932df
* Tue Oct 15 2024 pjakobsson@suse.de
- kunit: replace KUNIT_TRIGGER_STATIC_STUB maro with (drm-backport-placeholder)
- commit cb638de
* Tue Oct 15 2024 pjakobsson@suse.de
- mei: fix vsc dependency (drm-backport-placeholder).
- Update config files.
- commit f460aee
* Tue Oct 15 2024 pjakobsson@suse.de
- fbdev: Remove support for Carillo Ranch driver (drm-backport-placeholder).
- Update config files.
- commit 64e997c
* Tue Oct 15 2024 pjakobsson@suse.de
- fbdev/intelfb: Remove driver (drm-backport-placeholder).
- Update config files.
- commit b2be923
* Tue Oct 15 2024 tzimmermann@suse.com
- drm/amd/display: Add disable timeout option (bsc#1231435)
- commit cb303b5
* Tue Oct 15 2024 pjakobsson@suse.de
- fbdev: amba-clcd: Delete the old CLCD driver (drm-backport-placeholder).
- Update config files.
- commit e353b02
* Tue Oct 15 2024 pjakobsson@suse.de
- mei: rework Kconfig dependencies (drm-backport-placeholder).
- Update config files.
- commit 288ef5c
* Tue Oct 15 2024 pjakobsson@suse.de
- mei: Add transport driver for IVSC device (drm-backport-placeholder).
- Update config files.
- commit 5034b94
* Tue Oct 15 2024 pjakobsson@suse.de
- drm/xe: Introduce a new DRM driver for Intel GPUs (drm-backport-placeholder).
- Update config files.
- commit 6611251
* Tue Oct 15 2024 pjakobsson@suse.de
- fbdev: Remove default file-I/O implementations (drm-backport-placeholder).
- Update config files.
- commit 5582717
* Tue Oct 15 2024 pjakobsson@suse.de
- drm/loongson: Add platform dependency (drm-backport-placeholder).
- Update config files.
- commit 364a7a1
* Tue Oct 15 2024 tiwai@suse.de
- Refresh patches.suse/paddings-add-paddings-to-TypeC-stuff.patch
  Drop superfluous file mode modifications in the patch that broke the
  patch expansion recently
- commit e7ac9e1
* Tue Oct 15 2024 pjakobsson@suse.de
- drm: Remove Kconfig option for legacy support (CONFIG_DRM_LEGACY) (drm-backport-placeholder).
- Update config files.
- commit 0fee618
* Tue Oct 15 2024 tiwai@suse.de
- Move upstreamed scsi patch into sorted section
- commit 5db43b0
* Mon Oct 14 2024 pjakobsson@suse.de
- drm/panel: Add Synaptics R63353 panel driver (drm-backport-placeholder).
- Update config files.
- commit 4cbac51
* Mon Oct 14 2024 pjakobsson@suse.de
- drm/panel: Add Ilitek ILI9805 panel driver (drm-backport-placeholder).
- Update config files.
- commit b838c08
* Mon Oct 14 2024 pjakobsson@suse.de
- drm/imagination: Add skeleton PowerVR driver (drm-backport-placeholder).
- Update config files.
- commit 517e495
* Mon Oct 14 2024 pjakobsson@suse.de
- drm/xe: Add CONFIG_DRM_XE_PREEMPT_TIMEOUT (drm-backport-placeholder).
- Update config files.
- commit 99d25f0
* Mon Oct 14 2024 pjakobsson@suse.de
- drm/xe: Add min/max cap for engine scheduler properties (drm-backport-placeholder).
- Update config files.
- commit 29dea2b
* Mon Oct 14 2024 mkubecek@suse.cz
- nbd: fix race between timeout and normal completion
  (bsc#1230918).
- commit 57c54c8
* Mon Oct 14 2024 lhenriques@suse.de
- ext4: mark fc as ineligible using an handle in ext4_xattr_set()
  (bsc#1231640).
- ext4: use handle to mark fc as ineligible in
  __track_dentry_update() (bsc#1231639).
- jbd2: correctly compare tids with tid_geq function in
  jbd2_fc_begin_commit (bsc#1231638).
- ext4: fix incorrect tid assumption in ext4_fc_mark_ineligible()
  (bsc#1231637).
- ext4: fix fast commit inode enqueueing during a full journal
  commit (bsc#1231636).
- ext4: don't track ranges in fast_commit if inode has inlined
  data (bsc#1231635).
- ext4: fix possible tid_t sequence overflows (bsc#1231634).
- commit 6951914
* Mon Oct 14 2024 oneukum@suse.com
- net: sysfs: Fix /sys/class/net/<iface> path for statistics
  (git-fixes).
- commit 54925d7
* Mon Oct 14 2024 oneukum@suse.com
- devlink: Fix command annotation documentation (git-fixes).
- commit 2b95827
* Mon Oct 14 2024 oneukum@suse.com
- blacklist.conf: no code change
- commit e4a59fd
* Mon Oct 14 2024 oneukum@suse.com
- blacklist.conf: irrelevant in our configs
- commit 5d62c4f
* Mon Oct 14 2024 oneukum@suse.com
- blacklist.conf: irrelevant in our configs
- commit 21e5259
* Mon Oct 14 2024 oneukum@suse.com
- x86/Documentation: Indent 'note::' directive for protocol
  version number note (git-fixes).
- commit ec31602
* Mon Oct 14 2024 ddiss@suse.de
- mm/filemap: optimize filemap folio adding (bsc#1231617).
- lib/xarray: introduce a new helper xas_get_order (bsc#1231617).
- mm/filemap: return early if failed to allocate memory for split
  (bsc#1231617).
- commit c3c5888
* Mon Oct 14 2024 oneukum@suse.com
- blacklist.conf: infrastructure without code change
- commit 67e5178
* Mon Oct 14 2024 oneukum@suse.com
- srcu: Fix callbacks acceleration mishandling (git-fixes).
- task_work: add kerneldoc annotation for 'data' argument
  (git-fixes).
- commit a4661ee
* Mon Oct 14 2024 pjakobsson@suse.de
- fbdev: Rename FB_SYS_FOPS token to FB_SYSMEM_FOPS (drm-backport-placeholder).
- Update config files.
- commit 538c557
* Mon Oct 14 2024 oneukum@suse.com
- blacklist.conf: kABI
- commit 6fc8778
* Mon Oct 14 2024 pjakobsson@suse.de
- backlight: mp3309c: Add support for MPS MP3309C (drm-backport-placeholder).
- Update config files.
- commit e39faab
* Mon Oct 14 2024 oneukum@suse.com
- tools/nolibc: use C89 comment syntax (git-fixes).
- Refresh
  patches.suse/tools-nolibc-ensure-stack-protector-guard-is-ne.patch.
- commit 31870ba
* Mon Oct 14 2024 pjakobsson@suse.de
- drm/xe: Define DRM_XE_DEBUG_SRIOV config (drm-backport-placeholder).
- Update config files.
- commit d5f93be
* Mon Oct 14 2024 pjakobsson@suse.de
- nouveau/gsp: add kconfig option to enable GSP paths by default (drm-backport-placeholder).
- Update config files.
- commit 1c1f618
* Mon Oct 14 2024 pjakobsson@suse.de
- drm/xe/display: Implement display support (drm-backport-placeholder).
- Update config files.
- commit feb41d0
* Mon Oct 14 2024 pjakobsson@suse.de
- drm/amd/display: Refactor dc_state interface (drm-backport-placeholder).
- Refresh patches.suse/drm-amd-display-Add-null-checker-before-passing-vari.patch.
- Refresh patches.suse/drm-amd-display-Remove-pixle-rate-limit-for-subvp.patch.
- Refresh patches.suse/drm-amd-display-Revert-Remove-pixle-rate-limit-for-s.patch.
- Delete patches.suse/0001-drm-amd-display-Add-a-dc_state-NULL-check-in-dc_stat.patch.
- Delete patches.suse/drm-amd-display-Clean-up-dsc-blocks-in-accelerated-m.patch.
- commit 3e6d0ad
* Mon Oct 14 2024 jlee@suse.com
- ACPI: resource: Consolidate IRQ trigger-type override DMI tables (jsc#PED-11164).
- ACPI: utils: Remove redundant braces around individual statement (jsc#PED-11164).
- ACPI: utils: Fix up white space in a few places (jsc#PED-11164).
- ACPI: utils: Dynamically determine acpi_handle_list size (jsc#PED-11164).
  Refresh
  patches.suse/ACPI-thermal-Fix-acpi_thermal_unregister_thermal_zon.patch.
- ACPI: OSI: refactor deprecated strncpy() (jsc#PED-11164).
- ACPI: OSL: Add empty lines after local variable declarations (jsc#PED-11164).
- ACPI: OSL: Remove redundant parentheses in return statements (jsc#PED-11164).
- ACPI: OSL: Fix up white space in parameter lists (jsc#PED-11164).
- ACPI: OSL: add __printf format attribute to acpi_os_vprintf() (jsc#PED-11164).
- ACPI: scan: Rename acpi_scan_device_not_present() to be about enumeration (jsc#PED-11164).
  Refresh
  patches.suse/ACPI-scan-Fix-device-check-notification-handling.patch.
- ACPI: scan: Use the acpi_device_is_present() helper in more places (jsc#PED-11164).
- ACPICA: Add defines for CDAT SSLBIS (jsc#PED-11164).
- ACPI: thermal: Use thermal_zone_for_each_trip() for updating trips (jsc#PED-11164).
- ACPI: thermal: Combine passive and active trip update functions (jsc#PED-11164).
- ACPI: thermal: Move get_active_temp() (jsc#PED-11164).
- ACPI: thermal: Fix up function header formatting in two places (jsc#PED-11164).
- ACPI: thermal: Drop list of device ACPI handles from struct acpi_thermal (jsc#PED-11164).
- ACPI: thermal: Rename structure fields holding temperature in deci-Kelvin (jsc#PED-11164).
  Refresh
  patches.suse/ACPI-thermal-Add-Thermal-fast-Sampling-Period-_TFP-support.patch.
- ACPI: thermal: Drop critical_valid and hot_valid trip flags (jsc#PED-11164).
- ACPI: thermal: Do not use trip indices for cooling device binding (jsc#PED-11164).
- ACPI: thermal: Mark uninitialized active trips as invalid (jsc#PED-11164).
- ACPI: thermal: Merge trip initialization functions (jsc#PED-11164).
  Refresh
  patches.suse/ACPI-thermal-Add-Thermal-fast-Sampling-Period-_TFP-support.patch.
- ACPI: thermal: Collapse trip devices update function wrappers (jsc#PED-11164).
- ACPI: thermal: Collapse trip devices update functions (jsc#PED-11164).
  Refresh
  patches.suse/ACPI-thermal-Add-Thermal-fast-Sampling-Period-_TFP-support.patch.
- ACPI: thermal: Add device list to struct acpi_thermal_trip (jsc#PED-11164).
  Refresh
  patches.suse/ACPI-thermal-Add-Thermal-fast-Sampling-Period-_TFP-support.patch.
- ACPI: thermal: Fix a small leak in acpi_thermal_add() (jsc#PED-11164).
- ACPI: thermal: Drop valid flag from struct acpi_thermal_trip (jsc#PED-11164).
  Refresh
  patches.suse/ACPI-thermal-Add-Thermal-fast-Sampling-Period-_TFP-support.patch.
  patches.suse/thermal-ACPI-Invalidate-trip-points-with-temperature.patch.
- ACPI: thermal: Drop redundant trip point flags (jsc#PED-11164).
- ACPI: thermal: Untangle initialization and updates of active trips (jsc#PED-11164).
  Refresh
  patches.suse/thermal-ACPI-Invalidate-trip-points-with-temperature.patch.
- ACPI: thermal: Untangle initialization and updates of the passive trip (jsc#PED-11164).
  Refresh
  patches.suse/ACPI-thermal-Add-Thermal-fast-Sampling-Period-_TFP-support.patch.
- ACPI: thermal: Simplify critical and hot trips representation (jsc#PED-11164).
- ACPI: thermal: Create and populate trip points table earlier (jsc#PED-11164).
- ACPI: thermal: Determine the number of trip points earlier (jsc#PED-11164).
  Refresh
  patches.suse/ACPI-thermal-Add-Thermal-fast-Sampling-Period-_TFP-support.patch.
- ACPI: thermal: Fold acpi_thermal_get_info() into its caller (jsc#PED-11164).
- ACPI: thermal: Simplify initialization of critical and hot trips (jsc#PED-11164).
- commit cceb91d
* Mon Oct 14 2024 pjakobsson@suse.de
- drm/amd/display: Create one virtual connector in DC (drm-backport-placeholder).
- Refresh patches.suse/drm-amd-display-adjust-few-initialization-order-in-d.patch.
- Delete patches.suse/drm-amd-display-Stop-amdgpu_dm-initialize-when-link-.patch.
- commit 97522af
* Mon Oct 14 2024 pjakobsson@suse.de
- drm/sched: Drop suffix from drm_sched_wakeup_if_can_queue (drm-backport-placeholder).
- Delete patches.suse/drm-sched-Always-wake-up-correct-scheduler-in-drm_sc.patch.
- commit 8aa726f
* Mon Oct 14 2024 pjakobsson@suse.de
- drm/i915: Track gt pm wakerefs (drm-backport-placeholder).
- Update config files.
- Delete patches.suse/drm-i915-vma-Fix-UAF-on-destroy-against-retire-race.patch.
- commit 3dfaf4b
* Mon Oct 14 2024 pjakobsson@suse.de
- mei: Add MEI hardware support for IVSC device (drm-backport-placeholder).
- Update config files.
- commit 8f3efc6
* Mon Oct 14 2024 tiwai@suse.de
- HID: amd_sfh: Switch to device-managed dmam_alloc_coherent()
  (git-fixes).
- hid: intel-ish-hid: Fix uninitialized variable 'rv' in
  ish_fw_xfer_direct_dma (git-fixes).
- usb: dwc3: core: Stop processing of pending events if controller
  is halted (git-fixes).
- usb: gadget: core: force synchronous registration (git-fixes).
- commit 2bb6fd5
* Sun Oct 13 2024 tiwai@suse.de
- hwmon: (adt7470) Add missing dependency on REGMAP_I2C
  (git-fixes).
- hwmon: (adm9240) Add missing dependency on REGMAP_I2C
  (git-fixes).
- hwmon: (mc34vr500) Add missing dependency on REGMAP_I2C
  (git-fixes).
- hwmon: (tmp513) Add missing dependency on REGMAP_I2C
  (git-fixes).
- hwmon: intel-m10-bmc-hwmon: relabel Columbiaville to CVL Die
  Temperature (git-fixes).
- commit 07e1f67
* Sat Oct 12 2024 tiwai@suse.de
- media: mc: Expand MUST_CONNECT flag to always require an
  enabled link (stable-fixes).
- Refresh
  patches.suse/media-mc-Fix-graph-walk-in-media_pipeline_start.patch.
- commit efed889
* Sat Oct 12 2024 tiwai@suse.de
- i2c: ocores: use devm_ managed clks (git-fixes).
- Refresh
  patches.suse/i2c-ocores-Remove-ifdef-guards-for-PM-related-functi.patch.
- commit cb046a9
* Sat Oct 12 2024 tiwai@suse.de
- Bluetooth: btusb: Don't fail external suspend requests
  (git-fixes).
- Bluetooth: btrtl: Set msft ext address filter quirk for RTL8852B
  (stable-fixes).
- media: mc: Add num_links flag to media_pad (stable-fixes).
- commit 5b595f3
* Sat Oct 12 2024 tiwai@suse.de
- gpio: aspeed: Use devm_clk api to manage clock source
  (git-fixes).
- gpio: aspeed: Add the flush write to ensure the write complete
  (git-fixes).
- ata: libata: avoid superfluous disk spin down + spin up during
  hibernation (git-fixes).
- nouveau/dmem: Fix vulnerability in migrate_to_ram upon copy
  error (git-fixes).
- nouveau/dmem: Fix privileged error in copy engine channel
  (git-fixes).
- drm/vc4: Stop the active perfmon before being destroyed
  (git-fixes).
- drm/v3d: Stop the active perfmon before being destroyed
  (git-fixes).
- drm/i915/hdcp: fix connector refcounting (git-fixes).
- commit 8534efe
* Sat Oct 12 2024 shung-hsi.yu@suse.com
- kABI: bpf: struct bpf_insn_acces_aux kABI workaround (git-fixes).
- commit c2cff36
* Fri Oct 11 2024 vkarasulli@suse.de
- Update
  patches.suse/Bluetooth-btintel_pcie-Allocate-memory-for-driver-pr.patch
  (git-fixes CVE-2024-46869 bsc#1231173).
- commit aa4601c
* Fri Oct 11 2024 vkarasulli@suse.de
- Update patches.suse/ASoC-meson-axg-card-fix-use-after-free.patch
  (git-fixes CVE-2024-46849 bsc#1231073).
- Update
  patches.suse/KVM-x86-Acquire-kvm-srcu-when-handling-KVM_SET_VCPU_.patch
  (git-fixes CVE-2024-46830 bsc#1231116).
- Update
  patches.suse/PCI-keystone-Add-workaround-for-Errata-i2037-AM65x-S.patch
  (stable-fixes CVE-2024-47667 bsc#1231481).
- Update patches.suse/USB-usbtmc-prevent-kernel-usb-infoleak.patch
  (git-fixes CVE-2024-47671 bsc#1231541).
- Update patches.suse/arm64-tlb-Fix-TLBI-RANGE-operand.patch
  (bsc#1229585 CVE-2024-35980 bsc#1224574).
- Update
  patches.suse/dma-buf-heaps-Fix-off-by-one-in-CMA-heap-fault-handl.patch
  (git-fixes CVE-2024-46852 bsc#1231082).
- Update
  patches.suse/drm-amd-amdgpu-Check-tbo-resource-pointer.patch
  (stable-fixes CVE-2024-46807 bsc#1231138).
- Update
  patches.suse/drm-amd-display-Add-array-index-check-for-hdcp-ddc-a.patch
  (stable-fixes CVE-2024-46804 bsc#1231132).
- Update
  patches.suse/drm-amd-display-Avoid-overflow-from-uint32_t-to-uint.patch
  (stable-fixes CVE-2024-47661 bsc#1231496).
- Update
  patches.suse/drm-amd-display-Avoid-race-between-dcn10_set_drr-and.patch
  (git-fixes CVE-2024-46851 bsc#1231081).
- Update
  patches.suse/drm-amd-display-Check-BIOS-images-before-it-is-used.patch
  (stable-fixes CVE-2024-46809 bsc#1231148).
- Update
  patches.suse/drm-amd-display-Check-gpio_id-before-used-as-array-i.patch
  (stable-fixes CVE-2024-46818 bsc#1231203).
- Update
  patches.suse/drm-amd-display-Check-msg_id-before-processing-trans.patch
  (stable-fixes CVE-2024-46814 bsc#1231193).
- Update
  patches.suse/drm-amd-display-Check-num_valid_sets-before-accessin.patch
  (stable-fixes CVE-2024-46815 bsc#1231195).
- Update
  patches.suse/drm-amd-display-Correct-the-defined-value-for-AMDGPU.patch
  (stable-fixes CVE-2024-46871 bsc#1231434).
- Update
  patches.suse/drm-amd-display-Fix-index-may-exceed-array-range-wit.patch
  (stable-fixes CVE-2024-46811 bsc#1231179).
- Update
  patches.suse/drm-amd-display-Remove-register-from-DCN35-DMCUB-dia.patch
  (stable-fixes CVE-2024-47662 bsc#1231440).
- Update
  patches.suse/drm-amd-display-Skip-inactive-planes-within-ModeSupp.patch
  (stable-fixes CVE-2024-46812 bsc#1231187).
- Update
  patches.suse/drm-amd-display-Stop-amdgpu_dm-initialize-when-strea.patch
  (stable-fixes CVE-2024-46817 bsc#1231200).
- Update
  patches.suse/drm-amd-display-added-NULL-check-at-start-of-dc_vali.patch
  (stable-fixes CVE-2024-46802 bsc#1231111).
- Update
  patches.suse/drm-amd-pm-Fix-negative-array-index-read.patch
  (stable-fixes CVE-2024-46821 bsc#1231169).
- Update
  patches.suse/drm-amdgpu-Fix-smatch-static-checker-warning.patch
  (stable-fixes CVE-2024-46835 bsc#1231098).
- Update
  patches.suse/drm-amdgpu-Fix-the-warning-division-or-modulo-by-zer.patch
  (stable-fixes CVE-2024-46806 bsc#1231136).
- Update
  patches.suse/drm-amdgpu-fix-the-waring-dereferencing-hive.patch
  (stable-fixes CVE-2024-46805 bsc#1231135).
- Update
  patches.suse/drm-amdgpu-the-warning-dereferencing-obj-for-nbio_v7.patch
  (stable-fixes CVE-2024-46819 bsc#1231202).
- Update
  patches.suse/drm-amdkfd-Check-debug-trap-enable-before-write-dbg_.patch
  (stable-fixes CVE-2024-46803 bsc#1231131).
- Update
  patches.suse/drm-bridge-tc358767-Check-if-fully-initialized-befor.patch
  (stable-fixes CVE-2024-46810 bsc#1231178).
- Update
  patches.suse/i3c-mipi-i3c-hci-Error-out-instead-on-BUG_ON-in-IBI-.patch
  (stable-fixes CVE-2024-47665 bsc#1231452).
- Update
  patches.suse/lib-generic-radix-tree.c-Fix-rare-race-in-__genradix.patch
  (stable-fixes CVE-2024-47668 bsc#1231502).
- Update
  patches.suse/msft-hv-3054-x86-hyperv-fix-kexec-crash-due-to-VP-assist-page-cor.patch
  (git-fixes CVE-2024-46864 bsc#1231108).
- Update
  patches.suse/nilfs2-fix-state-management-in-error-path-of-log-writing-function.patch
  (git-fixes CVE-2024-47669 bsc#1231474).
- Update
  patches.suse/ocfs2-add-bounds-checking-to-ocfs2_xattr_find_entry.patch
  (bsc#1228410 CVE-2024-41016 CVE-2024-47670 bsc#1231537).
- Update
  patches.suse/perf-x86-intel-Limit-the-period-on-Haswell.patch
  (git-fixes CVE-2024-46848 bsc#1231072).
- Update
  patches.suse/platform-x86-panasonic-laptop-Fix-SINF-array-out-of-.patch
  (git-fixes CVE-2024-46859 bsc#1231089).
- Update
  patches.suse/rcu-Fix-buffer-overflow-in-print_cpu_stall_info.patch
  (bsc#1226623 CVE-2024-38576).
- Update
  patches.suse/rcu-tasks-Fix-show_rcu_tasks_trace_gp_kthread-buffer-overflow.patch
  (bsc#1226631 CVE-2024-38577).
- Update
  patches.suse/scsi-lpfc-Handle-mailbox-timeouts-in-lpfc_get_sfp_in.patch
  (bsc#1228857 CVE-2024-46842 bsc#1231101).
- Update
  patches.suse/spi-nxp-fspi-fix-the-KASAN-report-out-of-bounds-bug.patch
  (git-fixes CVE-2024-46853 bsc#1231083).
- Update
  patches.suse/spi-rockchip-Resolve-unbalanced-runtime-PM-system-PM.patch
  (git-fixes CVE-2024-46846 bsc#1231075).
- Update
  patches.suse/staging-iio-frequency-ad9834-Validate-frequency-para.patch
  (git-fixes CVE-2024-47663 bsc#1231441).
- Update
  patches.suse/usb-gadget-aspeed_udc-validate-endpoint-index-for-as.patch
  (stable-fixes CVE-2024-46836 bsc#1231092).
- Update
  patches.suse/usbnet-ipheth-do-not-stop-RX-on-failing-RX-callback.patch
  (git-fixes CVE-2024-46861 bsc#1231102).
- Update
  patches.suse/wifi-ath12k-fix-firmware-crash-due-to-invalid-peer-n.patch
  (stable-fixes CVE-2024-46827 bsc#1231171).
- Update
  patches.suse/wifi-iwlwifi-mvm-don-t-wait-for-tx-queues-if-firmwar.patch
  (stable-fixes CVE-2024-47672 bsc#1231540).
- Update
  patches.suse/wifi-iwlwifi-mvm-pause-TCM-when-the-firmware-is-stop.patch
  (stable-fixes CVE-2024-47673 bsc#1231539).
- Update
  patches.suse/wifi-iwlwifi-mvm-use-IWL_FW_CHECK-for-link-ID-check.patch
  (stable-fixes CVE-2024-46825 bsc#1231170).
- Update
  patches.suse/wifi-mt76-mt7921-fix-NULL-pointer-access-in-mt7921_i.patch
  (stable-fixes CVE-2024-46860 bsc#1231093).
- commit 1ed6329
* Fri Oct 11 2024 mgorman@suse.de
- sched/smt: Fix unbalance sched_smt_present dec/inc
  (CVE-2024-44958 bsc#1230179).
- sched/smt: Introduce sched_smt_present_inc/dec() helper
  (CVE-2024-44958 bsc#1230179).
- commit b09820b
* Fri Oct 11 2024 tiwai@suse.de
- crypto: octeontx* - Select CRYPTO_AUTHENC (git-fixes).
- commit 155c418
* Fri Oct 11 2024 tiwai@suse.de
- spi: spi-imx: Fix pm_runtime_set_suspended() with runtime pm
  enabled (git-fixes).
- spi: s3c64xx: fix timeout counters in flush_fifo (git-fixes).
- i2c: synquacer: Deal with optional PCLK correctly (git-fixes).
- media: imx335: Fix reset-gpio handling (git-fixes).
- i2c: xiic: Try re-initialization on bus busy timeout
  (git-fixes).
- platform/x86: touchscreen_dmi: add nanote-next quirk
  (stable-fixes).
- platform/x86: lenovo-ymc: Ignore the 0x0 state (stable-fixes).
- hwmon: (nct6775) add G15CF to ASUS WMI monitoring list
  (stable-fixes).
- power: reset: brcmstb: Do not go into infinite loop if reset
  fails (stable-fixes).
- wifi: ath9k_htc: Use __skb_set_length() for resetting urb
  before resubmit (stable-fixes).
- wifi: mt76: mt7915: hold dev->mt76.mutex while disabling tx
  worker (stable-fixes).
- wifi: mt76: mt7915: add dummy HW offload of IEEE 802.11
  fragmentation (stable-fixes).
- wifi: mt76: mt7915: disable tx worker during tx BA session
  enable/disable (stable-fixes).
- wifi: rtw89: avoid reading out of bounds when loading TX power
  FW elements (stable-fixes).
- wifi: rtw89: correct base HT rate mask for firmware
  (stable-fixes).
- wifi: mwifiex: Fix memcpy() field-spanning write warning in
  mwifiex_cmd_802_11_scan_ext() (stable-fixes).
- wifi: cfg80211: Set correct chandef when starting CAC
  (stable-fixes).
- wifi: mac80211: fix RCU list iterations (stable-fixes).
- wifi: iwlwifi: mvm: avoid NULL pointer dereference
  (stable-fixes).
- wifi: iwlwifi: allow only CN mcc from WRDD (stable-fixes).
- wifi: iwlwifi: mvm: drop wrong STA selection in TX
  (stable-fixes).
- wifi: iwlwifi: mvm: Fix a race in scan abort flow
  (stable-fixes).
- wifi: iwlwifi: mvm: use correct key iteration (stable-fixes).
- wifi: ath9k: fix possible integer overflow in
  ath9k_get_et_stats() (stable-fixes).
- wifi: ath11k: fix array out-of-bound access in SoC stats
  (stable-fixes).
- wifi: ath12k: fix array out-of-bound access in SoC stats
  (stable-fixes).
- wifi: rtw89: avoid to add interface to list twice when SER
  (stable-fixes).
- wifi: rtw88: select WANT_DEV_COREDUMP (stable-fixes).
- i2c: xiic: improve error message when transfer fails to start
  (stable-fixes).
- i2c: synquacer: Remove a clk reference from struct synquacer_i2c
  (stable-fixes).
- media: i2c: imx335: Enable regulator supplies (stable-fixes).
- commit 490fb1f
* Fri Oct 11 2024 tiwai@suse.de
- ALSA: usb-audio: Replace complex quirk lines with macros
  (stable-fixes).
- commit 6f67136
* Fri Oct 11 2024 tiwai@suse.de
- Bluetooth: RFCOMM: FIX possible deadlock in
  rfcomm_sk_state_change (git-fixes).
- ACPI: battery: Fix possible crash when unregistering a battery
  hook (git-fixes).
- ACPI: battery: Simplify battery hook locking (stable-fixes).
- ACPI: resource: Add Asus ExpertBook B2502CVA to
  irq1_level_low_skip_override[] (stable-fixes).
- ACPI: resource: Add Asus Vivobook X1704VAP to
  irq1_level_low_skip_override[] (stable-fixes).
- HID: Ignore battery for all ELAN I2C-HID devices (stable-fixes).
- HID: multitouch: Add support for Thinkpad X12 Gen 2 Kbd
  Portfolio (stable-fixes).
- ASoC: codecs: wsa883x: Handle reading version failure
  (stable-fixes).
- ALSA: usb-audio: Add logitech Audio profile quirk
  (stable-fixes).
- ALSA: usb-audio: Define macros for quirk table entries
  (stable-fixes).
- ALSA: hdsp: Break infinite MIDI input flush loop (stable-fixes).
- ALSA: asihpi: Fix potential OOB array access (stable-fixes).
- ALSA: usb-audio: Add input value sanity checks for standard
  types (stable-fixes).
- ACPI: PAD: fix crash in exit_round_robin() (stable-fixes).
- ACPI: video: Add force_vendor quirk for Panasonic Toughbook
  CF-18 (stable-fixes).
- ACPI: CPPC: Add support for setting EPP register in FFH
  (stable-fixes).
- ACPI: EC: Do not release locks during operation region accesses
  (stable-fixes).
- ACPICA: iasl: handle empty connection_node (stable-fixes).
- ACPICA: Fix memory leak if acpi_ps_get_next_field() fails
  (stable-fixes).
- ACPICA: Fix memory leak if acpi_ps_get_next_namepath() fails
  (stable-fixes).
- ACPICA: check null return of ACPI_ALLOCATE_ZEROED() in
  acpi_db_convert_to_package() (stable-fixes).
- crypto: octeontx2 - Fix authenc setkey (stable-fixes).
- crypto: octeontx - Fix authenc setkey (stable-fixes).
- Bluetooth: btusb: Add Realtek RTL8852C support ID 0x0489:0xe122
  (stable-fixes).
- can: netlink: avoid call to do_set_data_bittiming callback
  with stale can_priv::ctrlmode (stable-fixes).
- commit 650f32e
* Fri Oct 11 2024 pjakobsson@suse.de
- mei: Add Meteor Lake support for IVSC device (drm-backport-placeholder)
- commit c9f9c94
* Fri Oct 11 2024 pjakobsson@suse.de
- Revert "drm/udl: Add ARGB8888 as a format" (drm-backport-placeholder)
- commit 4491cc1
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/udl: Add ARGB8888 as a format (drm-backport-placeholder)
- commit ca076c1
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Return immediately on tile_init failure (drm-backport-placeholder)
- commit 0b33d93
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915/panelreplay: Move out psr_init_dpcd() from init_connector() (drm-backport-placeholder)
- commit 40162f1
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915/dp: Fix connector DSC HW state readout (drm-backport-placeholder)
- commit cde2136
* Fri Oct 11 2024 pjakobsson@suse.de
- fbdev/hyperv_fb: Fix logic error for Gen2 VMs in hvfb_getmem() (drm-backport-placeholder)
- commit 9694c83
* Fri Oct 11 2024 pjakobsson@suse.de
- Revert "drm/msm/dp: use drm_bridge_hpd_notify() to report HPD status (drm-backport-placeholder)
- commit cb02374
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/xe_trace: Add move_lacks_source detail to xe_bo_move trace (drm-backport-placeholder)
- commit 1d2f94a
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Deny unbinds if uapi ufence pending (drm-backport-placeholder)
- commit 6452a9a
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Expose user fence from xe_sync_entry (drm-backport-placeholder)
- commit 7e074e0
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Use pointers in trace events (drm-backport-placeholder)
- commit 769b1ed
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/xe_bo_move: Enhance xe_bo_move trace (drm-backport-placeholder)
- commit 4de96ee
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/mmio: fix build warning for BAR resize on 32-bit (drm-backport-placeholder)
- commit d5c548e
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: get rid of MAX_BINDS (drm-backport-placeholder).
- commit 0e403e2
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Use vmalloc for array of bind allocation in bind IOCTL (drm-backport-placeholder)
- commit a88dbd4
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Don't support execlists in xe_gt_tlb_invalidation layer (drm-backport-placeholder)
- commit 00fa731
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Fix execlist splat (drm-backport-placeholder)
- commit 6f390c0
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/uapi: Remove unused flags (drm-backport-placeholder)
- commit 873c283
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/uapi: Remove DRM_XE_VM_BIND_FLAG_ASYNC comment left over (drm-backport-placeholder)
- commit 4734edf
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Add uapi for dumpable bos (drm-backport-placeholder)
- commit 6e58420
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/ttm/tests: depend on UML || COMPILE_TEST (drm-backport-placeholder)
- commit b144cbe
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/bridge: aux-hpd: separate allocation and registration (drm-backport-placeholder)
- commit 46cf03e
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/bridge: aux-hpd: fix OF node leaks (drm-backport-placeholder)
- commit ee3dc5f
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Fix modpost warning on xe_mocs kunit module (drm-backport-placeholder)
- commit b737e26
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/xe_gt_idle: Drop redundant newline in name (drm-backport-placeholder)
- commit c3e0b54
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Return 2MB page size for compact 64k PTEs (drm-backport-placeholder)
- commit d429776
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Add XE_VMA_PTE_64K VMA flag (drm-backport-placeholder)
- commit fc149ff
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Fix xe_vma_set_pte_size (drm-backport-placeholder)
- commit efb32b8
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/uapi: Remove support for persistent exec_queues (drm-backport-placeholder)
- commit 1020d3e
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/msm/a6xx: set highest_bank_bit to 13 for a610 (drm-backport-placeholder)
- commit 59ea0ac
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: Fix implicit assumtion in gfx11 debug flags (drm-backport-placeholder)
- commit 3d0b43e
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdkfd: update SIMD distribution algo for GFXIP 9.4.2 onwards (drm-backport-placeholder)
- commit 7d3440a
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Increase ips2_eval delay for DCN35 (drm-backport-placeholder)
- commit ad92b7e
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: avoid function cast warnings (drm-backport-placeholder)
- commit 619f1a0
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/pt: Allow for stricter type- and range checking (drm-backport-placeholder)
- commit b853f3d
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/display: fix i915_gem_object_is_shmem() wrapper (drm-backport-placeholder)
- commit ba4f3fe
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/vm: Avoid reserving zero fences (drm-backport-placeholder)
- commit 185f9d6
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/rockchip: vop2: add a missing unlock in vop2_crtc_atomic_enable() (drm-backport-placeholder)
- commit edab9d3
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/nouveau: omit to create schedulers using the legacy uAPI (drm-backport-placeholder)
- commit ca72408
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/nouveau: don't fini scheduler if not initialized (drm-backport-placeholder)
- commit b95614c
* Fri Oct 11 2024 pjakobsson@suse.de
- accel/ivpu: Fix DevTLB errors on suspend/resume and recovery (drm-backport-placeholder)
- commit f714026
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/msm/mdss: specify cfg bandwidth for SDM670 (drm-backport-placeholder)
- commit d18716f
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Implement bounds check for stream encoder creation (drm-backport-placeholder git-fixes CVE-2024-26660 bsc#1222266)
- commit 1793720
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Clear phantom stream count and plane count (drm-backport-placeholder)
- commit a884fd5
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Disable ODM by default for DCN35 (drm-backport-placeholder)
- commit 395c3fd
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Update phantom pipe enable / disable sequence (drm-backport-placeholder)
- commit 85bef83
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Increase eval/entry delay for DCN35 (drm-backport-placeholder)
- commit c0da823
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: remove asymmetrical irq disabling in jpeg 4.0.5 suspend (drm-backport-placeholder)
- commit 662b8c8
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: set odm_combine_policy based on context in dcn32 (drm-backport-placeholder)
- commit a26cd1e
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915: Replace dead 01.org link (drm-backport-placeholder)
- commit c43e0e0
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Remove TEST_VM_ASYNC_OPS_ERROR (drm-backport-placeholder)
- commit 9602636
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/vm: don't ignore error when in_kthread (drm-backport-placeholder)
- commit 947faf1
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Assume large page size if VMA not yet bound (drm-backport-placeholder)
- commit b46144c
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/display: Fix memleak in display initialization (drm-backport-placeholder)
- commit e9a8251
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Map both mem.kernel_bb_pool and usm.bb_pool (drm-backport-placeholder)
- commit 7f5f200
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: circumvent bogus stringop-overflow warning (drm-backport-placeholder)
- commit 1e4ebc6
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Pick correct userptr VMA to repin on REMAP op failure (drm-backport-placeholder)
- commit dadfd2c
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Take a reference in xe_exec_queue_last_fence_get() (drm-backport-placeholder)
- commit 7cec96c
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Fix loop in vm_bind_ioctl_ops_unwind (drm-backport-placeholder)
- commit d4c8342
* Fri Oct 11 2024 pjakobsson@suse.de
- accel/ivpu: Add job status for jobs aborted by the driver (drm-backport-placeholder)
- commit a9796dc
* Fri Oct 11 2024 pjakobsson@suse.de
- accel/ivpu/40xx: Stop passing SKU boot parameters to FW (drm-backport-placeholder)
- commit 7f3500d
* Fri Oct 11 2024 pjakobsson@suse.de
- accel/ivpu/40xx: Enable D0i3 message (drm-backport-placeholder)
- commit 64089fc
* Fri Oct 11 2024 pjakobsson@suse.de
- accel/ivpu: Disable d3hot_delay on all NPU generations (drm-backport-placeholder)
- commit dffc492
* Fri Oct 11 2024 pjakobsson@suse.de
- accel/ivpu: Correct MMU queue size checking functions (drm-backport-placeholder)
- commit 5e3f133
* Fri Oct 11 2024 pjakobsson@suse.de
- accel/ivpu: Force snooping for MMU writes (drm-backport-placeholder)
- commit e4aabb2
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/sched: Re-queue run job worker when drm_sched_entity_pop_job() (drm-backport-placeholder)
- commit 4f07212
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu/pm: Use inline function for IP version check (drm-backport-placeholder)
- commit 92457b8
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: remove asymmetrical irq disabling in vcn 4.0.5 suspend (drm-backport-placeholder)
- commit e022aea
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: drm/amdgpu: remove golden setting for gfx 11.5.0 (drm-backport-placeholder)
- commit c5fd093
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: Fix the warning info in mode1 reset (drm-backport-placeholder)
- commit 66a04f9
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Underflow workaround by increasing SR exit latency (drm-backport-placeholder)
- commit 3b71c53
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Fix DPSTREAM CLK on and off sequence (drm-backport-placeholder)
- commit 96906a8
* Fri Oct 11 2024 pjakobsson@suse.de
- Revert "drm/amd/display: initialize all the dpm level's stutter latency" (drm-backport-placeholder).
- Refresh patches.suse/drm-amd-display-fix-input-states-translation-error-f.patch.
- commit 7e7500b
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdkfd: Use S_ENDPGM_SAVED in trap handler (drm-backport-placeholder)
- commit b28cb90
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdkfd: Correct partial migration virtual addr (drm-backport-placeholder)
- commit 9ddb9be
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: move the drm client creation behind drm device (drm-backport-placeholder)
- commit 66e03f5
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Make all GuC ABI shift values unsigned (drm-backport-placeholder)
- commit 386c9d1
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/vm: Subclass userptr vmas (drm-backport-placeholder)
- commit 5edf0d9
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Use LRC prefix rather than CTX prefix in lrc desc defines (drm-backport-placeholder)
- commit 81b32d7
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Don't use __user error pointers (drm-backport-placeholder)
- commit 0127410
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Annotate mcr_[un]lock() (drm-backport-placeholder)
- commit e077ba0
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Only allow 1 ufence per exec / bind IOCTL (drm-backport-placeholder)
- commit dc9994c
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Grab mem_access when disabling C6 on skip_guc_pc platforms (drm-backport-placeholder)
- commit 160665f
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Fix crash in trace_dma_fence_init() (drm-backport-placeholder)
- commit 0022b2f
* Fri Oct 11 2024 pjakobsson@suse.de
- dma-buf: heaps: Don't track CMA dma-buf pages under RssFile (drm-backport-placeholder).
- Refresh patches.suse/dma-buf-heaps-Fix-off-by-one-in-CMA-heap-fault-handl.patch.
- commit 81d4202
* Fri Oct 11 2024 pjakobsson@suse.de
- accel/ivpu: Improve recovery and reset support (drm-backport-placeholder)
- commit ed3428e
* Fri Oct 11 2024 pjakobsson@suse.de
- accel/ivpu: Improve stability of ivpu_submit_ioctl() (drm-backport-placeholder)
- commit 44b6962
* Fri Oct 11 2024 pjakobsson@suse.de
- accel/ivpu: Fix dev open/close races with unbind (drm-backport-placeholder)
- commit c4a3d4a
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/dp_mst: Separate @failing_port list in (drm-backport-placeholder)
- commit 93c8aa8
* Fri Oct 11 2024 pjakobsson@suse.de
- accel/ivpu: Deprecate DRM_IVPU_PARAM_CONTEXT_PRIORITY param (drm-backport-placeholder)
- commit 3067a56
* Fri Oct 11 2024 pjakobsson@suse.de
- accel/ivpu: Improve buffer object debug logs (drm-backport-placeholder)
- commit d8e558b
* Fri Oct 11 2024 pjakobsson@suse.de
- accel/ivpu: Disable buffer sharing among VPU contexts (drm-backport-placeholder)
- commit 4243030
* Fri Oct 11 2024 pjakobsson@suse.de
- accel/ivpu: Free buffer sgt on unbind (drm-backport-placeholder)
- commit 097fa0c
* Fri Oct 11 2024 pjakobsson@suse.de
- accel/ivpu: Fix for missing lock around drm_gem_shmem_vmap() (drm-backport-placeholder)
- commit 811d7e1
* Fri Oct 11 2024 pjakobsson@suse.de
- accel/ivpu: Add diagnostic messages when VPU fails to boot or suspend (drm-backport-placeholder)
- commit 09ae78b
* Fri Oct 11 2024 pjakobsson@suse.de
- accel/ivpu: Add debug prints for MMU map/unmap operations (drm-backport-placeholder)
- commit fb5e033
* Fri Oct 11 2024 pjakobsson@suse.de
- accel/ivpu: Call diagnose failure in ivpu_mmu_cmdq_sync() (drm-backport-placeholder)
- commit 78b525a
* Fri Oct 11 2024 pjakobsson@suse.de
- accel/ivpu: Dump MMU events in case of VPU boot timeout (drm-backport-placeholder)
- commit 01fe6c2
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/tests: mm: Call drm_mm_print in drm_test_mm_debug (drm-backport-placeholder)
- commit 299e8a1
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/ttm: allocate dummy_read_page without DMA32 on fail (drm-backport-placeholder)
- commit d9b3704
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/sched: Drain all entities in DRM sched run job worker (drm-backport-placeholder)
- commit 28c06f6
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: "Enable IPS by default" (drm-backport-placeholder)
- commit 86e8859
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd: Add a DC debug mask for IPS (drm-backport-placeholder)
- commit e783925
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Replay + IPS + ABM in Full Screen VPB (drm-backport-placeholder)
- commit 285641c
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Add IPS checks before dcn register access (drm-backport-placeholder).
- Refresh patches.suse/drm-amd-display-Fix-uninitialized-variables-in-DM.patch.
- commit 0865f76
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Add Replay IPS register for DMUB command table (drm-backport-placeholder)
- commit fd75538
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Allow IPS2 during Replay (drm-backport-placeholder)
- commit 77aded0
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: Fix null pointer dereference (drm-backport-placeholder)
- commit 9c64f38
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/pm: udpate smu v13.0.6 message permission (drm-backport-placeholder)
- commit 53b0795
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Remove PVC from xe_wa kunit tests (drm-backport-placeholder)
- commit 87f3c02
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/vm: bugfix in xe_vm_create_ioctl (drm-backport-placeholder)
- commit b14b451
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/xe2: Use XE_CACHE_WB pat index (drm-backport-placeholder)
- commit fa355b5
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/display: Avoid calling readq() (drm-backport-placeholder)
- commit f254e00
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/mmio: Cast to u64 when printing (drm-backport-placeholder)
- commit 56ebae1
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Use _ULL for u64 division (drm-backport-placeholder)
- commit 4bf07a6
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Use a NULL pointer instead of 0. (drm-backport-placeholder)
- commit cddc5a2
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/dmabuf: Make xe_dmabuf_ops static (drm-backport-placeholder)
- commit 50650ed
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/exynos: fix incorrect type issue (drm-backport-placeholder)
- commit 94c7415
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/v3d: Free the job and assign it to NULL if initialization fails (drm-backport-placeholder)
- commit 70d5e08
* Fri Oct 11 2024 pjakobsson@suse.de
- fbdev: stifb: Fix crash in stifb_blank() (drm-backport-placeholder)
- commit 7db1c76
* Fri Oct 11 2024 pjakobsson@suse.de
- fbcon: Fix incorrect printed function name in fbcon_prepare_logo() (drm-backport-placeholder)
- commit e1fd7b7
* Fri Oct 11 2024 pjakobsson@suse.de
- fbdev: vt8500lcdfb: Remove unnecessary print function dev_err() (drm-backport-placeholder)
- commit 40480d2
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/ttm: fix ttm pool initialization for no-dma-device drivers (drm-backport-placeholder)
- commit 96d908e
* Fri Oct 11 2024 pjakobsson@suse.de
- Revert "firmware/sysfb: Clear screen_info state after consuming it" (drm-backport-placeholder).
- Refresh patches.suse/Add-parameter-to-disable-simple-framebuffer-devices.patch.
- Refresh patches.suse/drivers-firmware-skip-simpledrm-if-nvidia-drm.modese.patch.
- commit e6001e2
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: display support should not depend on EXPERT (drm-backport-placeholder)
- commit a8ae1e9
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Fix bounds checking in __xe_bo_placement_for_flags() (drm-backport-placeholder)
- commit 2cd97bd
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/migrate: Fix CCS copy for small VRAM copy chunks (drm-backport-placeholder)
- commit 40e5809
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: unlock on error path in xe_vm_add_compute_exec_queue() (drm-backport-placeholder)
- commit 9de6f92
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/selftests: Fix an error pointer dereference bug (drm-backport-placeholder)
- commit c6ef562
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/device: clean up on error in probe() (drm-backport-placeholder)
- commit aa7b4a6
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Fix build bug for GCC 11 (drm-backport-placeholder)
- commit b08e249
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Check skip_guc_pc before setting SLPC flag (drm-backport-placeholder)
- commit 4dd6f7d
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Fix modifying exec_queue priority in xe_migrate_init (drm-backport-placeholder)
- commit bad272b
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Fix guc_exec_queue_set_priority (drm-backport-placeholder)
- commit ce5fd8a
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Annotate xe_ttm_stolen_mgr::mapping with __iomem (drm-backport-placeholder)
- commit 751631e
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Annotate multiple mmio pointers with __iomem (drm-backport-placeholder)
- commit 6d897c1
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Annotate xe_mem_region::mapping with __iomem (drm-backport-placeholder)
- commit 1505db7
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Use __iomem for the regs pointer (drm-backport-placeholder)
- commit 10d09f8
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe/vm: Fix an error path (drm-backport-placeholder)
- commit 65fa1ea
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Fix exec IOCTL long running exec queue ring full condition (drm-backport-placeholder)
- commit 6ff84ba
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/xe: Fix definition of intel_wakeref_t (drm-backport-placeholder)
- commit 1b93dfe
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Drop 'acrtc' and add 'new_crtc_state' NULL check for (drm-backport-placeholder)
- commit 908926d
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdkfd: init drm_client with funcs hook (drm-backport-placeholder)
- commit cb7e38a
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Clear OPTC mem select on disable (drm-backport-placeholder)
- commit 282eb07
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Add logging resource checks (drm-backport-placeholder)
- commit dc0ab83
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Init link enc resources in dc_state only if res_pool (drm-backport-placeholder)
- commit a805750
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: move debug options init prior to amdgpu device init (drm-backport-placeholder)
- commit 993efad
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: add debug flag to place fw bo on vram for frontdoor (drm-backport-placeholder)
- commit 65233c6
* Fri Oct 11 2024 pjakobsson@suse.de
- Revert "drm/amdgpu: add param to specify fw bo location for front-door loading" (drm-backport-placeholder).
- Refresh patches.suse/drm-amdgpu-make-damage-clips-support-configurable.patch.
- commit 25ff115
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: Fix unsigned comparison with less than zero in (drm-backport-placeholder)
- commit 82ff0d4
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: Do not program VM_L2_CNTL under SRIOV (drm-backport-placeholder)
- commit 222db77
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: update ATHUB_MISC_CNTL offset for athub v3.3 (drm-backport-placeholder)
- commit 35fb932
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: update headers for nbio v7.11 (drm-backport-placeholder)
- commit 82f4ad0
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu/pm: clarify debugfs pm output (drm-backport-placeholder)
- commit 6abe0b2
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: cleanup inconsistent indenting in amdgpu_dm_color (drm-backport-placeholder)
- commit d0b05d0
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: make a correction on comment (drm-backport-placeholder)
- commit cbb7401
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdkfd: Fix sparse __rcu annotation warnings (drm-backport-placeholder)
- commit 5c505a0
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: Packed socket_id to ras feature mask (drm-backport-placeholder)
- commit 7d541ad
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: Support poison error injection via ras_ctrl debugfs (drm-backport-placeholder)
- commit 9787bb2
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: Drop unnecessary sentences about CE and deferred error. (drm-backport-placeholder)
- commit 5d41d03
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.266 (drm-backport-placeholder)
- commit 9b3045b
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Dpia hpd status not in sync after S4 (drm-backport-placeholder)
- commit 5d2bf30
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Update z8 latency (drm-backport-placeholder)
- commit f34e7f3
* Fri Oct 11 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Fix conversions between bytes and KB" (drm-backport-placeholder)
- commit fac7a19
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: revert "Optimize VRR updates to only necessary ones" (drm-backport-placeholder)
- commit 9e58e36
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: revert "for FPO & SubVP/DRR config program vmin/max" (drm-backport-placeholder)
- commit cb8b407
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Disconnect phantom pipe OPP from OPTC being disabled (drm-backport-placeholder)
- commit 0c04c82
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/pm: Remove I2C_CLASS_SPD support (drm-backport-placeholder)
- commit d3cbb13
* Fri Oct 11 2024 pjakobsson@suse.de
- fbdev: remove I2C_CLASS_DDC support (drm-backport-placeholder)
- commit 589cf87
* Fri Oct 11 2024 pjakobsson@suse.de
- drm: remove I2C_CLASS_DDC support (drm-backport-placeholder)
- commit 9d29aaa
* Fri Oct 11 2024 pjakobsson@suse.de
- backlight: ili922x: Add an error code check in ili922x_write() (drm-backport-placeholder)
- commit 701d84e
* Fri Oct 11 2024 pjakobsson@suse.de
- backlight: ili922x: Drop kernel-doc for local macros (drm-backport-placeholder)
- commit 981de59
* Fri Oct 11 2024 pjakobsson@suse.de
- backlight: mp3309c: Fix uninitialized local variable (drm-backport-placeholder)
- commit e9da56e
* Fri Oct 11 2024 pjakobsson@suse.de
- backlight: pwm_bl: Use dev_err_probe (drm-backport-placeholder)
- commit 249b582
* Fri Oct 11 2024 pjakobsson@suse.de
- iommu/tegra: Use tegra_dev_iommu_get_stream_id() in the remaining (drm-backport-placeholder)
- commit 2169294
* Fri Oct 11 2024 pjakobsson@suse.de
- mei: vsc: Rework firmware image names (drm-backport-placeholder)
- commit 5ad4eda
* Fri Oct 11 2024 pjakobsson@suse.de
- mei: pxp: spdx should be at first line (drm-backport-placeholder)
- commit cd54fdb
* Fri Oct 11 2024 pjakobsson@suse.de
- mei: fix spellos in mei.h (drm-backport-placeholder)
- commit b93b3d2
* Fri Oct 11 2024 pjakobsson@suse.de
- vgacon: drop IA64 reference in VGA_CONSOLE dependency list (drm-backport-placeholder)
- commit 316ebad
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/v3d: Fix support for register debugging on the RPi 4 (drm-backport-placeholder)
- commit c1d0212
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/rockchip: vop2: Drop unused if_dclk_rate variable (drm-backport-placeholder)
- commit 1047fde
* Fri Oct 11 2024 ailiop@suse.com
- ocfs2: fix the la space leak when unmounting an ocfs2 volume
  (git-fixes).
- commit 92d1b30
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/rockchip: vop2: Drop superfluous include (drm-backport-placeholder)
- commit ae0cdc4
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915/perf: reconcile Excess struct member kernel-doc warnings (drm-backport-placeholder)
- commit 794e492
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915/guc: reconcile Excess struct member kernel-doc warnings (drm-backport-placeholder)
- commit b668a68
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915/gt: reconcile Excess struct member kernel-doc warnings (drm-backport-placeholder)
- commit aa6b866
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915/gem: reconcile Excess struct member kernel-doc warnings (drm-backport-placeholder)
- commit d1d21ce
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915: don't make assumptions about intel_wakeref_t type (drm-backport-placeholder)
- commit d282aef
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915/dp: Fix the PSR debugfs entries wrt. MST connectors (drm-backport-placeholder)
- commit cb10629
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915/display: Fix C20 pll selection for state verification (drm-backport-placeholder)
- commit f01f406
* Fri Oct 11 2024 pjakobsson@suse.de
- pwm: Rename pwm_apply_state() to pwm_apply_might_sleep() (drm-backport-placeholder).
- Refresh patches.suse/leds-pwm-Disable-PWM-when-going-to-suspend.patch.
- commit 614fe91
* Fri Oct 11 2024 ailiop@suse.com
- jfs: Fix uninit-value access of new_ea in ea_buffer (git-fixes).
- commit b1e0ef1
* Fri Oct 11 2024 ailiop@suse.com
- jfs: check if leafidx greater than num leaves per dmap tree
  (git-fixes).
- commit 4cb79e7
* Fri Oct 11 2024 ailiop@suse.com
- jfs: Fix uaf in dbFreeBits (git-fixes).
- commit da4aab1
* Fri Oct 11 2024 ailiop@suse.com
- jfs: UBSAN: shift-out-of-bounds in dbFindBits (git-fixes).
- commit fee8a70
* Fri Oct 11 2024 pjakobsson@suse.de
- fbdev/hyperv_fb: Do not clear global screen_info (drm-backport-placeholder)
- commit 90b5dec
* Fri Oct 11 2024 pjakobsson@suse.de
- firmware/sysfb: Clear screen_info state after consuming it (drm-backport-placeholder).
- Refresh patches.suse/Add-parameter-to-disable-simple-framebuffer-devices.patch.
- Refresh patches.suse/drivers-firmware-skip-simpledrm-if-nvidia-drm.modese.patch.
- commit a4ba9bb
* Fri Oct 11 2024 pjakobsson@suse.de
- fbdev/hyperv_fb: Remove firmware framebuffers with aperture helpers (drm-backport-placeholder)
- commit 00d216d
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/hyperv: Remove firmware framebuffers with aperture helper (drm-backport-placeholder)
- commit 2870c59
* Fri Oct 11 2024 pjakobsson@suse.de
- fbdev/sis: Remove dependency on screen_info (drm-backport-placeholder)
- commit ee7cc3d
* Fri Oct 11 2024 pjakobsson@suse.de
- video/logo: use %%u format specifier for unsigned int values (drm-backport-placeholder)
- commit 3b328cc
* Fri Oct 11 2024 pjakobsson@suse.de
- video/sticore: Remove info field from STI struct (drm-backport-placeholder)
- commit d7fd36c
* Fri Oct 11 2024 pjakobsson@suse.de
- arch/parisc: Detect primary video device from device instance (drm-backport-placeholder)
- commit 72aefb9
* Fri Oct 11 2024 pjakobsson@suse.de
- fbdev/stifb: Allocate fb_info instance with framebuffer_alloc() (drm-backport-placeholder)
- commit 1207e3c
* Fri Oct 11 2024 pjakobsson@suse.de
- video/sticore: Store ROM device in STI struct (drm-backport-placeholder)
- commit d60262b
* Fri Oct 11 2024 pjakobsson@suse.de
- fbdev: flush deferred IO before closing (drm-backport-placeholder)
- commit a1cdb96
* Fri Oct 11 2024 pjakobsson@suse.de
- fbdev: hgafb: fix kernel-doc comments (drm-backport-placeholder)
- commit 9db63d4
* Fri Oct 11 2024 pjakobsson@suse.de
- fbdev: fsl-diu-fb: Fix sparse warning due to virt_to_phys() prototype (drm-backport-placeholder)
- commit 90d9710
* Fri Oct 11 2024 pjakobsson@suse.de
- fbdev: imxfb: add '*/' on a separate line in block comment (drm-backport-placeholder)
- commit 6e65441
* Fri Oct 11 2024 pjakobsson@suse.de
- fbdev: imxfb: use __func__ for function name (drm-backport-placeholder)
- commit a83dd2d
* Fri Oct 11 2024 pjakobsson@suse.de
- fbdev: imxfb: Fix style warnings relating to printk() (drm-backport-placeholder)
- commit 1aa10f9
* Fri Oct 11 2024 pjakobsson@suse.de
- fbdev: imxfb: add missing spaces after ',' (drm-backport-placeholder)
- commit f7caaec
* Fri Oct 11 2024 pjakobsson@suse.de
- fbdev: imxfb: drop ftrace-like logging (drm-backport-placeholder)
- commit 68e1575
* Fri Oct 11 2024 pjakobsson@suse.de
- fbdev: imxfb: add missing SPDX tag (drm-backport-placeholder)
- commit 0ccfc63
* Fri Oct 11 2024 pjakobsson@suse.de
- fbdev: imxfb: replace some magic numbers with constants (drm-backport-placeholder)
- commit bd2596f
* Fri Oct 11 2024 pjakobsson@suse.de
- fbdev: imxfb: use BIT, FIELD_{GET,PREP} and GENMASK macros (drm-backport-placeholder)
- commit 5096b5c
* Fri Oct 11 2024 pjakobsson@suse.de
- fbdev: imxfb: move PCR bitfields near their offset (drm-backport-placeholder)
- commit ff40ed5
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915: Use kmap_local_page() in gem/i915_gem_execbuffer.c (drm-backport-placeholder)
- commit ed12366
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915: Use kmap_local_page() in i915_cmd_parser.c (drm-backport-placeholder)
- commit d0f5927
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915: Use memcpy_from_page() in gt/uc/intel_uc_fw.c (drm-backport-placeholder)
- commit ef13d22
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915: Use kmap_local_page() in gem/selftests/i915_gem_context.c (drm-backport-placeholder)
- commit 3ea7d61
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915: Use kmap_local_page() in gem/selftests/i915_gem_coherency.c (drm-backport-placeholder)
- commit 7344ca3
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915: Use kmap_local_page() in gem/selftests/huge_pages.c (drm-backport-placeholder)
- commit 6622ef6
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915: Use kmap_local_page() in gem/i915_gem_shmem.c (drm-backport-placeholder)
- commit 33fe2b4
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915: Use memcpy_[from/to]_page() in gem/i915_gem_pyhs.c (drm-backport-placeholder)
- commit 70f5794
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915: Use kmap_local_page() in gem/i915_gem_object.c (drm-backport-placeholder)
- commit d9fe030
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915: Add Wa_14019877138 (drm-backport-placeholder)
- commit a7fbae7
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915/uapi: fix typos/spellos and punctuation (drm-backport-placeholder)
- commit dd6ee07
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/i915/selftests: Fix spelling mistake "initialiased" -> (drm-backport-placeholder)
- commit 27730fe
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Allow z8/z10 from driver (drm-backport-placeholder)
- commit 6f11802
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Move fixpt_from_s3132 to amdgpu_dm (drm-backport-placeholder)
- commit c73d22f
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Fix recent checkpatch errors in amdgpu_dm (drm-backport-placeholder)
- commit 486c8fe
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Fix power_helpers.c codestyle (drm-backport-placeholder)
- commit c460565
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Fix hdcp_log.h codestyle (drm-backport-placeholder)
- commit 905f52c
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Fix hdcp2_execution.c codestyle (drm-backport-placeholder)
- commit cb80693
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Fix hdcp_psp.h codestyle (drm-backport-placeholder)
- commit dae4412
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Fix freesync.c codestyle (drm-backport-placeholder)
- commit d094324
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Fix hdcp_psp.c codestyle (drm-backport-placeholder)
- commit dc0688f
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Fix hdcp1_execution.c codestyle (drm-backport-placeholder)
- commit d7759a9
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: add param to specify fw bo location for front-door loading (drm-backport-placeholder).
- Refresh patches.suse/drm-amdgpu-make-damage-clips-support-configurable.patch.
- commit 5f5333a
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: Remove unreachable code in 'atom_skip_src_int()' (drm-backport-placeholder)
- commit 4e15eed
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Removing duplicate copyright text (drm-backport-placeholder)
- commit 05fc4c6
* Fri Oct 11 2024 pjakobsson@suse.de
- Revert "drm/amdgpu: enable mca debug mode on APU by default" (drm-backport-placeholder)
- commit 19cf82f
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: Drop redundant unsigned >=0 comparision (drm-backport-placeholder)
- commit 39216d0
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Adjust kdoc for 'dcn35_hw_block_power_down' & (drm-backport-placeholder)
- commit 8a69a69
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Address function parameter 'context' not described (drm-backport-placeholder)
- commit cf9056c
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: Use kvcalloc instead of kvmalloc_array in (drm-backport-placeholder)
- commit f495694
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: Use kzalloc instead of kmalloc+__GFP_ZERO in amdgpu_ras.c (drm-backport-placeholder)
- commit d5a1877
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amdgpu: Cleanup indenting in amdgpu_connector_dvi_detect() (drm-backport-placeholder)
- commit 44bd642
* Fri Oct 11 2024 pjakobsson@suse.de
- drm/amd/display: Add some functions for Panel Replay (drm-backport-placeholder)
- commit d63bc3e
* Fri Oct 11 2024 pjakobsson@suse.de
- Re-revert "drm/amd/display: Enable Replay for static screen use cases" (drm-backport-placeholder).
- commit bce0433
* Fri Oct 11 2024 shung-hsi.yu@suse.com
- kABI: bpf: enum bpf_{type_flag,arg_type} kABI workaround (git-fixes).
- commit 93e6047
* Thu Oct 10 2024 vkarasulli@suse.de
- iommu/amd: Allocate the page table root using GFP_KERNEL
  (git-fixes).
- commit cdbbb3f
* Thu Oct 10 2024 vkarasulli@suse.de
- iommu/amd: Fix typo of , instead of ; (git-fixes).
- commit baf85d0
* Thu Oct 10 2024 nmorey@suse.com
- VMCI: Remove handle_arr_calc_size() (jsc#PED-11026)
- commit 9ebfd1f
* Thu Oct 10 2024 nmorey@suse.com
- VMCI: Remove VMCI_HANDLE_ARRAY_HEADER_SIZE and VMCI_HANDLE_ARRAY_MAX_CAPACITY (jsc#PED-11026)
- commit cea5601
* Thu Oct 10 2024 nmorey@suse.com
- VMCI: Use struct_size() in kmalloc() (jsc#PED-11026)
- commit ac2562c
* Thu Oct 10 2024 dwagner@suse.de
- block: sed-opal: add ioctl IOC_OPAL_SET_SID_PW (bsc#1229677).
- commit 5ca02dc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Fixing stream allocation regression (drm-backport-placeholder)
- commit 1fb84a8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Verify disallow bits were cleared for idle (drm-backport-placeholder)
- commit 2488b67
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Fix Mismatch between pipe and stream (drm-backport-placeholder)
- commit 16f59a5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Refactor INIT into component folder (drm-backport-placeholder)
- commit b4489e3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Switch DMCUB notify idle command to NO_WAIT (drm-backport-placeholder)
- commit 7967383
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amdgpu/gfx11: need acquire mutex before access CP_VMID_RESET v2 (drm-backport-placeholder)
- commit c37770d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Wait forever for DMCUB to wake up (drm-backport-placeholder)
- commit 1579324
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Always exit DMCUB idle when called (drm-backport-placeholder)
- commit 16ff136
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Add log end specifier (drm-backport-placeholder)
- commit 04d2245
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Assign stream status for FPO + Vactive cases (drm-backport-placeholder)
- commit 3f937de
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Correctly restore user_level (drm-backport-placeholder)
- commit 365552a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Add null pointer guards where needed (drm-backport-placeholder)
- commit f0e498b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Add HDMI capacity computations using fixed31_32 (drm-backport-placeholder)
- commit 7be3d6a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Add more mechanisms for tests (drm-backport-placeholder)
- commit f5ef7e6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Don't allow FPO if no planes (drm-backport-placeholder)
- commit 083943d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Fix subvp+drr logic errors (drm-backport-placeholder)
- commit 4063c03
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: enable dcn35 idle power optimization (drm-backport-placeholder)
- commit 304c26c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Disable IPS by default (drm-backport-placeholder)
- commit 58f30d4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amdgpu: Add register read/write debugfs support for AID's (drm-backport-placeholder)
- commit 5919cec
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: remove redundant initialization of variable (drm-backport-placeholder)
- commit 457793e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amdgpu: Add umc page retirement for umc v12_0 (drm-backport-placeholder)
- commit 6efb19c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/pm: smu v13_0_6 supports ecc info by default (drm-backport-placeholder)
- commit 53e02c2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amdgpu: Add poison mode check error condition for umc v12_0 (drm-backport-placeholder)
- commit 552757a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amdgpu: MCA supports recording umc address information (drm-backport-placeholder)
- commit dac30b9
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.265 (drm-backport-placeholder)
- commit 6b92cbe
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.197.0 (drm-backport-placeholder)
- commit 99a9722
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: change static screen wait frame_count for ips (drm-backport-placeholder)
- commit c96e4bd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Fix hang/underflow when transitioning to ODM4:1 (drm-backport-placeholder git-fixes CVE-2023-52671 bsc#1224729)
- commit f38a5f0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Fix lightup regression with DP2 single display (drm-backport-placeholder)
- commit ed9a571
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Deep copy dml2_context when copying dc_state (drm-backport-placeholder)
- commit 033ac06
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Create dc_state after resource initialization (drm-backport-placeholder)
- commit c2a59ce
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Fix null reference to state when getting subvp type (drm-backport-placeholder)
- commit 75b3d96
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Refactor phantom resource allocation (drm-backport-placeholder)
- commit 8f9d74c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Wake DMCUB before executing GPINT commands (drm-backport-placeholder git-fixes CVE-2023-52624 bsc#1222083)
- commit dda0bbd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: add debug option for ExtendedVBlank DLG adjust (drm-backport-placeholder)
- commit 5bb15fa
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Set test_pattern_changed update flag on pipe enable (drm-backport-placeholder)
- commit 3385172
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: skip error logging when DMUB is inactive from S3 (drm-backport-placeholder).
- Refresh patches.suse/0001-drm-amd-display-Validate-function-returns.patch.
- commit b90a481
* Thu Oct 10 2024 mfranc@suse.cz
- supported.conf: add an s390x crypto module (jsc#PED-11040)
- commit de000ad
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amdkfd: Use partial hmm page walk during buffer validation in SVM (drm-backport-placeholder)
- commit 57f1e23
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd: Add missing definitions for `SMU_MAX_LEVELS_VDDGFX` (drm-backport-placeholder)
- commit e416681
* Thu Oct 10 2024 pjakobsson@suse.de
- Documentation/amdgpu: Remove a spurious character (drm-backport-placeholder)
- commit 5d176a2
* Thu Oct 10 2024 pjakobsson@suse.de
- Documentation/amdgpu: Add Hawk Point processors (drm-backport-placeholder)
- commit 668e4bf
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Add a new DC debug mask for PSR-SU (drm-backport-placeholder).
- commit 4bd62a7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Add function for dumping clk registers (drm-backport-placeholder)
- commit e7d423c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Unify optimize_required flags and VRR adjustments (drm-backport-placeholder)
- commit 78f68d4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/imagination: pvr_device.h: fix all kernel-doc warnings (drm-backport-placeholder)
- commit 3c8c2b0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/gpuvm: fix all kernel-doc warnings in include/drm/drm_gpuvm.h (drm-backport-placeholder)
- commit 199840e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/rockchip: vop2: clean up some inconsistent indenting (drm-backport-placeholder)
- commit 2feeb47
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/rockchip: vop2: Avoid use regmap_reinit_cache at runtime (drm-backport-placeholder)
- commit 9b2c5f3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm: Warn when freeing a framebuffer that's still on a list (drm-backport-placeholder)
- commit 4c25e23
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix warning on impossible condition (drm-backport-placeholder)
- commit abf369a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix UBSAN splat in add_preempt_fences() (drm-backport-placeholder)
- commit 92aa2ab
* Thu Oct 10 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: avoid overriding existing undefined opcode (drm-backport-placeholder)
- commit bd1df9d
* Thu Oct 10 2024 pjakobsson@suse.de
- accel/habanalabs: add parent_device sysfs attribute (drm-backport-placeholder)
- commit 901a4fb
* Thu Oct 10 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: add zero padding when printing QM CP (drm-backport-placeholder)
- commit 480f620
* Thu Oct 10 2024 pjakobsson@suse.de
- accel/habanalabs: report 3 instances of Infineon second stage (drm-backport-placeholder)
- commit 160284f
* Thu Oct 10 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: add signed dev info uAPI (drm-backport-placeholder)
- commit 71b6296
* Thu Oct 10 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: use correct registers to dump QM CQ info (drm-backport-placeholder)
- commit b62b48d
* Thu Oct 10 2024 pjakobsson@suse.de
- accel/habanalabs: expose module id through sysfs (drm-backport-placeholder)
- commit d19ea06
* Thu Oct 10 2024 pjakobsson@suse.de
- accel/habanalabs: update sysfs-driver-habanalabs with the accel path (drm-backport-placeholder)
- commit f8b4dda
* Thu Oct 10 2024 pjakobsson@suse.de
- accel/habanalabs: print error code when mapping fails (drm-backport-placeholder)
- commit cbbe7e3
* Thu Oct 10 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: get the correct QM CQ info upon an error (drm-backport-placeholder)
- commit b6a2d0f
* Thu Oct 10 2024 pjakobsson@suse.de
- accel/habanalabs: set hard reset flag if graceful reset is skipped (drm-backport-placeholder)
- commit ed26bc3
* Thu Oct 10 2024 pjakobsson@suse.de
- accel/habanalabs: remove 'get temperature' debug print (drm-backport-placeholder)
- commit be64586
* Thu Oct 10 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: fix undef opcode reporting (drm-backport-placeholder)
- commit dbfe2f0
* Thu Oct 10 2024 mfranc@suse.cz
- Update config files for s390x, enable a crypto module (jsc#PED-11040).
- commit ab87074
* Thu Oct 10 2024 pjakobsson@suse.de
- accel/habanalabs: fix EQ heartbeat mechanism (drm-backport-placeholder)
- commit 9be453f
* Thu Oct 10 2024 pjakobsson@suse.de
- accel/habanalabs: add log when eq event is not received (drm-backport-placeholder)
- commit 982c3d5
* Thu Oct 10 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: assume hard-reset by FW upon PCIe AXI drain (drm-backport-placeholder)
- commit 1ef66f1
* Thu Oct 10 2024 pjakobsson@suse.de
- accel/habanalabs: update device boot error check (drm-backport-placeholder)
- commit 730deb4
* Thu Oct 10 2024 pjakobsson@suse.de
- accel/habanalabs: add pcie reset prepare/done hooks (drm-backport-placeholder)
- commit d87f56a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/bridge: properly refcount DT nodes in aux bridge drivers (drm-backport-placeholder)
- commit 3a96b94
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/imagination: Fix error path in pvr_vm_create_context (drm-backport-placeholder)
- commit 623baa4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/imagination: Fix ERR_PTR test on pointer to pointer. (drm-backport-placeholder)
- commit 38edd0d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/imagination: Fixed oops when misusing ioctl CREATE_HWRT_DATASET (drm-backport-placeholder)
- commit d477102
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/imagination: Fixed infinite loop in pvr_vm_mips_map() (drm-backport-placeholder)
- commit 9a0c62a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Disable 32bits build (drm-backport-placeholder)
- commit f223f91
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove uninitialized variable from warning (drm-backport-placeholder)
- commit cc53747
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove ci-only GuC FW definitions (drm-backport-placeholder)
- commit 918cd6a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix build without CONFIG_FAULT_INJECTION (drm-backport-placeholder)
- commit d1e5a76
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Remove reset uevent for now (drm-backport-placeholder)
- commit 44e00c9
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Move DRM_XE_ACC_GRANULARITY_* where they are used (drm-backport-placeholder)
- commit 8925985
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Move CPU_CACHING defines before doc (drm-backport-placeholder)
- commit 2c817f2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Add examples of user space code (drm-backport-placeholder)
- commit b2d1b35
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Add block diagram of a device (drm-backport-placeholder)
- commit 90a4fe1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Document the memory_region bitmask (drm-backport-placeholder)
- commit a6f907a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: More uAPI documentation additions and cosmetic updates (drm-backport-placeholder)
- commit f9c2a46
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Order sections (drm-backport-placeholder)
- commit 06b9395
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Make constant comments visible in kernel doc (drm-backport-placeholder)
- commit af75ca2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Document DRM_XE_DEVICE_QUERY_HWCONFIG (drm-backport-placeholder)
- commit c406b31
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Document drm_xe_query_config keys (drm-backport-placeholder)
- commit 9fa9557
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Document use of size in drm_xe_device_query (drm-backport-placeholder)
- commit 9246c50
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Add missing documentation for struct members (drm-backport-placeholder)
- commit 18ed85b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Add a comment to each struct (drm-backport-placeholder)
- commit 6a29086
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Remove sync binds (drm-backport-placeholder)
- commit 9f8f0ff
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Ensure every uapi struct has drm_xe prefix (drm-backport-placeholder)
- commit 813931c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pmu: Remove PMU from Xe till uapi is finalized (drm-backport-placeholder)
- commit e44c70e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Remove DRM_XE_UFENCE_WAIT_MASK_* (drm-backport-placeholder)
- commit 3118542
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Remove DRM_IOCTL_XE_EXEC_QUEUE_SET_PROPERTY (drm-backport-placeholder)
- commit 0bf2700
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Return correct error code for xe_wait_user_fence_ioctl (drm-backport-placeholder)
- commit 0c106e3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: add exec_queue_id member to drm_xe_wait_user_fence (drm-backport-placeholder)
- commit 00e8558
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Enable W=1 warnings by default (drm-backport-placeholder)
- commit 1c7fed9
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/display: Fix dummy __i915_inject_probe_error() (drm-backport-placeholder)
- commit 8629289
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/bo: Remove unusued variable (drm-backport-placeholder)
- commit c92db45
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Return error if drm_buddy_init() fails (drm-backport-placeholder)
- commit 7d14903
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Drop some unnecessary header includes (drm-backport-placeholder)
- commit 3d8b356
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Re-sort GT register header (drm-backport-placeholder)
- commit fdb182e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Define interrupt vector bits with the interrupt registers (drm-backport-placeholder)
- commit 91d85fb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Move GSC HECI base offsets out of register header (drm-backport-placeholder)
- commit 9bb61b5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Move engine base offsets to engine register header (drm-backport-placeholder)
- commit 3a92a4c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix whitespace in register definitions (drm-backport-placeholder)
- commit b365257
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Move some per-engine register definitions to the engine (drm-backport-placeholder)
- commit 3976ac6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Drop "_REG" suffix from CSFE_CHICKEN1 (drm-backport-placeholder)
- commit 30cc402
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Support flat ccs (drm-backport-placeholder)
- commit 630eba5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Modify xe_bo_test for system memory (drm-backport-placeholder)
- commit 46d6b6f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Handle flat ccs move for igfx. (drm-backport-placeholder)
- commit 7f7b5cf
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Update emit_pte to use compression enabled PAT index (drm-backport-placeholder)
- commit 82757c6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Update chunk size for each iteration of ccs copy (drm-backport-placeholder)
- commit 7d352e6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe_migrate: Use NULL 1G PTE mapped at 255GiB VA for ccs clear (drm-backport-placeholder)
- commit 38af4f7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Updates on XY_CTRL_SURF_COPY_BLT (drm-backport-placeholder)
- commit c7a7558
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Allocate extra pages for ccs during bo create (drm-backport-placeholder)
- commit 05fcd38
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Modify main memory to ccs memory ratio. (drm-backport-placeholder)
- commit e247372
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Determine bios enablement for flat ccs on igfx (drm-backport-placeholder)
- commit 0b7237d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove duplicate RING_MAX_NONPRIV_SLOTS definition (drm-backport-placeholder)
- commit 2f8c527
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Allow num_batch_buffer / num_binds == 0 in IOCTLs (drm-backport-placeholder)
- commit 8d98af7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove vram size info from sysfs (drm-backport-placeholder)
- commit 2fe20bd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use a flags field instead of bools for sync parse (drm-backport-placeholder)
- commit 128a8b7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use a flags field instead of bools for VMA create (drm-backport-placeholder)
- commit 924e727
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use DRM_GPUVM_RESV_PROTECTED for gpuvm (drm-backport-placeholder)
- commit 55387c1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix lockdep warning in xe_force_wake calls (drm-backport-placeholder)
- commit cb34f4e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Check skip_guc_pc before disabling gucrc (drm-backport-placeholder)
- commit 9c8c15a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use NULL PTEs as scratch PTEs (drm-backport-placeholder)
- commit 1882c68
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Restrict huge PTEs to 1GiB (drm-backport-placeholder)
- commit c9b6b57
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add frequency throttle reasons sysfs attributes (drm-backport-placeholder)
- commit d50c008
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Create a xe_gt_freq component for raw management and sysfs (drm-backport-placeholder)
- commit 3ab0fb8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Change the name of frequency sysfs attributes (drm-backport-placeholder)
- commit 62d0c0a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/vm: Avoid asid lookup if none allocated (drm-backport-placeholder)
- commit 69bbbad
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Rename info.supports_* to info.has_* (drm-backport-placeholder)
- commit 7589162
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/kunit: Add test for LMTT operations (drm-backport-placeholder)
- commit c6a061c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/kunit: Enable CONFIG_PCI_IOV in .kunitconfig (drm-backport-placeholder)
- commit fa3509e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pf: Introduce Local Memory Translation Table (drm-backport-placeholder)
- commit aeb8ab0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Introduce SR-IOV logging macros (drm-backport-placeholder)
- commit 9421d4f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Avoid any races around ccs_mode update (drm-backport-placeholder)
- commit 5717715
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Allow userspace to configure CCS mode (drm-backport-placeholder)
- commit 5fa8f9a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Enable Fixed CCS mode setting (drm-backport-placeholder)
- commit 4533ad3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Add workaround 18032095049 and 16021639441 (drm-backport-placeholder)
- commit 85c6bf1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Add workaround 14019988906 (drm-backport-placeholder)
- commit 264d4f0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/huc: HuC authentication via GSC (drm-backport-placeholder)
- commit 832d95a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/huc: Prepare for 2-step HuC authentication (drm-backport-placeholder)
- commit 4cef47d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/kunit: Test WAs for MTL and LNL (drm-backport-placeholder)
- commit 15d0e30
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/kunit: Add stub to read_gmdid (drm-backport-placeholder)
- commit 056c4b4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/kunit: Move fake pci data to test-priv (drm-backport-placeholder)
- commit 55f050b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/kunit: Remove handling of XE_TEST_SUBPLATFORM_ANY (drm-backport-placeholder)
- commit 85f4e84
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Expand XE_REG_OPTION_MASKED documentation (drm-backport-placeholder)
- commit 25287b8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Kill exec_queue_set_property (drm-backport-placeholder)
- commit 7274468
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove unused extension definition (drm-backport-placeholder)
- commit ac2a915
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Use LR abbrev for long-running vms (drm-backport-placeholder)
- commit c21a38b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Move xe_exec after xe_exec_queue (drm-backport-placeholder)
- commit 6ace711
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Fix various struct padding for 64b alignment (drm-backport-placeholder)
- commit 15caf9f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Add Tile ID information to the GT info query (drm-backport-placeholder)
- commit 28df6f7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Crystal Reference Clock updates (drm-backport-placeholder)
- commit 4e35069
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Kill tile_mask (drm-backport-placeholder)
- commit 160eddd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Split xe_sync types from flags (drm-backport-placeholder)
- commit f4dccfd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Align on a common way to return arrays (engines) (drm-backport-placeholder)
- commit 5aad345
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Align on a common way to return arrays (gt) (drm-backport-placeholder)
- commit 7677087
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Align on a common way to return arrays (memory regions) (drm-backport-placeholder)
- commit c6db923
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Reject bo creation of unaligned size (drm-backport-placeholder)
- commit 20d737f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Make DRM_XE_DEVICE_QUERY_ENGINES future proof (drm-backport-placeholder)
- commit 9b00e94
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Separate bo_create placement from flags (drm-backport-placeholder)
- commit 0a8a711
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Extend drm_xe_vm_bind_op (drm-backport-placeholder)
- commit 35a24f1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: add some debug info for d3cold (drm-backport-placeholder)
- commit 2fe76ac
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Split GuC params used for "hwconfig" and "post-hwconfig" (drm-backport-placeholder)
- commit 504df51
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uc: Extract xe_uc_sanitize_reset (drm-backport-placeholder)
- commit fec111b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uc: Store firmware binary in system-memory backed BO (drm-backport-placeholder)
- commit 78b713a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uc: Split xe_uc_fw_init (drm-backport-placeholder)
- commit ff3dd8f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add a helper for DRM device-lifetime BO create (drm-backport-placeholder)
- commit 8a92bc0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Reorder GGTT init to earlier point in probe (drm-backport-placeholder)
- commit 9fd2784
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Move force_wake init to earlier point in probe (drm-backport-placeholder)
- commit 71bd4ce
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Move system memory management init to earlier point in probe (drm-backport-placeholder)
- commit 48c79c5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Don't "peek" into GMD_ID (drm-backport-placeholder)
- commit 4eaf0d3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/device: Introduce xe_device_probe_early (drm-backport-placeholder)
- commit 4a7b104
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Map the entire BAR0 and hold onto the initial mapping (drm-backport-placeholder)
- commit dc9a188
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Introduce xe_tile_init_early and use at earlier point in (drm-backport-placeholder)
- commit 58d5227
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Split xe_info_init (drm-backport-placeholder)
- commit f3b71eb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/dsb: DSB implementation for xe (drm-backport-placeholder)
- commit 4a0870a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Add workaround 16020292621 (drm-backport-placeholder)
- commit 331ee45
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Respond to TRTT faults as unsuccessful page fault (drm-backport-placeholder)
- commit 3625ccb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Support device page faults on integrated platforms (drm-backport-placeholder)
- commit 6d2db41
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Move xe_mmio_probe_tiles outside of MMIO setup (drm-backport-placeholder)
- commit 174921c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Move xe_set_dma_info outside of MMIO setup (drm-backport-placeholder)
- commit c932713
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/irq: Don't call pci_free_irq_vectors (drm-backport-placeholder)
- commit 21d96e7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use managed pci_enable_device (drm-backport-placeholder)
- commit cc4c34e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Skip calling drm_dev_put on probe error (drm-backport-placeholder)
- commit 7f18de2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix header guard warning (drm-backport-placeholder)
- commit 4e15840
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: rename bypass_mtcfg to skip_mtcfg (drm-backport-placeholder)
- commit 7f9cf0a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: add skip_pcode flag (drm-backport-placeholder)
- commit e3b4c9a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mocs: update MOCS table for xe2 (drm-backport-placeholder)
- commit b6392c7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Manually setup C6 when skip_guc_pc is set (drm-backport-placeholder)
- commit b9b9fef
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add skip_guc_pc flag (drm-backport-placeholder)
- commit 1e61554
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Rename xe_gt_idle_sysfs to xe_gt_idle (drm-backport-placeholder)
- commit 3019fee
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/doc: Include documentation about xe_assert() (drm-backport-placeholder)
- commit 0618ea2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Include only required GuC ABI headers (drm-backport-placeholder)
- commit e40dc68
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Remove obsolete GuC CTB documentation (drm-backport-placeholder)
- commit c8dc4fe
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Drop ancient GuC CTB definitions (drm-backport-placeholder)
- commit 053ca25
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: explicitly set GGTT access for GuC DMA (drm-backport-placeholder)
- commit 58590e8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: support pat_index selection with vm_bind (drm-backport-placeholder)
- commit 49ce8ba
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pat: annotate pat_index with coherency mode (drm-backport-placeholder)
- commit dba98bd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Add support for CPU caching mode (drm-backport-placeholder)
- commit 135e7fe
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/kunit: Return number of iterated devices (drm-backport-placeholder)
- commit 48bdbe7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: fix mem_access for early lrc generation (drm-backport-placeholder)
- commit 8e7837c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/gsc: Define GSC FW for MTL (drm-backport-placeholder)
- commit 7708646
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/gsc: Define GSCCS for MTL (drm-backport-placeholder)
- commit be968ba
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/gsc: Query GSC compatibility version (drm-backport-placeholder)
- commit c428b6c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/gsc: Trigger a driver flr to cleanup the GSC on unload (drm-backport-placeholder)
- commit 1568a98
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/gsc: Implement WA 14015076503 (drm-backport-placeholder)
- commit 1dcbef6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/gsc: GSC FW load (drm-backport-placeholder)
- commit bc5a553
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/gsc: Parse GSC FW header (drm-backport-placeholder)
- commit 5dc7c38
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/gsc: Introduce GSC FW (drm-backport-placeholder)
- commit 2e7b63c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uc: Rework uC version tracking (drm-backport-placeholder)
- commit 4e9b634
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Encapsulate all the module parameters (drm-backport-placeholder)
- commit 7922dfb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Add workaround 14020013138 (drm-backport-placeholder)
- commit dce5609
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/dg2: Drop Wa_22014600077 (drm-backport-placeholder)
- commit 3e5c298
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Sync MTL PCI IDs with i915 (drm-backport-placeholder)
- commit 01dad4d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/vm: Fix ASID XA usage (drm-backport-placeholder)
- commit 4b8e901
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/bo: Remove leftover trace_printk() (drm-backport-placeholder)
- commit cdeb74b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/bo: Rename xe_bo_get_sg() to xe_bo_sg() (drm-backport-placeholder)
- commit 64a4cd1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Ensure that we don't access the placements array (drm-backport-placeholder)
- commit ab27091
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Print virtualization mode during probe (drm-backport-placeholder)
- commit ddbee65
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Prepare for running in different SR-IOV modes (drm-backport-placeholder)
- commit 91b6c11
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add device flag to indicate SR-IOV support (drm-backport-placeholder)
- commit 1d9b1b5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Add workaround 14019449301 (drm-backport-placeholder)
- commit 8237e3c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Add workaround 16021867713 (drm-backport-placeholder)
- commit 9b4da7d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Add workaround 14017421178 (drm-backport-placeholder)
- commit 0bacf3d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mmio: Make xe_mmio_wait32() aware of interrupts (drm-backport-placeholder)
- commit 135179f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mmio: Move xe_mmio_wait32() to xe_mmio.c (drm-backport-placeholder)
- commit ab14900
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add mocs kunit (drm-backport-placeholder)
- commit 11c13f4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix modpost warning on kunit modules (drm-backport-placeholder)
- commit 567c9a6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: ATS-M device ID update (drm-backport-placeholder)
- commit 6bac4ec
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add missing RPL and ADL (drm-backport-placeholder)
- commit fdae64a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Include RPL-U to pciidlist (drm-backport-placeholder)
- commit 627886e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Only set xe_vma_op.map fields for GPUVA map operations (drm-backport-placeholder)
- commit aba9ba2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove GEN[0-9]*_ prefixes (drm-backport-placeholder)
- commit eb69465
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mocs: Bring comment about mocs back to reality (drm-backport-placeholder)
- commit ff82e33
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fold GEN11_MOCS_ENTRIES into gen12_mocs_desc (drm-backport-placeholder)
- commit 9bffb01
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/bo: don't hold dma-resv lock over drm_gem_handle_create (drm-backport-placeholder)
- commit a274720
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Use valid scratch register for posting read (drm-backport-placeholder)
- commit b6d45ae
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Fix handling of GUC_HXG_TYPE_NO_RESPONSE_BUSY (drm-backport-placeholder)
- commit 5b92609
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Copy response data from proper registers (drm-backport-placeholder)
- commit 6052fdf
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Fix wrong assert about full_len (drm-backport-placeholder)
- commit d9de806
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/dg2: Wa_18028616096 now applies to all DG2 (drm-backport-placeholder)
- commit a2ce3a4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Be more specific about the vm_bind prefetch region (drm-backport-placeholder)
- commit 5df7972
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Differentiate WAIT_OP from WAIT_MASK (drm-backport-placeholder)
- commit 6c90041
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Standardize the FLAG naming and assignment (drm-backport-placeholder)
- commit d1a3f4f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Rename query's mem_usage to mem_regions (drm-backport-placeholder)
- commit 97e1ca7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Rename *_mem_regions masks (drm-backport-placeholder)
- commit 47da7ee
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Change rsvd to pad in struct drm_xe_class_instance (drm-backport-placeholder)
- commit 95d435a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Add _FLAG to uAPI constants usable for flags (drm-backport-placeholder)
- commit ee00d6c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Add missing DRM_ prefix in uAPI constants (drm-backport-placeholder)
- commit 5da3ce4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Make xe_mmio_tile_vram_size() static (drm-backport-placeholder)
- commit 43ce299
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pmu: Drop interrupt pmu event (drm-backport-placeholder)
- commit 2cd4424
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Remove unused QUERY_CONFIG_GT_COUNT (drm-backport-placeholder)
- commit 6c4f6b0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Remove unused QUERY_CONFIG_MEM_REGION_COUNT (drm-backport-placeholder)
- commit 1c3165f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Remove unused inaccessible memory region (drm-backport-placeholder)
- commit 229c53c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Kill VM_MADVISE IOCTL (drm-backport-placeholder)
- commit 44c95d7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Remove GT_TYPE_REMOTE (drm-backport-placeholder)
- commit 04cd8fd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Remove useless XE_QUERY_CONFIG_NUM_PARAM (drm-backport-placeholder)
- commit 71b6f01
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Promote guc_to_gt/xe helpers to .h (drm-backport-placeholder)
- commit 8d27562
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/display: Add writing of remapped dpt (drm-backport-placeholder)
- commit 9cffff3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/display: Don't try to use vram if not available (drm-backport-placeholder)
- commit 62584d0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/hdcp: Define intel_hdcp_gsc_check_status in Xe (drm-backport-placeholder)
- commit 5b2c816
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/display: Create a dummy version for vga decode (drm-backport-placeholder)
- commit 8bfa167
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/display: Add Xe implementation for fence checks used by fbc (drm-backport-placeholder)
- commit ce3e25f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/display: Add i915_gem.h compatibility header (drm-backport-placeholder)
- commit 88c0a07
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/display: Xe stolen memory handling for fbc support (drm-backport-placeholder)
- commit 622f922
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/display: Add empty define for i915_ggtt_clear_scanout (drm-backport-placeholder)
- commit 227b3b7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/display: Add empty def for i915_gem_object_flush_if_display (drm-backport-placeholder)
- commit d6717ce
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/display: Add i915_active.h compatibility header (drm-backport-placeholder)
- commit 310fcbd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/display: Add frontbuffer setter/getter for xe_bo (drm-backport-placeholder)
- commit 750dc20
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/display: Add macro to get i915 device from xe_bo (drm-backport-placeholder)
- commit b344629
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/display: Add struct i915_active for Xe (drm-backport-placeholder)
- commit 52e6fe9
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/display: Use acpi_target_system_state only if ACPI_SLEEP is (drm-backport-placeholder)
- commit 6db13f6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/display: fix error handling flow when device probing fails (drm-backport-placeholder)
- commit 4bed914
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/display: ensure clear-color surfaces are cpu mappable (drm-backport-placeholder)
- commit 41d25b9
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/display: Silence kernel-doc warnings related to display (drm-backport-placeholder)
- commit d539b37
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/display: Improve s2idle handling. (drm-backport-placeholder)
- commit 01fa0c3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use pool of ordered wq for GuC submission (drm-backport-placeholder)
- commit d64bd9a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Raise GT frequency before GuC/HuC load (drm-backport-placeholder)
- commit 18074bc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix build with KUNIT=m (drm-backport-placeholder)
- commit c9e6a05
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Drop EXECLIST_CONTROL from error state dump (drm-backport-placeholder)
- commit c318451
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/tests: Fix migrate test (drm-backport-placeholder)
- commit 7cf02e7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/gsc: enable pvc support (drm-backport-placeholder)
- commit 5ec3541
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add Wa_14019877138 (drm-backport-placeholder)
- commit 37b03eb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: clear the serviced bits on INTR_IDENTITY_REG (drm-backport-placeholder)
- commit 7558da0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: move the lmem verification code into a separate function (drm-backport-placeholder)
- commit a6c038b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix unbind of unaccessed VMA (fault mode) (drm-backport-placeholder)
- commit 9fd5b9f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xelpmp: Add Wa_16021867713 (drm-backport-placeholder)
- commit c0b9de7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Update SPDX deprecated license identifier (drm-backport-placeholder)
- commit d6d2a33
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix pagefault and access counter worker functions (drm-backport-placeholder)
- commit e289c61
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: implement driver initiated function-reset (drm-backport-placeholder)
- commit f7af0d5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: stringify the argument to avoid potential vulnerability (drm-backport-placeholder)
- commit 3444e61
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add Wa_14019821291 (drm-backport-placeholder)
- commit 0985753
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mtl: Use 16.67 Mhz freq scale factor to get rpX (drm-backport-placeholder)
- commit fafc59a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Program correct MOCS registers (drm-backport-placeholder)
- commit 6cb8d5f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix dequeue of access counter work item (drm-backport-placeholder)
- commit a4a8e80
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Adjust tile_present mask when skipping rebinds (drm-backport-placeholder)
- commit ea64b91
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Dump CTB during TLB timeout (drm-backport-placeholder)
- commit d3b9349
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Replace usage of mem_type_to_tile (drm-backport-placeholder)
- commit 1d3323f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove unused xe_bo_to_tile (drm-backport-placeholder)
- commit 13df20f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Replace xe_ttm_vram_mgr.tile with xe_mem_region (drm-backport-placeholder)
- commit 83e99b4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/hwmon: Expose power1_max_interval (drm-backport-placeholder)
- commit 62872f7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/hwmon: Protect hwmon rw attributes with hwmon_lock (drm-backport-placeholder)
- commit 653bde3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/hwmon: Add kernel doc and refactor xe hwmon (drm-backport-placeholder)
- commit 1bc9e5f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/bo: sync kernel fences for KMD buffers (drm-backport-placeholder)
- commit 1d19094
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/bo: consider dma-resv fences for clear job (drm-backport-placeholder)
- commit 67728b4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/migrate: fix MI_ARB_ON_OFF usage (drm-backport-placeholder)
- commit 93ead03
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xelpmp: Extend Wa_22016670082 to Xe_LPM+ (drm-backport-placeholder)
- commit 2606d28
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe_exec_queue: Add check for access counter granularity (drm-backport-placeholder)
- commit 30b21ef
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix WA 14010918519 write to wrong register (drm-backport-placeholder)
- commit e828783
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/huc: Define HuC for MTL (drm-backport-placeholder)
- commit f371b72
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/huc: Don't re-auth HuC if it's already authenticated (drm-backport-placeholder)
- commit d94ef3b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/huc: HuC is not supported on GTs that don't have video engines (drm-backport-placeholder)
- commit 6363871
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/huc: Extract version and binary offset from new HuC headers (drm-backport-placeholder)
- commit 855911b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uc: Prepare for parsing of different header types (drm-backport-placeholder)
- commit eb7ebb2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Extend rpX values extraction for future platforms (drm-backport-placeholder)
- commit 13fc762
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mocs: MOCS registers are multicast on Xe_HP and beyond (drm-backport-placeholder)
- commit e53237c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Update SVG state handling (drm-backport-placeholder)
- commit 3fe0b83
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Emit SVG state on RCS during driver load on DG2 and MTL (drm-backport-placeholder)
- commit ece9d48
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Prepare to emit non-register state while recording default (drm-backport-placeholder)
- commit 62ada7e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/trace: Optimize trace definition (drm-backport-placeholder)
- commit a577513
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add event tracing for CTB (drm-backport-placeholder)
- commit 7f0745d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add performance tuning settings for MTL and Xe2 (drm-backport-placeholder)
- commit 79b1a0d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Add initial workarounds (drm-backport-placeholder)
- commit 02a789f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Simplify xe_res_get_buddy() (drm-backport-placeholder)
- commit 483e75b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: fix pat[2] programming with 2M/1G pages (drm-backport-placeholder)
- commit 23712cc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Bump PVC GuC version to 70.9.1 (drm-backport-placeholder)
- commit 899ae52
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Fix naming of XE_QUERY_CONFIG_MAX_EXEC_QUEUE_PRIORITY (drm-backport-placeholder)
- commit 8853b00
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Rename gts to gt_list (drm-backport-placeholder)
- commit 22c559c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Remove unused field of drm_xe_query_gt (drm-backport-placeholder)
- commit 565cf84
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Replace useless 'instance' per unique gt_id (drm-backport-placeholder)
- commit f6c7cd6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Document drm_xe_query_gt (drm-backport-placeholder)
- commit 11cb6f7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix VM bind out-sync signaling ordering (drm-backport-placeholder)
- commit ea8ed5e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove async worker and rework sync binds (drm-backport-placeholder)
- commit 544e33e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Kill DRM_XE_UFENCE_WAIT_VM_ERROR (drm-backport-placeholder)
- commit 7f7ae89
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Kill XE_VM_PROPERTY_BIND_OP_ERROR_CAPTURE_ADDRESS extension (drm-backport-placeholder)
- commit 149f258
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Use common drm_xe_ext_set_property extension (drm-backport-placeholder)
- commit 4d669b0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove XE_EXEC_QUEUE_SET_PROPERTY_COMPUTE_MODE from uAPI (drm-backport-placeholder)
- commit 3eeca5a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Rename exec_queue_kill_compute to (drm-backport-placeholder)
- commit b0584ba
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Deprecate XE_EXEC_QUEUE_SET_PROPERTY_COMPUTE_MODE (drm-backport-placeholder)
- commit 3336128
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix xe_exec_queue_is_idle for parallel exec queues (drm-backport-placeholder)
- commit 97445b6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Remove MMIO ioctl (drm-backport-placeholder)
- commit 2c4c36e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/vm: Remove VM_BIND_OP macro (drm-backport-placeholder)
- commit a5bbdbf
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Separate VM_BIND's operation and flag (drm-backport-placeholder)
- commit 6ac65ca
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Correlate engine and cpu timestamps with better accuracy (drm-backport-placeholder)
- commit ea0df04
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Set the correct type for xe_to_user_engine_class (drm-backport-placeholder)
- commit 795b761
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix array bounds check for queries (drm-backport-placeholder)
- commit 11b9bbb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/debugfs: Include GFXPIPE commands in LRC dump (drm-backport-placeholder)
- commit e1c649c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/debugfs: Add dump of default LRCs' MI instructions (drm-backport-placeholder)
- commit a216c48
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Extract MI_* instructions to their own header (drm-backport-placeholder)
- commit 560b2ec
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Clarify number of dwords/qwords stored by MI_STORE_DATA_IMM (drm-backport-placeholder)
- commit 58c5de0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Separate number of registers from MI_LRI opcode (drm-backport-placeholder)
- commit d6fbcae
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Make MI_FLUSH_DW immediate size more explicit (drm-backport-placeholder)
- commit ea4df84
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/gsc: add gsc device support (drm-backport-placeholder)
- commit e35fecd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/gsc: add has_heci_gscfi indication to device (drm-backport-placeholder)
- commit 3203ed0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/gsc: add HECI2 register offsets (drm-backport-placeholder)
- commit 665a416
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/dg2: Remove one PCI ID (drm-backport-placeholder)
- commit 30ee5b4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add new DG2 PCI IDs (drm-backport-placeholder)
- commit 0cf1810
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Set PTE_AE for smem allocations in integrated devices (drm-backport-placeholder)
- commit 619df1a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: refactor xe_mmio_probe_tiles to support MMIO extension (drm-backport-placeholder)
- commit f22907b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: map MMIO BAR according to the num of tiles in device desc (drm-backport-placeholder)
- commit 0458959
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: add MMIO extension support flags (drm-backport-placeholder)
- commit a436f2e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: add a flag to bypass multi-tile config from MTCFG reg (drm-backport-placeholder)
- commit 399e313
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: add read/write support for MMIO extension space (drm-backport-placeholder)
- commit 7b24fbc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: add 28-bit address support in struct xe_reg (drm-backport-placeholder)
- commit 0ffa38a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: directly use pat_index for pte_encode (drm-backport-placeholder)
- commit 0973ea6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pat: trim the xelp PAT table (drm-backport-placeholder)
- commit 806f02b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add missing ADL entries to xe_test_wa (drm-backport-placeholder)
- commit 8bd3613
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/rpls: Add Stepping info for RPLS (drm-backport-placeholder)
- commit 27a2571
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/rpls: Add RPLS Support (drm-backport-placeholder)
- commit fab9211
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/rplu: s/ADLP/ALDERLAKE_P (drm-backport-placeholder)
- commit 9ff3699
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/rtp: Fix doc for XE_RTP_ACTIONS (drm-backport-placeholder)
- commit 6d9deb7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/gt: Dump PAT table when failing to initialize (drm-backport-placeholder)
- commit 6fc204e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pat: Add debugfs node to dump PAT (drm-backport-placeholder)
- commit 721971b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Add one more bit to encode PAT to ppgtt entries (drm-backport-placeholder)
- commit 764ee73
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Program PAT tables (drm-backport-placeholder)
- commit e2cfb6c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/tests/xe_migrate.c: Add vram to vram KUNIT test (drm-backport-placeholder)
- commit 2f9decc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe_migrate.c: Use DPA offset for page table entries. (drm-backport-placeholder)
- commit 71064d8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Follow XeHPC for TLB invalidation (drm-backport-placeholder)
- commit 54aeeb5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/vm: Prefer xe_assert() over XE_WARN_ON() (drm-backport-placeholder)
- commit 4ad3541
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: add gt tuning for indirect state (drm-backport-placeholder)
- commit ef88481
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add infrastructure for per engine tuning (drm-backport-placeholder)
- commit 96c8e40
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/hwmon: fix uaf on unload (drm-backport-placeholder)
- commit 4bae032
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Add missing mocs entry (drm-backport-placeholder)
- commit 2ebce5d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove devcoredump readout of IPEIR (drm-backport-placeholder)
- commit 43a7a25
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix devcoredump readout of IPEHR (drm-backport-placeholder)
- commit 6163c51
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix RING_MI_MODE label in devcoredump (drm-backport-placeholder)
- commit 694f245
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: fix range printing for debug messages (drm-backport-placeholder)
- commit c90d107
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/vm: use list_last_entry() to fetch last_op (drm-backport-placeholder)
- commit 3c62802
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/vm: print the correct 'keep' when printing gpuva ops (drm-backport-placeholder)
- commit 9e6cb5d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/hwmon: Expose hwmon energy attribute (drm-backport-placeholder)
- commit ae545b3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/hwmon: Expose input voltage attribute (drm-backport-placeholder)
- commit b6a08fd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/hwmon: Expose card reactive critical power (drm-backport-placeholder)
- commit d0ac25b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/hwmon: Expose power attributes (drm-backport-placeholder)
- commit beb6760
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix exec queue usage for unbinds (drm-backport-placeholder)
- commit e8aee67
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Leverage ComputeCS read L3 caching (drm-backport-placeholder)
- commit 5f5e9e5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Update MOCS fields in blitter instructions (drm-backport-placeholder)
- commit 57c7c11
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Set tile y type in XY_FAST_COPY_BLT to Tile4 (drm-backport-placeholder)
- commit bb2f2f2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Rename MEM_SET instruction (drm-backport-placeholder)
- commit 08f1523
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Adjust mocs field mask definitions (drm-backport-placeholder)
- commit fb373be
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Extend reserved stolen sizes (drm-backport-placeholder)
- commit bef1358
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/tuning: Add missing engine class rules for LRC tuning (drm-backport-placeholder)
- commit 9fa89c1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: timeout needs to be a signed value (drm-backport-placeholder)
- commit acb930c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: set PTE_AE for all platforms supporting it (drm-backport-placeholder)
- commit 9913564
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add a missing mutex_destroy to xe_ttm_vram_mgr (drm-backport-placeholder)
- commit f551114
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Ensure mutex are destroyed (drm-backport-placeholder)
- commit d6ee6ce
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: do not register to PM if GuC is disabled (drm-backport-placeholder)
- commit 11f7287
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use vfunc for ggtt pte encoding (drm-backport-placeholder)
- commit 8176465
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use pat_index to encode pde/pte (drm-backport-placeholder)
- commit 0b50d3f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pat: Keep track of relevant indexes (drm-backport-placeholder)
- commit 7502f2e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pat: Prefer the arch/IP names (drm-backport-placeholder)
- commit f57cc2a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/dg2: Fix using wrong PAT table (drm-backport-placeholder)
- commit 140d536
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use vfunc to initialize PAT (drm-backport-placeholder)
- commit 781df78
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/migrate: Do not hand-encode pte (drm-backport-placeholder)
- commit 4b76bb3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use vfunc for pte/pde ppgtt encoding (drm-backport-placeholder)
- commit 5f48461
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove check for vma == NULL (drm-backport-placeholder)
- commit 02fdab1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Normalize pte/pde encoding (drm-backport-placeholder)
- commit 32f93e8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Infer service copy functionality from engine list (drm-backport-placeholder)
- commit d8fcb44
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/irq: Clear GFX_MSTR_IRQ as part of IRQ reset (drm-backport-placeholder)
- commit 633bd2f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add Wa_18028616096 (drm-backport-placeholder)
- commit d44bcc8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Align size to PAGE_SIZE (drm-backport-placeholder)
- commit 8c6b592
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Accept a const xe device (drm-backport-placeholder)
- commit 6990a0c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: add msix support (drm-backport-placeholder)
- commit 26bb8aa
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: change old msi irq api to a new one (drm-backport-placeholder)
- commit 72e3229
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: proper setting of irq enabled flag (drm-backport-placeholder)
- commit 5565842
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Implement fdinfo memory stats printing (drm-backport-placeholder)
- commit a545c91
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Account ring buffer and context state storage (drm-backport-placeholder)
- commit 2f31fe9
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Track page table memory usage for client (drm-backport-placeholder)
- commit 43984f2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Record each drm client with its VM (drm-backport-placeholder)
- commit 5403036
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add tracking support for bos per client (drm-backport-placeholder)
- commit e6684cf
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Interface xe drm client with fdinfo interface (drm-backport-placeholder)
- commit 210d899
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add drm-client infrastructure (drm-backport-placeholder)
- commit 28844b5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add child contexts to the GuC context lookup (drm-backport-placeholder)
- commit a448476
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/wa: Apply tile workarounds at probe/resume (drm-backport-placeholder)
- commit 78a1f9e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Disallow pinning dma-bufs in VRAM (drm-backport-placeholder)
- commit 804f0ac
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Simplify final return from xe_irq_install() (drm-backport-placeholder)
- commit 613fd53
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Reinstate pipelined fence enable_signaling (drm-backport-placeholder)
- commit 83d057c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uc: Add GuC/HuC firmware path overrides (drm-backport-placeholder)
- commit 7fd2eae
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uc: Fix uC status tracking (drm-backport-placeholder)
- commit b1d1db2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uc: Rename guc_submission_enabled() to uc_enabled() (drm-backport-placeholder)
- commit df7871f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pmu: Enable PMU interface (drm-backport-placeholder)
- commit d17e94f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use spinlock in forcewake instead of mutex (drm-backport-placeholder)
- commit 588ceac
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Get GT clock to nanosecs (drm-backport-placeholder)
- commit 4fdb6da
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Switch to major-only GuC FW tracking for MTL (drm-backport-placeholder)
- commit 94323b9
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Introduce Xe assert macros (drm-backport-placeholder)
- commit 4748681
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Replace XE_WARN_ON with drm_warn when just printing a string (drm-backport-placeholder)
- commit a1e5473
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix fence reservation accouting (drm-backport-placeholder)
- commit e078f14
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Convert pagefaulting code to use drm_exec (drm-backport-placeholder)
- commit fa07716
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/bo: Remove the lock_no_vm()/unlock_no_vm() interface (drm-backport-placeholder)
- commit 232d9bd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/vm: Simplify and document xe_vm_lock() (drm-backport-placeholder)
- commit c1cd78f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/bo: Simplify xe_bo_lock() (drm-backport-placeholder)
- commit e0d8601
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mmio: Account for GSI offset when checking ranges (drm-backport-placeholder)
- commit 516a7fe
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Remove useless max_page_size (drm-backport-placeholder)
- commit 01df4bd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Typo lingo and other small backwards compatible fixes (drm-backport-placeholder)
- commit 573f895
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix LRC workarounds (drm-backport-placeholder)
- commit 371d6e1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add dbg messages for LRC WAs (drm-backport-placeholder)
- commit 51b45b2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/reg_sr: Use xe_gt_dbg (drm-backport-placeholder)
- commit 6cdba4c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/reg_sr: Simplify check for masked registers (drm-backport-placeholder)
- commit f09e34d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pat: Use 0 instead of space on error (drm-backport-placeholder)
- commit 5025f78
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/selftests: make eviction test tile centric (drm-backport-placeholder)
- commit ef0f5b9
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/selftests: consider multi-GT for eviction test (drm-backport-placeholder)
- commit 8c498ea
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pm: Use PM functions only if CONFIG_PM_SLEEP is enabled (drm-backport-placeholder)
- commit 26a94bb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix array of binds (drm-backport-placeholder)
- commit 5edddd7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/gpuva: Add drm_gpuva_for_each_op_reverse (drm-backport-placeholder)
- commit 637904e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fixup unwind on VM ops errors (drm-backport-placeholder)
- commit f67bb47
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Convert xe_vma_op_flags to BIT macros (drm-backport-placeholder)
- commit b4a4336
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: fix has_llc on rkl (drm-backport-placeholder)
- commit 94bfa10
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: nuke GuC on unload (drm-backport-placeholder).
- commit ef1dc77
* Thu Oct 10 2024 msuchanek@suse.de
- tty: hvc: convert to u8 and size_t (git-fixes).
- commit 068222b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Prevent return with locked vm (drm-backport-placeholder)
- commit 4bb0701
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add patch version on guc firmware init (drm-backport-placeholder)
- commit 64a2bac
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pvc: Use fast copy engines as migrate engine on PVC (drm-backport-placeholder)
- commit 2411933
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pvc: Force even num engines to use 64B (drm-backport-placeholder)
- commit 58e637c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pvc: Blacklist BCS_SWCTRL register (drm-backport-placeholder)
- commit 001ce25
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/ct: fix resv_space print (drm-backport-placeholder)
- commit 0d7b704
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: standardize vm-less kernel submissions (drm-backport-placeholder)
- commit f9cec59
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: split kernel vs permanent engine flags (drm-backport-placeholder)
- commit e1f3345
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: fix submissions without vm (drm-backport-placeholder)
- commit 6e9bd2f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Drop xe_mmio_write64() (drm-backport-placeholder)
- commit aea578f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Avoid 64-bit register reads (drm-backport-placeholder)
- commit 3f3e3f5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/lnl: Hook up MOCS table (drm-backport-placeholder)
- commit 84a5c2f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/lnl: Add GuC firmware definition (drm-backport-placeholder)
- commit 41fb3d4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/lnl: Add LNL platform definition (drm-backport-placeholder)
- commit 4ca6720
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Program GuC's MOCS on Xe2 and beyond (drm-backport-placeholder)
- commit 0e0e27c
* Thu Oct 10 2024 msuchanek@suse.de
- powerpc/powernv/pci: use pci_dev_id() to simplify the code
  (jsc#PED-10539).
- powerpc/powernv/pci: Remove last IODA1 defines (jsc#PED-10539).
- powerpc/powernv/pci: Remove MVE code (jsc#PED-10539).
- powerpc/powernv/pci: Remove ioda1 support (jsc#PED-10539).
- commit 12239b1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Add MOCS table (drm-backport-placeholder)
- commit 05f8aaf
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Track VA bits independently of max page table level (drm-backport-placeholder)
- commit 03372c2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Define Xe2_LPM IP features (drm-backport-placeholder)
- commit 8716d6a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Define Xe2_LPG IP features (drm-backport-placeholder)
- commit d892fbb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: AuxCCS is no longer used (drm-backport-placeholder)
- commit 6889971
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Handle fused-off CCS engines (drm-backport-placeholder)
- commit 3be9230
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Update context image layouts (drm-backport-placeholder)
- commit de8c2a3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Add MCR register steering for media GT (drm-backport-placeholder)
- commit dd8e4b4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Add MCR register steering for primary GT (drm-backport-placeholder)
- commit 966378f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Add GT topology readout (drm-backport-placeholder)
- commit e708800
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe2: Update render/compute context image sizes (drm-backport-placeholder)
- commit a0f7f16
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Stop tracking 4-tile support (drm-backport-placeholder)
- commit 77db713
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: enable idle msg and set hysteresis for GSCCS (drm-backport-placeholder)
- commit ecfa065
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: don't expose the GSCCS to users (drm-backport-placeholder)
- commit 1b42881
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: GSC forcewake support (drm-backport-placeholder)
- commit 934c65b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: add GSCCS ring ops (drm-backport-placeholder)
- commit 2ad8e9b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: add GSCCS irq support (drm-backport-placeholder)
- commit 2c86843
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: base definitions for the GSCCS (drm-backport-placeholder)
- commit 1497297
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: common function to assign queue name (drm-backport-placeholder)
- commit 306ac47
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Simplify engine class sched_props setting (drm-backport-placeholder)
- commit b32fd91
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/dg2: Remove Wa_15010599737 (drm-backport-placeholder)
- commit 0a2b705
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Improve vram info debug printing (drm-backport-placeholder)
- commit 7cbfd60
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Make xe_mem_region struct (drm-backport-placeholder)
- commit 64f4476
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Call __guc_exec_queue_fini_async direct for KERNEL (drm-backport-placeholder)
- commit 2539fd2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: skip rebind_list if vma destroyed (drm-backport-placeholder).
- commit e9a7233
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc_submit: fixup deregister in job timeout (drm-backport-placeholder)
- commit ff59c46
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pm: Add vram_d3cold_threshold for d3cold capable device (drm-backport-placeholder)
- commit b49f01f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add Wa_14015150844 for DG2 and Xe_LPG (drm-backport-placeholder)
- commit b04ad6e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: don't warn for bogus pagefaults (drm-backport-placeholder)
- commit 0ce456e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Implement HW workaround 14016763929 (drm-backport-placeholder)
- commit 5e0a338
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Update ARL-S DevIDs to the latest BSpec (drm-backport-placeholder)
- commit 1c10ad6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Set max pte size when skipping rebinds (drm-backport-placeholder)
- commit eb99e52
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc_submit: prevent repeated unregister (drm-backport-placeholder)
- commit 6f36c78
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix error path in xe_guc_pc_start() (drm-backport-placeholder)
- commit 68a62ba
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix error path in xe_guc_pc_gucrc_disable() (drm-backport-placeholder)
- commit 58b61bc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add sysfs for preempt reset timeout (drm-backport-placeholder)
- commit 0a79525
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add timeslice duration engine property to sysfs (drm-backport-placeholder)
- commit 3e42fdf
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add job timeout engine property to sysfs (drm-backport-placeholder)
- commit a2860a1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add sysfs for default engine scheduler properties (drm-backport-placeholder)
- commit 5605864
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add sysfs entries for engines under its GT (drm-backport-placeholder)
- commit 0a25d83
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Rename engine to exec_queue (drm-backport-placeholder)
- commit 7fe4c44
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Rename xe_engine.[ch] to xe_exec_queue.[ch] (drm-backport-placeholder)
- commit fa25dcc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix error paths of __xe_bo_create_locked (drm-backport-placeholder)
- commit 1706f67
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: remove header variable from parse_g2h_msg (drm-backport-placeholder)
- commit 4de4f26
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Prefer WARN() over BUG() to avoid crashing the kernel (drm-backport-placeholder)
- commit e959d4d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/macro: Remove unused constant (drm-backport-placeholder)
- commit eb02f5e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add define WQ_HEADER_SIZE (drm-backport-placeholder)
- commit e785196
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove ct->fence_context (drm-backport-placeholder)
- commit a9cda2d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove XE_GUC_CT_SELFTEST (drm-backport-placeholder)
- commit 6f74539
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mtl: Reduce Wa_14018575942 scope to the CCS engine (drm-backport-placeholder)
- commit f0b594e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Ensure memory eviction on s2idle. (drm-backport-placeholder)
- commit b0e57eb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Only init runtime PM after all d3cold config is in place. (drm-backport-placeholder)
- commit ec51cfb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix the runtime_idle call and d3cold.allowed decision. (drm-backport-placeholder)
- commit ad1e268
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Move d3cold_allowed decision all together. (drm-backport-placeholder)
- commit e0aa5ee
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Only set PCI d3cold_allowed when we are really allowing. (drm-backport-placeholder)
- commit af84452
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Introduce fault injection for gt reset (drm-backport-placeholder)
- commit 6220815
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Notify Userspace when gt reset fails (drm-backport-placeholder)
- commit 2817060
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Invert mask and val in xe_mmio_wait32. (drm-backport-placeholder)
- commit b5ac388
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix an invalid locking wait context bug (drm-backport-placeholder)
- commit 4b0ba62
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Sort xe_regs.h (drm-backport-placeholder)
- commit e83349d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Carve out top of DSM as reserved (drm-backport-placeholder)
- commit f9bec59
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix MTL+ stolen memory mapping (drm-backport-placeholder)
- commit 4f76f12
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Set PTE_DM bit for stolen on MTL (drm-backport-placeholder)
- commit 143a07e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Decouple vram check from xe_bo_addr() (drm-backport-placeholder)
- commit 68a9135
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove vma arg from xe_pte_encode() (drm-backport-placeholder)
- commit 33152d7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: fix mcr semaphore locking for MTL (drm-backport-placeholder)
- commit 0f66efc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix checking for unset value (drm-backport-placeholder)
- commit 9542719
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/engine: add missing rpm for bind engines (drm-backport-placeholder)
- commit 0781798
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Signal out-syncs on VM binds if no operations (drm-backport-placeholder)
- commit 9a4696c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Always use xe_vm_queue_rebind_worker helper (drm-backport-placeholder)
- commit 67889fb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Invert guc vs execlists parameters and info. (drm-backport-placeholder)
- commit 983d77e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Remove XE_QUERY_CONFIG_FLAGS_USE_GUC (drm-backport-placeholder)
- commit 232178c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: fully turn on small-bar support (drm-backport-placeholder)
- commit a46a2c3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: add the userspace bits for small-bar (drm-backport-placeholder)
- commit 8adf900
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/bo: support tiered vram allocation for small-bar (drm-backport-placeholder)
- commit 876a02d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: xe_engine_create_ioctl should check gt_count, not tile_count (drm-backport-placeholder)
- commit 99b3bd7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mtl: Map PPGTT as CPU:WC (drm-backport-placeholder)
- commit c876362
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: add lockdep annotation for xe_device_mem_access_put() (drm-backport-placeholder)
- commit 31f61e6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use migrate engine for page fault binds (drm-backport-placeholder)
- commit 5e1cd4d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Only alloc userptr part of xe_vma for userptrs (drm-backport-placeholder)
- commit 1a150ad
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Combine destroy_cb and destroy_work in xe_vma into union (drm-backport-placeholder)
- commit 351928f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Change tile masks from u64 to u8 (drm-backport-placeholder)
- commit dacee6e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Replace list_del_init with list_del for (drm-backport-placeholder)
- commit db8d077
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Reduce the number list links in xe_vma (drm-backport-placeholder)
- commit 0ff73ee
* Thu Oct 10 2024 msuchanek@suse.de
- Update patches.suse/powerpc-pseries-iommu-Split-Dynamic-DMA-Window-to-be.patch
  (jsc#PED-9897).
- commit f929d43
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Avoid doing rebinds (drm-backport-placeholder)
- commit 66e889c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove xe_vma_op_unmap (drm-backport-placeholder)
- commit a2eb35d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Make bind engines safe (drm-backport-placeholder)
- commit 6762be0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Introduce a range-fence utility (drm-backport-placeholder)
- commit dc4f393
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/execlist: Log when using execlist submission (drm-backport-placeholder)
- commit bc08cfc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Cleanup style warnings and errors (drm-backport-placeholder)
- commit 9e6978c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/execlist: Remove leftover printk messages (drm-backport-placeholder)
- commit fb0ba91
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Rely on kmalloc/kzalloc log message (drm-backport-placeholder)
- commit 8beed18
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use FIELD_PREP/FIELD_GET for tile id encoding (drm-backport-placeholder)
- commit d96473f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Normalize XE_VM_FLAG* names (drm-backport-placeholder)
- commit eb541da
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: add missing bulk_move reset (drm-backport-placeholder)
- commit 0c5e0f3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/selftests: restart GT after xe_bo_restore_kernel() (drm-backport-placeholder)
- commit ec9d5d4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/selftests: hold rpm for ccs_test_migrate() (drm-backport-placeholder)
- commit 1706776
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/selftests: hold rpm for evict_test_run_device() (drm-backport-placeholder)
- commit 3f13ed9
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: add lockdep annotation for xe_device_mem_access_get() (drm-backport-placeholder)
- commit d02cf6c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: drop xe_device_mem_access_get() from invalidation_vma (drm-backport-placeholder)
- commit caa0db7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/ggtt: prime ggtt->lock against FS_RECLAIM (drm-backport-placeholder)
- commit 6cec90c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: drop xe_device_mem_access_get() from guc_ct_send (drm-backport-placeholder)
- commit d824594
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: ensure correct access_put ordering (drm-backport-placeholder)
- commit c57d95c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mmio: grab mem_access in xe_mmio_ioctl (drm-backport-placeholder)
- commit 16bcae5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc_pc: add missing mem_access for freq_rpe_show (drm-backport-placeholder)
- commit 9595ad3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/debugfs: grab mem_access around forcewake (drm-backport-placeholder)
- commit 1933ee5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/vm: tidy up xe_runtime_pm usage (drm-backport-placeholder)
- commit e7088bc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: fix xe_device_mem_access_get() races (drm-backport-placeholder)
- commit d43a9f9
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pm: Init pcode and restore vram on power lost (drm-backport-placeholder)
- commit c3033c5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pm: Toggle d3cold_allowed using vram_usages (drm-backport-placeholder)
- commit 3ba045d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pm: Add vram_d3cold_threshold Sysfs (drm-backport-placeholder)
- commit 91f944c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pm: Refactor xe_pm_runtime_init (drm-backport-placeholder)
- commit 4e28cc9
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pm: Add pci d3cold_capable support (drm-backport-placeholder)
- commit 22cf4f8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: remove gucrc disable from suspend path (drm-backport-placeholder)
- commit eaf7734
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Cleanup style warnings (drm-backport-placeholder)
- commit 857d3ed
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Prevent flooding the kernel log with XE_IOCTL_ERR (drm-backport-placeholder)
- commit 0cee449
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix typos (drm-backport-placeholder)
- commit 14f6ecc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Cleanup COMPLEX_MACRO style issues (drm-backport-placeholder)
- commit 07e32bd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Cleanup TRAILING_WHITESPACE style issues (drm-backport-placeholder)
- commit a2682b5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Cleanup CODE_INDENT style issues (drm-backport-placeholder)
- commit bbbc62b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Cleanup POINTER_LOCATION style issues (drm-backport-placeholder)
- commit fd64375
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Cleanup OPEN_BRACE style issues (drm-backport-placeholder)
- commit cb044ac
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Cleanup SPACING style issues (drm-backport-placeholder)
- commit 50cf0ba
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix lockdep warning from xe_vm_madvise (drm-backport-placeholder)
- commit bbe5fe8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix BUG_ON during bind with prefetch (drm-backport-placeholder)
- commit b250742
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mmio: update gt_count when probing multi-tile (drm-backport-placeholder).
- commit 38c61c9
* Thu Oct 10 2024 msuchanek@suse.de
- powerpc/pseries/iommu: Define spapr_tce_table_group_ops only
  with CONFIG_IOMMU_API (jsc#PED-10539).
- powerpc/iommu: Reimplement the iommu_table_group_ops for pSeries
  (jsc#PED-10539).
- powerpc/iommu: Move dev_has_iommu_table() to iommu.c
  (jsc#PED-10539).
- powerpc/pseries/iommu: Use the iommu table[0] for IOV VF's DDW
  (jsc#PED-10539).
- powerpc/pseries/iommu: Fix the VFIO_IOMMU_SPAPR_TCE_GET_INFO
  ioctl output (jsc#PED-10539).
- powerpc/iommu: Move pSeries specific functions to
  pseries/iommu.c (jsc#PED-10539).
- powerpc/iommu: Refactor spapr_tce_platform_iommu_attach_dev()
  (jsc#PED-10539).
- powerpc/iommu: Only build sPAPR access functions on pSeries
  (jsc#PED-10539).
- commit b7cf2c4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: handle TLB invalidations from CT fast-path (drm-backport-placeholder).
- commit f519d1d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/ct: update g2h outstanding for CTB capture (drm-backport-placeholder)
- commit 29a65f2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/tlb: print seqno_recv on fence TLB timeout (drm-backport-placeholder)
- commit 0f8dc5c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/tlb: also update seqno_recv during reset (drm-backport-placeholder)
- commit 6ed23bb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/gt: tweak placement for signalling TLB fences after GT reset (drm-backport-placeholder)
- commit 2731444
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/ct: serialise fast_lock during CT disable (drm-backport-placeholder)
- commit c26c9a2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/tlb: increment next seqno after successful CT send (drm-backport-placeholder)
- commit e737a2e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/ct: hold fast_lock when reserving space for g2h (drm-backport-placeholder)
- commit e5dcd21
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: hold mem_access.ref for CT fast-path (drm-backport-placeholder)
- commit ace46c3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/tlb: ensure we access seqno_recv once (drm-backport-placeholder)
- commit 37a8dbb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/tlb: drop unnecessary smp_wmb() (drm-backport-placeholder)
- commit e67940f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Port Xe to GPUVA (drm-backport-placeholder)
- commit a9468fe
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove __xe_vm_bind forward declaration (drm-backport-placeholder)
- commit aeab99a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add helpers to hide struct xe_vma internals (drm-backport-placeholder)
- commit a97da79
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Ban a VM if rebind worker hits an error (drm-backport-placeholder)
- commit 6e13e5f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use internal VM flags in xe_vm_create (drm-backport-placeholder)
- commit e5dc2b3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: make kobject type struct as constant (drm-backport-placeholder)
- commit 5b34296
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: make GT sysfs init return void (drm-backport-placeholder)
- commit 1434e1f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Fix h2g_write usage of GUC_CTB_MSG_MAX_LEN (drm-backport-placeholder)
- commit 1cec2f1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mmio: add xe_mmio_read16() (drm-backport-placeholder)
- commit 6ae20d3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Make page-table updates using the default engine happen in (drm-backport-placeholder)
- commit e25da89
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Enable PCI device earlier (drm-backport-placeholder)
- commit ebe64a7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Print proper revid value for unknown media revision (drm-backport-placeholder)
- commit a540487
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Don't raise error on fused-off media (drm-backport-placeholder)
- commit 55c3c72
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Return GMD_ID revid properly (drm-backport-placeholder)
- commit 8ea4e4b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Make usable size of VRAM readable (drm-backport-placeholder)
- commit f555968
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add sysfs entry to report per tile memory size (drm-backport-placeholder)
- commit fbc0f9d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add GTs under respective tile sysfs (drm-backport-placeholder)
- commit 9f5afae
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add sysfs entry for tile (drm-backport-placeholder)
- commit 24ff372
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use nanoseconds instead of jiffies in uapi for user fence (drm-backport-placeholder)
- commit e02ddf0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: properly check bounds for xe_wait_user_fence_ioctl() (drm-backport-placeholder)
- commit d8ff8da
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: fix bounds checking for 'len' in xe_engine_create_ioctl (drm-backport-placeholder)
- commit 5809bde
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/slpc: Start SLPC before GuC submission on reset (drm-backport-placeholder)
- commit d8a9dcf
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: fix HuC FW ordering for DG1 (drm-backport-placeholder)
- commit ed463f7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add missing ADL entries to xe_test_wa (drm-backport-placeholder)
- commit 63433c0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/kunit: Handle fake device creation for all (drm-backport-placeholder)
- commit 82a6d8c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pm: Disable PM on unbounded pcie parent bridge (drm-backport-placeholder)
- commit 092b9eb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix vm refcount races (drm-backport-placeholder)
- commit 0bf8c5d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/bo: Evict VRAM to TT rather than to system (drm-backport-placeholder)
- commit 9d16c26
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/bo: Gracefully handle errors from ttm_bo_move_accel_cleanup(). (drm-backport-placeholder)
- commit 755b210
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/bo: Avoid creating a system resource when allocating a fresh (drm-backport-placeholder)
- commit 59a0a17
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/bo: Fix swapin when moving to VRAM (drm-backport-placeholder)
- commit 767f6ff
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mtl: Add support to get C6 residency/status of MTL (drm-backport-placeholder)
- commit f4bf25c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: add a new sysfs directory for gtidle properties (drm-backport-placeholder)
- commit 132ff60
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/bo: consider bo->flags in xe_bo_migrate() (drm-backport-placeholder)
- commit d61a470
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/doc: include xe_drm.h (drm-backport-placeholder)
- commit 5533aa4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: silence kernel-doc errors (drm-backport-placeholder)
- commit ded551a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: add some kernel-doc for region query (drm-backport-placeholder)
- commit 2755101
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: restrict system wide accounting (drm-backport-placeholder)
- commit 69013c0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Document topology mask query (drm-backport-placeholder)
- commit 2c6f26d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Move defines before relevant fields (drm-backport-placeholder)
- commit 97fb9c0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Document structures for device query (drm-backport-placeholder)
- commit e1def6f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix unreffed ptr leak on engine lookup (drm-backport-placeholder)
- commit 0cf81b8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Skip applying copy engine fuses (drm-backport-placeholder)
- commit f96ec3a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/bo: handle PL_TT -> PL_TT (drm-backport-placeholder)
- commit 7afd5cb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: VM LRU bulk move (drm-backport-placeholder)
- commit 9a6f5b4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Only try to lock external BOs in VM bind (drm-backport-placeholder)
- commit 57d757b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Ensure LR engines are not persistent (drm-backport-placeholder)
- commit 6bc09f9
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Long running job update (drm-backport-placeholder)
- commit 677af23
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: NULL binding implementation (drm-backport-placeholder)
- commit 841c95b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/Xe: Use EOPNOTSUPP instead of ENOTSUPP (drm-backport-placeholder)
- commit 238f274
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: limit GGTT size to GUC_GGTT_TOP (drm-backport-placeholder)
- commit 0413f8b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mtl: Add some initial MTL workarounds (drm-backport-placeholder)
- commit b09738a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix check for platform without geometry pipeline (drm-backport-placeholder)
- commit 6c9c1f2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix uninitialized variables (drm-backport-placeholder)
- commit 599fcae
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix GT looping for standalone media (drm-backport-placeholder)
- commit 2e1ddb3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Donot apply forcewake while reading actual frequency (drm-backport-placeholder)
- commit f0e51ac
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Normalize error messages with %%#x (drm-backport-placeholder)
- commit 5ef0444
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Fix typo s/enabled/enable/ (drm-backport-placeholder)
- commit bea8de8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Rename pte/pde encoding functions (drm-backport-placeholder)
- commit fb20825
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Move XE_PTE_FLAG_READ_ONLY to xe_vm_types.h (drm-backport-placeholder)
- commit 2d952cc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: s/XE_PTE_READ_ONLY/XE_PTE_FLAG_READ_ONLY (drm-backport-placeholder)
- commit c4d68c6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use Xe ordered workqueue for rebind worker (drm-backport-placeholder)
- commit 8248ce6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Handle unmapped userptr in analyze VM (drm-backport-placeholder)
- commit 6a9d418
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Emit a render cache flush after each rcs/ccs batch (drm-backport-placeholder)
- commit 84011ad
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Invalidate TLB also on bind if in scratch page mode (drm-backport-placeholder)
- commit f98840e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/reg_sr: Apply limit to register whitelisting (drm-backport-placeholder)
- commit cb848d8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/reg_sr: Use a single parameter for xe_reg_sr_apply_whitelist() (drm-backport-placeholder)
- commit 120f07b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Read HXG fields from DW1 of G2H response (drm-backport-placeholder)
- commit e0e3dc1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix some formatting issues in uAPI (drm-backport-placeholder)
- commit ee5a8bc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Group engine related structs (drm-backport-placeholder)
- commit 7b36385
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use SPDX-License-Identifier instead of license text (drm-backport-placeholder)
- commit e81fb3a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/wa: Extend scope of Wa_14015795083 (drm-backport-placeholder)
- commit 196ef5a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: REBAR resize should be best effort (drm-backport-placeholder)
- commit 52f5b80
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Don't hardcode GuC's MOCS index in register header (drm-backport-placeholder)
- commit 4826ec1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Initialize MOCS earlier (drm-backport-placeholder)
- commit 5d85e2e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Reformat xe_guc_regs.h (drm-backport-placeholder)
- commit e58ca76
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Replace deprecated DRM_ERROR() (drm-backport-placeholder)
- commit 622085f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add kerneldoc description of multi-tile devices (drm-backport-placeholder)
- commit 2ad2697
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Reinstate media GT support (drm-backport-placeholder)
- commit b29837e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Update query uapi to support standalone media (drm-backport-placeholder)
- commit 1a6e979
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Allow GT looping and lookup on standalone media (drm-backport-placeholder)
- commit 1d8d3b1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/tlb: Obtain forcewake when doing GGTT TLB invalidations (drm-backport-placeholder)
- commit 2358ec6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Invalidate TLB on all affected GTs during GGTT updates (drm-backport-placeholder)
- commit ae60c71
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Replace xe_gt_irq_postinstall with xe_irq_enable_hwe (drm-backport-placeholder)
- commit 4d4224d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/irq: Untangle postinstall functions (drm-backport-placeholder)
- commit 479d9ac
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/irq: Ensure primary GuC won't clobber media GuC's interrupt (drm-backport-placeholder)
- commit 94760f1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/irq: Move ASLE backlight interrupt logic (drm-backport-placeholder)
- commit bcdccc6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Interrupts are delivered per-tile, not per-GT (drm-backport-placeholder)
- commit a31eef4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add media GT to tile (drm-backport-placeholder)
- commit efb9fde
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Allocate GT dynamically (drm-backport-placeholder)
- commit 56645f1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Drop extra_gts[] declarations and XE_GT_TYPE_REMOTE (drm-backport-placeholder)
- commit a2cb12a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Drop vram_id (drm-backport-placeholder)
- commit a9823e4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Clarify 'gt' retrieval for primary tile (drm-backport-placeholder)
- commit d1299cb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Move migration from GT to tile (drm-backport-placeholder)
- commit 83212e6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Memory allocations are tile-based, not GT-based (drm-backport-placeholder)
- commit afeb239
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Move VRAM from GT to tile (drm-backport-placeholder)
- commit 95a824f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Move GGTT from GT to tile (drm-backport-placeholder)
- commit e2a3948
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Move register MMIO into xe_tile (drm-backport-placeholder)
- commit 0780461
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add for_each_tile iterator (drm-backport-placeholder)
- commit 5820a74
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add backpointer from gt to tile (drm-backport-placeholder)
- commit 32082b2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Introduce xe_tile (drm-backport-placeholder)
- commit 145713c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mtl: Disable media GT (drm-backport-placeholder)
- commit b2028c3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/vm: fix double list add (drm-backport-placeholder)
- commit 1b3979f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Replace PVC check by engine type check (drm-backport-placeholder)
- commit 259bbdf
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Rename GPU offset helper to reflect true usage (drm-backport-placeholder)
- commit c01811f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Size GT device memory correctly (drm-backport-placeholder)
- commit 43e6f6b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Simplify rebar sizing (drm-backport-placeholder)
- commit 81767d6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Rework size helper to be a little more correct (drm-backport-placeholder)
- commit 23c2adc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Prevent evicting for page tables (drm-backport-placeholder)
- commit bb45cae
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: keep pulling mem_access_get further back (drm-backport-placeholder)
- commit 660ac12
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: don't allocate under ct->lock (drm-backport-placeholder)
- commit 88b4b3c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/migrate: retain CCS aux state for vram -> vram (drm-backport-placeholder)
- commit 4e54ad0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/bo: further limit where CCS pages are needed (drm-backport-placeholder)
- commit 250e47b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Support copying of data between system memory bos (drm-backport-placeholder)
- commit c9fb67e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix the migrate selftest for integrated GPUs (drm-backport-placeholder)
- commit 0285d92
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Port Wa_14014475959 to xe_wa and fix it (drm-backport-placeholder)
- commit fb8037f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/rtp: Also check gt type (drm-backport-placeholder)
- commit 5246fed
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Port Wa_1509372804 to xe_wa (drm-backport-placeholder)
- commit e97dbe5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Port Wa_16015675438/Wa_18020744125 to xe_wa (drm-backport-placeholder)
- commit c8bc1ea
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Port Wa_22012727170/Wa_22012727685 to xe_wa (drm-backport-placeholder)
- commit 9e59904
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Port Wa_16011777198 to xe_wa (drm-backport-placeholder)
- commit ddb6e68
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Port Wa_14012197797/Wa_22011391025 to xe_wa (drm-backport-placeholder)
- commit 8ee2292
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Port Wa_16011759253 to xe_wa (drm-backport-placeholder)
- commit 093c43f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Port Wa_22012773006 to xe_wa (drm-backport-placeholder)
- commit 7e9ca3a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add support for OOB workarounds (drm-backport-placeholder)
- commit 78f0534
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Include build directory (drm-backport-placeholder)
- commit f2802be
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/rtp: Add support for entries with no action (drm-backport-placeholder)
- commit 7a56f69
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/rtp: Add check for media stepping (drm-backport-placeholder)
- commit 7a911ce
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/rtp: Rename STEP to GRAPHICS_STEP (drm-backport-placeholder)
- commit 5acda89
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/debugfs: Dump active workarounds (drm-backport-placeholder)
- commit c16b7b4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/wa: Track gt/engine/lrc active workarounds (drm-backport-placeholder)
- commit bf80e71
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/rtp: Allow to track active workarounds (drm-backport-placeholder)
- commit 65c301a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/rtp: Add "_sr" to entry/function names (drm-backport-placeholder)
- commit fa7d5c3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/rtp: Replace XE_WARN_ON (drm-backport-placeholder)
- commit 475dc4b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/rtp: Split rtp process initialization (drm-backport-placeholder)
- commit 5c1cfa1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix Wa_22011802037 annotation (drm-backport-placeholder)
- commit 84e7c98
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pvc: Don't try to invalidate AuxCCS TLB (drm-backport-placeholder)
- commit ad54308
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Validate uAPI padding and reserved fields (drm-backport-placeholder)
- commit e895899
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add explicit padding to uAPI definition (drm-backport-placeholder)
- commit 423d9a2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Apply upper limit to sg element size (drm-backport-placeholder)
- commit 1af7fd7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add stepping support for GMD_ID platforms (drm-backport-placeholder)
- commit 30a6109
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fail xe_device_create() if wq allocation fails (drm-backport-placeholder)
- commit 0e22d15
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Call drmm_add_action_or_reset() early in xe_device_create() (drm-backport-placeholder)
- commit 6437f89
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Do not forget to drm_dev_put() in xe_pci_probe() (drm-backport-placeholder)
- commit 17e94a0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: fix kernel-doc issues (drm-backport-placeholder)
- commit 9de0af0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Change GuC interrupt data (drm-backport-placeholder)
- commit 48efe13
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Move Media GuC register definition to regs/ (drm-backport-placeholder)
- commit f74bbd6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Limit CONFIG_DRM_XE_SIMPLE_ERROR_CAPTURE to itself. (drm-backport-placeholder)
- commit 960948f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add HW Engine snapshot to xe_devcoredump. (drm-backport-placeholder)
- commit ca3d50e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Convert Xe HW Engine print to snapshot capture and print. (drm-backport-placeholder)
- commit bc6d224
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add GuC Submit Engine snapshot to xe_devcoredump. (drm-backport-placeholder)
- commit 8711626
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Convert GuC Engine print to snapshot capture and print. (drm-backport-placeholder)
- commit 6975e4b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Introduce guc_submit_types.h with relevant structs. (drm-backport-placeholder)
- commit 62ab7ea
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add GuC CT snapshot to xe_devcoredump. (drm-backport-placeholder)
- commit ffb22e5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Convert GuC CT print to snapshot capture and print. (drm-backport-placeholder)
- commit 5f94422
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Extract non mapped regions out of GuC CTB into its own (drm-backport-placeholder)
- commit a044e49
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Do not take any action if our device was removed. (drm-backport-placeholder)
- commit 7bcdf0b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Introduce the dev_coredump infrastructure. (drm-backport-placeholder)
- commit d35bcf2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use GT oriented log messages in xe_gt.c (drm-backport-placeholder)
- commit e771ca8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Introduce GT oriented log messages (drm-backport-placeholder)
- commit c053cdf
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Allow dma-fences as in-syncs for compute / faulting VM (drm-backport-placeholder)
- commit 43225bb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Allow compute VMs to output dma-fences on binds (drm-backport-placeholder)
- commit f4391a7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Call exit functions when xe_register_pci_driver() fails (drm-backport-placeholder)
- commit d897370
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Get rid of MAKE_INIT_EXIT_FUNCS (drm-backport-placeholder)
- commit b969551
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove unused define (drm-backport-placeholder)
- commit 34d72b6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Load HuC on Alderlake P (drm-backport-placeholder)
- commit 07602b7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/adln: Enable ADL-N (drm-backport-placeholder)
- commit bd9872f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/adlp: Add revid => step mapping (drm-backport-placeholder)
- commit 51e11f4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: fix tlb_invalidation_seqno_past() (drm-backport-placeholder)
- commit f332ecd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix indent in xe_hw_engine_print_state() (drm-backport-placeholder)
- commit ad0aa89
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Rename reg field to addr (drm-backport-placeholder)
- commit 44cd0ba
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mmio: Use struct xe_reg (drm-backport-placeholder)
- commit 0166463
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Handle -EDEADLK case in exec ioctl (drm-backport-placeholder)
- commit ffd6e2b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Handle -EDEADLK case in preempt worker (drm-backport-placeholder)
- commit de66a94
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: destroy clients engine and vm xarrays on close (drm-backport-placeholder)
- commit 4675a37
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Print GT info on TLB inv failure (drm-backport-placeholder)
- commit e25ed65
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Do not sleep in atomic (drm-backport-placeholder)
- commit 61438a5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Handle RCU_MODE as masked from definition (drm-backport-placeholder)
- commit 04b9703
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Remove special handling for PVC A* (drm-backport-placeholder)
- commit 2d28f93
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix comment on Wa_22013088509 (drm-backport-placeholder)
- commit 62d8a32
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Do not mark 1809175790 as a WA (drm-backport-placeholder)
- commit b65cd87
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Enable the compat ioctl functionality (drm-backport-placeholder)
- commit 2b807ec
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix splat during error dump (drm-backport-placeholder)
- commit 15af8cf
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Set default MOCS value for copy cs instructions (drm-backport-placeholder)
- commit 76f3059
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Set default MOCS value for cs instructions (drm-backport-placeholder)
- commit 215d88e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Include only relevant header in xe_module.h (drm-backport-placeholder)
- commit f633561
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Enable Raptorlake-P (drm-backport-placeholder)
- commit 39562cf
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix media detection for pre-GMD_ID platforms (drm-backport-placeholder)
- commit 229d885
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Move helper macros to separate header (drm-backport-placeholder)
- commit c2829dd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Plumb xe_reg into WAs, rtp, etc (drm-backport-placeholder)
- commit 45471cd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Annotate masked registers used by RTP (drm-backport-placeholder)
- commit 5bd3efc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use XE_REG/XE_REG_MCR (drm-backport-placeholder)
- commit 3277a5d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Introduce xe_reg/xe_reg_mcr (drm-backport-placeholder)
- commit 282b3db
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Clarify register types on PAT programming (drm-backport-placeholder)
- commit ca7ea1d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use REG_FIELD/REG_BIT for all regs/*.h (drm-backport-placeholder)
- commit fbf0175
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Drop gen afixes from registers (drm-backport-placeholder)
- commit 93bcdfc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Convert GuC registers to REG_FIELD/REG_BIT (drm-backport-placeholder)
- commit c862aba
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove extra xe_mmio_read32 from xe_mmio_wait32 (drm-backport-placeholder)
- commit 071666e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Move GuC registers to regs/ (drm-backport-placeholder)
- commit 2a5f509
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Rename GEN11_SOFT_SCRATCH for clarity (drm-backport-placeholder)
- commit ab67ccf
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Rename instruction field to avoid confusion (drm-backport-placeholder)
- commit 44b8016
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Rename RC0/RC6 macros (drm-backport-placeholder)
- commit d90c2a3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Cleanup page-related defines (drm-backport-placeholder)
- commit f0745c7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix print of RING_EXECLIST_SQ_CONTENTS_HI (drm-backport-placeholder)
- commit 0da7d64
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Update comment on why d3cold is still blocked. (drm-backport-placeholder)
- commit 58d4d81
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Limit the system memory size to half of the system memory (drm-backport-placeholder)
- commit 809e6a0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix build without CONFIG_PM_SLEEP (drm-backport-placeholder)
- commit 23d60cd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc_pc: Reorder forcewake and xe_pm_runtime calls (drm-backport-placeholder)
- commit fbbe3e6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Keep all resize bar related prints inside xe_resize_vram_bar (drm-backport-placeholder)
- commit 8b8baa7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Drop GFX_FLSH_CNTL_GEN6 write during GGTT invalidation (drm-backport-placeholder)
- commit 859b110
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix xe_mmio_rmw32 operation (drm-backport-placeholder)
- commit aa1e7de
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/lrc: give start_seqno a better default (drm-backport-placeholder)
- commit 6523713
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/sched_job: prefer dma_fence_is_later (drm-backport-placeholder)
- commit 4e594c3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/sr: Apply masked registers properly (drm-backport-placeholder)
- commit 14e4b22
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/tlb: fix expected_seqno calculation (drm-backport-placeholder)
- commit 2f9b4a1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add Rocketlake device info (drm-backport-placeholder)
- commit fc31575
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mmio: stop incorrectly triggering drm_warn (drm-backport-placeholder)
- commit adbc19b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: GuC and HuC loading support for RKL (drm-backport-placeholder)
- commit 3b2b389
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Only request PCODE_WRITE_MIN_FREQ_TABLE on LLC platforms (drm-backport-placeholder)
- commit d3b46f7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Track whether platform has LLC (drm-backport-placeholder)
- commit 5ee317a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use packed bitfields for xe->info feature flags (drm-backport-placeholder)
- commit 0f3b47e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Don't grab runtime PM ref in engine create IOCTL (drm-backport-placeholder)
- commit fec53d1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Let primary and media GT share a kernel_bb_pool (drm-backport-placeholder)
- commit 3655894
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix memory use after free (drm-backport-placeholder)
- commit 5feda4c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: fix suspend-resume for dgfx (drm-backport-placeholder)
- commit 92df723
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Clean up xe_device_desc (drm-backport-placeholder)
- commit a1e2edf
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add KUnit test for xe_pci.c IP engine lists (drm-backport-placeholder)
- commit cf7c440
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Select graphics/media descriptors from GMD_ID (drm-backport-placeholder)
- commit 78de04a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add printable name to IP descriptors (drm-backport-placeholder)
- commit 061db2c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Clarify GT counting logic (drm-backport-placeholder)
- commit 0b5ce91
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Move engine masks into IP descriptor structures (drm-backport-placeholder)
- commit 7c1c038
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Move most platform traits to graphics IP (drm-backport-placeholder)
- commit 2fd4288
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Set require_force_probe in each platform's description (drm-backport-placeholder)
- commit a9d08dd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Start splitting xe_device_desc into graphics/media structures (drm-backport-placeholder)
- commit 11c0739
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Always log GuC/HuC firmware versions (drm-backport-placeholder)
- commit d58b539
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Always write GEN12_RCU_MODE.GEN12_RCU_MODE_CCS_ENABLE for CCS (drm-backport-placeholder)
- commit fef1ee1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Update GuC/HuC firmware autoselect logic (drm-backport-placeholder)
- commit b575cbf
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add test for GT workarounds and tunings (drm-backport-placeholder)
- commit 6f96cdd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add basic unit tests for rtp (drm-backport-placeholder)
- commit 83326c5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/reg_sr: Save errors for kunit integration (drm-backport-placeholder)
- commit 468a6bf
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Generalize fake device creation (drm-backport-placeholder)
- commit 6290509
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use symbol namespace for kunit tests (drm-backport-placeholder)
- commit 0cc631b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Move test infra out of xe_pci.[ch] (drm-backport-placeholder)
- commit 171877c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Extract function to initialize xe->info (drm-backport-placeholder)
- commit ec31efb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/irq: Don't clobber display interrupts on multi-tile platforms (drm-backport-placeholder)
- commit 9d41c36
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/irq: Drop commented-out code for non-existent media engines (drm-backport-placeholder)
- commit 0ddab06
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/irq: Drop remaining "gen11_" prefix from IRQ functions (drm-backport-placeholder)
- commit e6001fc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/irq: Rename and clarify top-level interrupt handling routines (drm-backport-placeholder)
- commit 5e8c654
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/irq: Drop unnecessary GEN11_ and GEN12_ register prefixes (drm-backport-placeholder)
- commit b389751
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/irq: Drop IRQ_INIT and IRQ_RESET macros (drm-backport-placeholder)
- commit e0af082
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/irq: Add helpers to find ISR/IIR/IMR/IER registers (drm-backport-placeholder)
- commit 9a2f343
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/irq: Drop gen3_ prefixes (drm-backport-placeholder)
- commit 1107958
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: fix pvc unload issue (drm-backport-placeholder)
- commit 118ec3a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix platform order (drm-backport-placeholder)
- commit 996807d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use proper vram offset (drm-backport-placeholder)
- commit c65ea3c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/tests: Set correct expectation (drm-backport-placeholder)
- commit 66b99b8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/tests: Use proper batch base address (drm-backport-placeholder)
- commit 96aef55
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove unused revid from firmware name (drm-backport-placeholder)
- commit f8582c6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Don't emit extra MI_BATCH_BUFFER_END in WA batchbuffer (drm-backport-placeholder)
- commit a383e3f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Adjust batchbuffer space warning when creating a job (drm-backport-placeholder)
- commit b00eb33
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Include hardware prefetch buffer in batchbuffer allocations (drm-backport-placeholder)
- commit b34ae76
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Better error messages for xe_gt_record_default_lrcs (drm-backport-placeholder)
- commit e353ce4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: don't auto fall back to execlist mode if guc failed to init (drm-backport-placeholder)
- commit 2a5f344
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pat: Define PAT tables as static (drm-backport-placeholder)
- commit 0ece5b1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/bo: refactor try_add_vram (drm-backport-placeholder)
- commit 93db710
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: add XE_BO_CREATE_VRAM_MASK (drm-backport-placeholder)
- commit 7ccfa44
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mtl: Handle PAT_INDEX offset jump (drm-backport-placeholder)
- commit b61ead8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mtl: Fix PAT table coherency settings (drm-backport-placeholder)
- commit da9f250
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pat: Clean up PAT register definitions (drm-backport-placeholder)
- commit b447ca8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pat: Handle unicast vs MCR PAT registers (drm-backport-placeholder)
- commit f0eaa99
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pat: Use table-based programming of PAT settings (drm-backport-placeholder)
- commit 89da362
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pat: Move PAT setup to a dedicated file (drm-backport-placeholder)
- commit b633913
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Decrement fault mode counts in xe_vm_close_and_put (drm-backport-placeholder)
- commit 6ecb658
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add max engine priority to xe query (drm-backport-placeholder)
- commit 59107aa
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Load HuC on Alderlake S (drm-backport-placeholder)
- commit 4a4516a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/huc: Support for loading unversiond HuC (drm-backport-placeholder)
- commit 2f94f0d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix potential deadlock handling page faults (drm-backport-placeholder)
- commit dad4baa
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use BO's GT to determine dma_offset when programming PTEs (drm-backport-placeholder)
- commit 02354bd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/gt: some error handling fixes (drm-backport-placeholder)
- commit d2fd074
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Reinstate render / compute cache invalidation in ring ops (drm-backport-placeholder)
- commit 79ae9d7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use atomic instead of mutex for xe_device_mem_access_ongoing (drm-backport-placeholder)
- commit 03b3cc6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Drop zero length arrays (drm-backport-placeholder)
- commit c2e210d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/buddy: add compatible and intersects hooks (drm-backport-placeholder)
- commit c663ea0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/buddy: add visible tracking (drm-backport-placeholder)
- commit 144a871
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Stop accepting value in xe_migrate_clear (drm-backport-placeholder)
- commit ebf09cd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use max wopcm size when validating the preset GuC wopcm size (drm-backport-placeholder)
- commit 76d28e9
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/buddy: remove the virtualized start (drm-backport-placeholder).
- commit 1a4438e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mcr: Separate version from engine type selection (drm-backport-placeholder)
- commit 7bcb407
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/vram: start tracking the io_size (drm-backport-placeholder)
- commit fc4ce3d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/vm: Defer vm rebind until next exec if nothing to execute (drm-backport-placeholder)
- commit ef056e7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/tests: Test both CPU- and GPU page-table updates with the (drm-backport-placeholder)
- commit 9b87a8e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use a small negative initial seqno (drm-backport-placeholder)
- commit e8195dd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Introduce xe_engine_is_idle() (drm-backport-placeholder)
- commit d798d90
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/tests: Support CPU page-table updates in the migrate test (drm-backport-placeholder)
- commit 53a39a5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/migrate: Update cpu page-table updates (drm-backport-placeholder)
- commit 5a80969
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use a define to set initial seqno for fences (drm-backport-placeholder)
- commit 99bc48f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/xe_uc_fw: Use firmware files from standard locations (drm-backport-placeholder)
- commit 2d3fc7d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/irq: the irq handler local variable need not be static (drm-backport-placeholder)
- commit 65d4653
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Replace i915 with xe in uapi (drm-backport-placeholder)
- commit d079330
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add missing LRC workarounds for graphics 1200 (drm-backport-placeholder)
- commit 1ba07cc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add missing ADL-P engine workaround (drm-backport-placeholder)
- commit a2e2753
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add missing DG2 lrc workarounds (drm-backport-placeholder)
- commit 5c0a6f2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add missing DG2 lrc tunings (drm-backport-placeholder)
- commit 0829795
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add missing DG2 engine workarounds (drm-backport-placeholder)
- commit 018e982
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add missing DG2 gt workarounds and tunings (drm-backport-placeholder)
- commit 1327c41
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add PVC engine workarounds (drm-backport-placeholder)
- commit fcaf88d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add PVC gt workarounds (drm-backport-placeholder)
- commit 7f5d17d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Reorder WAs to consider the platform (drm-backport-placeholder)
- commit 8eccc85
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/debugfs: Dump register save-restore tables (drm-backport-placeholder)
- commit 3d35003
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Print whitelist while applying (drm-backport-placeholder)
- commit 8121693
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/reg_sr: Tweak verbosity for register printing (drm-backport-placeholder)
- commit 35be299
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/rtp: Add match helper for gslice fused off (drm-backport-placeholder)
- commit da95fc8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: add xe_ttm_stolen_cpu_access_needs_ggtt() (drm-backport-placeholder)
- commit 6da4a06
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: one more s/lmem/vram/ (drm-backport-placeholder)
- commit 37307bc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix overflow in vram manager (drm-backport-placeholder)
- commit 474d967
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: make compound literal initialization const (drm-backport-placeholder)
- commit a608b82
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pvc: Remove A* steppings (drm-backport-placeholder)
- commit 0492e1b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Name LRC wa after the engine it belongs (drm-backport-placeholder)
- commit 30e6ee8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove dump function from reg_sr (drm-backport-placeholder)
- commit b52b34d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/rtp: Add match for render reset domain (drm-backport-placeholder)
- commit 9e2000f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/rtp: Move match function from wa to rtp (drm-backport-placeholder)
- commit 1b7c6de
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Constify xe_dss_mask_group_ffs() (drm-backport-placeholder)
- commit 2a3d740
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Allow const propagation in gt_to_xe() (drm-backport-placeholder)
- commit a94ed0c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mcr: Document how to initialize group/instance (drm-backport-placeholder)
- commit 9705d97
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mcr: Add L3BANK steering for DG2 (drm-backport-placeholder)
- commit 761750c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/vm: Use the correct vma destroy sequence on userptr failure (drm-backport-placeholder)
- commit 0abd82a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add support for CCS engine fusing (drm-backport-placeholder)
- commit 00732d4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Separate engine fuse handling into dedicated functions (drm-backport-placeholder)
- commit e0bea4a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: s/lmem/vram/ (drm-backport-placeholder)
- commit 7513f3b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Handle regset overflow check for entire GT (drm-backport-placeholder)
- commit 295bca5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/stolen: Exclude reserved lmem portion (drm-backport-placeholder)
- commit 88654c7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/migrate: Fix number of PT structs in docbook (drm-backport-placeholder)
- commit 3cf325d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/tests: Grab a memory access reference around the migrate (drm-backport-placeholder)
- commit 4bc4da3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/tests: Remove CONFIG_FB dependency (drm-backport-placeholder)
- commit a2a3508
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix ROW_CHICKEN2 define (drm-backport-placeholder)
- commit 3be116b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix duplicated setting for register 0x6604 (drm-backport-placeholder).
- commit 7b28223
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix size of xe_eu_mask_t (drm-backport-placeholder)
- commit 230e751
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix typo persitent->persistent (drm-backport-placeholder)
- commit f26ffeb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/device: Prefer the drm-managed mutex_init (drm-backport-placeholder)
- commit 0b93a8c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/bo: explicitly reject zero sized BO (drm-backport-placeholder)
- commit 2de681e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: prefer xe_bo_create_pin_map() (drm-backport-placeholder)
- commit 885145d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mocs: Drop HAS_RENDER_L3CC flag (drm-backport-placeholder)
- commit 18efd68
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mocs: LNCF MOCS settings only need to be restored on pre-Xe_HP (drm-backport-placeholder)
- commit 856f581
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mocs: add MTL mocs (drm-backport-placeholder)
- commit d5abd74
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mocs: Drop duplicate assignment of uc_index (drm-backport-placeholder)
- commit 30652ea
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mocs: Drop xe_mocs_info_index (drm-backport-placeholder)
- commit 5577577
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mocs: Add missing RKL handling (drm-backport-placeholder)
- commit 98622ed
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mocs: Drop unwanted TGL table (drm-backport-placeholder)
- commit b4fa062
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Do not spread i915_reg_defs.h include (drm-backport-placeholder)
- commit e959cf5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Prefer single underscore for header guards (drm-backport-placeholder)
- commit 9217819
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove dependency on intel_mchbar_regs.h (drm-backport-placeholder)
- commit 4bed29e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc_pc: Move gt register to the proper place (drm-backport-placeholder)
- commit a0d2bf7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove dependency on i915_reg.h (drm-backport-placeholder)
- commit ab44b54
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove dependency on intel_gpu_commands.h (drm-backport-placeholder)
- commit fb02471
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove dependency on intel_lrc_reg.h (drm-backport-placeholder)
- commit 03f70f9
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove dependency on intel_gt_regs.h (drm-backport-placeholder)
- commit 5765dce
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove dependency on intel_engine_regs.h (drm-backport-placeholder)
- commit ee723ac
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Sort includes (drm-backport-placeholder)
- commit 511ae04
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Assume MTL's forcewake register continues to future platforms (drm-backport-placeholder)
- commit a1693b9
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove gen-based mmio offsets from hw engine init (drm-backport-placeholder)
- commit 0807bd7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix kunit integration due to missing prototypes (drm-backport-placeholder)
- commit 660bbd9
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pm: fix unbalanced ref handling (drm-backport-placeholder)
- commit 56207e5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Remove i915_regs.h include (drm-backport-placeholder)
- commit 5fe1029
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove outdated build workaround (drm-backport-placeholder)
- commit 79c222e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove duplicate media_ver (drm-backport-placeholder)
- commit 66a72c2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add missing include xe_wait_user_fence.h (drm-backport-placeholder)
- commit 4c9d3b1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add missing doc for xe parameter (drm-backport-placeholder)
- commit 3e4c65e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove unused functions (drm-backport-placeholder)
- commit deffead
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix application of LRC tunings (drm-backport-placeholder)
- commit b442214
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Make local functions static (drm-backport-placeholder)
- commit 1f4f685
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/query: zero the region info (drm-backport-placeholder)
- commit 19d924a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/stolen: don't map stolen on small-bar (drm-backport-placeholder)
- commit eb1c032
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mmio: fix forcewake ref leak in xe_mmio_ioctl (drm-backport-placeholder)
- commit 18de41f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove unseless xe_force_wake_prune. (drm-backport-placeholder)
- commit b53307a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Update the list of devices to add even more TGL devices (drm-backport-placeholder).
- commit e7b4a2c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Initialize ret in mcr_lock() (drm-backport-placeholder)
- commit 36e0612
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/rtp: Support multiple actions per entry (drm-backport-placeholder)
- commit 76af44a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/rtp: Split action and entry flags (drm-backport-placeholder)
- commit 0b6cfe2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Rename xe_rtp_regval to xe_rtp_action (drm-backport-placeholder)
- commit 8e940c1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mcr: Add SQIDI steering for DG2 (drm-backport-placeholder)
- commit e6cb5db
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mcr: Use designated init for xe_steering_types (drm-backport-placeholder)
- commit 153f464
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove TODO from workaround documentation (drm-backport-placeholder)
- commit 0b94bf4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove TODO from rtp infra (drm-backport-placeholder)
- commit 36c714b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix xe_tuning include (drm-backport-placeholder)
- commit ff3af41
* Thu Oct 10 2024 tiwai@suse.de
- Update config files: drop WWAN for non-Arm platforms (jsc#PED-10478)
- commit 9aac4e2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix typo in MCR documentation (drm-backport-placeholder)
- commit 3804f73
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add debugfs for dumping GGTT mappings (drm-backport-placeholder)
- commit 57f6363
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Drop TLB invalidation from ring operations (drm-backport-placeholder)
- commit 4708811
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add TLB invalidation fence after rebinds issued from execs (drm-backport-placeholder)
- commit e196f20
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add has_asid to device info (drm-backport-placeholder)
- commit 75d6b64
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Signal invalidation fence immediately if CT send fails (drm-backport-placeholder)
- commit 5acb27d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Propagate VM unbind error to invalidation fence (drm-backport-placeholder)
- commit ba1df49
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Lock GGTT on when restoring kernel BOs (drm-backport-placeholder)
- commit 7766988
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use GuC to do GGTT invalidations for the GuC firmware (drm-backport-placeholder)
- commit 458efb7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Propagate error from bind operations to async fence (drm-backport-placeholder)
- commit c4f71a8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add range based TLB invalidations (drm-backport-placeholder)
- commit a257570
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add has_range_tlb_invalidation device attribute (drm-backport-placeholder)
- commit 6d43dd1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Delete debugfs entry to issue TLB invalidation (drm-backport-placeholder)
- commit 6c6bea7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Only set VM->asid for platforms that support a ASID (drm-backport-placeholder)
- commit 98ba592
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add TDR for invalidation fence timeout cleanup (drm-backport-placeholder)
- commit 966be75
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add TLB invalidation fence ftrace (drm-backport-placeholder)
- commit 96e7ae6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Kernel doc GT TLB invalidations (drm-backport-placeholder)
- commit 9b98dcc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Invalidate TLB after unbind is complete (drm-backport-placeholder)
- commit beb3eaa
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add TLB invalidation fence (drm-backport-placeholder)
- commit 4e58d3f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Move TLB invalidation variable to own sub-structure in GT (drm-backport-placeholder)
- commit 92b35f0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Break of TLB invalidation into its own file (drm-backport-placeholder)
- commit f563d7a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Don't process TLB invalidation done in CT fast-path (drm-backport-placeholder)
- commit 007eeab
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/migrate: Update emit_pte to cope with a size level than 4k (drm-backport-placeholder)
- commit b7936bc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/ggtt: fix GGTT scratch usage for DG2 (drm-backport-placeholder)
- commit 762d2e3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/ggtt: fix alignment usage for DG2 (drm-backport-placeholder)
- commit 9980957
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/ppgtt: fix scratch page usage on DG2 (drm-backport-placeholder)
- commit a32f409
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/ppgtt: clear the scratch page (drm-backport-placeholder)
- commit d0d2f53
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/bo: reduce xe_bo_create_pin_map() restrictions (drm-backport-placeholder)
- commit 017a31e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Map initial FB at the same place in GGTT too (drm-backport-placeholder)
- commit 553e57b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Convert memory device refcount to s32 (drm-backport-placeholder)
- commit 1c9a55d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Add XE_ENGINE_GET_PROPERTY uAPI (drm-backport-placeholder)
- commit 7fdaa18
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/uapi: Rename XE_ENGINE_PROPERTY_X to XE_ENGINE_SET_PROPERTY_X (drm-backport-placeholder)
- commit 587e831
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Use global macros to set PM functions (drm-backport-placeholder)
- commit 2a8fa34
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: skip Kunit tests requiring real hardware when running on UML (drm-backport-placeholder)
- commit afb59c1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc_pc: Fix Meteor Lake registers. (drm-backport-placeholder)
- commit a40d8fe
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix Meteor Lake rsa issue on guc loading (drm-backport-placeholder)
- commit c188fff
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/gt: Enable interrupt while initializing root gt (drm-backport-placeholder)
- commit 36d01d3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: KUnit tests depend on CONFIG_DRM_FBDEV_EMULATION (drm-backport-placeholder)
- commit a90eb01
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/Kconfig.debug: select DEBUG_FS for KUnit runs (drm-backport-placeholder)
- commit 35b11b7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add min config for kunit integration ARCH=um (drm-backport-placeholder)
- commit 38b933a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Add documentation for mem_type (drm-backport-placeholder)
- commit 7740aad
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/gt: Fix min() with u32 and u64 (drm-backport-placeholder)
- commit 83b1965
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix tracepoints on 32b (drm-backport-placeholder)
- commit cbbf190
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/mmio: Use non-atomic writeq/readq variant for 32b (drm-backport-placeholder)
- commit b178efd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix some log messages on 32b (drm-backport-placeholder)
- commit 04c2639
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/ggtt: Use BIT_ULL() for 64bit (drm-backport-placeholder)
- commit a381e0c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: fix xe_mmio_total_vram_size (drm-backport-placeholder)
- commit 0b738ad
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/pcode: fix pcode error check (drm-backport-placeholder)
- commit 3f9c3c3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: enforce GSMBASE for DG1 instead of BAR2 (drm-backport-placeholder)
- commit 5ecb838
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fix hidden gotcha regression with bo create (drm-backport-placeholder)
- commit ef10949
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Add support GuC MMIO send / recv (drm-backport-placeholder)
- commit 9fc1075
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: s/xe_guc_send_mmio/xe_guc_mmio_send (drm-backport-placeholder)
- commit 2b012bc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/guc: Report submission version of GuC firmware (drm-backport-placeholder)
- commit c4b7b3b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Fake pulling gt->info.engine_mask from hwconfig blob (drm-backport-placeholder)
- commit b32f2e5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Ensure VMA not userptr before calling xe_bo_is_stolen (drm-backport-placeholder)
- commit da553c2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Implement stolen memory. (drm-backport-placeholder)
- commit 155afa1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Take memory ref on kernel job creation (drm-backport-placeholder)
- commit 99bd305
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe/migrate: Add kerneldoc for the migrate subsystem (drm-backport-placeholder)
- commit 1c6e245
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove i915_utils dependency from xe_pcode. (drm-backport-placeholder)
- commit 52823b9
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Convert xe_mmio_wait32 to us so we can stop using (drm-backport-placeholder)
- commit f09fb64
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Let's avoid i915_utils in the xe_force_wake. (drm-backport-placeholder)
- commit ebbe98d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Stop using i915_utils in xe_wopcm. (drm-backport-placeholder)
- commit 3b61018
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Remove i915_utils dependency from xe_guc_pc. (drm-backport-placeholder)
- commit 075c569
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Wait for success on guc done. (drm-backport-placeholder)
- commit 3c4ea46
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Convert guc_ready to regular xe_mmio_wait32 (drm-backport-placeholder)
- commit fb50597
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Let's return last value read on xe_mmio_wait32. (drm-backport-placeholder)
- commit d9909fb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Stop using i915's range_overflows_t macro. (drm-backport-placeholder)
- commit 8fa1c33
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/xe: Implement a local xe_mmio_wait32 (drm-backport-placeholder)
- commit 95ebf07
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915/display: Remove dead code around (drm-backport-placeholder)
- commit d80ae87
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915/dmc: Print out the DMC mmio register list at fw load time (drm-backport-placeholder)
- commit 0919091
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915/dmc: Also disable HRR event on TGL/ADLS main DMC (drm-backport-placeholder)
- commit c17e507
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915/dmc: Also disable the flip queue event on TGL main DMC (drm-backport-placeholder)
- commit 2a47c60
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915: Simplify intel_ddi_compute_min_voltage_level() (drm-backport-placeholder)
- commit 082fc53
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915/mtl: Calculate the correct voltage level from port_clock (drm-backport-placeholder)
- commit 3d0983c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915: Split intel_ddi_compute_min_voltage_level() into platform (drm-backport-placeholder)
- commit 2dbae3b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915/mtl: Fix voltage_level for cdclk==480MHz (drm-backport-placeholder)
- commit 5e73447
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915/cdclk: Rewrite cdclk->voltage_level selection to use tables (drm-backport-placeholder)
- commit d0f2bda
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915/cdclk: Remove the assumption that cdclk divider==2 when (drm-backport-placeholder)
- commit 7563001
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915/cdclk: Give the squash waveform length a name (drm-backport-placeholder)
- commit 03822de
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915/cdclk: s/-1/~0/ when dealing with unsigned values (drm-backport-placeholder)
- commit 811d08d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915/display: Wait for PHY readiness not needed for disabling (drm-backport-placeholder)
- commit 2024098
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915/display: do not use cursor size reduction on MTL (drm-backport-placeholder)
- commit 1e042c2
* Thu Oct 10 2024 hare@suse.de
- nvme-multipath: suppress partition scan until the disk is ready
  (bsc#1228244).
- commit 5accc60
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915: Drop irqsave/restore for flip_done_handler() (drm-backport-placeholder)
- commit ce7ce73
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915: Stop accessing crtc->state from the flip done irq (drm-backport-placeholder)
- commit 43ae3a6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915/mtl: Rename the link_bit_rate to clock in C20 pll_state (drm-backport-placeholder)
- commit f9ff7b0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915/mtl: Remove misleading "clock" field from C20 pll_state (drm-backport-placeholder)
- commit e72939a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915/mtl: Use port clock compatible numbers for C20 phy (drm-backport-placeholder)
- commit acfc550
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915/tv: Drop redundant null checks (drm-backport-placeholder)
- commit c551a1c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915: s/cstate/crtc_state/ in intel_get_frame_time_us() (drm-backport-placeholder)
- commit 6a92df1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915: Drop redunant null check from intel_get_frame_time_us() (drm-backport-placeholder)
- commit e6dec60
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915: Drop NULL fb check from intel_fb_uses_dpt() (drm-backport-placeholder)
- commit 9356acc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915: Drop crtc NULL check from intel_crtc_active() (drm-backport-placeholder)
- commit 9c5a63b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915: Drop redundant NULL check (drm-backport-placeholder)
- commit 250feb1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/i915: Streamline intel_dsc_pps_read() (drm-backport-placeholder)
- commit 8cfb963
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/mediatek: Support MT8188 Padding in display driver (drm-backport-placeholder)
- commit ade5d73
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/mediatek: Refine device table of OVL adaptor (drm-backport-placeholder)
- commit 7981c22
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/mediatek: Sort OVL adaptor components (drm-backport-placeholder)
- commit cdac8bd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/mediatek: Start/Stop components with function pointers (drm-backport-placeholder)
- commit 1a7f23e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/mediatek: Power on/off devices with function pointers (drm-backport-placeholder).
- Delete patches.suse/drm-mediatek-Add-DRM_MODE_ROTATE_0-to-rotation-prope.patch.
- commit 404790f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/mediatek: Manage component's clock with function pointers (drm-backport-placeholder)
- commit 0eeb170
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/mediatek: Add component ID to component match structure (drm-backport-placeholder)
- commit 2d795b8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/mediatek: Rename OVL_ADAPTOR_TYPE_RDMA (drm-backport-placeholder)
- commit dc62be9
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/mediatek: Stop using iommu_present() (drm-backport-placeholder)
- commit 1fd93e4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/mediatek: Use devm_platform_ioremap_resource() (drm-backport-placeholder)
- commit 9ab910c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dp: call dp_display_get_next_bridge() during probe (drm-backport-placeholder)
- commit 9f1cdcd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: move CSC tables to dpu_hw_util.c (drm-backport-placeholder)
- commit b27e61c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: add cdm blocks to dpu snapshot (drm-backport-placeholder)
- commit 3c1cb38
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: introduce separate wb2_format arrays for rgb and yuv (drm-backport-placeholder)
- commit d4fefd8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: reserve cdm blocks for writeback in case of YUV output (drm-backport-placeholder)
- commit f1d3945
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: plug-in the cdm related bits to writeback setup (drm-backport-placeholder)
- commit 2cae83c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: add an API to setup the CDM block for writeback (drm-backport-placeholder).
- Refresh patches.suse/drm-msm-dpu-Add-mutex-lock-in-control-vblank-irq.patch.
- commit ac8335a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: add CDM related logic to dpu_hw_ctl layer (drm-backport-placeholder).
- Delete patches.suse/drm-msm-dpu-Allow-configuring-multiple-active-DSC-bl.patch.
- commit 383bb25
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: add support to allocate CDM from RM (drm-backport-placeholder)
- commit d26c0f1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: add cdm blocks to RM (drm-backport-placeholder)
- commit a77ae8c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: add dpu_hw_cdm abstraction for CDM block (drm-backport-placeholder)
- commit e3b5bba
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: add cdm blocks to sm8250 dpu_hw_catalog (drm-backport-placeholder)
- commit bc3129d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: add cdm blocks to sc7280 dpu_hw_catalog (drm-backport-placeholder)
- commit 4b23cd8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: move csc matrices to dpu_hw_util (drm-backport-placeholder)
- commit cb87505
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: fix writeback programming for YUV cases (drm-backport-placeholder)
- commit 48f8582
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: add formats check for writeback encoder (drm-backport-placeholder)
- commit 5cdd0ad
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: remove extra drm_encoder_cleanup from the error path (drm-backport-placeholder)
- commit 5f324f8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: move encoder status to standard encoder debugfs dir (drm-backport-placeholder)
- commit 8bf3dd8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/ci: remove rebase-merge directory (drm-backport-placeholder)
- commit 4266b88
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/gem: Convert to drm_exec (drm-backport-placeholder)
- commit 49f2ca0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/exec: Pass in initial # of objects (drm-backport-placeholder)
- commit 3c49519
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/gem: Cleanup submit_cleanup_bo() (drm-backport-placeholder)
- commit 81bc232
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/gem: Split out submit_unpin_objects() helper (drm-backport-placeholder)
- commit aaf6428
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/gem: Don't queue job to sched in error cases (drm-backport-placeholder)
- commit b49d964
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/gem: Remove submit_unlock_unpin_bo() (drm-backport-placeholder)
- commit 719d9db
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/gem: Remove "valid" tracking (drm-backport-placeholder)
- commit 1338ef5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm: Add param for the highest bank bit (drm-backport-placeholder)
- commit cb9d2a5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm: Refactor UBWC config setting (drm-backport-placeholder)
- commit 2bd5e9c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dp: Fix platform_get_irq() check (drm-backport-placeholder)
- commit 2dc104a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: use drmm-managed allocation for dpu_encoder_virt (drm-backport-placeholder).
- Refresh patches.suse/drm-msm-dpu-split-dpu_encoder_wait_for_event-into-tw.patch.
- commit 91fa9fb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: drop dpu_encoder_phys_ops::destroy (drm-backport-placeholder)
- commit 98a73bd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: use drmm-managed allocation for dpu_crtc (drm-backport-placeholder)
- commit bb08cce
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: use drmm-managed allocation for dpu_plane (drm-backport-placeholder)
- commit fc11e37
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: remove QoS teardown on plane destruction (drm-backport-placeholder)
- commit e3ab2da
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: drop unused dpu_plane::lock (drm-backport-placeholder)
- commit 3c43030
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: use devres-managed allocation for HW blocks (drm-backport-placeholder).
- Refresh patches.suse/drm-msm-dpu-finalise-global-state-object.patch.
- commit 50ffd22
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: use devres-managed allocation for VBIF data (drm-backport-placeholder)
- commit 233d720
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: use devres-managed allocation for interrupts data (drm-backport-placeholder)
- commit 6cb9f91
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: remove IS_ERR_OR_NULL for dpu_hw_intr_init() error (drm-backport-placeholder)
- commit f950310
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: cleanup dpu_kms_hw_init error path (drm-backport-placeholder)
- commit cf9a827
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/mdss: Handle the reg bus ICC path (drm-backport-placeholder)
- commit 72e5605
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/mdss: inline msm_mdss_icc_request_bw() (drm-backport-placeholder)
- commit 997e58b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm: dsi: add support for DSI 2.8.0 (drm-backport-placeholder)
- commit 3ade82b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm: dsi: add support for DSI-PHY on SM8650 (drm-backport-placeholder)
- commit 77d89f2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm: mdss: add support for SM8650 (drm-backport-placeholder)
- commit 0df8c81
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: add support for SM8650 DPU (drm-backport-placeholder)
- commit 838a466
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: Add hw revision 4.1 (SDM670) (drm-backport-placeholder)
- commit 8b971ac
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm: mdss: add support for SDM670 (drm-backport-placeholder)
- commit f334876
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/gpu: drop duplicating VIG feature masks (drm-backport-placeholder)
- commit 04c063a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: merge DPU_SSPP_SCALER_QSEED3, QSEED3LITE, QSEED4 (drm-backport-placeholder)
- commit f8dd884
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: rewrite scaler and CSC presense checks (drm-backport-placeholder)
- commit 01f3b47
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: drop DPU_HW_SUBBLK_INFO macro (drm-backport-placeholder)
- commit e06b247
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: deduplicate some (most) of SSPP sub-blocks (drm-backport-placeholder)
- commit 68040b2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: drop the `smart_dma_priority' field from struct (drm-backport-placeholder)
- commit 098677a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: drop the `id' field from DPU_HW_SUBBLK_INFO (drm-backport-placeholder)
- commit 064b0a9
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: Drop unused qseed_type from catalog dpu_caps (drm-backport-placeholder)
- commit 965f196
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: Drop unused get_scaler_ver callback from SSPP (drm-backport-placeholder)
- commit 66c41dc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dp: add a missing unlock in dp_hpd_plug_handle() (drm-backport-placeholder)
- commit 6fd775a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: Capture dpu snapshot when frame_done_timer timeouts (drm-backport-placeholder).
- Refresh patches.suse/drm-msm-dpu-Ratelimit-framedone-timeout-msgs.patch.
- commit 3416770
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dp: move of_dp_aux_populate_bus() to eDP probe() (drm-backport-placeholder)
- commit 6415aba
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dp: delete EV_HPD_INIT_SETUP (drm-backport-placeholder)
- commit 4ffaa2b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dp: incorporate pm_runtime framework into DP driver (drm-backport-placeholder).
- Refresh patches.suse/drm-msm-dp-Avoid-a-long-timeout-for-AUX-transfer-if-.patch.
- commit b28c4e8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dp: move parser->parse() and dp_power_client_init() to probe (drm-backport-placeholder)
- commit 903b88e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dp: use drm_bridge_hpd_notify() to report HPD status changes (drm-backport-placeholder)
- commit 5f6a549
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dp: rename is_connected with link_ready (drm-backport-placeholder)
- commit 7921ed8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dp: tie dp_display_irq_handler() with dp driver (drm-backport-placeholder)
- commit 2111b43
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/mdp4: use drmm-managed allocation for mdp4_lcdc_encoder (drm-backport-placeholder)
- commit 96e1908
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/mdp4: use drmm-managed allocation for mdp4_dtv_encoder (drm-backport-placeholder)
- commit 493e413
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/mdp4: use drmm-managed allocation for mdp4_dsi_encoder (drm-backport-placeholder)
- commit 511bcb2
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/mdp4: use drmm-managed allocation for mdp4_crtc (drm-backport-placeholder)
- commit 54ff4e8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/mdp4: use bulk regulators API for LCDC encoder (drm-backport-placeholder)
- commit 17b3ac1
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/mdp5: use drmm-managed allocation for mdp5_encoder (drm-backport-placeholder)
- commit a9ec848
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/mdp5: use drmm-managed allocation for mdp5_crtc (drm-backport-placeholder)
- commit a2027d7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/mdp5: use devres-managed allocation for INTF data (drm-backport-placeholder)
- commit c1db945
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/mdp5: use devres-managed allocation for SMP data (drm-backport-placeholder)
- commit 20d3544
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/mdp5: use devres-managed allocation for pipe data (drm-backport-placeholder)
- commit 4aff805
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/mdp5: use devres-managed allocation for mixer data (drm-backport-placeholder)
- commit 85e5f6f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/mdp5: use devres-managed allocation for CTL manager data (drm-backport-placeholder)
- commit c1f54d7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/mdp5: use devres-managed allocation for configuration data (drm-backport-placeholder)
- commit e5bbd71
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dp: cleanup debugfs handling (drm-backport-placeholder)
- commit 931a55c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/dpu: enable smartdma on sm8350 (drm-backport-placeholder)
- commit 3446261
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/a6xx: Add missing BIT(7) to REG_A6XX_UCHE_CLIENT_PF (drm-backport-placeholder)
- commit 1ef5124
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/gem: Demote allocations to __GFP_NOWARN (drm-backport-placeholder)
- commit 2ab455e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/gem: Demote userspace errors to DRM_UT_DRIVER (drm-backport-placeholder)
- commit 392a526
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/gem: Add metadata (drm-backport-placeholder)
- commit 6e14d2c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm: Small uabi fixes (drm-backport-placeholder)
- commit c8f3846
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm: don't create GPU-related debugfs files with no GPU present (drm-backport-placeholder)
- commit 6988f3e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/gpu: Skip retired submits in recover worker (drm-backport-placeholder)
- commit 5378ee8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/msm/gpu: Move gpu devcore's to gpu device (drm-backport-placeholder)
- commit a060ac3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Revert " drm/amd/display: Use channel_width = 2 for (drm-backport-placeholder)
- commit 49a2640
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: remove HPO PG in driver side (drm-backport-placeholder)
- commit c68f942
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/swsmu: remove duplicate definition of smu v14_0_0 driver if (drm-backport-placeholder)
- commit 5078bf5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amdgpu: make an improvement on amdgpu_hmm_range_get_pages (drm-backport-placeholder)
- commit 82909c4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amdgpu: increase hmm range get pages timeout (drm-backport-placeholder)
- commit 1031ecf
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: fix documentation for (drm-backport-placeholder)
- commit c5c2391
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: fix documentation for amdgpu_dm_verify_lut3d_size() (drm-backport-placeholder)
- commit 4dd11c0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/pm: Remove unneeded semicolon (drm-backport-placeholder)
- commit 999b773
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Add 3x4 CTM support for plane CTM (drm-backport-placeholder)
- commit a622281
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: add plane CTM support (drm-backport-placeholder)
- commit 6539bcb
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/pm: add power save mode workload for smu 13.0.10 (drm-backport-placeholder)
- commit ec2dc2e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amdgpu/vpe: enable vpe dpm (drm-backport-placeholder)
- commit f379af3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: add plane CTM driver-specific property (drm-backport-placeholder)
- commit 189fb06
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: copy 3D LUT settings from crtc state to (drm-backport-placeholder)
- commit ece68da
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/pm: support return vpe clock table (drm-backport-placeholder)
- commit 6cbe172
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: allow newer DC hardware to use degamma ROM for (drm-backport-placeholder)
- commit d2fbcd3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: add plane blend LUT and TF support (drm-backport-placeholder)
- commit a921d25
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: handle empty LUTs in __set_input_tf (drm-backport-placeholder)
- commit b351133
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: add plane 3D LUT support (drm-backport-placeholder)
- commit 31e4463
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/radeon: Prevent multiple debug error lines on suspend (drm-backport-placeholder)
- commit eee1dd8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: add plane shaper TF support (drm-backport-placeholder)
- commit 8cd8e78
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: add plane shaper LUT support (drm-backport-placeholder)
- commit 11b152d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: add HDR multiplier support (drm-backport-placeholder)
- commit 6c8d54b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: add dc_fixpt_from_s3132 helper (drm-backport-placeholder)
- commit 57fd3c0
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: reject atomic commit if setting both plane and CRTC (drm-backport-placeholder)
- commit 2fb5ef3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: add plane degamma TF and LUT support (drm-backport-placeholder)
- commit f6e8afd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: decouple steps for mapping CRTC degamma to DC plane (drm-backport-placeholder)
- commit 5011288
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: mark plane as needing reset if color props change (drm-backport-placeholder)
- commit c2104c3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: set sdr_ref_white_level to 80 for out_transfer_func (drm-backport-placeholder)
- commit 808ecac
* Thu Oct 10 2024 tiwai@suse.de
- watchdog/hpwdt: Support Suspend and Resume (jsc#PED-10967).
- commit 93f04b4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd: include drm/drm_edid.h only where needed (drm-backport-placeholder).
- Refresh patches.suse/drm-amdgpu-avoid-using-null-object-of-framebuffer.patch.
- commit fd95db9
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: add CRTC gamma TF support (drm-backport-placeholder)
- commit 3841e7e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: encapsulate atomic regamma operation (drm-backport-placeholder)
- commit 336c403
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: add comments to describe DM crtc color mgmt behavior (drm-backport-placeholder)
- commit dd79569
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: add CRTC gamma TF driver-specific property (drm-backport-placeholder)
- commit 053356c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: add plane blend LUT and TF driver-specific (drm-backport-placeholder)
- commit c4bb563
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: add plane shaper LUT and TF driver-specific (drm-backport-placeholder)
- commit b75516c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amdgpu: Switch to aca bank for xgmi pcs err cnt (drm-backport-placeholder)
- commit e3a6932
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: add plane 3D LUT driver-specific properties (drm-backport-placeholder)
- commit ce16656
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/radeon: include drm/drm_edid.h only where needed (drm-backport-placeholder)
- commit 0df453e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/pm: enable Wifi RFI mitigation feature support for SMU13.0.7 (drm-backport-placeholder).
- Refresh patches.suse/drm-amd-pm-update-the-power-cap-setting.patch.
- commit da46551
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/pm: enable Wifi RFI mitigation feature support for SMU13.0.0 (drm-backport-placeholder).
- Refresh patches.suse/drm-amd-pm-update-the-power-cap-setting.patch.
- commit 49d70d4
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/pm: add flood detection for wbrf events (drm-backport-placeholder)
- commit 02763cd
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/pm: setup the framework to support Wifi RFI mitigation feature (drm-backport-placeholder).
- Refresh patches.suse/drm-amdgpu-make-damage-clips-support-configurable.patch.
- commit 3eb71bc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/pm: update driver_if and ppsmc headers for coming wbrf (drm-backport-placeholder)
- commit de853ed
* Thu Oct 10 2024 pjakobsson@suse.de
- Documentation/driver-api: Add document about WBRF mechanism (drm-backport-placeholder).
- Refresh patches.suse/crypto-iaa-Add-IAA-Compression-Accelerator-Documenta.patch.
- commit c3f9e91
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amdkfd: Import DMABufs for interop through DRM (drm-backport-placeholder)
- commit 65b11e7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amdkfd: Export DMABufs from KFD using GEM handles (drm-backport-placeholder)
- commit 976d7d3
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amdgpu: xgmi_fill_topology_info (drm-backport-placeholder)
- commit 6e7825c
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Fix memory leak in dm_set_writeback() (drm-backport-placeholder)
- commit c11165e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: add plane HDR multiplier driver-specific property (drm-backport-placeholder)
- commit 2fd6ae8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: document AMDGPU pre-defined transfer functions (drm-backport-placeholder)
- commit b562091
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: explicitly define EOTF and inverse EOTF (drm-backport-placeholder)
- commit 33aef62
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: add plane degamma TF driver-specific property (drm-backport-placeholder)
- commit e42a697
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.264 (drm-backport-placeholder)
- commit 4c09a4e
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: fix HW block PG sequence (drm-backport-placeholder)
- commit a3955dc
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Exit from idle state before accessing HW data (drm-backport-placeholder)
- commit 074516b
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Disable OPTC pg to match DC Hubp/dpp pg (drm-backport-placeholder)
- commit a64965a
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Revert DP2 MST hub triple display fix (drm-backport-placeholder)
- commit c863258
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: trivial comment change (drm-backport-placeholder)
- commit c6566ad
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Revert "Fix conversions between bytes and KB" (drm-backport-placeholder)
- commit 4bd997d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: allow DP40 cables to do UHBR13.5 (drm-backport-placeholder)
- commit 7a8dc98
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Use explicit size for types in DCCG's struct (drm-backport-placeholder)
- commit 255f1be
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Remove minor revision 5 until proper parser is ready (drm-backport-placeholder)
- commit 3cba227
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/pm: Remove redundant function members of pptable_funcs (drm-backport-placeholder)
- commit e69d09d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amdgpu: Use the right method to get IP version (drm-backport-placeholder)
- commit 592bf02
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: add driver-specific property for plane degamma LUT (drm-backport-placeholder)
- commit 69c9c25
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/drm_plane: track color mgmt changes per plane (drm-backport-placeholder).
- Delete patches.suse/drm-Add-kabi-placeholders-to-commonly-used-structs.patch.
- commit 5c7be01
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/drm_property: make replace_property_blob_from_id a DRM helper (drm-backport-placeholder)
- commit 5d61ed9
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/drm_mode_object: increase max objects to accommodate new color props (drm-backport-placeholder).
- Refresh patches.suse/drm-Add-kabi-placeholders-to-commonly-used-structs.patch.
- commit 7cce4c7
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/amd/display: Fix spelling mistake "SMC_MSG_AllowZstatesEntr" -> (drm-backport-placeholder)
- commit fe01096
* Thu Oct 10 2024 pjakobsson@suse.de
- drm: ci: Update xfails (drm-backport-placeholder)
- commit 5f58ec8
* Thu Oct 10 2024 pjakobsson@suse.de
- drm/doc: ci: Add IGT version details for flaky tests (drm-backport-placeholder)
- commit f0fe9c5
* Thu Oct 10 2024 pjakobsson@suse.de
- drm: ci: uprev IGT (drm-backport-placeholder)
- commit 0aa6b94
* Thu Oct 10 2024 pjakobsson@suse.de
- drm: ci: virtio: Make artifacts available (drm-backport-placeholder)
- commit 812401f
* Thu Oct 10 2024 pjakobsson@suse.de
- drm: ci: mt8173: Do not set IGT_FORCE_DRIVER to panfrost (drm-backport-placeholder)
- commit 94c6a10
* Thu Oct 10 2024 pjakobsson@suse.de
- drm: ci: Use scripts/config to enable/disable configs (drm-backport-placeholder)
- commit c872c3d
* Thu Oct 10 2024 pjakobsson@suse.de
- drm: ci: Enable new jobs (drm-backport-placeholder)
- commit 0b43be6
* Thu Oct 10 2024 pjakobsson@suse.de
- drm: ci: arm64.config: Enable DA9211 regulator (drm-backport-placeholder)
- commit feafe1e
* Wed Oct  9 2024 krisman@suse.de
- fix bitmap corruption on close_range() with CLOSE_RANGE_UNSHARE
  (CVE-2024-45025 bsc#1230456).
- commit c3824ef
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: ci: Force db410c to host mode (drm-backport-placeholder).
- Refresh patches.suse/drm-ci-use-clk_ignore_unused-for-apq8016.patch.
- commit f2caada
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: ci: igt_runner: Remove todo (drm-backport-placeholder)
- commit 7985a42
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: vm: Fix heap lookup condition (drm-backport-placeholder)
- commit 7b4a983
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/vc4: hdmi: Create destroy state implementation (drm-backport-placeholder)
- commit c2d66d4
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel: ilitek-ili9805: adjust the includes (drm-backport-placeholder)
- commit 56bdafe
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel: synaptics-r63353: adjust the includes (drm-backport-placeholder)
- commit ca8083e
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/uapi: drm_mode.h: fix spellos and grammar (drm-backport-placeholder)
- commit af56a6d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/drm_modeset_helper_vtables.h: fix typos/spellos (drm-backport-placeholder)
- commit 9bc1b89
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/fourcc: fix spelling/typos (drm-backport-placeholder)
- commit 554cf5d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/rockchip: vop2: rename VOP_FEATURE_OUTPUT_10BIT to (drm-backport-placeholder)
- commit 9582a84
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/rockchip: vop2: Add support for rk3588 (drm-backport-placeholder)
- commit 8640997
* Wed Oct  9 2024 pjakobsson@suse.de
- dt-bindings: rockchip,vop2: Add more endpoint definition (drm-backport-placeholder)
- commit 902848b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/rockchip: vop2: rename grf to sys_grf (drm-backport-placeholder)
- commit 4448681
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/rockchip: vop2: set bg dly and prescan dly at vop2_post_config (drm-backport-placeholder)
- commit 31d8186
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/rockchip: vop2: Set YUV/RGB overlay mode (drm-backport-placeholder)
- commit 9194274
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/rockchip: vop2: Add write mask for VP config done (drm-backport-placeholder)
- commit ba93ef9
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/rockchip: vop2: set half_block_en bit in all mode (drm-backport-placeholder)
- commit 0beadb5
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/rockchip: move output interface related definition to (drm-backport-placeholder)
- commit 24dfd69
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/bridge: ti-sn65dsi86: Associate PWM device to auxiliary device (drm-backport-placeholder)
- commit deb846f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel: simple: Add AUO G156HAN04.0 LVDS display support (drm-backport-placeholder)
- commit a9e4655
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel: ilitek-ili9805: add support for Tianma TM041XDHG01 panel (drm-backport-placeholder)
- commit 3dc7104
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel: st7701: Add Anbernic RG-ARC Panel Support (drm-backport-placeholder)
- commit 4dec42c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel: nv3052c: Add Fascontek FS035VG158 LCD display (drm-backport-placeholder)
- commit a9fee33
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel: nv3052c: Allow specifying registers per panel (drm-backport-placeholder)
- commit 83a6c34
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel: nv3052c: Add SPI device IDs (drm-backport-placeholder)
- commit d22f271
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel: nv3052c: Document known register names (drm-backport-placeholder)
- commit 668c15b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Move dereference after NULL check in (drm-backport-placeholder)
- commit 4b1d1e2
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Remove unneeded semicolon (drm-backport-placeholder)
- commit c78202b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/vkms: move wb's atomic_check from encoder to connector (drm-backport-placeholder)
- commit b42e34f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/atomic-helper: rename drm_atomic_helper_check_wb_encoder_state (drm-backport-placeholder)
- commit d11764d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/edp-panel: Move the KDC panel to a separate group (drm-backport-placeholder)
- commit 110ae94
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/bridge: aux-hpd: Replace of_device.h with explicit include (drm-backport-placeholder)
- commit d5b9eca
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/doc/rfc: Xe is using drm_exec, so mark as completed (drm-backport-placeholder)
- commit a35676d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/doc/rfc: Move userptr integration and vm_bind to the 'completed' (drm-backport-placeholder)
- commit 6017fc4
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/doc/rfc: Move Xe 'ASYNC VM_BIND' to the 'completed' section (drm-backport-placeholder)
- commit c6a7581
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/doc/rfc: Mark drm_scheduler as completed (drm-backport-placeholder)
- commit 9ece45c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/doc/rfc: Mark long running workload as complete. (drm-backport-placeholder)
- commit 481a260
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/debugfs: fix potential NULL pointer dereference (drm-backport-placeholder)
- commit d84ebab
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/bridge: Return NULL instead of plain 0 in (drm-backport-placeholder)
- commit 2739374
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: Enable event log on MES 11 (drm-backport-placeholder)
- commit ff6b9cd
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: SW part of MES event log enablement (drm-backport-placeholder)
- commit c24304d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Restore guard against default backlight value < 1 (drm-backport-placeholder)
- commit b63fc84
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/amdgpu: SRIOV full reset issue with VCN (drm-backport-placeholder)
- commit dd24c83
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/amdgpu: Add SMUIO headers for 10.0.2 (drm-backport-placeholder)
- commit 5388581
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd: Add a DC debug mask for DML2 (drm-backport-placeholder).
- commit 1bb5784
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: Read aquavanjaram USR register state (drm-backport-placeholder)
- commit 5736b97
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: Read aquavanjaram WAFL register state (drm-backport-placeholder)
- commit d6c5071
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.263 (drm-backport-placeholder)
- commit 2b918f1
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Update code comment to be more accurate (drm-backport-placeholder)
- commit 5140a36
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Adjust code style (drm-backport-placeholder)
- commit d6dd512
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Disable DWB frame capture to emulate oneshot (drm-backport-placeholder)
- commit 22af8d2
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Add new set_fc_enable to struct dwbc_funcs (drm-backport-placeholder)
- commit 0f32ed2
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Setup for mmhubbub3_warmup_mcif with big buffer (drm-backport-placeholder)
- commit 29e623f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Add writeback enable field (wb_enabled) (drm-backport-placeholder)
- commit ef33c6c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Fix writeback_info is not removed (drm-backport-placeholder)
- commit b90f211
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Validate hw_points_num before using it (drm-backport-placeholder)
- commit 509872d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Fix writeback_info never got updated (drm-backport-placeholder)
- commit 5887e19
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Add writeback enable/disable in dc (drm-backport-placeholder)
- commit e986333
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Hande writeback request from userspace (drm-backport-placeholder)
- commit c98fe32
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Create fake sink and stream for writeback connector (drm-backport-placeholder)
- commit 9a9993c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Create amdgpu_dm_wb_connector (drm-backport-placeholder)
- commit 69908a1
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Skip writeback connector when we get (drm-backport-placeholder)
- commit 515d8b0
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Initialize writeback connector (drm-backport-placeholder)
- commit 0141260
* Wed Oct  9 2024 oneukum@suse.com
- i2c: core: Setup i2c_adapter runtime-pm before calling
  device_add() (git-fixes).
- commit 5095dfb
* Wed Oct  9 2024 oneukum@suse.com
- i2c: ismt: kill transaction in hardware on timeout (git-fixes).
- commit f6029bb
* Wed Oct  9 2024 vkarasulli@suse.de
- iommufd: Check the domain owner of the parent before creating
  a nesting domain (git-fixes).
- commit 3ff7340
* Wed Oct  9 2024 vkarasulli@suse.de
- iommufd: Protect against overflow of ALIGN() during iova
  allocation (git-fixes).
- commit fffeb67
* Wed Oct  9 2024 vkarasulli@suse.de
- iommu/amd: Do not set the D bit on AMD v2 table entries
  (git-fixes).
- commit e3053a9
* Wed Oct  9 2024 oneukum@suse.com
- i2c: omap: wakeup the controller during suspend() callback
  (git-fixes).
- commit 52f3dad
* Wed Oct  9 2024 oneukum@suse.com
- i2c: omap: switch to NOIRQ_SYSTEM_SLEEP_PM_OPS() and
  RUNTIME_PM_OPS() (git-fixes).
- commit 3fe2f94
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Skip entire amdgpu_dm build if !CONFIG_DRM_AMD_DC (drm-backport-placeholder)
- commit 107d418
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Avoid virtual stream encoder if not explicitly (drm-backport-placeholder)
- commit 7ebb9a7
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: add MPC MCM 1D LUT clock gating programming (drm-backport-placeholder)
- commit 8a523e8
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: keep domain24 power on if eDP not exist (drm-backport-placeholder)
- commit 8c932c2
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Added delay to DPM log (drm-backport-placeholder)
- commit dd04bfb
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Pass debug watermarks through to DCN35 DML2 (drm-backport-placeholder)
- commit 0ed5bbe
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: revert removing otg toggle w/a back when no active (drm-backport-placeholder)
- commit 974d3d0
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Update BIOS FW info table revision (drm-backport-placeholder)
- commit 0b32d24
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Skip DPIA-specific DP LL automation flag for (drm-backport-placeholder)
- commit 5af4abe
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Fix null pointer (drm-backport-placeholder)
- commit c833d99
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Use channel_width = 2 for vram table 3.0 (drm-backport-placeholder)
- commit 355c0a8
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: insert drv-pmfw log + rollback to new context (drm-backport-placeholder)
- commit ab0736b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Increase scratch buffer size (drm-backport-placeholder)
- commit 166d61f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Change dither policy for 10bpc to round (drm-backport-placeholder)
- commit 77dc84b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Add missing dcn35 RCO registers (drm-backport-placeholder)
- commit d46d99c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdkfd: Use partial migrations/mapping for GPU/CPU page faults in SVM (drm-backport-placeholder).
- Refresh patches.suse/drm-amdkfd-Add-VRAM-accounting-for-SVM-migration.patch.
- commit d1c9ad8
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Only enumerate top local sink as DP2 output (drm-backport-placeholder)
- commit 03db7a3
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Add ODM check during pipe split/merge validation (drm-backport-placeholder).
- Refresh patches.suse/drm-amd-display-Override-min-required-DCFCLK-in-dml1.patch.
- commit c214767
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: initialize all the dpm level's stutter latency (drm-backport-placeholder).
- Refresh patches.suse/drm-amd-display-fix-input-states-translation-error-f.patch.
- commit 0a55c8e
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Optimize fast validation cases (drm-backport-placeholder)
- commit 0f3b5b4
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/amdgpu: Move vcn4 fw_shared init to a single function (drm-backport-placeholder)
- commit 27060dc
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/guc: Create the guc_to_i915() wrapper (drm-backport-placeholder)
- commit 630de62
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/selftests: wait for active idle event in (drm-backport-placeholder)
- commit 9b3612b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/guc: Add a selftest for FAST_REQUEST errors (drm-backport-placeholder)
- commit 4ae5cc7
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/guc: Fix for potential false positives in GuC hang selftest (drm-backport-placeholder)
- commit 9192b37
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Skip pxp init if gt is wedged (drm-backport-placeholder)
- commit 95fafb2
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/pxp: Add drm_dbgs for critical PXP events. (drm-backport-placeholder)
- commit 1a7147b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dg2: Drop Wa_22014600077 (drm-backport-placeholder)
- commit 857f541
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: ATS-M device ID update (drm-backport-placeholder)
- commit 7743199
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Replace custom intel runtime_pm tracker with ref_tracker (drm-backport-placeholder)
- commit 798d204
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Add __rcu annotation to cursor when iterating client (drm-backport-placeholder)
- commit 3a353d6
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Remove return type from i915_drm_client_remove_object (drm-backport-placeholder)
- commit 895cd50
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/mtl: Update Wa_22018931422 (drm-backport-placeholder)
- commit dced297
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dg2: Wa_18028616096 now applies to all DG2 (drm-backport-placeholder)
- commit 643a7d4
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/huc: Stop printing about unsupported HuC on MTL (drm-backport-placeholder)
- commit 0de66a8
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/gt: add missing new-line to GT_TRACE (drm-backport-placeholder)
- commit 392a7db
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Read a shadowed mmio register for ggtt flush (drm-backport-placeholder)
- commit 1c880c3
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Implement fdinfo memory stats printing (drm-backport-placeholder)
- commit b70c3f4
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Add stable memory region names (drm-backport-placeholder)
- commit d9bb7b2
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Account ring buffer and context state storage (drm-backport-placeholder)
- commit 8f36167
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Track page table backing store usage (drm-backport-placeholder)
- commit 6494d66
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Record which client owns a VM (drm-backport-placeholder)
- commit 7302b04
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Add ability for tracking buffer objects per client (drm-backport-placeholder)
- commit 76138d9
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: i915: Adapt to -Walloc-size (drm-backport-placeholder)
- commit 28c25a7
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/xelpmp: Add Wa_16021867713 (drm-backport-placeholder)
- commit 2916e5a
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/gt: Temporarily disable CPU caching into DMA for MTL (drm-backport-placeholder)
- commit 63ad729
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/gt: Remove prohibited space after opening parenthesis (drm-backport-placeholder)
- commit eb6b4cb
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: move gpu error sysfs to i915_gpu_error.c (drm-backport-placeholder)
- commit e938cca
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: move gpu error debugfs to i915_gpu_error.c (drm-backport-placeholder)
- commit d411ced
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: make some error capture functions static (drm-backport-placeholder)
- commit d3732d1
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/mtl: Add Wa_14019821291 (drm-backport-placeholder)
- commit 91179c2
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Set copy engine arbitration for Wa_16018031267 / (drm-backport-placeholder)
- commit 0c4e9b2
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/gt: add selftest to exercise WABB (drm-backport-placeholder)
- commit df81b00
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Add WABB blit for Wa_16018031267 / Wa_16018063123 (drm-backport-placeholder)
- commit b963e45
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Reserve some kernel space per vm (drm-backport-placeholder)
- commit f5766ad
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/mtl: Add Wa_22016670082 (drm-backport-placeholder)
- commit 3b0fabd
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/pmu: rearrange hrtimer pointer chasing (drm-backport-placeholder)
- commit 1dbdf37
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/pmu: add event_to_pmu() helper (drm-backport-placeholder)
- commit 08405f6
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/pmu: add pmu_to_i915() helper (drm-backport-placeholder)
- commit 0e18a0c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/gt: Remove unncessary {} from if-else (drm-backport-placeholder)
- commit d543559
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/gt: Remove {} from if-else (drm-backport-placeholder)
- commit 4c5dff9
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/gt: Use proper priority enum instead of 0 (drm-backport-placeholder)
- commit f391df8
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/exynos: dpi: Change connector type to DPI (drm-backport-placeholder)
- commit 51217cb
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/exynos: Convert to platform remove callback returning void (drm-backport-placeholder).
- Refresh patches.suse/drm-exynos-dp-drop-driver-owner-initialization.patch.
- commit e8d472a
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: move update_logtype() into ifdef section (drm-backport-placeholder)
- commit 6f6292f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Removed unused functions in pvr_fw_trace (drm-backport-placeholder)
- commit f41f31e
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/xlnx: Do not include <drm/drm_plane_helper.h> (drm-backport-placeholder)
- commit 94c7fbe
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/simpledrm: Do not include <drm/drm_plane_helper.h> (drm-backport-placeholder)
- commit 0a4be02
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/ofdrm: Do not include <drm/drm_plane_helper.h> (drm-backport-placeholder)
- commit e9d1201
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/solomon: Do not include <drm/drm_plane_helper.h> (drm-backport-placeholder)
- commit 160d2a0
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/shmobile: Do not include <drm/drm_plane_helper.h> (drm-backport-placeholder)
- commit 1b8d464
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/loongson: Do not include <drm/drm_plane_helper.h> (drm-backport-placeholder)
- commit 5f04e00
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: Do not include <drm/drm_plane_helper.h> (drm-backport-placeholder)
- commit cb693a2
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/plane-helper: Move drm_plane_helper_atomic_check() into udl (drm-backport-placeholder)
- commit 9c165bc
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: Remove source code for non-KMS drivers (drm-backport-placeholder).
- Refresh patches.suse/drm-Add-kabi-placeholders-to-commonly-used-structs.patch.
- commit 09183cf
* Wed Oct  9 2024 tiwai@suse.de
- Drop the previous HD-audio TAS2781 fix (bsc#1230132)
  The proposed fix turned out to be incorrect
- commit b3a4c29
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: Remove locking for legacy ioctls and DRM_UNLOCKED (drm-backport-placeholder)
- commit 4fc2b51
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: Remove support for legacy drivers (drm-backport-placeholder)
- commit 891f757
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: Remove the legacy DRM_IOCTL_MODESET_CTL ioctl (drm-backport-placeholder)
- commit c31a9e9
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: Remove entry points for legacy ioctls (drm-backport-placeholder)
- commit f16dc19
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/radeon: Do not include <drm/drm_legacy.h> (drm-backport-placeholder)
- commit 804a3c0
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: Include <drm/drm_device.h> (drm-backport-placeholder)
- commit 0457c5f
* Wed Oct  9 2024 pjakobsson@suse.de
- accel: Include <drm/drm_auth.h> (drm-backport-placeholder)
- commit 9ff2413
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Include <drm/drm_auth.h> (drm-backport-placeholder)
- commit 49fc36a
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: Include <drm/drm_auth.h> (drm-backport-placeholder)
- commit 5eece35
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/edp-panel: Sort the panel entries (drm-backport-placeholder)
- commit 101fd87
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel-edp: Add SDC ATNA45AF01 (drm-backport-placeholder)
- commit ec31427
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/atomic: add private obj state to state dump (drm-backport-placeholder)
- commit d27aa3e
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/gpuvm: Let drm_gpuvm_bo_put() report when the vm_bo object is (drm-backport-placeholder)
- commit f7ea47b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panfrost: Synchronize and disable interrupts before powering off (drm-backport-placeholder)
- commit aae0fde
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panfrost: Add gpu_irq, mmu_irq to struct panfrost_device (drm-backport-placeholder)
- commit b248a51
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel-simple: add Evervision VGG644804 panel entry (drm-backport-placeholder)
- commit 469048d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel: ilitek-ili9881c: Add Ampire AM8001280G LCD panel (drm-backport-placeholder)
- commit ed35291
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel: ilitek-ili9881c: make use of prepare_prev_first (drm-backport-placeholder)
- commit e5ffbe1
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel: himax-hx8394: Add Support for Powkiddy X55 panel (drm-backport-placeholder)
- commit 6f5c783
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel: himax-hx8394: Add Panel Rotation Support (drm-backport-placeholder)
- commit 6bc6789
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel: himax-hx8394: Drop shutdown logic (drm-backport-placeholder)
- commit 59f7c7f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel: himax-hx8394: Drop prepare/unprepare tracking (drm-backport-placeholder)
- commit 8031374
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel: simple: Add BOE BP101WX1-100 panel (drm-backport-placeholder)
- commit 0d869ac
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: vm: make use of GPUVM's drm_exec helper (drm-backport-placeholder)
- commit 896d4b1
* Wed Oct  9 2024 rgoldwyn@suse.com
- Update config files: Enable NFSD_V2 (bsc#1230914)
  NFSv2 was disabled because of the upstream kernel commit 2f3a4b2ac2f2
  ("nfsd: allow disabling NFSv2 at compile time").
  Enable it for the few users who cannot upgrade to NFSv3.
  https://bugzilla.suse.com/show_bug.cgi?id=1230914#c5
- commit 9e3254d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/gpuvm: fall back to drm_exec_lock_obj() (drm-backport-placeholder)
- commit 86092f2
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: Fix missing error code in v3d_submit_cpu_ioctl() (drm-backport-placeholder)
- commit c9b0023
* Wed Oct  9 2024 pjakobsson@suse.de
- Revert "drm: Introduce pixel_source DRM plane property" (drm-backport-placeholder)
- commit cb27d69
* Wed Oct  9 2024 pjakobsson@suse.de
- Revert "drm: Introduce solid fill DRM plane property" (drm-backport-placeholder)
- commit 8fc6031
* Wed Oct  9 2024 pjakobsson@suse.de
- Revert "drm: Add solid fill pixel source" (drm-backport-placeholder)
- commit 20e7932
* Wed Oct  9 2024 pjakobsson@suse.de
- Revert "drm/atomic: Add pixel source to plane state dump" (drm-backport-placeholder)
- commit dc5a499
* Wed Oct  9 2024 pjakobsson@suse.de
- Revert "drm/atomic: Add solid fill data to plane state dump" (drm-backport-placeholder)
- commit 64ea9b0
* Wed Oct  9 2024 pjakobsson@suse.de
- Revert "drm/atomic: Move framebuffer checks to helper" (drm-backport-placeholder)
- commit 3e6629e
* Wed Oct  9 2024 pjakobsson@suse.de
- Revert "drm/atomic: Loosen FB atomic checks" (drm-backport-placeholder)
- commit 3a45415
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/bridge: migrate bridge_chains to per-encoder file (drm-backport-placeholder)
- commit cf33041
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/encoder: register per-encoder debugfs dir (drm-backport-placeholder)
- commit 2312b62
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/bridge: implement generic DP HPD bridge (drm-backport-placeholder)
- commit 79a0e98
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/bridge: add transparent bridge helper (drm-backport-placeholder)
- commit 66beced
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/bridge: lt8912b: Add power supplies (drm-backport-placeholder)
- commit 17dee2f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/bridge: lt8912b: Add suspend/resume support (drm-backport-placeholder)
- commit 1a9fe7c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/display/dp: Add the remaining Square PHY patterns DPCD register (drm-backport-placeholder)
- commit fb54e88
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/qxl: remove unused declaration (drm-backport-placeholder)
- commit 9bfa4b5
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Removed unused function to_pvr_vm_gpuva() (drm-backport-placeholder)
- commit 97c00d3
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: pvr_gpuvm_free() now static (drm-backport-placeholder)
- commit b46ebdb
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: pvr_device_process_active_queues now static (drm-backport-placeholder)
- commit 19769a2
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Fixed missing header in pvr_fw_meta (drm-backport-placeholder)
- commit 84ce1bc
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Fixed warning due to implicit cast to bool (drm-backport-placeholder)
- commit adad7f1
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/test: add a test suite for GEM objects backed by shmem (drm-backport-placeholder)
- commit ca13858
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: remove drm_bridge_hpd_disable() from (drm-backport-placeholder)
- commit fac3898
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: improve the documentation of connector hpd ops (drm-backport-placeholder)
- commit 7e5b369
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/atomic: Loosen FB atomic checks (drm-backport-placeholder)
- commit f23a42d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/atomic: Move framebuffer checks to helper (drm-backport-placeholder)
- commit c3bd780
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/atomic: Add solid fill data to plane state dump (drm-backport-placeholder)
- commit dec9119
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/atomic: Add pixel source to plane state dump (drm-backport-placeholder)
- commit 9282b79
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: Add solid fill pixel source (drm-backport-placeholder)
- commit 5b9d0fc
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: Introduce solid fill DRM plane property (drm-backport-placeholder)
- commit 58be80a
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: Introduce pixel_source DRM plane property (drm-backport-placeholder)
- commit 367334b
* Wed Oct  9 2024 pjakobsson@suse.de
- dma-buf/sw_sync: Add fence deadline support (drm-backport-placeholder)
- commit 1768432
* Wed Oct  9 2024 pjakobsson@suse.de
- dma-buf/sync_file: Add SET_DEADLINE ioctl (drm-backport-placeholder)
- commit 2c0d6b0
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/syncobj: Add deadline support for syncobj waits (drm-backport-placeholder)
- commit 84af35a
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/qaic: Expand DRM device lifecycle (drm-backport-placeholder)
- commit ca11b19
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/qaic: Increase number of in_reset states (drm-backport-placeholder)
- commit 99a9bf5
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: Create a CPU job extension for the copy performance query (drm-backport-placeholder)
- commit 77b166b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: Create a CPU job extension for the reset performance query (drm-backport-placeholder)
- commit e2f6435
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: Create a CPU job extension to copy timestamp query to a (drm-backport-placeholder)
- commit b1b95b4
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: Create a CPU job extension for the reset timestamp job (drm-backport-placeholder)
- commit ebc45a8
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: Create a CPU job extension for the timestamp query job (drm-backport-placeholder)
- commit 40f61d8
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: Create a CPU job extension for a indirect CSD job (drm-backport-placeholder)
- commit 5225a23
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: Enable BO mapping (drm-backport-placeholder)
- commit 2e1fc13
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: Detach the CSD job BO setup (drm-backport-placeholder)
- commit 7dd1ced
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: Create tracepoints to track the CPU job (drm-backport-placeholder)
- commit 2cef8d9
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: Use v3d_get_extensions() to parse CPU job data (drm-backport-placeholder)
- commit 5b83fb6
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: Add a CPU job submission (drm-backport-placeholder)
- commit e09cdea
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: Decouple job allocation from job initiation (drm-backport-placeholder)
- commit 069ea29
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: Don't allow two multisync extensions in the same job (drm-backport-placeholder)
- commit 26950b2
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: Simplify job refcount handling (drm-backport-placeholder)
- commit 105409c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: Detach job submissions IOCTLs to a new specific file (drm-backport-placeholder)
- commit dec63b5
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: Move wait BO ioctl to the v3d_bo file (drm-backport-placeholder)
- commit 1144f0f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: Remove unused function header (drm-backport-placeholder)
- commit 00ad787
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/tidss: Use DRM_PLANE_COMMIT_ACTIVE_ONLY (drm-backport-placeholder)
- commit f6b32d3
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/tidss: IRQ code cleanup (drm-backport-placeholder)
- commit c85af7b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/tidss: Add simple K2G manual reset (drm-backport-placeholder)
- commit 0a455e7
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/tidss: Drop useless variable init (drm-backport-placeholder).
- Refresh patches.suse/drm-tidss-Check-for-K2G-in-in-dispc_softreset.patch.
- Refresh patches.suse/drm-tidss-Return-error-value-from-from-softreset.patch.
- commit 76781e0
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/tidss: Use PM autosuspend (drm-backport-placeholder)
- commit 3a4a213
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/tidss: Use pm_runtime_resume_and_get() (drm-backport-placeholder)
- commit 1014a08
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/tidss: Add support for AM62A7 DSS (drm-backport-placeholder)
- commit 9d2f01a
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/omapdrm: Improve check for contiguous buffers (drm-backport-placeholder)
- commit e44deb5
* Wed Oct  9 2024 pjakobsson@suse.de
- dma-buf: Correct the documentation of name and exp_name symbols (drm-backport-placeholder)
- commit 9f8cca1
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: fix off by one in pvr_vm_mips_init() error handling (drm-backport-placeholder)
- commit a3a186a
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Fix IS_ERR() vs NULL bug in pvr_request_firmware() (drm-backport-placeholder)
- commit 6a47b1f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Fix error codes in pvr_device_clk_init() (drm-backport-placeholder)
- commit e01f758
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/nouveau: Removes unnecessary args check in (drm-backport-placeholder)
- commit 4a56a9d
* Wed Oct  9 2024 pjakobsson@suse.de
- Documentation/gpu: VM_BIND locking document (drm-backport-placeholder)
- commit 2934932
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev: Warn on incorrect framebuffer access (drm-backport-placeholder)
- commit 230f429
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev: Move default fb_mmap code into helper function (drm-backport-placeholder)
- commit e48d845
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev: Push pgprot_decrypted() into mmap implementations (drm-backport-placeholder)
- commit 36f26cc
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev: Remove trailing whitespaces (drm-backport-placeholder)
- commit 1ee54a2
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev/cyber2000fb: Initialize fb_ops with fbdev macros (drm-backport-placeholder)
- commit 95b776a
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev/wm8505fb: Initialize fb_ops to fbdev I/O-memory helpers (drm-backport-placeholder)
- commit 9992914
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev/vt8500lcdfb: Initialize fb_ops with fbdev macros (drm-backport-placeholder)
- commit 07e3891
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev/clps711x-fb: Initialize fb_ops with fbdev macros (drm-backport-placeholder)
- commit 4cab110
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev/ps3fb: Initialize fb_ops with fbdev macros (drm-backport-placeholder)
- commit 0bdef2f
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev/ps3fb: Set FBINFO_VIRTFB flag (drm-backport-placeholder)
- commit b38220a
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev/au1200fb: Initialize fb_ops with fbdev macros (drm-backport-placeholder)
- commit 4615af2
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev/au1200fb: Set FBINFO_VIRTFB flag (drm-backport-placeholder)
- commit d4421c8
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev/udlfb: Select correct helpers (drm-backport-placeholder)
- commit a4ac695
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev/smscufx: Select correct helpers (drm-backport-placeholder)
- commit 576a49a
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev/sh_mobile_lcdcfb: Initialize fb_ops with fbdev macros (drm-backport-placeholder)
- commit acfb276
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev/sh_mobile_lcdcfb: Set FBINFO_VIRTFB flag (drm-backport-placeholder)
- commit 07b2729
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev/arcfb: Use generator macros for deferred I/O (drm-backport-placeholder)
- commit f7d066c
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev/arcfb: Set FBINFO_VIRTFB flag (drm-backport-placeholder)
- commit b59fd1b
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev/vfb: Initialize fb_ops with fbdev macros (drm-backport-placeholder)
- commit 95c7671
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev/vfb: Set FBINFO_VIRTFB flag (drm-backport-placeholder)
- commit f62900e
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/bridge: ti-sn65dsi86: Simplify using pm_runtime_resume_and_get() (drm-backport-placeholder)
- commit 6860fb6
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel-edp: Avoid adding multiple preferred modes (drm-backport-placeholder)
- commit bb6b9d2
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel-edp: Add auo_b116xa3_mode (drm-backport-placeholder)
- commit 14b2191
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/tilcdc: Convert to platform remove callback returning void (drm-backport-placeholder)
- commit 5ff23dd
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/sched: Partial revert of "Qualify drm_sched_wakeup() by (drm-backport-placeholder)
- commit fc04205
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Numerous documentation fixes. (drm-backport-placeholder)
- commit becb6c5
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/ast: Move detection code into PCI probe helper (drm-backport-placeholder)
- commit f6e9434
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/ast: Detect ast device type and config mode without ast device (drm-backport-placeholder)
- commit 39befaf
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/ast: Add enum ast_config_mode (drm-backport-placeholder)
- commit f4fa7cd
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/ast: Partially implement POST without ast device instance (drm-backport-placeholder)
- commit ff7795c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/ast: Enable MMIO without ast device instance (drm-backport-placeholder)
- commit 3e72de9
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/ast: Enable VGA without ast device instance (drm-backport-placeholder)
- commit 7bcf98f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/ast: Add I/O helpers without ast device (drm-backport-placeholder)
- commit 1354418
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/ast: Retrieve I/O-memory ranges without ast device (drm-backport-placeholder)
- commit 823ed87
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/ast: Rework I/O register setup (drm-backport-placeholder)
- commit bfca030
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/ast: Turn ioregs_lock to modeset_lock (drm-backport-placeholder)
- commit 007de6c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: vm: fix drm_gpuvm reference count (drm-backport-placeholder)
- commit e7e1f24
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: vm: check for drm_gpuvm_range_valid() (drm-backport-placeholder)
- commit c052a34
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: vm: prevent duplicate drm_gpuvm_bo instances (drm-backport-placeholder)
- commit 3d2f3ff
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Remove unneeded semicolon (drm-backport-placeholder)
- commit 700f442
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Fix a couple of spelling mistakes in literal strings (drm-backport-placeholder)
- commit 2d4853d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: Use device_get_match_data() (drm-backport-placeholder)
- commit fe86306
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/sched: Fix compilation issues with DRM priority rename (drm-backport-placeholder)
- commit 956ba72
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/ttm: Schedule delayed_delete worker closer (drm-backport-placeholder)
- commit 9815569
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/sched: Reverse run-queue priority enumeration (drm-backport-placeholder)
- commit b592ea6
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/sched: Rename priority MIN to LOW (drm-backport-placeholder)
- commit 5154f13
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/nouveau: enable dynamic job-flow control (drm-backport-placeholder)
- commit 3d305f1
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/nouveau: implement 1:1 scheduler - entity relationship (drm-backport-placeholder).
- Delete patches.suse/drm-nouveau-don-t-fini-scheduler-before-entity-flush.patch.
- commit cfe0fd3
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/nouveau: use GPUVM common infrastructure (drm-backport-placeholder)
- commit 3c8680d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/todo: Add entry about implementing buffer age for damage tracking (drm-backport-placeholder)
- commit 61cd18b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/plane: Extend damage tracking kernel-doc (drm-backport-placeholder)
- commit f40f97f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/vmwgfx: Disable damage clipping if FB changed since last (drm-backport-placeholder)
- commit 9319031
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: Introduce documentation for hotspot properties (drm-backport-placeholder)
- commit 657c488
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: Introduce DRM_CLIENT_CAP_CURSOR_PLANE_HOTSPOT (drm-backport-placeholder)
- commit cfee896
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: Remove legacy cursor hotspot code (drm-backport-placeholder)
- commit f29c8ca
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/virtio: Use the hotspot properties from cursor planes (drm-backport-placeholder)
- commit 998de14
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/vboxvideo: Use the hotspot properties from cursor planes (drm-backport-placeholder)
- commit 347e8db
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/qxl: Use the hotspot properties from cursor planes (drm-backport-placeholder)
- commit eb71226
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/vmwgfx: Use the hotspot properties from cursor planes (drm-backport-placeholder)
- commit 5ee667b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/atomic: Add support for mouse hotspots (drm-backport-placeholder).
- Refresh patches.suse/drm-Add-kabi-placeholders-to-commonly-used-structs.patch.
- commit 4bbf7e1
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: introduce DRM_CAP_ATOMIC_ASYNC_PAGE_FLIP (drm-backport-placeholder)
- commit 1826eb1
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: allow DRM_MODE_PAGE_FLIP_ASYNC for atomic commits (drm-backport-placeholder)
- commit b4f5067
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: Refuse to async flip with atomic prop changes (drm-backport-placeholder)
- commit 2aa7f1d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Add intel_fb_bo_framebuffer_fini (drm-backport-placeholder)
- commit 11ca540
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: use octal permissions in display debugfs (drm-backport-placeholder)
- commit 1429d33
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: pass struct intel_connector to connector debugfs fops (drm-backport-placeholder)
- commit 891cb41
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: use intel_connector in intel_connector_debugfs_add() (drm-backport-placeholder)
- commit 9107f6e
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/rpm: add rpm_to_i915() helper around container_of() (drm-backport-placeholder)
- commit 64e5bbc
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: handle uncore spinlock when not available (drm-backport-placeholder)
- commit 97a2c29
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsi: Use devm_gpiod_get() for all GPIOs (drm-backport-placeholder)
- commit b8c72a8
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Don't use "proxy" headers (drm-backport-placeholder)
- commit 85160a3
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/syncmap: squelch a sparse warning (drm-backport-placeholder)
- commit 08b171f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Split i915 specific code away from intel_fb.c (drm-backport-placeholder)
- commit 6aeba42
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Handle invalid fb_modifier in (drm-backport-placeholder)
- commit c1ae840
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Convert intel_fb_modifier_to_tiling as non-static (drm-backport-placeholder)
- commit 20887e4
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: use intel_bo_to_drm_bo in intel_fb.c (drm-backport-placeholder)
- commit 528e861
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: use intel_bo_to_drm_bo in intel_fbdev (drm-backport-placeholder)
- commit 42edebf
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: split i915 specific code from intel_fbdev (drm-backport-placeholder)
- commit f6b4a15
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Skip state verification with TBT-ALT mode (drm-backport-placeholder)
- commit e502e9c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: add bool type checks in PIPE_CONF_CHECK_* (drm-backport-placeholder)
- commit d71dc38
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: use PIPE_CONF_CHECK_BOOL() for bool members (drm-backport-placeholder)
- commit 7ed3a6d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dgfx: DGFX uses direct VBT pin mapping (drm-backport-placeholder)
- commit 3187946
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Fix IP version of the WAs (drm-backport-placeholder)
- commit 1a4fe30
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/irq: Improve error logging for unexpected DE Misc interrupts (drm-backport-placeholder)
- commit 7f5659b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Clean up some DISPLAY_VER checks (drm-backport-placeholder).
- Refresh patches.suse/drm-i915-mst-Limit-MST-DSC-to-TGL.patch.
- commit 5299d9c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/psr: Include some basic PSR information in the state dump (drm-backport-placeholder)
- commit f9f8371
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: remove the FBC restriction if PSR2 is enabled (drm-backport-placeholder)
- commit 8e9cd71
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/psr: Add proper handling for disabling sel fetch for planes (drm-backport-placeholder)
- commit bdfb8c9
* Wed Oct  9 2024 tiwai@suse.de
- Bluetooth: L2CAP: Fix uaf in l2cap_connect (git-fixes).
- Bluetooth: MGMT: Fix possible crash on mgmt_index_removed
  (git-fixes).
- wifi: rtw88: Fix USB/SDIO devices not transmitting beacons
  (stable-fixes).
- wifi: ath11k: use work queue to process beacon tx event
  (git-fixes).
- commit 93b113e
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/psr: Move plane sel fetch configuration into plane source files (drm-backport-placeholder).
- Refresh patches.suse/drm-i915-display-Use-i915_gem_object_get_dma_address.patch.
- commit d9b3fed
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Move the SDP split debug spew to the correct place (drm-backport-placeholder)
- commit 1c3668a
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: enable mca debug mode on APU by default (drm-backport-placeholder)
- commit 519a728
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: distinguish rlc fw for different SKU (drm-backport-placeholder)
- commit c0c0e6a
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: Fix missing mca debugfs node (drm-backport-placeholder)
- commit 7d8f268
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: Skip access gfx11 golden registers under SRIOV (drm-backport-placeholder)
- commit 168d70d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: Read aquavanjaram XGMI register state (drm-backport-placeholder)
- commit 904fb99
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: Read aquavanjaram PCIE register state (drm-backport-placeholder)
- commit 299403a
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: Add reg_state sysfs attribute (drm-backport-placeholder)
- commit edb2ef7
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: add amdgpu_reg_state.h (drm-backport-placeholder)
- commit b78dc14
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Promote DAL to 3.2.262 (drm-backport-placeholder)
- commit 0863c88
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Add DSC granular throughput adjustment (drm-backport-placeholder)
- commit 1dff101
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.194.0 (drm-backport-placeholder)
- commit 54aaf04
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdkfd: Run restore_workers on freezable WQs (drm-backport-placeholder)
- commit e5b10cf
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Update Fixed VS/PE Retimer Sequence (drm-backport-placeholder)
- commit 5296418
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: block dcn315 dynamic crb allocation when unintended (drm-backport-placeholder)
- commit 2157b57
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: remove unnecessary braces to fix coding style (drm-backport-placeholder)
- commit c37dc55
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: Move mca debug mode decision to ras (drm-backport-placeholder)
- commit 995fe8c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: 3.2.261 (drm-backport-placeholder)
- commit 1d19af2
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: [FW Promotion] Release 0.0.193.0 (drm-backport-placeholder)
- commit 7271398
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Refactor OPTC into component folder (drm-backport-placeholder).
- Refresh patches.suse/drm-amd-display-Do-not-recursively-call-manual-trigg.patch.
- commit a4423cb
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: If P-State is supported try SubVP for smaller vlevel (drm-backport-placeholder)
- commit ae01a3c
* Wed Oct  9 2024 pjakobsson@suse.de
- Revert "drm/amd/display: Enable CM low mem power optimization" (drm-backport-placeholder)
- commit d53f780
* Wed Oct  9 2024 oneukum@suse.com
- i2c: stm32f7: perform most of irq job in threaded handler
  (git-fixes).
- commit 4a35980
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Enable SubVP on 1080p60 displays (drm-backport-placeholder).
- Refresh patches.suse/drm-amd-display-Override-min-required-DCFCLK-in-dml1.patch.
- commit f90226e
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Disable Timing sync check in Full-Screen Video Case (drm-backport-placeholder)
- commit a9f484f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: adjust flow for deallocation mst payload (drm-backport-placeholder)
- commit 7a82933
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Simplify brightness initialization (drm-backport-placeholder)
- commit 55b0b63
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: replay: Augment Frameupdate Command (drm-backport-placeholder)
- commit 3c1e79f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: replay: generalize the send command function usage (drm-backport-placeholder)
- commit 1511591
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Refactor DSC into component folder (drm-backport-placeholder)
- commit 2ca75dc
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: always use mpc factor of 2 for stereo timings (drm-backport-placeholder)
- commit a83e4b2
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: update pixel clock params after stream slice count (drm-backport-placeholder)
- commit e1fddf9
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: Retire query/reset_ras_err_status from gfx_v9_4_3 (drm-backport-placeholder)
- commit 66e1ee9
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: add skip_implict_edp_power_control flag for dce110 (drm-backport-placeholder)
- commit ff4e4d9
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdkfd: Copy HW exception data to user event (drm-backport-placeholder)
- commit 3d91b8e
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Add new Replay command and Disabled Replay Timing (drm-backport-placeholder)
- commit ade2314
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/pm: Add sysfs attribute to get pm metrics (drm-backport-placeholder)
- commit 5489a62
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/pm: Add pm metrics support to SMU v13.0.6 (drm-backport-placeholder)
- commit 1261aef
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/pm: Add support to fetch pm metrics sample (drm-backport-placeholder)
- commit 770a6b5
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Remove redundant DRM device struct in amdgpu_dm_, (drm-backport-placeholder)
- commit 16503b8
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd: Document device reset methods (drm-backport-placeholder)
- commit d6f17fc
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: Add function parameter 'xcc_mask' not described in (drm-backport-placeholder)
- commit 111ffd7
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: add amdgpu runpm usage trace for separate funcs (drm-backport-placeholder)
- commit 77a7466
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: add pm metrics structure definition (drm-backport-placeholder)
- commit 861db6d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: expose the connected port num info through sysfs (drm-backport-placeholder)
- commit 77f8d9f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Promote DC to 3.2.260 (drm-backport-placeholder)
- commit 986f8ad
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd: Exclude dGPUs in eGPU enclosures from DPM quirks (drm-backport-placeholder)
- commit d658612
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd: Use the first non-dGPU PCI device for BW limits (drm-backport-placeholder)
- commit e799ff7
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Add missing chips for HDCP (drm-backport-placeholder)
- commit 1177f3d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Add new command to disable replay timing resync (drm-backport-placeholder)
- commit cff704c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Enable DSC Flag in MST Mode Validation (drm-backport-placeholder)
- commit a164297
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Send PQ bit in AMD VSIF (drm-backport-placeholder)
- commit 0b6eb97
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Add disable timeout option (drm-backport-placeholder).
- Refresh patches.suse/drm-amd-display-Fix-potential-null-pointer-dereferen.patch.
- commit 82cf259
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Enable DCN clock gating for DCN35 (drm-backport-placeholder)
- commit 109a9a4
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Prefer currently used OTG master when acquiring free (drm-backport-placeholder)
- commit ccf0009
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Try to acquire a free OTG master not used in cur ctx (drm-backport-placeholder)
- commit 6bedea9
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Refactor resource into component directory (drm-backport-placeholder).
- Refresh patches.suse/0001-drm-amd-display-Add-NULL-pointer-check-for-kzalloc.patch.
- Refresh patches.suse/drm-amd-display-Check-denominator-crb_pipes-before-u.patch.
- Refresh patches.suse/drm-amd-display-Fix-null-pointer-deref-in-dcn20_reso.patch.
- Refresh patches.suse/drm-amd-display-Init-DPPCLK-from-SMU-on-dcn32.patch.
- Refresh patches.suse/drm-amd-display-Override-min-required-DCFCLK-in-dml1.patch.
- commit 26d913a
* Wed Oct  9 2024 oneukum@suse.com
- i2c: i801: Add lis3lv02d for Dell XPS 15 7590 (git-fixes).
- commit 38f58af
* Wed Oct  9 2024 oneukum@suse.com
- i2c: i801: Add lis3lv02d for Dell Precision 3540 (git-fixes).
- commit 036aff9
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: add a debugfs interface for the DMUB trace mask (drm-backport-placeholder)
- commit 1c08466
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/display: Enable CM low mem power optimization (drm-backport-placeholder)
- commit d4d6dd4
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: correct mca ipid die/socket/addr decode (drm-backport-placeholder)
- Update patches.suse/drm-amd-display-Fix-potential-null-pointer-dereferen.patch
- Delete patches.suse/0001-drm-amd-display-Add-disable-timeout-option.patch
- commit 983ef9b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdkfd: Clear the VALU exception state in the trap handler (drm-backport-placeholder)
- commit d1bc5e5
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: Refactor 'amdgpu_connector_dvi_detect' in (drm-backport-placeholder)
- commit c17d06d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/pm: Make smu_v13_0_baco_set_armd3_sequence() static (drm-backport-placeholder)
- commit 6de8874
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/pm: Move some functions to smu_v13_0.c as generic code (drm-backport-placeholder)
- commit b82bd2f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/radeon: Fix warning using plain integer as NULL (drm-backport-placeholder)
- commit 715477a
* Wed Oct  9 2024 pjakobsson@suse.de
- amdgpu: Adjust kmalloc_array calls for new -Walloc-size (drm-backport-placeholder)
- commit 1c561e0
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amd/pm: Fix return value and drop redundant param (drm-backport-placeholder)
- commit 600c6de
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdkfd: Move TLB flushing logic into amdgpu (drm-backport-placeholder)
- commit beb3db6
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: update mappings not managed by KFD (drm-backport-placeholder)
- commit 807ebdd
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/amdgpu: Implement a new 64bit sequence memory driver (drm-backport-placeholder)
- commit b6dafe1
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Fix glk+ degamma LUT conversions (drm-backport-placeholder)
- commit 4dc06a1
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: s/clamp()/min()/ in i965_lut_11p6_max_pack() (drm-backport-placeholder)
- commit 7f302c8
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Adjust LUT rounding rules (drm-backport-placeholder)
- commit 0956613
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: Fix color LUT rounding (drm-backport-placeholder)
- commit 463ff24
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: In intel_framebuffer_init switch to use (drm-backport-placeholder)
- commit 3762e74
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: in skl_surf_address check for dpt-vma (drm-backport-placeholder)
- commit 1b69fd9
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Separate xe and i915 common dpt code into own file (drm-backport-placeholder)
- commit 82ca857
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Implement audio fastset (drm-backport-placeholder)
- commit a8a8d11
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Push audio_{enable,disable}() to the pre/post pane update (drm-backport-placeholder)
- commit 5604dfd
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Hoist the encoder->audio_{enable,disable}() calls higher up (drm-backport-placeholder)
- commit 320a4f1
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Convert audio enable/disable into encoder vfuncs (drm-backport-placeholder)
- commit e456452
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Split g4x+ HDMI audio presence detect from port enable (drm-backport-placeholder)
- commit ffa8fa3
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Split g4x+ DP audio presence detect from port enable (drm-backport-placeholder)
- commit ea4997d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Wrap g4x+ DP/HDMI audio enable/disable (drm-backport-placeholder)
- commit 709b350
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Push audio enable/disable further out (drm-backport-placeholder)
- commit 751d9ec
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Polish some RMWs (drm-backport-placeholder)
- commit 4178bb7
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Do not check psr2 if psr/panel replay is not (drm-backport-placeholder)
- commit aa7e5ad
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Use int type for entry_setup_frames (drm-backport-placeholder)
- commit c5e3fe5
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/iosf: Drop unused APIs (drm-backport-placeholder)
- commit 5c9c52d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsi: Combine checks in mipi_exec_gpio() (drm-backport-placeholder)
- commit d11e965
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsi: Replace poking of CHV GPIOs behind the driver's back (drm-backport-placeholder)
- commit dc6db49
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsi: Prepare soc_gpio_set_value() to distinguish GPIO (drm-backport-placeholder)
- commit 68355fb
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsi: Replace poking of VLV GPIOs behind the driver's back (drm-backport-placeholder)
- commit b1037c3
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsi: Extract common soc_gpio_set_value() helper (drm-backport-placeholder)
- commit 3a5f032
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsi: Fix wrong initial value for GPIOs in (drm-backport-placeholder)
- commit 89af6b8
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsi: Remove GPIO lookup table at the end of (drm-backport-placeholder)
- commit 2a4599a
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsi: Replace check with a (missing) MIPI sequence name (drm-backport-placeholder)
- commit 89b7575
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsi: Get rid of redundant 'else' (drm-backport-placeholder)
- commit 14e8b0f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsi: Replace while(1) with one with clear exit condition (drm-backport-placeholder)
- commit c68fee4
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsi: bxt/icl GPIO set value do not need gpio source (drm-backport-placeholder)
- commit 3c8872e
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsi: rename platform specific *_exec_gpio() to (drm-backport-placeholder)
- commit 5ec5026
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsi: clarify GPIO exec sequence (drm-backport-placeholder)
- commit 1fbc8f4
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsi: switch mipi_exec_gpio() from dev_priv to i915 (drm-backport-placeholder)
- commit fe4340c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsi: assume BXT gpio works for non-native GPIO (drm-backport-placeholder)
- commit c8532ea
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp: Reuse intel_dp_{max,effective}_data_rate in (drm-backport-placeholder)
- commit 5130231
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp: Simplify intel_dp_max_data_rate() (drm-backport-placeholder)
- commit 46a8331
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp: Report a rounded-down value as the maximum data rate (drm-backport-placeholder)
- commit c2f3dde
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Fix PBN / MTP_TU size calculation for UHBR rates (drm-backport-placeholder)
- commit ab3e6d7
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Calculate the BW overhead in (drm-backport-placeholder)
- commit 4adb4b1
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp: Fix UHBR link M/N values (drm-backport-placeholder)
- commit 8d180e7
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp: Account for channel coding efficiency on UHBR links (drm-backport-placeholder)
- commit da56e7e
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp: Replace intel_dp_is_uhbr_rate() with (drm-backport-placeholder)
- commit 16d1439
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/dp_mst: Add kunit tests for drm_dp_get_vc_payload_bw() (drm-backport-placeholder)
- commit 3f8c975
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/dp_mst: Fix PBN divider calculation for UHBR rates (drm-backport-placeholder)
- commit d31ed25
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/dp_mst: Store the MST PBN divider value in fixed point format (drm-backport-placeholder)
- commit 9aea1c3
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/fbc: Bump ivb FBC max surface size to 4kx4k (drm-backport-placeholder)
- commit 946207f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/fbc: Bump max surface size to 8kx4k on icl+ (drm-backport-placeholder)
- commit a12b100
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/fbc: Split plane size vs. surface size checks apart (drm-backport-placeholder)
- commit 6fa2aee
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: convert vlv_dpio_read()/write() from pipe to phy (drm-backport-placeholder)
- commit 76234ef
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: add vlv_pipe_to_phy() helper to replace DPIO_PHY() (drm-backport-placeholder)
- commit f24b8a2
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: move *_crtc_clock_get() to intel_dpll.c (drm-backport-placeholder)
- commit 115404f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: keep struct intel_display members sorted (drm-backport-placeholder)
- commit 34662aa
* Wed Oct  9 2024 oneukum@suse.com
- i2c: cpm: Remove linux,i2c-index conversion from be32
  (git-fixes).
- commit 5d04b4e
* Wed Oct  9 2024 oneukum@suse.com
- i2c: ocores: Move system PM hooks to the NOIRQ phase
  (git-fixes).
- commit 0df7a53
* Wed Oct  9 2024 oneukum@suse.com
- i2c: ocores: Remove #ifdef guards for PM related functions
  (git-fixes).
- commit ead06ad
* Wed Oct  9 2024 tiwai@suse.de
- wifi: iwlwifi: config: label 'gl' devices as discrete
  (git-fixes).
- commit 6321867
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsb: DSB code refactoring (drm-backport-placeholder).
- Refresh patches.suse/drm-i915-dsb-Fix-DSB-vblank-waits-when-using-VRR.patch.
- commit e65f183
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Fix fractional bpp handling in intel_link_bw_reduce_bpp() (drm-backport-placeholder)
- commit 40832bf
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/panelreplay: Debugfs support for panel replay (drm-backport-placeholder)
- commit f7ea6ae
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/xe2lpd: implement WA for underruns while enabling FBC (drm-backport-placeholder)
- commit 5d3103f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp: Tune down FEC detection timeout error message (drm-backport-placeholder)
- commit f620b5a
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Use int for entry setup frames (drm-backport-placeholder)
- commit fe9fda5
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsc: Allow DSC only with fractional bpp when forced from (drm-backport-placeholder)
- commit 7a9f1be
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsc: Add debugfs entry to validate DSC fractional bpp (drm-backport-placeholder)
- commit 8b6760c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp: Iterate over output bpp with fractional step size (drm-backport-placeholder)
- commit 669ee3c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsc/mtl: Add support for fractional bpp (drm-backport-placeholder)
- commit 38fb58c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/audio: Consider fractional vdsc bpp while computing tu_data (drm-backport-placeholder)
- commit da34510
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Consider fractional vdsc bpp while computing m_n (drm-backport-placeholder)
- commit 9531ae2
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Store compressed bpp in U6.4 format (drm-backport-placeholder)
- commit 90d6640
* Wed Oct  9 2024 tiwai@suse.de
- kconfig: qconf: fix buffer overflow in debug links (git-fixes).
- platform/x86: ISST: Fix the KASAN report slab-out-of-bounds bug
  (git-fixes).
- i2c: stm32f7: Do not prepare/unprepare clock during runtime
  suspend/resume (git-fixes).
- gpio: davinci: fix lazy disable (git-fixes).
- drm/i915/gem: fix bitwise and logical AND mixup (git-fixes).
- drm/sched: Always wake up correct scheduler in
  drm_sched_entity_push_job (git-fixes).
- drm/sched: Add locking to drm_sched_entity_modify_sched
  (git-fixes).
- drm: Consistently use struct drm_mode_rect for FB_DAMAGE_CLIPS
  (git-fixes).
- Bluetooth: hci_event: Align BR/EDR JUST_WORKS paring with LE
  (git-fixes).
- Bluetooth: btmrvl: Use IRQF_NO_AUTOEN flag in request_irq()
  (git-fixes).
- ieee802154: Fix build error (git-fixes).
- Input: adp5589-keys - fix adp5589_gpio_get_value() (git-fixes).
- Input: adp5589-keys - fix NULL pointer dereference (git-fixes).
- drm/amdgpu/vcn: enable AV1 on both instances (stable-fixes).
- drm/amd/display: Validate backlight caps are sane
  (stable-fixes).
- drm/amd/display: Skip to enable dsc if it has been off
  (stable-fixes).
- drm/amd/display: Add HDMI DSC native YCbCr422 support
  (stable-fixes).
- drm/amd/display: Clean up dsc blocks in accelerated mode
  (stable-fixes).
- drm/amd/display: Round calculated vtotal (stable-fixes).
- efistub/tpm: Use ACPI reclaim memory for event log to avoid
  corruption (stable-fixes).
- iio: magnetometer: ak8975: drop incorrect AK09116 compatible
  (git-fixes).
- Input: i8042 - add TUXEDO Stellaris 15 Slim Gen6 AMD to i8042
  quirk table (stable-fixes).
- Input: i8042 - add another board name for TUXEDO Stellaris
  Gen5 AMD line (stable-fixes).
- Input: i8042 - add TUXEDO Stellaris 16 Gen5 AMD to i8042 quirk
  table (stable-fixes).
- hwmon: (max16065) Fix alarm attributes (git-fixes).
- ACPI: resource: Add another DMI match for the TongFang GMxXGxx
  (stable-fixes).
- wifi: rtw88: 8821cu: Remove VID/PID 0bda:c82c (stable-fixes).
- ASoC: tas2781: Use of_property_read_reg() (stable-fixes).
- wifi: iwlwifi: remove AX101, AX201 and AX203 support from LNL
  (stable-fixes).
- hwmon: (max16065) Remove use of i2c_match_id() (stable-fixes).
- nouveau/gsp: Avoid addressing beyond end of rpc->entries
  (stable-fixes).
- thunderbolt: Improve DisplayPort tunnel setup process to be
  more robust (stable-fixes).
- iio: magnetometer: ak8975: Fix 'Unexpected device' error
  (git-fixes).
- iio: magnetometer: ak8975: Convert enum->pointer for data in
  the match tables (stable-fixes).
- commit 85984c8
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/display/dp: Add helper function to get DSC bpp precision (drm-backport-placeholder)
- commit fca8bac
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/mtl: C20 state verification (drm-backport-placeholder)
- commit 991253a
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: update in-source bug filing URLs (drm-backport-placeholder)
- commit b8b4bec
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: remove excess functions from plane protection check (drm-backport-placeholder)
- commit 62a14fc
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: abstract plane protection check (drm-backport-placeholder)
- commit 8601da9
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/panelreplay: enable/disable panel replay (drm-backport-placeholder)
- commit ec45969
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/panelreplay: Enable panel replay dpcd initialization for DP (drm-backport-placeholder)
- commit d8d2063
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/panelreplay: Initializaton and compute config for panel (drm-backport-placeholder)
- commit d2fcaa4
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/psr: Move psr specific dpcd init into own function (drm-backport-placeholder)
- commit 93ccbda
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panelreplay: dpcd register definition for panelreplay (drm-backport-placeholder)
- commit b0dc9d1
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/gvt: Clean up zero initializers (drm-backport-placeholder)
- commit 100ff5a
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Do plane/etc. updates more atomically across pipes (drm-backport-placeholder)
- commit 5f8334a
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Split intel_update_crtc() into two parts (drm-backport-placeholder)
- commit 1c7424e
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Drop redundant !modeset check (drm-backport-placeholder)
- commit 0acbe5e
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Query compressed bpp properly using correct DPCD and DP (drm-backport-placeholder)
- commit d5dea7f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Check BW limitations only after all streams are (drm-backport-placeholder)
- commit 4c380f2
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Improve BW sharing between MST streams (drm-backport-placeholder)
- commit 3b5d48d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Force modeset CRTC if DSC toggling requires it (drm-backport-placeholder)
- commit 93362b9
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Factor out function to clear pipe update flags (drm-backport-placeholder)
- commit 8aece5c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Enable MST DSC decompression for all streams (drm-backport-placeholder)
- commit 248c5f0
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Enable DSC passthrough (drm-backport-placeholder)
- commit 00dd16b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp: Enable DSC via the connector decompression AUX (drm-backport-placeholder)
- commit 8b66225
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Enable decompression in the sink from the MST (drm-backport-placeholder)
- commit 137dab0
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Handle the Synaptics HBlank expansion quirk (drm-backport-placeholder)
- commit 397cdfd
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp: Disable FEC ready flag in the sink (drm-backport-placeholder)
- commit c0d0f6c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp: Wait for FEC detected status in the sink (drm-backport-placeholder)
- commit 1559b07
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp: Rename intel_ddi_disable_fec_state() to (drm-backport-placeholder)
- commit d278e27
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Add missing DSC compression disabling (drm-backport-placeholder)
- commit 9a0cb04
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp: Make sure the DSC PPS SDP is disabled whenever DSC is (drm-backport-placeholder)
- commit d354f63
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Program the DSC PPS SDP for each stream (drm-backport-placeholder)
- commit a994e7e
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Add atomic state for all streams on pre-tgl (drm-backport-placeholder)
- commit 341a551
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Account for FEC and DSC overhead during BW (drm-backport-placeholder)
- commit 11a8600
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp: Pass actual BW overhead to m_n calculation (drm-backport-placeholder)
- commit 51696c8
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp: Specify the FEC overhead as an increment vs. a remainder (drm-backport-placeholder)
- commit bfe074c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Enable FEC early once it's known DSC is needed (drm-backport-placeholder)
- commit 2d51adf
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/dp: Add helpers to calculate the link BW overhead (drm-backport-placeholder)
- commit 7824c72
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/dp_mst: Add HBLANK expansion quirk for Synaptics MST hubs (drm-backport-placeholder)
- commit a87b097
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/dp: Add DP_HBLANK_EXPANSION_CAPABLE and DSC_PASSTHROUGH_EN DPCD (drm-backport-placeholder)
- commit d26d5d4
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/dp_mst: Allow DSC in any Synaptics last branch device (drm-backport-placeholder)
- commit a576de3
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/dp_mst: Swap the order of checking root vs. non-root port BW (drm-backport-placeholder)
- commit 68785b6
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/dp_mst: Factor out a helper to check the atomic state of a (drm-backport-placeholder)
- commit 843c532
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/dp_mst: Add helper to determine if an MST port is downstream of (drm-backport-placeholder)
- commit dc02f89
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: move display spinlock init to display code (drm-backport-placeholder)
- commit 99b79a7
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: move display mutex inits to display code (drm-backport-placeholder)
- commit b5ed358
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Support PSR entry VSC packet to be transmitted one (drm-backport-placeholder)
- commit b2c16e1
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dp_mst: Disable DSC on ICL MST outputs (drm-backport-placeholder)
- commit 8dc2e1f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Move for_each_engine* out of i915_drv.h (drm-backport-placeholder)
- commit 02061de
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Remove unused for_each_uabi_class_engine (drm-backport-placeholder)
- commit 930a084
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsi: Extract port_ctrl_reg() (drm-backport-placeholder)
- commit d291bc9
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/dsi: Remove dead GLK checks (drm-backport-placeholder)
- commit 3c2046b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Extract mchbar_reg() (drm-backport-placeholder)
- commit 7f64d24
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Stop using a 'reg' variable (drm-backport-placeholder)
- commit 0f1307a
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Extract hsw_chicken_trans_reg() (drm-backport-placeholder)
- commit 07281b6
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Use intel_bo_to_drm_bo instead of obj->base (drm-backport-placeholder)
- commit c2a0317
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Use dma_fence interfaces instead of i915_sw_fence (drm-backport-placeholder)
- commit 8410555
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/mst: Always write CHICKEN_TRANS (drm-backport-placeholder)
- commit 4760e78
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/mst: Clear ACT just before triggering payload allocation (drm-backport-placeholder)
- commit b3dcecd
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/mst: Disable transcoder before deleting the payload (drm-backport-placeholder)
- commit 6c7cec9
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/mst: Swap TRANSCONF vs. FECSTALL_DIS_DPTSTREAM_DPTTG disable (drm-backport-placeholder)
- commit d8312ac
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/hdcp: Add more conditions to enable hdcp (drm-backport-placeholder)
- commit 276aa44
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/hdcp: Convert intel_hdcp_enable to a blanket function (drm-backport-placeholder)
- commit 22f1593
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/hdcp: Rename HCDP 1.4 enablement function (drm-backport-placeholder)
- commit ddba188
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Move the g45 PEG band gap HPD workaround to the HPD code (drm-backport-placeholder)
- commit 986cf6b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Extract _intel_{enable,disable}_shared_dpll() (drm-backport-placeholder)
- commit a1cabf1
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Move the DPLL extra power domain handling up one level (drm-backport-placeholder)
- commit 4ef790c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: Abstract the extra JSL/EHL DPLL4 power domain better (drm-backport-placeholder).
- Refresh patches.suse/drm-i915-Suppress-old-PLL-pipe_mask-checks-for-MG-TC.patch.
- commit 1bef2a6
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/bios: Clamp VBT HDMI level shift on BDW (drm-backport-placeholder)
- commit 1489147
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: move Makefile display debugfs files next to display (drm-backport-placeholder)
- commit 677dc0d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: fix Makefile sort and indent (drm-backport-placeholder)
- commit 91d6d89
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Abstract C10/C20 pll calculation (drm-backport-placeholder)
- commit d5bf12b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Abstract C10/C20 pll hw readout (drm-backport-placeholder)
- commit 54da76c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/lnl: Fix check for TC phy (drm-backport-placeholder)
- commit de19f55
* Wed Oct  9 2024 oneukum@suse.com
- i2c: core: fix lockdep warning for sparsely nested adapter chain
  (git-fixes).
- commit 691570d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/lnl: Extend C10/C20 phy (drm-backport-placeholder)
- commit fc31537
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/sprite: move sprite_name() to intel_sprite.c (drm-backport-placeholder)
- commit d606e11
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Reset message bus after each read/write operation (drm-backport-placeholder)
- commit 317fe24
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: remove display device info from i915 capabilities (drm-backport-placeholder)
- commit 4cccff6
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Move enable_dp_mst under display (drm-backport-placeholder)
- commit 1900034
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Move nuclear_pageflip under display (drm-backport-placeholder)
- commit b266ba0
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Move verbose_state_checks under display (drm-backport-placeholder)
- commit 40494b5
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Use device parameters instead of module in (drm-backport-placeholder)
- commit 44aade5
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Move disable_display parameter under display (drm-backport-placeholder)
- commit f927609
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Move force_reset_modeset_test parameter under (drm-backport-placeholder)
- commit c22691d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Move load_detect_test parameter under display (drm-backport-placeholder)
- commit d3d267a
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Move enable_dpcd_backlight module parameter under (drm-backport-placeholder)
- commit ce53d7d
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Move edp_vswing module parameter under display (drm-backport-placeholder)
- commit 3de8b5a
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Move invert_brightness module parameter under (drm-backport-placeholder)
- commit 166192a
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Move enable_ips module parameter under display (drm-backport-placeholder)
- commit f70b194
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Move disable_power_well module parameter under (drm-backport-placeholder)
- commit f327114
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Move enable_sagv module parameter under display (drm-backport-placeholder)
- commit 8c58a24
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Move enable_dpt module parameter under display (drm-backport-placeholder)
- commit ae40bde
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Move enable_dc module parameter under display (drm-backport-placeholder)
- commit 521b96e
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Move vbt_sdvo_panel_type module parameter under (drm-backport-placeholder)
- commit d4928af
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Move panel_use_ssc module parameter under display (drm-backport-placeholder)
- commit c80ee19
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Move lvds_channel_mode module parameter under (drm-backport-placeholder)
- commit 7ae4f48
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Move vbt_firmware module parameter under display (drm-backport-placeholder)
- commit db4dfb8
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Move psr related module parameters under display (drm-backport-placeholder)
- commit 4060a56
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Move enable_fbc module parameter under display (drm-backport-placeholder)
- commit e434256
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Dump also display parameters (drm-backport-placeholder)
- commit eac29e2
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Add framework to add parameters specific to display (drm-backport-placeholder)
- commit 89b3a25
* Wed Oct  9 2024 oneukum@suse.com
- i2c: exynos5: Calculate t_scl_l, t_scl_h according to i2c spec
  (git-fixes).
- commit cbbb120
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: debugfs entry to list display capabilities (drm-backport-placeholder)
- commit 3d350b2
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: stop including i915_utils.h from intel_runtime_pm.h (drm-backport-placeholder)
- commit 41ee94f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/aux: rename dev_priv to i915 (drm-backport-placeholder)
- commit 0204e88
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/aux: add separate register macros and functions for VLV/CHV (drm-backport-placeholder)
- commit a4b5444
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915: drop gt/intel_gt.h include from skl_universal_plane.c (drm-backport-placeholder)
- commit 06f3d84
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/i915/display: Use intel_bo_to_drm_bo instead of obj->base (drm-backport-placeholder)
- commit fd8b3ab
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Add driver documentation (drm-backport-placeholder)
- commit 0c92450
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Add firmware trace to debugfs (drm-backport-placeholder)
- commit 26e9a1e
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Add firmware trace header (drm-backport-placeholder)
- commit 80fdb52
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Implement job submission and scheduling (drm-backport-placeholder)
- commit 975718f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Implement context creation/destruction ioctls (drm-backport-placeholder)
- commit 7aeeb58
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Implement free list and HWRT create and destroy (drm-backport-placeholder)
- commit 3f28ebe
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Implement MIPS firmware processor and MMU support (drm-backport-placeholder)
- commit ad4e5f0
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Implement firmware infrastructure and META FW (drm-backport-placeholder)
- commit 1c59d0c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Implement power management (drm-backport-placeholder)
- commit b91a8c3
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Add GEM and VM related code (drm-backport-placeholder)
- commit cf9a815
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Add GPU ID parsing and firmware loading (drm-backport-placeholder)
- commit 728069b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Add FWIF headers (drm-backport-placeholder)
- commit 224ebaa
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Add firmware and MMU related headers (drm-backport-placeholder)
- commit bbf1f78
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Add GPU register headers (drm-backport-placeholder)
- commit f796a85
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination: Get GPU resources (drm-backport-placeholder)
- commit 0dd8070
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imagination/uapi: Add PowerVR driver UAPI (drm-backport-placeholder)
- commit 1266290
* Wed Oct  9 2024 pjakobsson@suse.de
- dt-bindings: gpu: Add Imagination Technologies PowerVR/IMG GPU (drm-backport-placeholder)
- commit a420e56
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/gpuvm: Helper to get range of unmap from a remap op. (drm-backport-placeholder)
- commit caa07f9
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/rockchip: rk3066_hdmi: include drm/drm_atomic.h (drm-backport-placeholder)
- commit 6876e88
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/nouveau/fifo: Remove duplicated include in chan.c (drm-backport-placeholder)
- commit acb3d0a
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev/simplefb: Suppress error on missing power domains (drm-backport-placeholder)
- commit 14cc344
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/edid/firmware: drop drm_kms_helper.edid_firmware backward compat (drm-backport-placeholder)
- commit d1f019c
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/sprd: Convert to platform remove callback returning void (drm-backport-placeholder)
- commit 86ce511
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/nouveau: Convert to platform remove callback returning void (drm-backport-placeholder)
- commit ab24b58
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/meson: Convert to platform remove callback returning void (drm-backport-placeholder)
- commit 5e39513
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/mediatek: Convert to platform remove callback returning void (drm-backport-placeholder)
- commit e5cae02
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/kmb: Convert to platform remove callback returning void (drm-backport-placeholder)
- commit 5821c35
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imx: lcdc: Convert to platform remove callback returning void (drm-backport-placeholder)
- commit 0900db6
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/imx/dcss: Convert to platform remove callback returning void (drm-backport-placeholder)
- commit af3602b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/etnaviv: Convert to platform remove callback returning void (drm-backport-placeholder)
- commit cf7be88
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/bridge: tpd12s015: Convert to platform remove callback returning (drm-backport-placeholder)
- commit cc41dd9
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/bridge: cdns-mhdp8546: Convert to platform remove callback (drm-backport-placeholder)
- commit 5a6af38
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/bridge: cdns-mhdp8546: Improve error reporting in remove callback (drm-backport-placeholder)
- commit affcca0
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/armada: Convert to platform remove callback returning void (drm-backport-placeholder)
- commit b658794
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/arcpgu: Convert to platform remove callback returning void (drm-backport-placeholder)
- commit 078f852
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/rockchip: rk3066_hdmi: Switch encoder hooks to atomic (drm-backport-placeholder)
- commit 7c2216f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/rockchip: rk3066_hdmi: Remove useless mode_fixup (drm-backport-placeholder)
- commit 379ec82
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/rockchip: vop2: Add NV20 and NV30 support (drm-backport-placeholder)
- commit 5c85330
* Wed Oct  9 2024 pjakobsson@suse.de
- dma-buf: Replace strlcpy() with strscpy() (drm-backport-placeholder)
- commit 9e33e19
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel-elida-kd35t133: Drop prepare/unprepare logic (drm-backport-placeholder)
- commit e7a2704
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel-elida-kd35t133: Drop shutdown logic (drm-backport-placeholder)
- commit a2a7882
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel-elida-kd35t133: drop (drm-backport-placeholder)
- commit efb62da
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel-elida-kd35t133: trival: update panel size from 5.5 to 3.5 (drm-backport-placeholder)
- commit 6188859
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel: nv3051d: Add Powkiddy RK2023 Panel Support (drm-backport-placeholder)
- commit 29475ea
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/print: Handle NULL drm device in __drm_printk() (drm-backport-placeholder)
- commit 5a2a68b
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/qaic: Update MAX_ORDER use to be inclusive (drm-backport-placeholder)
- commit e904343
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Use threaded IRQ to handle JOB done messages (drm-backport-placeholder)
- commit 7fcaae5
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Use dedicated work for job timeout detection (drm-backport-placeholder)
- commit 916b676
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Do not use cons->aborted for job_done_thread (drm-backport-placeholder)
- commit 7371602
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Do not use irqsave in ivpu_ipc_dispatch (drm-backport-placeholder)
- commit d536908
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Rename cons->rx_msg_lock (drm-backport-placeholder)
- commit 657fe85
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/client: Do not acquire module reference (drm-backport-placeholder)
- commit 7ffaf33
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/test: rearrange test entries in Kconfig and Makefile (drm-backport-placeholder)
- commit e614a74
* Wed Oct  9 2024 oneukum@suse.com
- i2c: i801: add helper i801_restore_regs (git-fixes).
- commit 3839f86
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/virtio: Fix return value for VIRTGPU_CONTEXT_PARAM_DEBUG_NAME (drm-backport-placeholder)
- commit cf3b015
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: Fix flip-task docs (drm-backport-placeholder)
- commit 3dd756f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: Remove struct drm_flip_task from DRM interfaces (drm-backport-placeholder)
- commit bc63ed4
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/ssd130x: Preallocate format-conversion buffer in atomic_check (drm-backport-placeholder)
- commit 1af558e
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/simpledrm: Preallocate format-conversion buffer in atomic_check (drm-backport-placeholder)
- commit cb0fa3f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/ofdrm: Preallocate format-conversion buffer in atomic_check (drm-backport-placeholder)
- commit 1f54c33
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/format-helper: Pass format-conversion state to helpers (drm-backport-placeholder)
- commit 89be72f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/atomic-helper: Add format-conversion state to shadow-plane state (drm-backport-placeholder)
- commit 150dc9b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/format-helper: Cache buffers with struct drm_format_conv_state (drm-backport-placeholder)
- commit 5b492d1
* Wed Oct  9 2024 pjakobsson@suse.de
- Revert "drm/sched: Define pr_fmt() for DRM using pr_*()" (drm-backport-placeholder)
- commit c2d8d5a
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/gpuvm: track/lock/validate external/evicted objects (drm-backport-placeholder)
- commit 66d0f01
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/gpuvm: add an abstraction for a VM / BO combination (drm-backport-placeholder)
- commit 88b6ff4
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/gpuvm: reference count drm_gpuvm structures (drm-backport-placeholder)
- commit 5b3da04
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/nouveau: separately allocate struct nouveau_uvmm (drm-backport-placeholder)
- commit f414a25
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/gpuvm: add drm_gpuvm_flags to drm_gpuvm (drm-backport-placeholder)
- commit d2f0723
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/nouveau: make use of the GPUVM's shared dma-resv (drm-backport-placeholder)
- commit 2e8f168
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/gpuvm: add common dma-resv per struct drm_gpuvm (drm-backport-placeholder)
- commit 857bcfe
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/nouveau: make use of drm_gpuvm_range_valid() (drm-backport-placeholder)
- commit e9d7bbd
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/gpuvm: export drm_gpuvm_range_valid() (drm-backport-placeholder)
- commit 62d701b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/gpuvm: don't always WARN in drm_gpuvm_check_overflow() (drm-backport-placeholder)
- commit 40ce39f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/gpuvm: convert WARN() to drm_WARN() variants (drm-backport-placeholder)
- commit b07db50
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/uapi: add explicit virtgpu context debug name (drm-backport-placeholder)
- commit 7d6fc6f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/virtio: use uint64_t more in virtio_gpu_context_init_ioctl (drm-backport-placeholder)
- commit 865c99e
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panfrost: Set regulators on/off during system sleep on MediaTek (drm-backport-placeholder)
- commit b0c9ba6
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panfrost: Implement ability to turn on/off regulators in suspend (drm-backport-placeholder)
- commit 87abf73
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panfrost: Set clocks on/off during system sleep on MediaTek SoCs (drm-backport-placeholder)
- commit 53eab61
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panfrost: Implement ability to turn on/off GPU clocks in suspend (drm-backport-placeholder)
- commit a84ac85
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panfrost: Tighten polling for soft reset and power on (drm-backport-placeholder)
- commit 6be17f0
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panfrost: Perform hard reset to recover GPU if soft reset fails (drm-backport-placeholder)
- commit b9e97f3
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/sched: implement dynamic job-flow control (drm-backport-placeholder)
- commit 907bec1
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/sched: Define pr_fmt() for DRM using pr_*() (drm-backport-placeholder)
- commit 71f8421
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panel-edp: drm/panel-edp: Add several generic edp panels (drm-backport-placeholder)
- commit 32c6699
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/sched: Qualify drm_sched_wakeup() by drm_sched_entity_is_ready() (drm-backport-placeholder)
- commit fb5b5e7
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/eld: add helpers to modify the SADs of an ELD (drm-backport-placeholder)
- commit f5cf5c4
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/edid: add helpers to get/set struct cea_sad from/to 3-byte sad (drm-backport-placeholder)
- commit d1ecd42
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/edid: use a temp variable for sads to drop one level of (drm-backport-placeholder)
- commit 974cc7f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/edid: include drm_eld.h only where required (drm-backport-placeholder).
- commit b703d68
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/eld: replace uint8_t with u8 (drm-backport-placeholder)
- commit e2e7c38
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/edid: split out drm_eld.h from drm_edid.h (drm-backport-placeholder)
- commit 220abb2
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/todo: Add entry to clean up former seltests suites (drm-backport-placeholder)
- commit 3db6914
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Use GEM shmem helper for all buffers (drm-backport-placeholder)
- commit 319c9bf
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Remove support for uncached buffers (drm-backport-placeholder)
- commit 3ffea60
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Fix locking in ivpu_bo_remove_all_bos_from_context() (drm-backport-placeholder).
- Refresh patches.suse/accel-ivpu-Fix-deadlock-in-context_xa.patch.
- commit e3f37b7
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Allocate vpu_addr in gem->open() callback (drm-backport-placeholder)
- commit d10a8b9
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/sched: Don't disturb the entity when in RR-mode scheduling (drm-backport-placeholder)
- commit 34f2c76
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Fix compilation with CONFIG_PM=n (drm-backport-placeholder)
- commit af26e60
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: Expose the total GPU usage stats on sysfs (drm-backport-placeholder)
- commit b076342
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: Implement show_fdinfo() callback for GPU usage stats (drm-backport-placeholder)
- commit 2b9af22
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: Do not round to megabytes for greater than 1MiB sizes in fdinfo (drm-backport-placeholder)
- commit 730b182
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/sched: Rename drm_sched_run_job_queue_if_ready and clarify (drm-backport-placeholder)
- commit df4538b
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/sched: Rename drm_sched_free_job_queue to be more descriptive (drm-backport-placeholder)
- commit 6ec0426
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/sched: Move free worker re-queuing out of the if block (drm-backport-placeholder)
- commit 2c0a0d3
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/sched: Rename drm_sched_get_cleanup_job to be more descriptive (drm-backport-placeholder)
- commit c8d85a2
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/qaic: Support for 0 resize slice execution in BO (drm-backport-placeholder)
- commit b5e23e7
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/qaic: Quiet array bounds check on DMA abort message (drm-backport-placeholder)
- commit 306cb1e
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: add brcm,2712-v3d as a compatible V3D device (drm-backport-placeholder)
- commit 686b8f6
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: fix up register addresses for V3D 7.x (drm-backport-placeholder)
- commit f1783b2
* Wed Oct  9 2024 oneukum@suse.com
- i2c: rcar: properly format a debug output (git-fixes).
- commit e7085c8
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: update UAPI to match user-space for V3D 7.x (drm-backport-placeholder)
- commit 9c8d55a
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev/simplefb: Add support for generic power-domains (drm-backport-placeholder)
- commit bde97bd
* Wed Oct  9 2024 pjakobsson@suse.de
- fbdev/simplefb: Support memory-region property (drm-backport-placeholder)
- commit 5b60b1a
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/sched: Add a helper to queue TDR immediately (drm-backport-placeholder)
- commit c1aaceb
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/sched: Add drm_sched_start_timeout_unlocked helper (drm-backport-placeholder)
- commit 54a0e27
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/sched: Split free_job into own work item (drm-backport-placeholder)
- commit 32834d4
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/sched: Convert drm scheduler to use a work queue rather than (drm-backport-placeholder)
- commit f3b4573
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/sched: Add drm_sched_wqueue_* helpers (drm-backport-placeholder)
- commit 9b3dd56
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Rename VPU to NPU in product strings (drm-backport-placeholder)
- commit 141e5fd
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Simplify MMU SYNC command (drm-backport-placeholder)
- commit ac4c441
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Make DMA allocations for MMU600 write combined (drm-backport-placeholder)
- commit b0cfb13
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Print CMDQ errors after consumer timeout (drm-backport-placeholder)
- commit 7c7b1d0
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Abort pending rx ipc on reset (drm-backport-placeholder)
- commit 9b28ac7
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Stop job_done_thread on suspend (drm-backport-placeholder)
- commit 4fa2fe1
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Assure device is off if power up sequence fail (drm-backport-placeholder)
- commit e9797f1
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu/40xx: Allow to change profiling frequency (drm-backport-placeholder)
- commit 2ce600f
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/panfrost: Remove incorrect IS_ERR() check (drm-backport-placeholder)
- commit dfb7477
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/v3d: wait for all jobs to finish before unregistering (drm-backport-placeholder)
- commit 9a2f6e9
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Add support for delayed D0i3 entry message (drm-backport-placeholder)
- commit 03bd422
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Introduce ivpu_ipc_send_receive_active() (drm-backport-placeholder)
- commit fe8dd6d
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Pass D0i3 residency time to the VPU firmware (drm-backport-placeholder)
- commit 8ab5dcf
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu/40xx: Capture D0i3 entry host and device timestamps (drm-backport-placeholder).
- Refresh patches.suse/accel-ivpu-Disable-PLL-after-VPU-IP-reset-during-FLR.patch.
- commit bff4411
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Change test_mode module param to bitmask (drm-backport-placeholder)
- commit 8de1dbc
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Add support for VPU_JOB_FLAGS_NULL_SUBMISSION_MASK (drm-backport-placeholder)
- commit d481178
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Remove reset from power up sequence (drm-backport-placeholder)
- commit e86e6f3
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Add dvfs_mode file to debugfs (drm-backport-placeholder)
- commit ddec721
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Remove unneeded drm_driver declaration (drm-backport-placeholder)
- commit 3482b7f
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/ivpu: Update FW API (drm-backport-placeholder)
- commit e38c22c
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/qaic: Support MHI QAIC_TIMESYNC channel (drm-backport-placeholder)
- commit f34ae35
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/qaic: Add support for periodic timesync (drm-backport-placeholder)
- commit 18b4a60
* Wed Oct  9 2024 pjakobsson@suse.de
- accel/qaic: Enable 1 MSI fallback mode (drm-backport-placeholder)
- commit 80cb375
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/doc: describe PATH format for DP MST (drm-backport-placeholder)
- commit 2165cbd
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: introduce CLOSEFB IOCTL (drm-backport-placeholder)
- commit 2e6524e
* Wed Oct  9 2024 pjakobsson@suse.de
- drm: extract closefb logic in separate function (drm-backport-placeholder)
- commit d4fecf9
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/atomic-helper: Fix spelling mistake "preceeding" -> "preceding" (drm-backport-placeholder)
- commit 642f207
* Wed Oct  9 2024 pjakobsson@suse.de
- docs: driver-api: properly format ToC headings (drm-backport-placeholder)
- commit d455fd0
* Wed Oct  9 2024 pjakobsson@suse.de
- drivers/gpu/drm/i915/i915_memcpy.c: fix missing includes (drm-backport-placeholder)
- commit 58811a3
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/modes: replace deprecated strncpy with strscpy_pad (drm-backport-placeholder)
- commit 4cc7186
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/tests: Switch to kunit devices (drm-backport-placeholder)
- commit 426afad
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/vc4: tests: Use KUNIT_DEFINE_ACTION_WRAPPER (drm-backport-placeholder)
- commit 2be7a02
* Wed Oct  9 2024 pjakobsson@suse.de
- drm/tests: Use KUNIT_DEFINE_ACTION_WRAPPER() (drm-backport-placeholder)
- commit ef6706a
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/mei-gsc_proxy-match-component-when-GSC-is-on-differe.patch (drm-backport-placeholder)
- commit 2216b65
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/mei-me-add-arrow-lake-point-H-DID.patch (drm-backport-placeholder)
- commit 2c11fa1
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/mei-me-add-arrow-lake-point-S-DID.patch (drm-backport-placeholder)
- commit 9a4345d
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-lock-the-client-object-tree.patch (drm-backport-placeholder)
- commit 019a7f7
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-boe-tv101wum-nl6-Fine-tune-Himax83102-j02--9dfc46c.patch (drm-backport-placeholder)
- commit c4b2d1c
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-Fix-output-poll-work-for-drm_kms_helper_poll-n.patch (drm-backport-placeholder)
- commit 7559a0d
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-pm-Fix-the-error-of-pwm1_enable-setting.patch (drm-backport-placeholder)
- commit ba94b50
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-handle-range-offsets-in-VRR-ranges.patch (drm-backport-placeholder)
- commit 27f80dc
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-check-dc_link-before-dereferencing.patch (drm-backport-placeholder)
- commit 0775ee9
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-swsmu-modify-the-gfx-activity-scaling.patch (drm-backport-placeholder)
- commit e665413
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-selftests-Fix-dependency-of-some-timeouts-o.patch (drm-backport-placeholder)
- commit d102ebb
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Don-t-explode-when-the-dig-port-we-don-t-ha.patch (drm-backport-placeholder)
- commit 233eb72
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Check-before-removing-mm-notifier.patch (drm-backport-placeholder)
- commit 7bea1d5
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-hdcp-Extract-hdcp-structure-from-correct-co.patch (drm-backport-placeholder)
- commit 3772ddc
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-hdcp-Remove-additional-timing-for-reading-m.patch (drm-backport-placeholder)
- commit 6c512e0
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-hdcp-Move-to-direct-reads-for-HDCP.patch (drm-backport-placeholder)
- commit d2649aa
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-report-byte-usage-in-VRAM-usage.patch (drm-backport-placeholder)
- commit dc122b6
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-monitor-patch-for-specific-eDP-b7cdccc.patch (drm-backport-placeholder)
- commit a3b34c2
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amd-pm-resolve-reboot-exception-for-si-ol.patch (drm-backport-placeholder)
- commit 1c72d18
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Enable-gpu-reset-for-S3-abort-cases-on-Ra.patch (drm-backport-placeholder)
- commit f10abb2
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-pm-Fix-the-power1_min_cap-value.patch (drm-backport-placeholder)
- commit d798eb5
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Prevent-potential-buffer-overflow-in.patch (drm-backport-placeholder)
- commit 0cbd6a7
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-buddy-check-range-allocation-matches-alignment.patch (drm-backport-placeholder)
- commit 23d5aba
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-buddy-fix-range-bias.patch (drm-backport-placeholder)
- commit 7c183e9
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/fbcon-always-restore-the-old-font-data-in-fbcon_do_s.patch (drm-backport-placeholder)
- commit 9a981cb
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-tegra-Remove-existing-framebuffer-only-if-we-sup.patch (drm-backport-placeholder)
- commit 3106e42
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/gpu-host1x-Skip-reset-assert-on-Tegra186.patch (drm-backport-placeholder)
- commit 83f5b44
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-add-an-ioctl-to-report-vram-usage.patch (drm-backport-placeholder)
- commit dcb3378
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-add-an-ioctl-to-return-vram-bar-size.patch (drm-backport-placeholder)
- commit 7002f74
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-the-runtime-resume-failure-issue.patch (drm-backport-placeholder)
- commit 88e86c4
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-null-pointer-dereference-on-edid.patch (drm-backport-placeholder)
- commit efcdc3f
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-memory-leak-in-dm_sw_fini.patch (drm-backport-placeholder)
- commit 85f82dd
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-input-states-translation-error-f.patch (drm-backport-placeholder)
- commit 30cb6cf
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-potential-null-pointer-dereferen.patch (drm-backport-placeholder git-fixes CVE-2024-26729 bsc#1222552).
- Delete patches.suse/0001-drm-amd-display-Disable-DMCUB-timeout-for-DCN35.patch
- commit e3cdf45
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Only-allow-dig-mapping-to-pwrseq-in-.patch (drm-backport-placeholder)
- commit 05fcec9
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-adjust-few-initialization-order-in-d.patch (drm-backport-placeholder).
- commit 8bff73f
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-tv-Fix-TV-mode.patch (drm-backport-placeholder)
- commit ee4fefc
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-syncobj-handle-NULL-fence-in-syncobj_eventfd_ent.patch (drm-backport-placeholder)
- commit b929fcc
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-syncobj-call-drm_syncobj_fence_add_wait-when-WAI.patch (drm-backport-placeholder)
- commit 08a0d88
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-ttm-Fix-an-invalid-freeing-on-already-freed-page.patch (drm-backport-placeholder)
- commit 9aa143f
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/accel-ivpu-Don-t-enable-any-tiles-by-default-on-VPU4.patch (drm-backport-placeholder)
- commit f825b3e
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-meson-Don-t-remove-bridges-which-are-created-by-.patch (drm-backport-placeholder)
- commit 0f62645
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-mmu-r535-uninitialized-variable-in-r535_.patch (drm-backport-placeholder)
- commit e6b9ea3
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-fix-function-cast-warnings.patch (drm-backport-placeholder)
- commit c863f88
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-buddy-Modify-duplicate-list_splice_tail-call.patch (drm-backport-placeholder)
- commit e492c96
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-Wire-up-tlb-ops.patch (drm-backport-placeholder)
- commit 8946dd1
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-msm-gpu-Push-gpu-lock-down-past-runpm.patch (drm-backport-placeholder)
- commit acb55e2
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-gem-Fix-double-resv-lock-aquire.patch (drm-backport-placeholder)
- commit 5f8a42c
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-display-Initialize-gamma-correction-mode-.patch (drm-backport-placeholder)
- commit 7fbfcad
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-soc21-update-VCN-4-max-HEVC-encoding-reso.patch (drm-backport-placeholder)
- commit a1ec61b
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fixed-integer-types-and-null-check-l.patch (drm-backport-placeholder)
- commit 8ab49b0
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-array-index-out-of-bounds-in-dcn.patch (drm-backport-placeholder)
- commit d420c93
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Preserve-original-aspect-ratio-in-cr.patch (drm-backport-placeholder)
- commit 461fb05
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-possible-NULL-dereference-on-dev.patch (drm-backport-placeholder)
- commit 6ca4669
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amd-display-increased-min_dcfclk_mhz-and-.patch (drm-backport-placeholder)
- commit eed6fb2
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-align-done-check.patch (drm-backport-placeholder)
- commit a8bf10c
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Stop-evicting-resources-on-APUs-in-suspend.patch (drm-backport-placeholder)
- commit 977be69
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-possible-buffer-overflow-in-find.patch (drm-backport-placeholder)
- commit 731309f
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-possible-use-of-uninitialized-ma.patch (drm-backport-placeholder)
- commit d6c2fb3
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Initialize-wait_time_microsec-variab.patch (drm-backport-placeholder)
- commit 111ba76
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-vs-typos.patch (drm-backport-placeholder)
- commit f58bad0
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Fix-L2-cache-size-reporting-in-GFX9.4.3.patch (drm-backport-placeholder)
- commit 9a372c7
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dp-Limit-SST-link-rate-to-8.1Gbps.patch (drm-backport-placeholder)
- commit 0e67ec8
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dsc-Fix-the-macro-that-calculates-DSCC_-DSC.patch (drm-backport-placeholder)
- commit 7647197
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-buddy-Fix-alloc_range-error-handling-code.patch (drm-backport-placeholder)
- commit a338e38
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-crtc-fix-uninitialized-variable-use-even-harder.patch (drm-backport-placeholder)
- commit 010bf7e
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-prime-Support-page-array-4GB.patch (drm-backport-placeholder)
- commit 7670f6f
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-svm-fix-kvcalloc-argument-order.patch (drm-backport-placeholder)
- commit 13c55af
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dp-return-correct-Colorimetry-for-DP_TEST_DY.patch (drm-backport-placeholder)
- commit c14d32a
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msms-dp-fixed-link-clock-divider-bits-be-over-wr.patch (drm-backport-placeholder)
- commit e7fbce1
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-fix-kernel-doc-warnings.patch (drm-backport-placeholder)
- commit be185b9
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-HDP-flush-for-VFs-on-nbio-v7.9.patch (drm-backport-placeholder)
- commit 21d6c55
* Wed Oct  9 2024 pjakobsson@suse.de
- Delete patches.suse/drm-amd-display-Implement-bounds-check-for-stream-en.patch.
- commit 7794cdb
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Increase-frame-larger-than-for-all-d.patch (drm-backport-placeholder)
- commit 4d5e9ca
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Avoid-fetching-VRAM-vendor-info.patch (drm-backport-placeholder)
- commit f545644
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-MST-Null-Ptr-for-RV.patch (drm-backport-placeholder)
- commit 276f0fa
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-shared-buff-copy-to-user.patch (drm-backport-placeholder)
- commit 9b7b4a5
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-reset-gpu-for-s3-suspend-abort-case.patch (drm-backport-placeholder)
- commit 69a2df8
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-skip-to-program-GFXDEC-registers-for-susp.patch (drm-backport-placeholder)
- commit cadd965
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-NULL-test-for-timing-generator-i.patch (drm-backport-placeholder)
- commit 27549d7
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-panel_cntl-could-be-null-in-dcn2.patch (drm-backport-placeholder)
- commit 1f031c1
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gvt-Fix-uninitialized-variable-in-handle_mm.patch (drm-backport-placeholder)
- commit 1f74647
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-nvkm_gsp_radix3_sg-should-use-nvkm_gsp_m.patch (drm-backport-placeholder)
- commit 7708200
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-fix-several-DMA-buffer-leaks.patch (drm-backport-placeholder)
- commit 2486750
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-offload-fence-uevents-work-to-workqueue.patch (drm-backport-placeholder)
- commit aa5631e
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-gsp-use-correct-size-for-registry-rpc.patch (drm-backport-placeholder)
- commit 91d7ed8
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-reserve-the-BO-before-validating-it.patch (drm-backport-placeholder)
- commit 65578a4
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-missing-error-code-in-gmc_v6-7-8-9_0_.patch (drm-backport-placeholder)
- commit 0b60260
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-buffer-overflow-in-get_host_rout.patch (drm-backport-placeholder)
- commit b440cff
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-NULL-check-for-kzalloc-in-amdgpu.patch (drm-backport-placeholder)
- commit 5bc4e05
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Don-t-init-MEC2-firmware-when-it-fails-to-lo.patch (drm-backport-placeholder)
- commit b5fea1d
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-dcn35-8k30-Underflow-Corruption-.patch (drm-backport-placeholder)
- commit b8da477
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-incorrect-mpc_combine-array-size.patch (drm-backport-placeholder)
- commit e2b3ad6
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-USB-C-flag-update-after-enc10-fe.patch (drm-backport-placeholder)
- commit 6c9a7c4
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-increased-min_dcfclk_mhz-and-min_fcl.patch (drm-backport-placeholder)
- commit 03e1149
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Use-correct-drm-device-for-cgroup-permiss.patch (drm-backport-placeholder)
- commit 90660a8
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amd-pm-fix-the-high-voltage-and-temperatu.patch (drm-backport-placeholder)
- commit 1492102
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-virtio-Set-segment-size-for-virtio_gpu-device.patch (drm-backport-placeholder)
- commit d53df6e
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-tegra-Do-not-assume-that-a-NULL-domain-means-no-DMA-IOMMU (drm-backport-placeholder)
- commit 2cff0cb
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-samsung-dsim-Don-t-use-FORCE_STOP_STATE.patch (drm-backport-placeholder)
- commit c82842e
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/Revert-nouveau-push-event-block-allowing-out-of-the-.patch (drm-backport-placeholder)
- commit 8849523
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-psr-Only-allow-PSR-in-LPSP-mode-on-HSW-non-.patch (drm-backport-placeholder)
- commit 24afd75
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drivers-firmware-Move-sysfb_init-from-device_.patch (drm-backport-placeholder)
- commit 56eac83
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-anx7625-Ensure-bridge-is-suspended-in-dis.patch (drm-backport-placeholder)
- commit bbf79cc
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/accel-ivpu-Disable-PLL-after-VPU-IP-reset-during-FLR.patch (drm-backport-placeholder).
- commit cc83328
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-parade-ps8640-Make-sure-we-drop-the-AUX-m.patch (drm-backport-placeholder)
- commit e47a7ec
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-parade-ps8640-Ensure-bridge-is-suspended-.patch (drm-backport-placeholder)
- commit f010011
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-sii902x-Fix-audio-codec-unregistration.patch (drm-backport-placeholder)
- commit 351ac47
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-raydium-rm692e5-select-CONFIG_DRM_DISPLAY_.patch (drm-backport-placeholder)
- commit 46352ba
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-samsung-s6d7aa0-drop-DRM_BUS_FLAG_DE_HIGH-.patch (drm-backport-placeholder)
- commit 5eca48c
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-simple-add-missing-bus-flags-for-Tianma-tm.patch (drm-backport-placeholder)
- commit d57af0c
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-parade-ps8640-Wait-for-HPD-when-doing-an-.patch (drm-backport-placeholder)
- commit d848b4b
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Disable-ips-before-dc-interrupt-sett.patch (drm-backport-placeholder)
- commit b18b81c
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-gfx11-set-UNORD_DISPATCH-in-compute-MQDs.patch (drm-backport-placeholder)
- commit dd2d1e3
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-gfx10-set-UNORD_DISPATCH-in-compute-MQDs.patch (drm-backport-placeholder)
- commit 3a2e018
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-amdgpu-Assign-GART-pages-to-AMD-device-mappi.patch (drm-backport-placeholder)
- commit aeee7b4
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-Fetch-current-power-limit-from-FW.patch (drm-backport-placeholder)
- commit 63d1590
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Show-vram-vendor-only-if-available.patch (drm-backport-placeholder)
- commit cd9d44c
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-update-the-power-cap-setting.patch (drm-backport-placeholder).
- commit 044e902
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Avoid-fetching-vram-vendor-information.patch (drm-backport-placeholder)
- commit 6ae7822
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-pm-Fix-the-power-source-flag-error.patch (drm-backport-placeholder)
- commit 6d2cf85
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-uninitialized-variable-usage-in-.patch (drm-backport-placeholder)
- commit fbc6ad4
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-exynos-gsc-minor-fix-for-loop-iteration-in-gsc_r.patch (drm-backport-placeholder)
- commit 954b240
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-exynos-fix-accidental-on-stack-copy-of-exynos_dr.patch (drm-backport-placeholder)
- commit 7d16e0d
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Drop-Wstringop-overflow.patch (drm-backport-placeholder)
- commit b32fe2b
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-i915-dsi-Do-display-on-sequence-later-on-.patch (drm-backport-placeholder)
- commit f59b665
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-sis-Error-out-if-pixclock-equals-zero.patch (drm-backport-placeholder)
- commit eecbdde
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-savage-Error-out-if-pixclock-equals-zero.patch (drm-backport-placeholder)
- commit 4516e73
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-vmm-don-t-set-addr-on-the-fail-path-to-avoid.patch (drm-backport-placeholder)
- commit 9f0ac5f
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Enable-GFXOFF-for-Compute-on-GFX11.patch (drm-backport-placeholder)
- commit b969401
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-revert-Adjust-removal-control-flow-for-sm.patch (drm-backport-placeholder)
- commit db2376b
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-a-switch-statement-in-populate_d.patch (drm-backport-placeholder)
- commit 67ecdd9
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Align-the-returned-error-code-with-l.patch (drm-backport-placeholder)
- commit 046bcd2
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-DML2-watermark-calculation.patch (drm-backport-placeholder)
- commit 03da004
* Wed Oct  9 2024 pjakobsson@suse.de
- Delete patches.suse/drm-amd-display-Clear-OPTC-mem-select-on-disable.patch.
- commit a0b4f3b
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Port-DENTIST-hang-and-TDR-fixes-to-O.patch (drm-backport-placeholder)
- commit e61a763
* Wed Oct  9 2024 pjakobsson@suse.de
- Delete patches.suse/drm-amd-display-Add-logging-resource-checks.patch.
- commit 5a5051e
* Wed Oct  9 2024 pjakobsson@suse.de
- Delete patches.suse/drm-amd-display-Init-link-enc-resources-in-dc_state-.patch.
- commit d9c966b
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Avoid-enum-conversion-warning.patch (drm-backport-placeholder)
- commit 0141779
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-Fix-smuv13.0.6-current-clock-reporting.patch (drm-backport-placeholder)
- commit 6551372
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-Add-error-log-for-smu-v13.0.6-reset.patch (drm-backport-placeholder)
- commit 653fce8
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Fix-node-NULL-check-in-svm_range_get_rang.patch (drm-backport-placeholder)
- commit 07bedce
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-drop-exp-hw-support-check-for-GC-9.4.3.patch (drm-backport-placeholder)
- commit d760136
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-variable-deferencing-before-NULL.patch (drm-backport-placeholder)
- commit c7884ad
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-update-regGL2C_CTRL4-value-in-golden-sett.patch (drm-backport-placeholder)
- commit b704937
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Release-adev-pm.fw-before-return-in-amdgp.patch (drm-backport-placeholder)
- commit 3affdc6
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-with-right-return-code-EIO-in-amdgpu_.patch (drm-backport-placeholder)
- commit 91cf6fe
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-powerplay-Fix-kzalloc-parameter-ATOM_Tonga_P.patch (drm-backport-placeholder)
- commit f463838
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fall-back-to-INPUT-power-for-AVG-power-vi.patch (drm-backport-placeholder)
- commit 87d321d
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-avg-vs-input-power-reporting-on-smu7.patch (drm-backport-placeholder)
- commit f2cea65
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-fixes-for-HMM-mem-allocation.patch (drm-backport-placeholder)
- commit 03c9c59
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amd-display-fix-bandwidth-validation-fail.patch (drm-backport-placeholder)
- commit 7d6942c
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Fix-lock-dependency-warning-with-srcu.patch (drm-backport-placeholder)
- commit 164dd9b
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-correct-the-cu-count-for-gfx-v11.patch (drm-backport-placeholder)
- commit 9b48bed
* Wed Oct  9 2024 pjakobsson@suse.de
- Delete patches.suse/Revert-drm-amd-display-Fix-conversions-between-bytes.patch.
- commit 200b25d
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Request-usb4-bw-for-mst-streams.patch (drm-backport-placeholder)
- commit 3b1f2b3
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-To-adjust-dprefclk-by-down-spread-pe.patch (drm-backport-placeholder)
- commit 9c2264e
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Fix-lock-dependency-warning.patch (drm-backport-placeholder)
- commit 876d448
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/backlight-hx8357-Convert-to-agnostic-GPIO-API.patch (drm-backport-placeholder)
- commit f503be5
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-gsp-handle-engines-in-runl-without-nonstall-.patch (drm-backport-placeholder)
- commit e247c14
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dp-Fix-the-max-DSC-bpc-supported-by-source.patch (drm-backport-placeholder)
- commit 106249a
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-flush-deferred-work-in-fb_deferred_io_fsync.patch (drm-backport-placeholder)
- commit e52db6b
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-mmp-Fix-typo-and-wording-in-code-comment.patch (drm-backport-placeholder)
- commit 0036d03
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-imxfb-fix-left-margin-setting.patch (drm-backport-placeholder)
- commit c68dfcc
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-bandwidth-validation-failure-on-.patch (drm-backport-placeholder)
- commit 574e3ce
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-apply-the-RV2-system-aperture-fix-to-RN-C.patch (drm-backport-placeholder)
- commit 0a27ab7
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amdkfd-Relocate-TBA-TMA-to-opposite-side-.patch (drm-backport-placeholder)
- commit d97528c
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-avoid-stringop-overflow-warnings-for.patch (drm-backport-placeholder)
- commit eaf4f3e
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-smu7-fix-a-memleak-in-smu7_hwmgr_backend_.patch (drm-backport-placeholder)
- commit 5cbc025
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Fix-iterator-used-outside-loop-in-kfd_add.patch (drm-backport-placeholder)
- commit 7946f35
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Drop-fence-check-in-to_amdgpu_amdkfd_fenc.patch (drm-backport-placeholder)
- commit f2d5917
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-fw-from-request_firmware-not-released.patch (drm-backport-placeholder)
- commit b62af15
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-variable-mca_funcs-dereferenced-befor.patch (drm-backport-placeholder)
- commit 3c8073d
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Fix-type-of-dbg_flags-in-struct-kfd_proce.patch (drm-backport-placeholder)
- commit 04ab6b6
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-possible-NULL-dereference-in-amdgpu_r.patch (drm-backport-placeholder)
- commit 91c2524
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-dpia-display-mode-validation-log.patch (drm-backport-placeholder)
- commit e51c365
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Let-KFD-sync-with-VM-fences.patch (drm-backport-placeholder)
- commit dacf2b5
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-minor-issues-in-BW-Allocation-Ph.patch (drm-backport-placeholder)
- commit 48e1881
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-ecc-irq-enable-disable-unpaired.patch (drm-backport-placeholder)
- commit 6d8b06c
* Wed Oct  9 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Clear-OPTC-mem-select-on-disable.patch.
- Delete patches.suse/drm-amd-display-Disconnect-phantom-pipe-OPP-from-OPT.patch.
- Delete patches.suse/drm-amd-display-Fix-hang-underflow-when-transitionin.patch.
- commit b441ec6
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Only-clear-symclk-otg-flag-for-HDMI.patch (drm-backport-placeholder)
- commit b261cbb
* Wed Oct  9 2024 pjakobsson@suse.de
- Delete patches.suse/drm-amd-display-Fix-lightup-regression-with-DP2-sing.patch.
- commit 59a45fb
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Wake-DMCUB-before-sending-a-command.patch (drm-backport-placeholder)
- commit 53c9cf3
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Refactor-DMCUB-enter-exit-idle-inter.patch (drm-backport-placeholder)
- commit e5edbb4
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-usb-c-connector_type.patch (drm-backport-placeholder)
- commit 89af353
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-make-flip_timestamp_in_us-a-64-bit-v.patch (drm-backport-placeholder)
- commit 6dcd62e
* Wed Oct  9 2024 pjakobsson@suse.de
- Delete patches.suse/drm-rockchip-vop2-Avoid-use-regmap_reinit_cache-at-r.patch.
- commit 68f75db
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-Don-t-unref-the-same-fb-many-times-by-mistake-du.patch (drm-backport-placeholder)
- commit 293e886
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/accel-habanalabs-fix-information-leak-in-sec_attest_.patch (drm-backport-placeholder)
- commit e2648c8
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/accel-habanalabs-add-support-for-Gaudi2C-device.patch (drm-backport-placeholder)
- commit 8177e24
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-using-mul_u32_u32-requires-linux-math64.h.patch (drm-backport-placeholder)
- commit 38f7d33
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-dp-Add-phy_mtk_dp-module-as-pre-depende.patch (drm-backport-placeholder)
- commit 781cc45
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-underrun-in-VDO1-when-switches-off-.patch (drm-backport-placeholder)
- commit dc73f00
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Remove-the-redundant-driver-data-for-DP.patch (drm-backport-placeholder)
- commit a6596a2
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Return-error-if-MDP-RDMA-failed-to-enab.patch (drm-backport-placeholder)
- commit b883815
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Drop-enable-and-frame_count-parameters-f.patch (drm-backport-placeholder)
- commit 7a735cf
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Set-input_sel-bit-for-INTF.patch (drm-backport-placeholder)
- commit 8eff91a
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Add-mutex-lock-in-control-vblank-irq.patch (drm-backport-placeholder git-fixes CVE-2023-52586 bsc#1221081).
- commit 250fc7b
* Wed Oct  9 2024 pjakobsson@suse.de
- Delete patches.suse/drm-msm-dpu-fix-writeback-programming-for-YUV-cases.patch.
- commit fa94c53
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-rename-dpu_encoder_phys_wb_setup_cdp-to-.patch (drm-backport-placeholder)
- commit f1ac30e
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Ratelimit-framedone-timeout-msgs.patch (drm-backport-placeholder).
- commit 400b650
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-enable-writeback-on-SM8450.patch (drm-backport-placeholder)
- commit 2f845b2
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-enable-writeback-on-SM8350.patch (drm-backport-placeholder)
- commit 0f23e85
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-adreno-Fix-A680-chip-id.patch (drm-backport-placeholder)
- commit 87f9648
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-drop-MSM_ENC_VBLANK-support.patch (drm-backport-placeholder)
- commit fd01d21
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dp-Add-DisplayPort-controller-for-SM8650.patch (drm-backport-placeholder)
- commit 9928312
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-correct-clk-bit-for-WB2-block.patch (drm-backport-placeholder)
- commit 67c990a
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-use-drmm-managed-allocation-for-dpu_enco.patch (drm-backport-placeholder)
- commit 6eca76d
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-use-devres-managed-allocation-for-MDP-TO.patch (drm-backport-placeholder)
- commit 471847d
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-mdss-Rename-path-references-to-mdp_path.patch (drm-backport-placeholder)
- commit 25a8fec
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-mdss-switch-mdss-to-use-devm_of_icc_get.patch (drm-backport-placeholder)
- commit 1cb7df2
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-populate-SSPP-scaler-block-version.patch (drm-backport-placeholder)
- commit 05198dc
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dsi-Enable-runtime-PM.patch (drm-backport-placeholder)
- commit e49eb4f
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dsi-Use-pm_runtime_resume_and_get-to-prevent.patch (drm-backport-placeholder)
- commit a371877
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Add-missing-safe_lut_tbl-in-sc8180x-cata.patch (drm-backport-placeholder)
- commit abf7d25
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Correct-UBWC-settings-for-sc8280xp.patch (drm-backport-placeholder)
- commit 1d69c7b
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-mdp4-flush-vblank-event-on-disable.patch (drm-backport-placeholder)
- commit 4c5f2be
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-a6xx-add-QMP-dependency.patch (drm-backport-placeholder)
- commit 8f731dd
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-enable-SmartDMA-on-SM8450.patch (drm-backport-placeholder)
- commit 0eb07ee
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-try-multirect-based-on-mdp-clock-limits.patch (drm-backport-placeholder)
- commit 58545d3
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-a690-Fix-reg-values-for-a690.patch (drm-backport-placeholder)
- commit 3da22d5
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-Reduce-fallout-of-fence-signaling-vs-reclaim.patch (drm-backport-placeholder)
- commit 9431787
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-do-not-send-commands-to-DMUB-if-DMUB.patch (drm-backport-placeholder)
- commit 13ff92b
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-only-flush-mes-process-context-if-mes-sup.patch (drm-backport-placeholder)
- commit 509ee1f
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-fix-a-double-free-in-amdgpu_parse_extende.patch (drm-backport-placeholder)
- commit 477a7ca
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/gpu-drm-radeon-fix-two-memleaks-in-radeon_vm_init.patch (drm-backport-placeholder)
- commit 6a4d4f2
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-debugfs-fix-error-code-when-smc-register-.patch (drm-backport-placeholder)
- commit a704f4a
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-ftrace-event-amdgpu_bo_move-always-mo.patch (drm-backport-placeholder)
- commit 719f5af
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-fix-mes-set-shader-debugger-process-manag.patch (drm-backport-placeholder)
- commit 5120d32
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Enable-tunneling-on-high-priority-compute.patch (drm-backport-placeholder)
- commit f149497
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Force-p-state-disallow-if-leaving-no.patch (drm-backport-placeholder)
- commit 43ae861
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-For-prefetch-mode-0-extend-prefetch-.patch (drm-backport-placeholder)
- commit 9164d09
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-vop2-clear-afbc-en-and-transform-bit-fo.patch (drm-backport-placeholder)
- commit 819936e
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-rockchip-vop2-Use-regcache_sync-to-fix-su.patch (drm-backport-placeholder)
- commit c51d4e8
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-st7701-Fix-AVCL-calculation.patch (drm-backport-placeholder)
- commit 3c9dc93
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-trinity_dpm-fix-a-memleak-in-trinity_pars.patch (drm-backport-placeholder)
- commit 90fbd3c
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-dpm-fix-a-memleak-in-sumo_parse_power_tab.patch (drm-backport-placeholder)
- commit dc04731
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Use-drm_connector-in-create_stream_f.patch (drm-backport-placeholder)
- commit 676f7e9
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Return-drm_connector-from-find_first.patch (drm-backport-placeholder)
- commit adf3595
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-add-support-for-DTO-genarated-dscclk.patch (drm-backport-placeholder)
- commit 19d66f1
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-Replay-Desync-Error-IRQ-handler.patch (drm-backport-placeholder)
- commit a66bb51
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-dml2-copy-functions.patch (drm-backport-placeholder)
- commit 5d310af
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-MST-PBN-X.Y-value-calculations.patch (drm-backport-placeholder)
- commit c878ae3
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Pass-pwrseq-inst-for-backlight-and-A.patch (drm-backport-placeholder)
- commit 7619899
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-exynos-Call-drm_atomic_helper_shutdown-at-shutdo.patch (drm-backport-placeholder)
- commit 8f0314f
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-mipi-dsi-Fix-detach-call-without-attach.patch (drm-backport-placeholder)
- commit 0c8743b
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358767-Fix-return-value-on-error-case.patch (drm-backport-placeholder)
- commit fd9b126
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-cdns-mhdp8546-Fix-use-of-uninitialized-va.patch (drm-backport-placeholder)
- commit c02d819
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-framebuffer-Fix-use-of-uninitialized-variable.patch (drm-backport-placeholder)
- commit 367bf73
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-drm_file-fix-use-of-uninitialized-variable.patch (drm-backport-placeholder)
- commit 814c198
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-nxp-ptn3460-simplify-some-error-checking.patch (drm-backport-placeholder)
- commit ea17570
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-Fix-TODO-list-mentioning-non-KMS-drivers.patch (drm-backport-placeholder)
- commit 0ef3ea1
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-panfrost-Ignore-core_mask-for-poweroff-and-disab.patch (drm-backport-placeholder)
- commit b394531
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-nxp-ptn3460-fix-i2c_master_send-error-che.patch (drm-backport-placeholder)
- commit cb49ff2
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-drv-propagate-errors-from-drm_modeset_register_a.patch (drm-backport-placeholder)
- commit de6b962
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-imx-lcdc-Fix-double-free-of-driver-data.patch (drm-backport-placeholder)
- commit f377770
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-tidss-Fix-atomic_flush-check.patch (drm-backport-placeholder)
- commit 350c3a0
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-tidss-Fix-dss-reset.patch (drm-backport-placeholder)
- commit 3a1b576
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-tidss-Check-for-K2G-in-in-dispc_softreset.patch (drm-backport-placeholder).
- commit 4401572
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-tidss-Return-error-value-from-from-softreset.patch (drm-backport-placeholder).
- commit a5cf00a
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-tidss-Move-reset-to-the-end-of-dispc_init.patch (drm-backport-placeholder)
- commit cb671d3
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-sm712fb-Use-correct-initializer-macros-for-str.patch (drm-backport-placeholder)
- commit e32f9f1
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-acornfb-Fix-name-of-fb_ops-initializer-macro.patch (drm-backport-placeholder)
- commit a9da6d5
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-anx7625-Fix-Set-HPD-irq-detect-window-to-.patch (drm-backport-placeholder)
- commit 1058b64
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-bridge-Add-200ms-delay-to-wait-FW-HPD-sta.patch (drm-backport-placeholder)
- commit cb8c6ff
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-edp-Add-override_edid_mode-quirk-for-gener.patch (drm-backport-placeholder)
- commit de02273
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-imx93-mipi-dsi-Fix-a-couple-of-building-w.patch (drm-backport-placeholder)
- commit 1f3f9e5
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-Fix-typo-in-post_disable-description.patch (drm-backport-placeholder)
- commit ac7070c
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-virtio-Disable-damage-clipping-if-FB-changed-sin.patch (drm-backport-placeholder)
- commit 7d6c823
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-Allow-drivers-to-indicate-the-damage-helpers-to-.patch (drm-backport-placeholder)
- commit 5255c21
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-Disable-the-cursor-plane-on-atomic-contexts-with.patch (drm-backport-placeholder)
- commit a97f6b5
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-display-Use-i915_gem_object_get_dma_address.patch (drm-backport-placeholder stable-fixes).
- commit dca9728
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Stop-printing-pipe-name-as-hex.patch (drm-backport-placeholder)
- commit 071b5e0
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-check-return-value-of-radeon_ring_lock.patch (drm-backport-placeholder)
- commit 9f64cc9
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-r100-Fix-integer-overflow-issues-in-r100_.patch (drm-backport-placeholder)
- commit 7b57440
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-r600_cs-Fix-possible-int-overflows-in-r60.patch (drm-backport-placeholder)
- commit 4089089
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-conversions-between-bytes-and-KB.patch (drm-backport-placeholder)
- commit d32a35c
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-tiled-display-misalignment.patch (drm-backport-placeholder)
- commit 4f531f3
* Wed Oct  9 2024 pjakobsson@suse.de
- Delete patches.suse/drm-amd-display-update-pixel-clock-params-after-stre.patch.
- commit e9041df
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-dp_mst-Fix-fractional-DSC-bpp-handling.patch (drm-backport-placeholder)
- commit 1f5b729
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Use-named-initializers-for-DPLL-info.patch (drm-backport-placeholder)
- commit 7daf6c5
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-display-Move-releasing-gem-object-away-from.patch (drm-backport-placeholder)
- commit a4ed5cc
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-tilcdc-Fix-irq-free-on-unload.patch (drm-backport-placeholder)
- commit c90a22f
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-fence-fix-warning-directly-dereferencing.patch (drm-backport-placeholder)
- commit dee00f1
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-elida-kd35t133-hold-panel-in-reset-for-unp.patch (drm-backport-placeholder)
- commit 95ed533
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-nv3051d-Hold-panel-in-reset-for-unprepare.patch (drm-backport-placeholder)
- commit 07d3f72
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-panfrost-Really-power-off-GPU-cores-in-panfrost_.patch (drm-backport-placeholder)
- commit 9439d97
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-edp-drm-panel-edp-Fix-AUO-B116XTN02-name.patch (drm-backport-placeholder)
- commit 3568752
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-edp-drm-panel-edp-Fix-AUO-B116XAK01-name-a.patch (drm-backport-placeholder)
- commit 5863745
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-nt35510-fix-typo.patch (drm-backport-placeholder)
- commit 2aa987f
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-omapdrm-Annotate-dma-fence-critical-secti.patch (drm-backport-placeholder)
- commit f3671e2
* Wed Oct  9 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-tidss-Annotate-dma-fence-critical-section.patch (drm-backport-placeholder)
- commit 4593c23
* Wed Oct  9 2024 pjakobsson@suse.de
- blacklist.conf: Unblacklist patches part of the DRM v6.8 backport
- commit 2d9f420
* Wed Oct  9 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add a test case to write mtu result into .rodata
  (git-fixes).
- selftests/bpf: Add a test case to write strtol result into
  .rodata (git-fixes).
- commit 805bbba
* Wed Oct  9 2024 shung-hsi.yu@suse.com
- selftests/bpf: Rename ARG_PTR_TO_LONG test description
  (git-fixes).
- selftests/bpf: Fix ARG_PTR_TO_LONG {half-,}uninitialized test
  (git-fixes).
- bpf: Zero former ARG_PTR_TO_{LONG,INT} args in case of error
  (git-fixes).
- bpf: Improve check_raw_mode_ok test for MEM_UNINIT-tagged types
  (git-fixes).
- commit 4580630
* Wed Oct  9 2024 shung-hsi.yu@suse.com
- bpf: Fix helper writes to read-only maps (git-fixes).
- bpf: Remove truncation test in bpf_strtol and bpf_strtoul
  helpers (git-fixes).
- bpf: Fix bpf_strtol and bpf_strtoul helpers for 32bit
  (git-fixes).
- commit 5fc2ffd
* Wed Oct  9 2024 vkarasulli@suse.de
- bpf: Remove tst_run from lwt_seg6local_prog_ops (bsc#1230801
  CVE-2024-46754).
- commit a7335b8
* Wed Oct  9 2024 shung-hsi.yu@suse.com
- bpf: Fix error message on kfunc arg type mismatch (git-fixes).
- commit 04ed437
* Wed Oct  9 2024 shung-hsi.yu@suse.com
- selftests/bpf: test for malformed BPF_CORE_TYPE_ID_LOCAL
  relocation (git-fixes).
- bpf: correctly handle malformed BPF_CORE_TYPE_ID_LOCAL relos
  (git-fixes).
- commit 67ebe66
* Wed Oct  9 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add tests for ldsx of pkt data/data_end/data_meta
  accesses (git-fixes).
- bpf: Fail verification for sign-extension of packet
  data/data_end/data_meta (git-fixes).
- bpf, lsm: Add disabled BPF LSM hook list (git-fixes).
- commit df1486e
* Wed Oct  9 2024 shung-hsi.yu@suse.com
- bpf, net: Fix a potential race in do_sock_getsockopt()
  (git-fixes).
- bpf: Fix tailcall cases in test_bpf (git-fixes).
- bpf, x64: Remove tail call detection (git-fixes).
- bpf, verifier: Correct tail_call_reachable for bpf prog
  (git-fixes).
- commit e072387
* Tue Oct  8 2024 ohering@suse.de
- add bug reference for a mana change (bsc#1229769).
- commit 64c619e
* Tue Oct  8 2024 dsterba@suse.com
- net/sched: taprio: extend minimum interval restriction to entire cycle too (CVE-2024-36244 bsc#1226797)
- commit 5ade9d6
* Tue Oct  8 2024 andrea.porta@suse.com
- arm64: fix selection of HAVE_DYNAMIC_FTRACE_WITH_ARGS
  (git-fixes).
- commit 7e90455
* Tue Oct  8 2024 andrea.porta@suse.com
- arm64: errata: Enable the AC03_CPU_38 workaround for ampere1a
  (git-fixes).
- commit 994f16f
* Tue Oct  8 2024 jlee@suse.com
- aoe: fix the potential use-after-free problem in more places
  (bsc#1218562 CVE-2023-6270).
- commit 1a991ba
* Tue Oct  8 2024 tiwai@suse.de
- ALSA: hda: tas2781: Fix missing setup at runtime PM
  (bsc#1230132).
- commit 3dc7842
* Tue Oct  8 2024 tiwai@suse.de
- Move upstreamed sound patch into sorted section
- commit b11079c
* Tue Oct  8 2024 msuchanek@suse.de
- kbuild,bpf: Add module-specific pahole flags for distilled
  base BTF (bsc#1230414 bsc#1229450).
- kbuild: bpf: Tell pahole to DECL_TAG kfuncs (bsc#1230414
  bsc#1229450).
- kbuild, bpf: Use test-ge check for v1.25-only pahole
  (bsc#1230414 bsc#1229450).
- kbuild,bpf: Switch to using --btf_features for pahole v1.26
  and later (bsc#1230414 bsc#1229450).
- kbuild: avoid too many execution of scripts/pahole-flags.sh
  (bsc#1230414 bsc#1229450).
- btf, scripts: rust: drop is_rust_module.sh (bsc#1230414
  bsc#1229450).
- commit e2cacce
* Tue Oct  8 2024 tiwai@suse.de
- Use pahole -j1 option for reproducible builds (bsc#1230414
  bsc#1229450).
- commit 340585e
* Tue Oct  8 2024 lhenriques@suse.de
- ceph: fix cap ref leak via netfs init_request (bsc#1231384).
- commit ca24d43
* Tue Oct  8 2024 jgross@suse.com
- vhost/scsi: null-ptr-dereference in vhost_scsi_get_req()
  (git-fixes).
- commit 267df6b
* Tue Oct  8 2024 jgross@suse.com
- virtio_console: fix misc probe bugs (git-fixes).
- commit f7d3065
* Tue Oct  8 2024 ohering@suse.de
- RDMA/mana_ib: use the correct page size for mapping user-mode
  doorbell page (git-fixes).
- RDMA/mana_ib: use the correct page table index based on hardware
  page size (git-fixes).
- tools: hv: rm .*.cmd when make clean (git-fixes).
- x86/hyperv: Set X86_FEATURE_TSC_KNOWN_FREQ when Hyper-V provides
  frequency (git-fixes).
- commit 059fd95
* Tue Oct  8 2024 jgross@suse.com
- KVM: VMX: Set PFERR_GUEST_{FINAL,PAGE}_MASK if and only if
  the GVA is valid (git-fixes).
- commit bb6f3d3
* Tue Oct  8 2024 jgross@suse.com
- KVM: x86/mmu: Skip emulation on page fault iff 1+ SPs were
  unprotected (git-fixes).
- commit bcfafe2
* Tue Oct  8 2024 jgross@suse.com
- KVM: x86/mmu: Trigger unprotect logic only on write-protection
  page faults (git-fixes).
- commit 322cf36
* Mon Oct  7 2024 jgross@suse.com
- KVM: VMX: Also clear SGX EDECCSSA in KVM CPU caps when SGX is
  disabled (git-fixes).
- commit d7b7771
* Mon Oct  7 2024 fdmanana@suse.com
- btrfs: send: fix invalid clone operation for file that got
  its size decreased (git-fixes).
- commit 26ee3ac
* Mon Oct  7 2024 jgross@suse.com
- KVM: x86: Exit to userspace if fastpath triggers one on
  instruction skip (git-fixes).
- commit 1621f7b
* Mon Oct  7 2024 jgross@suse.com
- KVM: x86: Dedup fastpath MSR post-handling logic (git-fixes).
- commit c20ff7c
* Mon Oct  7 2024 jgross@suse.com
- KVM: x86: Re-enter guest if WRMSR(X2APIC_ICR) fastpath is
  successful (git-fixes).
- commit 0dc4c78
* Mon Oct  7 2024 davide.benini@suse.com
- blacklist.conf: as in mptcp_parse_option() it's never set OPTION_MPTCP_MPJ_SYNACK,
  we don't need to check for it. Setting OPTION_MPTCP_MPJ_SYNACK instead
  of OPTIONS_MPTCP_MPJ in mptcp_parse_option() is in another patch, which
  we don't include, so no need for this.
- commit 41ddd47
* Mon Oct  7 2024 jgross@suse.com
- kABI fix of VM: x86: Re-split x2APIC ICR into ICR+ICR2 for AMD
  (x2AVIC) (git-fixes).
- commit 0a6716e
* Mon Oct  7 2024 jgross@suse.com
- KVM: x86: Re-split x2APIC ICR into ICR+ICR2 for AMD (x2AVIC)
  (git-fixes).
- commit 6a07b23
* Mon Oct  7 2024 jgross@suse.com
- KVM: x86: Move x2APIC ICR helper above kvm_apic_write_nodecode()
  (git-fixes).
- commit 4f194f7
* Mon Oct  7 2024 oneukum@suse.com
- USB: misc: yurex: fix race between read and write (git-fixes).
- commit 7f6ab55
* Mon Oct  7 2024 oneukum@suse.com
- USB: misc: cypress_cy7c63: check for short transfer (git-fixes).
- commit 3dcfad1
* Mon Oct  7 2024 oneukum@suse.com
- USB: appledisplay: close race between probe and completion
  handler (git-fixes).
- commit 888718f
* Mon Oct  7 2024 jgross@suse.com
- KVM: x86: Enforce x2APIC's must-be-zero reserved ICR bits
  (git-fixes).
- commit 891c3ef
* Mon Oct  7 2024 oneukum@suse.com
- usb: xhci: fix loss of data on Cadence xHC (git-fixes).
- commit 9e9d585
* Mon Oct  7 2024 jgross@suse.com
- KVM: Write the per-page "segment" when clearing (part of)
  a guest page (git-fixes).
- commit dae8f10
* Mon Oct  7 2024 oneukum@suse.com
- xhci: Add a quirk for writing ERST in high-low order
  (git-fixes).
- commit d0eccfc
* Mon Oct  7 2024 tzimmermann@suse.com
- drm/amd/display: Validate function returns (bsc#1230774 CVE-2024-46775)
- commit fc9ad2b
* Mon Oct  7 2024 jgross@suse.com
- KVM: Fix coalesced_mmio_has_room() to avoid premature userspace
  exit (git-fixes).
- commit 93dbc58
* Mon Oct  7 2024 oneukum@suse.com
- blacklist.conf: broken in upstream
- commit 5b657b6
* Mon Oct  7 2024 jgross@suse.com
- KVM: Use dedicated mutex to protect kvm_usage_count to avoid
  deadlock (git-fixes).
- commit 2ff88a8
* Mon Oct  7 2024 msuchanek@suse.de
- Delete some more obsolete scripts
- commit 9bb77f8
* Mon Oct  7 2024 jgross@suse.com
- KVM: SVM: Disallow guest from changing userspace's
  MSR_AMD64_DE_CFG value (git-fixes).
- commit c8fa16d
* Mon Oct  7 2024 pjakobsson@suse.de
- drm/amd/display: Stop amdgpu_dm initialize when link nums greater than max_links (CVE-2024-46816 bsc#1231197).
- commit c05e7e2
* Mon Oct  7 2024 jgross@suse.com
- net: test for not too small csum_start in
  virtio_net_hdr_to_skb() (git-fixes).
- commit ed78dff
* Mon Oct  7 2024 jgross@suse.com
- vhost_vdpa: assign irq bypass producer token correctly
  (git-fixes).
- commit 1a9cba6
* Mon Oct  7 2024 pjakobsson@suse.de
- drm/amd/display: Check link_index before accessing dc->links (CVE-2024-46813 bsc#1231191).
- commit eb31596
* Mon Oct  7 2024 jgross@suse.com
- minmax: avoid overly complex min()/max() macro arguments in xen
  (git-fixes).
- Refresh
  patches.suse/xen-move-max_pfn-in-xen_memory_setup-out-of-function.patch.
- commit 754808b
* Sun Oct  6 2024 tonyj@suse.de
- perf mem: Fix missed p-core mem events on ADL and RPL
  (git-fixes).
- perf mem: Check mem_events for all eligible PMUs (git-fixes).
- perf hist: Don't set hpp_fmt_value for members in --no-group
  (git-fixes).
- perf dwarf-aux: Handle bitfield members from pointer access
  (git-fixes).
- perf annotate-data: Fix missing constant copy (git-fixes).
- perf annotate-data: Fix off-by-one in location range check
  (git-fixes).
- perf dwarf-aux: Check allowed location expressions when
  collecting variables (git-fixes).
- perf build: Fix up broken capstone feature detection fast path
  (git-fixes).
- perf vendor events: SKX, CLX, SNR uncore cache event fixes
  (git-fixes).
- perf python: Remove PYTHON_PERF ifdefs (git-fixes).
- perf bpf: Move BPF disassembly routines to separate file to
  avoid clash with capstone bpf headers (git-fixes).
- perf test pmu: Remove unused test_pmus (git-fixes).
- perf scripts python cs-etm: Restore first sample log in verbose
  mode (git-fixes).
- commit f1c255b
* Sun Oct  6 2024 tonyj@suse.de
- Add Alt-commit id's for git-fixes:
  Refresh: patches.suse/perf-comm-str-Avoid-sort-during-insert.patch.
  Refresh: patches.suse/perf-daemon-Fix-the-build-on-more-32-bit-architectures.patch.
  Refresh: patches.suse/perf-dsos-When-adding-a-dso-into-sorted-dsos-maintain-the-sort-order.patch.
  Refresh: patches.suse/perf-test-pmu-Set-uninitialized-PMU-alias-to-null.patch.
- commit aeed4b0
* Sun Oct  6 2024 tonyj@suse.de
- Update references tags on following patches for sp7 v6.11 perf userspace update
- patches.suse/perf-annotate-Fix-annotation_calc_lines-to-pass-correct-address-to-get_srcline.patch
- patches.suse/perf-annotate-Get-rid-of-duplicate-group-option-item.patch
- patches.suse/perf-annotate-Introduce-global-annotation_options.patch
- patches.suse/perf-annotate-Split-branch-stack-cycles-information-out-of-struct-annotation_line.patch
- patches.suse/perf-annotate-Use-global-annotation_options.patch
- patches.suse/perf-auxtrace-Fix-multiple-use-of-itrace-option.patch
- patches.suse/perf-bench-internals-inject-build-id-Fix-trap-divide-when-collecting-just-one-DSO.patch
- patches.suse/perf-bench-uprobe-Remove-lib64-from-libc.so.6-binary-path.patch
- patches.suse/perf-daemon-Fix-file-leak-in-daemon_session__control.patch
- patches.suse/perf-db-export-Fix-missing-reference-count-get-in-call_path_from_sample.patch
- patches.suse/perf-docs-Document-bpf-event-modifier.patch
- patches.suse/perf-docs-Fix-man-page-formatting-for-perf-lock.patch
- patches.suse/perf-env-Avoid-recursively-taking-env-bpf_progs.lock.patch
- patches.suse/perf-evlist-Fix-evlist__new_default-for-1-core-PMU.patch
- patches.suse/perf-evsel-Fix-duplicate-initialization-of-data-id-in-evsel__parse_sample.patch
- patches.suse/perf-expr-Fix-has_event-function-for-metric-style-events.patch
- patches.suse/perf-genelf-Set-ELF-program-header-addresses-properly.patch
- patches.suse/perf-header-Fix-one-memory-leakage-in-perf_event__fprintf_event_update.patch
- patches.suse/perf-header-Fix-segfault-on-build_mem_topology-error-path.patch
- patches.suse/perf-header-Support-num-and-width-of-branch-counters.patch
- patches.suse/perf-hisi-ptt-Fix-one-memory-leakage-in-hisi_ptt_process_auxtrace_event.patch
- patches.suse/perf-intel-pt-Fix-aux_watermark-calculation-for-64-bit-size.patch
- patches.suse/perf-intel-pt-Fix-exclude_guest-setting.patch
- patches.suse/perf-intel-pt-Fix-unassigned-instruction-op-discovered-by-MemorySanitizer.patch
- patches.suse/perf-jevents-Drop-or-simplify-small-integer-values.patch
- patches.suse/perf-list-fix-short-description-for-some-cache-events.patch
- patches.suse/perf-lock-contention-Add-a-missing-NULL-check.patch
- patches.suse/perf-machine-thread-Remove-exited-threads-by-default.patch
- patches.suse/perf-maps-Move-symbol-maps-functions-to-maps.c.patch
- patches.suse/perf-mem-Fix-error-on-hybrid-related-to-availability-of-mem-event-in-a-PMU.patch
- patches.suse/perf-metric-Don-t-remove-scale-from-counts.patch
- patches.suse/perf-pmu-Assume-sysfs-events-are-always-the-same-case.patch
- patches.suse/perf-pmu-Count-sys-and-cpuid-JSON-events-separately.patch
- patches.suse/perf-pmu-Fix-a-potential-memory-leak-in-perf_pmu__lookup.patch
- patches.suse/perf-pmu-Treat-the-msr-pmu-as-software.patch
- patches.suse/perf-pmu-events-powerpc-Update-json-mapfile-with-Power11-PVR.patch
- patches.suse/perf-pmus-Fixes-always-false-when-compare-duplicates-aliases.patch
- patches.suse/perf-print-events-make-is_event_supported-more-robust.patch
- patches.suse/perf-probe-Add-missing-libgen.h-header-needed-for-using-basename.patch
- patches.suse/perf-record-Check-conflict-between-timestamp-filename-option-and-pipe-mode-before-recording.patch
- patches.suse/perf-record-Delete-session-after-stopping-sideband-thread.patch
- patches.suse/perf-record-Fix-debug-message-placement-for-test-consumption.patch
- patches.suse/perf-record-Fix-possible-incorrect-free-in-record__switch_output.patch
- patches.suse/perf-record-Lazy-load-kernel-symbols.patch
- patches.suse/perf-report-Avoid-SEGV-in-report__setup_sample_type.patch
- patches.suse/perf-report-Convert-to-the-global-annotation_options.patch
- patches.suse/perf-report-Fix-condition-in-sort__sym_cmp.patch
- patches.suse/perf-sched-timehist-Fix-g-call-graph-option-failure.patch
- patches.suse/perf-script-Show-also-errors-for-insn-trace-option.patch
- patches.suse/perf-script-add-raw-disasm-arguments-to-insn-trace-option.patch
- patches.suse/perf-srcline-Add-missed-addr2line-closes.patch
- patches.suse/perf-stat-Avoid-metric-only-segv.patch
- patches.suse/perf-stat-Do-not-fail-on-metrics-on-s390-z-VM-systems.patch
- patches.suse/perf-stat-Don-t-display-metric-header-for-non-leader-uncore-events.patch
- patches.suse/perf-stat-Exit-perf-stat-if-parse-groups-fails.patch
- patches.suse/perf-stat-Fix-hard-coded-LL-miss-units.patch
- patches.suse/perf-stat-Fix-help-message-for-metric-no-threshold-option.patch
- patches.suse/perf-stat-Fix-the-hard-coded-metrics-calculation-on-the-hybrid.patch
- patches.suse/perf-symbols-Fix-ownership-of-string-in-dso__load_vmlinux.patch
- patches.suse/perf-test-Basic-branch-counter-support.patch
- patches.suse/perf-test-Make-test_arm_callgraph_fp.sh-more-robust.patch
- patches.suse/perf-test-Remove-atomics-from-test_loop-to-avoid-test-failures.patch
- patches.suse/perf-test-record-probe_libc_inet_pton-Fix-call-chain-match-on-powerpc.patch
- patches.suse/perf-test-record-user-regs-Fix-mask-for-vg-register.patch
- patches.suse/perf-test-shell-arm_coresight-Increase-buffer-size-for-Coresight-basic-tests.patch
- patches.suse/perf-tests-Apply-attributes-to-all-events-in-object-code-reading-test.patch
- patches.suse/perf-tests-Make-data-symbol-test-wait-for-perf-to-start.patch
- patches.suse/perf-tests-Make-test-data-symbol-more-robust-on-Neoverse-N1.patch
- patches.suse/perf-tests-Skip-data-symbol-test-if-buf1-symbol-is-missing.patch
- patches.suse/perf-tests-Skip-pipe-test-if-noploop-symbol-is-missing.patch
- patches.suse/perf-tests-lib-Add-perf_has_symbol.sh.patch
- patches.suse/perf-thread-Fixes-to-thread__new-related-to-initializing-comm.patch
- patches.suse/perf-thread_map-Free-strlist-on-normal-path-in-thread_map__new_by_tid_str.patch
- patches.suse/perf-tool-fix-dereferencing-NULL-al-maps.patch
- patches.suse/perf-tools-Add-branch-counter-knob.patch
- patches.suse/perf-tools-Add-get_unaligned_leNN.patch
- patches.suse/perf-tools-Add-use-PMU-reverse-lookup-from-config-to-name.patch
- patches.suse/perf-tools-Use-pmus-to-describe-type-from-attribute.patch
- patches.suse/perf-top-Convert-to-the-global-annotation_options.patch
- patches.suse/perf-top-Uniform-the-event-name-for-the-hybrid-machine.patch
- patches.suse/perf-top-Use-evsel-s-cpus-to-replace-user_requested_cpus.patch
- patches.suse/perf-ui-browser-Avoid-SEGV-on-title.patch
- patches.suse/perf-ui-browser-Don-t-save-pointer-to-stack-memory.patch
- patches.suse/perf-unwind-libdw-Handle-JIT-generated-DSOs-properly.patch
- patches.suse/perf-unwind-libunwind-Fix-base-address-for-.eh_frame.patch
- patches.suse/perf-vendor-events-Remove-UTF-8-characters-from-cmn.json.patch
- patches.suse/perf-vendor-events-amd-Add-Zen-4-memory-controller-events.patch
- patches.suse/perf-vendor-events-amd-Fix-Zen-4-cache-latency-events.patch
- patches.suse/perf-vendor-events-arm64-AmpereOne-Rename-BPU_FLUSH_MEM_FAULT-to-GPC_FLUSH_MEM_FAULT.patch
- patches.suse/perf-vendor-events-powerpc-Add-PVN-for-HX-C2000-CPU-with-Power8-Architecture.patch
- patches.suse/perf-vendor-events-powerpc-Update-datasource-event-name-to-fix-duplicate-events.patch
- patches.suse/tools-perf-Fix-perf-bench-epoll-to-enable-the-run-when-some-CPU-s-are-offline.patch
- patches.suse/tools-perf-Fix-perf-bench-futex-to-enable-the-run-when-some-CPU-s-are-offline.patch
- patches.suse/tools-perf-Fix-timing-issue-with-parallel-threads-in-perf-bench-wake-up-parallel.patch
- commit b604c15
* Sun Oct  6 2024 tonyj@suse.de
- sync tools/ headers with kernel source (local changes).
- commit 870bc16
* Sun Oct  6 2024 tonyj@suse.de
- Correct perf header check errors for arm64/include/asm/cputype.h
  refresh: patches.suse/tools-headers-Update-tools-s-copy-of-arm64-asm-headers.patch.
- commit 9bba5fa
* Sat Oct  5 2024 tonyj@suse.de
- Fix perf header check differences for cpufeatures.h and msr-index.h
  refresh: patches.suse/tools-headers-Update-tools-s-copy-of-x86-asm-headers.patch.
  refresh: patches.suse/tools-headers-x86-cpufeatures-Sync-with-the-kernel-sources-to-pick-TDX-Zen-APIC-MSR-fence-changes.patch.
- commit 1cdf328
* Sat Oct  5 2024 tonyj@suse.de
- tools/include: Sync x86 headers with the kernel sources
  (perf-sp7-v6.11-userspace-update).
- commit 7f639c8
* Sat Oct  5 2024 tonyj@suse.de
- tools headers x86 cpufeatures: Sync with the kernel sources to
  pick BHI mitigation changes (perf-sp7-v6.11-userspace-update).
- commit 65ac148
* Sat Oct  5 2024 tonyj@suse.de
- tools arch x86: Sync the msr-index.h copy with the kernel
  sources (perf-sp7-v6.11-userspace-update).
- commit 9ba6c7e
* Sat Oct  5 2024 tonyj@suse.de
- tools/include: Sync x86 asm/msr-index.h with the kernel sources
  (perf-sp7-v6.11-userspace-update).
- commit 86d2c44
* Sat Oct  5 2024 tonyj@suse.de
- tools/include: Sync x86 CPU feature headers with the kernel
  sources (perf-sp7-v6.11-userspace-update).
- Refresh patches.suse/kabi-reserve-cpuid-leaves.patch.
- commit 0202360
* Sat Oct  5 2024 tonyj@suse.de
- Update
  patches.suse/tools-headers-Update-tools-s-copy-of-arm64-asm-headers.patch
  to correct perf header differences check for cputype.h
- commit 19cbf90
* Sat Oct  5 2024 tonyj@suse.de
- Update
  patches.suse/perf-beauty-Update-copy-of-linux-socket.h-with-the-k.patch
  to correct perf header differences check for socket.h
- commit 96e7f75
* Sat Oct  5 2024 tonyj@suse.de
- tools/include: Sync uapi/linux/kvm.h with the kernel sources
  (perf-sp7-v6.11-userspace-update).
- commit 8179761
* Sat Oct  5 2024 tonyj@suse.de
- perf tools headers: update the asm-generic/unaligned.h copy
  with the kernel sources (perf-sp7-v6.11-userspace-update).
- commit d7f9038
* Sat Oct  5 2024 tonyj@suse.de
- Refresh
  patches.suse/perf-vendor-events-arm64-AmpereOneX-Add-core-PMU-events-and-metrics.patch
  to have correct exportpatch format and update References (jsc#PED-7859, perf-sp7-v6.11-userspace-update).
- commit ea83ec0
* Sat Oct  5 2024 tonyj@suse.de
- Switch to full upstream patch due to perf-sp7-v6.11-userspace-update.
  Update
  patches.suse/perf-arch-events-Fix-duplicate-RISC-V-SBI-firmware-event-name.patch
  (git-fixes, perf-sp7-v6.11-userspace-update).
- commit 916bf9a
* Sat Oct  5 2024 tonyj@suse.de
- perf script: Minimize "not reaching sample" for '-F
  +brstackinsn' (jsc#PED-10406).
- commit d396e21
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Move PM_BR_MPRED_CMPL event for power10
  platform (jsc#PED-9888).
- commit 94b831e
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events power10: Move the JSON/events (jsc#PED-9888).
- commit 4a539d7
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events power10: Update JSON/events (jsc#PED-9888).
- commit 0c3fa17
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events power10: Update JSON/events (jsc#PED-9888).
- commit bc2cd95
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Set instruction name to be used with insn-stat
  when using raw instruction (jsc#PED-9879).
- commit 72e9426
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add support to use libcapstone in powerpc
  (jsc#PED-9879).
- commit 39605ac
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Use capstone_init and remove open_capstone_handle
  from disasm.c (jsc#PED-9879).
- commit 625a788
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Make capstone_init non-static so that it can
  be used during symbol disassemble (jsc#PED-9879).
- commit b269ae0
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Update instruction tracking for powerpc
  (jsc#PED-9879).
- commit 278a31a
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add more instructions for instruction tracking
  (jsc#PED-9879).
- commit 272ffea
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add some of the arithmetic instructions to
  support instruction tracking in powerpc (jsc#PED-9879).
- commit a6a15cb
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add support to identify memory instructions of
  opcode 31 in powerpc (jsc#PED-9879).
- commit 7871bde
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add parse function for memory instructions in
  powerpc (jsc#PED-9879).
- commit e8a2994
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Update parameters for reg extract functions to
  use raw instruction on powerpc (jsc#PED-9879).
- commit 8de5429
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add support to capture and parse raw instruction
  in powerpc using dso__data_read_offset utility (jsc#PED-9879).
- commit bcc731c
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add disasm_line__parse() to parse raw instruction
  for powerpc (jsc#PED-9879).
- commit b088955
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Update TYPE_STATE_MAX_REGS to include max of
  regs in powerpc (jsc#PED-9879).
- commit 59ac334
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add "update_insn_state" callback function to
  handle arch specific instruction tracking (jsc#PED-9879).
- commit 08b19f0
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Move the data structures related to register
  type to header file (jsc#PED-9879).
- commit 0c08dfc
* Sat Oct  5 2024 tonyj@suse.de
- perf daemon: Fix the build on more 32-bit architectures
  (perf-sp7-v6.11-userspace-update).
- commit a51d61d
* Sat Oct  5 2024 tonyj@suse.de
- perf python: include "util/sample.h"
  (perf-sp7-v6.11-userspace-update).
- commit a42747c
* Sat Oct  5 2024 tonyj@suse.de
- perf lock contention: Fix spinlock and rwlock accounting
  (perf-sp7-v6.11-userspace-update).
- commit da1c71c
* Sat Oct  5 2024 tonyj@suse.de
- perf test pmu: Set uninitialized PMU alias to null
  (perf-sp7-v6.11-userspace-update).
- commit 1bee504
* Sat Oct  5 2024 tonyj@suse.de
- perf daemon: Fix the build on 32-bit architectures
  (perf-sp7-v6.11-userspace-update).
- commit 3fd8596
* Sat Oct  5 2024 tonyj@suse.de
- tools/include: Sync arm64 headers with the kernel sources
  (perf-sp7-v6.11-userspace-update).
- commit 4cf3123
* Sat Oct  5 2024 tonyj@suse.de
- tools/include: Sync uapi/asm-generic/unistd.h with the kernel
  sources (perf-sp7-v6.11-userspace-update).
- commit abfb6c5
* Sat Oct  5 2024 tonyj@suse.de
- tools/include: Sync uapi/sound/asound.h with the kernel sources
  (perf-sp7-v6.11-userspace-update).
- commit d63b66e
* Sat Oct  5 2024 tonyj@suse.de
- perf docs: Document cross compilation
  (perf-sp7-v6.11-userspace-update).
- commit 80f43bb
* Sat Oct  5 2024 tonyj@suse.de
- perf: build: Link lib 'zstd' for static build
  (perf-sp7-v6.11-userspace-update).
- commit 6e14c65
* Sat Oct  5 2024 tonyj@suse.de
- perf: build: Only link libebl.a for old libdw
  (perf-sp7-v6.11-userspace-update).
- commit 7cf8849
* Sat Oct  5 2024 tonyj@suse.de
- perf: build: Set Python configuration for cross compilation
  (perf-sp7-v6.11-userspace-update).
- commit a500364
* Sat Oct  5 2024 tonyj@suse.de
- perf: build: Setup PKG_CONFIG_LIBDIR for cross compilation
  (perf-sp7-v6.11-userspace-update).
- commit aac0143
* Sat Oct  5 2024 tonyj@suse.de
- perf dso: Fix build when libunwind is enabled
  (perf-sp7-v6.11-userspace-update).
- commit 3cd638c
* Sat Oct  5 2024 tonyj@suse.de
- tools: Make pkg-config dependency checks usable by other tools
  (perf-sp7-v6.11-userspace-update).
- commit ddcf80f
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Warn if libtracefs is not found
  (perf-sp7-v6.11-userspace-update).
- commit 35728a3
* Sat Oct  5 2024 tonyj@suse.de
- perf kvm: Add kvm-stat for loongarch64
  (perf-sp7-v6.11-userspace-update).
- commit a22cf57
* Sat Oct  5 2024 tonyj@suse.de
- perf kvm/riscv: Port perf kvm stat to RISC-V
  (perf-sp7-v6.11-userspace-update).
- commit 66796e9
* Sat Oct  5 2024 tonyj@suse.de
- perf trace: Fix iteration of syscall ids in syscalltbl->entries
  (perf-sp7-v6.11-userspace-update).
- commit 9ccbc11
* Sat Oct  5 2024 tonyj@suse.de
- perf dso: Fix address sanitizer build
  (perf-sp7-v6.11-userspace-update).
- commit eb45284
* Sat Oct  5 2024 tonyj@suse.de
- perf mem: Warn if memory events are not supported on all CPUs
  (perf-sp7-v6.11-userspace-update).
- commit 82eaeed
* Sat Oct  5 2024 tonyj@suse.de
- perf arm-spe: Support multiple Arm SPE PMUs
  (perf-sp7-v6.11-userspace-update).
- commit 3eddcac
* Sat Oct  5 2024 tonyj@suse.de
- perf build x86: Fix SC2034 error in syscalltbl.sh
  (perf-sp7-v6.11-userspace-update).
- commit d7577e3
* Sat Oct  5 2024 tonyj@suse.de
- perf record: Fix memset out-of-range error
  (perf-sp7-v6.11-userspace-update).
- commit 6c5415e
* Sat Oct  5 2024 tonyj@suse.de
- perf sched map: Add --fuzzy-name option for fuzzy matching in
  task names (perf-sp7-v6.11-userspace-update).
- commit c68043b
* Sat Oct  5 2024 tonyj@suse.de
- perf sched map: Add support for multiple task names using CSV
  (perf-sp7-v6.11-userspace-update).
- commit 4a7392b
* Sat Oct  5 2024 tonyj@suse.de
- perf sched map: Add task-name option to filter the output map
  (perf-sp7-v6.11-userspace-update).
- commit 3c3b975
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Conditionally add feature check flags for
  libtrace{event,fs} (perf-sp7-v6.11-userspace-update).
- commit ff190dd
* Sat Oct  5 2024 tonyj@suse.de
- perf install: Don't propagate subdir to Documentation submake
  (perf-sp7-v6.11-userspace-update).
- commit eeaa2ef
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events arm64:: Add i.MX95 DDR Performance Monitor
  metrics (perf-sp7-v6.11-userspace-update).
- commit 11c8320
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events arm64:: Add i.MX93 DDR Performance Monitor
  metrics (perf-sp7-v6.11-userspace-update).
- commit ed2974f
* Sat Oct  5 2024 tonyj@suse.de
- perf dsos: When adding a dso into sorted dsos maintain the
  sort order (perf-sp7-v6.11-userspace-update).
- commit debeae8
* Sat Oct  5 2024 tonyj@suse.de
- perf comm str: Avoid sort during insert
  (perf-sp7-v6.11-userspace-update).
- commit f4de814
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Calling available function for stats printing
  (perf-sp7-v6.11-userspace-update).
- commit df06434
* Sat Oct  5 2024 tonyj@suse.de
- perf sched replay: Fix -r/--repeat command line option for
  infinity (perf-sp7-v6.11-userspace-update).
- commit 867e9ca
* Sat Oct  5 2024 tonyj@suse.de
- perf: pmus: Remove unneeded semicolon
  (perf-sp7-v6.11-userspace-update).
- commit 64ede66
* Sat Oct  5 2024 tonyj@suse.de
- perf stat: Use field separator in the metric header
  (perf-sp7-v6.11-userspace-update).
- commit ab1a48b
* Sat Oct  5 2024 tonyj@suse.de
- perf stat: Fix a segfault with --per-cluster --metric-only
  (perf-sp7-v6.11-userspace-update).
- commit 4c83a0e
* Sat Oct  5 2024 tonyj@suse.de
- perf pmu: Don't de-duplicate core PMUs
  (perf-sp7-v6.11-userspace-update).
- commit 0330246
* Sat Oct  5 2024 tonyj@suse.de
- perf pmu: Restore full PMU name wildcard support
  (perf-sp7-v6.11-userspace-update).
- commit 6e69aa9
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Display pregress bar on redirected pipe data
  (perf-sp7-v6.11-userspace-update).
- commit 4f04df7
* Sat Oct  5 2024 tonyj@suse.de
- perf test stat_bpf_counter.sh: Stabilize the test results
  (perf-sp7-v6.11-userspace-update).
- commit 19ea9a1
* Sat Oct  5 2024 tonyj@suse.de
- perf python: Clean up build dependencies
  (perf-sp7-v6.11-userspace-update).
- commit ff42415
* Sat Oct  5 2024 tonyj@suse.de
- perf python: Switch module to linking libraries from building
  source (perf-sp7-v6.11-userspace-update).
- commit 9a720ce
* Sat Oct  5 2024 tonyj@suse.de
- perf util: Make util its own library
  (perf-sp7-v6.11-userspace-update).
- commit 3c9194c
* Sat Oct  5 2024 tonyj@suse.de
- perf bench: Make bench its own library
  (perf-sp7-v6.11-userspace-update).
- commit 1e6fd2e
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Make tests its own library
  (perf-sp7-v6.11-userspace-update).
- commit 84c48d7
* Sat Oct  5 2024 tonyj@suse.de
- perf pmu-events: Make pmu-events a library
  (perf-sp7-v6.11-userspace-update).
- commit 74f1146
* Sat Oct  5 2024 tonyj@suse.de
- perf ui: Make ui its own library
  (perf-sp7-v6.11-userspace-update).
- commit 25b57fc
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Add '*.a' to clean targets
  (perf-sp7-v6.11-userspace-update).
- commit 1e8a562
* Sat Oct  5 2024 tonyj@suse.de
- perf mem: Fix a segfault with NULL event->name
  (perf-sp7-v6.11-userspace-update).
- commit dc0b170
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Fix a compiler warning of NULL pointer
  (perf-sp7-v6.11-userspace-update).
- commit 9b15e08
* Sat Oct  5 2024 tonyj@suse.de
- perf symbol: Simplify kernel module checking
  (perf-sp7-v6.11-userspace-update).
- commit 6360752
* Sat Oct  5 2024 tonyj@suse.de
- perf unwind-libunwind: Add malloc() failure handling
  (perf-sp7-v6.11-userspace-update).
- commit 005c72c
* Sat Oct  5 2024 tonyj@suse.de
- util: constant -1 with expression of type char
  (perf-sp7-v6.11-userspace-update).
- commit 982ec89
* Sat Oct  5 2024 tonyj@suse.de
- perf: Timehist account sch delay for scheduled out running
  (perf-sp7-v6.11-userspace-update).
- commit bb15663
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Add APX and other new instructions to x86
  instruction decoder test (perf-sp7-v6.11-userspace-update).
- commit 2cf0938
* Sat Oct  5 2024 tonyj@suse.de
- perf intel pt: Add new JMPABS instruction to the Intel PT
  instruction decoder (perf-sp7-v6.11-userspace-update).
- commit 03c2e32
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Check output of the probe ... --funcs command
  (perf-sp7-v6.11-userspace-update).
- commit 1fc9eff
* Sat Oct  5 2024 tonyj@suse.de
- tools/perf: Fix parallel-perf python script to replace new
  python syntax ":=" usage (perf-sp7-v6.11-userspace-update).
- commit b54e8fb
* Sat Oct  5 2024 tonyj@suse.de
- tools/perf: Use is_perf_pid_map_name helper
  function to check dso's of pattern /tmp/perf-%%d.map
  (perf-sp7-v6.11-userspace-update).
- commit 05cb321
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Ensure libtraceevent and libtracefs versions have
  3 components (perf-sp7-v6.11-userspace-update).
- commit 91ce9c8
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Use pkg-config for feature check for
  libtrace{event,fs} (perf-sp7-v6.11-userspace-update).
- commit d5a28a3
* Sat Oct  5 2024 tonyj@suse.de
- perf arm: Workaround ARM PMUs cpu maps having offline cpus
  (perf-sp7-v6.11-userspace-update).
- commit ce9ed77
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add westmereex counter information
  (perf-sp7-v6.11-userspace-update).
- commit 609f242
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add westmereep-sp counter information
  (perf-sp7-v6.11-userspace-update).
- commit e0762c6
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add westmereep-dp counter information
  (perf-sp7-v6.11-userspace-update).
- commit 6184605
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add/update tigerlake events/metrics
  (perf-sp7-v6.11-userspace-update).
- commit 30ff9f6
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add snowridgex counter information
  (perf-sp7-v6.11-userspace-update).
- commit c5728e0
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add/update skylakex events/metrics
  (perf-sp7-v6.11-userspace-update).
- commit 7d2153d
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add/update skylake events/metrics
  (perf-sp7-v6.11-userspace-update).
- commit 26f6d4b
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add silvermont counter information
  (perf-sp7-v6.11-userspace-update).
- commit ee9df2d
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add/update sierraforest events/metrics
  (perf-sp7-v6.11-userspace-update).
- commit df6374d
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add/update sapphirerapids events/metrics
  (perf-sp7-v6.11-userspace-update).
- commit d3a8c6b
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update sandybridge metrics add event
  counter information (perf-sp7-v6.11-userspace-update).
- commit 97860cf
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add/update rocketlake events/metrics
  (perf-sp7-v6.11-userspace-update).
- commit e0fe1a1
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add nehalemex counter information
  (perf-sp7-v6.11-userspace-update).
- commit 11cfc52
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add nehalemep counter information
  (perf-sp7-v6.11-userspace-update).
- commit 9486f14
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update meteorlake events and add counter
  information (perf-sp7-v6.11-userspace-update).
- commit 5638683
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add lunarlake counter information
  (perf-sp7-v6.11-userspace-update).
- commit 47e2571
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add knightslanding counter information
  (perf-sp7-v6.11-userspace-update).
- commit 106648c
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update jaketown metrics add event counter
  information (perf-sp7-v6.11-userspace-update).
- commit 87d6e75
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update ivytown metrics add event counter
  information (perf-sp7-v6.11-userspace-update).
- commit 0ce21cd
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update ivybridge metrics add event counter
  information (perf-sp7-v6.11-userspace-update).
- commit 945185b
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add/update icelakex events/metrics
  (perf-sp7-v6.11-userspace-update).
- commit 293e22d
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add/update icelake events/metrics
  (perf-sp7-v6.11-userspace-update).
- commit 23049d3
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update haswellx metrics add event counter
  information (perf-sp7-v6.11-userspace-update).
- commit 279b041
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add haswell counter information
  (perf-sp7-v6.11-userspace-update).
- commit 7566f68
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update graniterapids events and add counter
  information (perf-sp7-v6.11-userspace-update).
- commit 1bcf6d5
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update/add grandridge events/metrics
  (perf-sp7-v6.11-userspace-update).
- commit 8e0d675
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add goldmontplus counter information
  (perf-sp7-v6.11-userspace-update).
- commit deaa285
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add goldmont counter information
  (perf-sp7-v6.11-userspace-update).
- commit a4306f4
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add/update emeraldrapids events/metrics
  (perf-sp7-v6.11-userspace-update).
- commit 5c817f5
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update elkhartlake events
  (perf-sp7-v6.11-userspace-update).
- commit 884932b
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update cascadelakex events/metrics
  (perf-sp7-v6.11-userspace-update).
- commit d54532f
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update broadwellx metrics add event counter
  information (perf-sp7-v6.11-userspace-update).
- commit 984d85f
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update broadwellde metrics add event
  counter information (perf-sp7-v6.11-userspace-update).
- commit 6aca814
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update broadwell metrics add event counter
  information (perf-sp7-v6.11-userspace-update).
- commit 1b354c4
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add bonnell counter information
  (perf-sp7-v6.11-userspace-update).
- commit 36b44e0
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update alderlaken events/metrics
  (perf-sp7-v6.11-userspace-update).
- commit 4556e6f
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Update alderlake events/metrics
  (perf-sp7-v6.11-userspace-update).
- commit 405f652
* Sat Oct  5 2024 tonyj@suse.de
- perf doc: Add AMD IBS usage document
  (perf-sp7-v6.11-userspace-update).
- commit 661058f
* Sat Oct  5 2024 tonyj@suse.de
- tools/perf: Handle perftool-testsuite_probe
  testcases fail when kernel debuginfo is not present
  (perf-sp7-v6.11-userspace-update).
- commit 2a27729
* Sat Oct  5 2024 tonyj@suse.de
- perf hist: Honor symbol_conf.skip_empty
  (perf-sp7-v6.11-userspace-update).
- commit fd579b2
* Sat Oct  5 2024 tonyj@suse.de
- perf hist: Add symbol_conf.skip_empty
  (perf-sp7-v6.11-userspace-update).
- commit a4f05e5
* Sat Oct  5 2024 tonyj@suse.de
- perf hist: Simplify __hpp_fmt() using hpp_fmt_data
  (perf-sp7-v6.11-userspace-update).
- commit a603d8d
* Sat Oct  5 2024 tonyj@suse.de
- perf hist: Factor out __hpp__fmt_print()
  (perf-sp7-v6.11-userspace-update).
- commit db61d4f
* Sat Oct  5 2024 tonyj@suse.de
- perf: sched map skips redundant lines with cpu filters
  (perf-sp7-v6.11-userspace-update).
- commit f0221f3
* Sat Oct  5 2024 tonyj@suse.de
- perf test pmu: Warn don't fail for legacy mixed case event names
  (perf-sp7-v6.11-userspace-update).
- commit 19306d7
* Sat Oct  5 2024 tonyj@suse.de
- perf record: Ensure space for lost samples
  (perf-sp7-v6.11-userspace-update).
- commit b107d3d
* Sat Oct  5 2024 tonyj@suse.de
- perf evsel: Refactor tool events
  (perf-sp7-v6.11-userspace-update).
- commit 0182d6f
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Speed up test case 70 annotate basic tests
  (perf-sp7-v6.11-userspace-update).
- commit d802399
* Sat Oct  5 2024 tonyj@suse.de
- perf stat: Choose the most disaggregate command line option
  (perf-sp7-v6.11-userspace-update).
- commit 67fd3d0
* Sat Oct  5 2024 tonyj@suse.de
- perf stat: Make options local (perf-sp7-v6.11-userspace-update).
- commit 83f265a
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Add/use a sorted insert for fixup overlap and insert
  (perf-sp7-v6.11-userspace-update).
- commit c02e56b
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Reduce sorting for overlapping mappings
  (perf-sp7-v6.11-userspace-update).
- commit bc684c7
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Fix use after free in
  __maps__fixup_overlap_and_insert
  (perf-sp7-v6.11-userspace-update).
- commit e3d7055
* Sat Oct  5 2024 tonyj@suse.de
- perf script: netdev-times: add location parameter to consume_skb
  (perf-sp7-v6.11-userspace-update).
- commit 57c0c14
* Sat Oct  5 2024 tonyj@suse.de
- perf: parse-events: Fix compilation error while defining
  DEBUG_PARSER (perf-sp7-v6.11-userspace-update).
- commit 7b52e9f
* Sat Oct  5 2024 tonyj@suse.de
- perf hisi-ptt: remove unused struct 'hisi_ptt_queue'
  (perf-sp7-v6.11-userspace-update).
- commit 728d804
* Sat Oct  5 2024 tonyj@suse.de
- perf genelf: remove unused struct 'options'
  (perf-sp7-v6.11-userspace-update).
- commit d5791f6
* Sat Oct  5 2024 tonyj@suse.de
- perf lock info: Display both map and thread by default
  (perf-sp7-v6.11-userspace-update).
- commit 8320927
* Sat Oct  5 2024 tonyj@suse.de
- perf top: Allow filters on events
  (perf-sp7-v6.11-userspace-update).
- commit b473bc7
* Sat Oct  5 2024 tonyj@suse.de
- perf bpf filter: Add uid and gid terms
  (perf-sp7-v6.11-userspace-update).
- commit 0b3af20
* Sat Oct  5 2024 tonyj@suse.de
- perf bpf filter: Give terms their own enum
  (perf-sp7-v6.11-userspace-update).
- commit 702addc
* Sat Oct  5 2024 tonyj@suse.de
- perf trace beauty: Always show mmap prot even though PROT_NONE
  (perf-sp7-v6.11-userspace-update).
- commit 5becc3c
* Sat Oct  5 2024 tonyj@suse.de
- perf trace beauty: Always show param if show_zero is set
  (perf-sp7-v6.11-userspace-update).
- commit ac851a8
* Sat Oct  5 2024 tonyj@suse.de
- perf docs: Fix typos (perf-sp7-v6.11-userspace-update).
- commit 66991e8
* Sat Oct  5 2024 tonyj@suse.de
- perf list: Fix the --no-desc option
  (perf-sp7-v6.11-userspace-update).
- commit 3092c77
* Sat Oct  5 2024 tonyj@suse.de
- perf arm-spe: Unaligned pointer work around
  (perf-sp7-v6.11-userspace-update).
- commit ab9562a
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Add some pmu core functionality tests
  (perf-sp7-v6.11-userspace-update).
- commit af6100e
* Sat Oct  5 2024 tonyj@suse.de
- perf pmus: Sort/merge/aggregate PMUs like mrvl_ddr_pmu
  (perf-sp7-v6.11-userspace-update).
- commit 5eccd4b
* Sat Oct  5 2024 tonyj@suse.de
- perf bpf: Fix handling of minimal vmlinux.h file when
  interrupting the build (perf-sp7-v6.11-userspace-update).
- commit 23cd469
* Sat Oct  5 2024 tonyj@suse.de
- Revert "perf record: Reduce memory for
  recording PERF_RECORD_LOST_SAMPLES event"
  (perf-sp7-v6.11-userspace-update).
- commit 1bd9321
* Sat Oct  5 2024 tonyj@suse.de
- tools headers arm64: Sync arm64's cputype.h with the kernel
  sources (perf-sp7-v6.11-userspace-update).
- commit 868b481
* Sat Oct  5 2024 tonyj@suse.de
- Revert "perf parse-events: Prefer sysfs/JSON hardware events
  over legacy" (perf-sp7-v6.11-userspace-update).
- commit 11b570b
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Ensure the number of type histograms
  (perf-sp7-v6.11-userspace-update).
- commit 7c02ee9
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Fix segfault on sample histogram
  (perf-sp7-v6.11-userspace-update).
- commit f2f6a15
* Sat Oct  5 2024 tonyj@suse.de
- perf lock: Avoid memory leaks from strdup()
  (perf-sp7-v6.11-userspace-update).
- commit c204300
* Sat Oct  5 2024 tonyj@suse.de
- perf sched: Rename 'switches' column header to
  'count' and add usage description, options for latency
  (perf-sp7-v6.11-userspace-update).
- commit 44bf0a0
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Ignore deleted cgroups
  (perf-sp7-v6.11-userspace-update).
- commit 87b1df4
* Sat Oct  5 2024 tonyj@suse.de
- perf parse: Allow tracepoint names to start with digits
  (perf-sp7-v6.11-userspace-update).
- commit 0372854
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Add new 'fake_tp' parameter for tests
  (perf-sp7-v6.11-userspace-update).
- commit 0e84163
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: pass parse_state to add_tracepoint
  (perf-sp7-v6.11-userspace-update).
- commit 78670af
* Sat Oct  5 2024 tonyj@suse.de
- perf symbols: Update kcore map before merging in remaining
  symbols (perf-sp7-v6.11-userspace-update).
- commit 305257e
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Re-use __maps__free_maps_by_name()
  (perf-sp7-v6.11-userspace-update).
- commit 237e581
* Sat Oct  5 2024 tonyj@suse.de
- perf symbols: Remove map from list before updating addresses
  (perf-sp7-v6.11-userspace-update).
- commit 232bd4d
* Sat Oct  5 2024 tonyj@suse.de
- perf tracepoint: Don't scan all tracepoints to test if one
  exists (perf-sp7-v6.11-userspace-update).
- commit d3ce571
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Fix build with HAVE_DWARF_CFI_SUPPORT
  (perf-sp7-v6.11-userspace-update).
- commit 4d6d72d
* Sat Oct  5 2024 tonyj@suse.de
- perf comm: Fix comm_str__put() for reference count checking
  (perf-sp7-v6.11-userspace-update).
- commit 272fe59
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Print array type name with ""
  (perf-sp7-v6.11-userspace-update).
- commit dcd9b22
* Sat Oct  5 2024 tonyj@suse.de
- perf hist: Avoid 'struct hist_entry_iter' mem_info memory leak
  (perf-sp7-v6.11-userspace-update).
- commit 8d9334a
* Sat Oct  5 2024 tonyj@suse.de
- perf mem-info: Add reference count checking
  (perf-sp7-v6.11-userspace-update).
- commit c54a516
* Sat Oct  5 2024 tonyj@suse.de
- perf mem-info: Move mem-info out of mem-events and symbol
  (perf-sp7-v6.11-userspace-update).
- commit 7c56c6d
* Sat Oct  5 2024 tonyj@suse.de
- perf comm: Add reference count checking to 'struct comm_str'
  (perf-sp7-v6.11-userspace-update).
- commit f2b6a1b
* Sat Oct  5 2024 tonyj@suse.de
- perf cpumap: Remove refcnt from 'struct cpu_aggr_map'
  (perf-sp7-v6.11-userspace-update).
- commit 653df4f
* Sat Oct  5 2024 tonyj@suse.de
- perf block-info: Remove unused refcount
  (perf-sp7-v6.11-userspace-update).
- commit 7d90765
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Fix memory leak in annotated_source
  (perf-sp7-v6.11-userspace-update).
- commit dd8398f
* Sat Oct  5 2024 tonyj@suse.de
- perf probe: Use zfree() to avoid possibly accessing dangling
  pointers (perf-sp7-v6.11-userspace-update).
- commit 2551e03
* Sat Oct  5 2024 tonyj@suse.de
- perf auxtrace: Allow number of queues to be specified
  (perf-sp7-v6.11-userspace-update).
- commit a1c1f23
* Sat Oct  5 2024 tonyj@suse.de
- perf cs-etm: Print error for new PERF_RECORD_AUX_OUTPUT_HW_ID
  versions (perf-sp7-v6.11-userspace-update).
- commit e5fed3d
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Fix a comment about multi_regs in
  extract_reg_offset function (perf-sp7-v6.11-userspace-update).
- commit bcc1cbd
* Sat Oct  5 2024 tonyj@suse.de
- perf kwork: Use zfree() to avoid possibly accessing dangling
  pointers (perf-sp7-v6.11-userspace-update).
- commit db5c021
* Sat Oct  5 2024 tonyj@suse.de
- perf callchain: Use zfree() to avoid possibly accessing dangling
  pointers (perf-sp7-v6.11-userspace-update).
- commit 07870b4
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Use zfree() to avoid possibly accessing dangling
  pointers (perf-sp7-v6.11-userspace-update).
- commit e470772
* Sat Oct  5 2024 tonyj@suse.de
- perf dso: Use container_of() to avoid a pointer in 'struct
  dso_data' (perf-sp7-v6.11-userspace-update).
- commit 8ffb0c5
* Sat Oct  5 2024 tonyj@suse.de
- perf symbol-elf: dso__load_sym_internal() reference count fixes
  (perf-sp7-v6.11-userspace-update).
- commit 22b0ac3
* Sat Oct  5 2024 tonyj@suse.de
- perf symbol-elf: Ensure dso__put()
  in machine__process_ksymbol_register()
  (perf-sp7-v6.11-userspace-update).
- commit 366d061
* Sat Oct  5 2024 tonyj@suse.de
- perf map: Add missing dso__put() in map__new()
  (perf-sp7-v6.11-userspace-update).
- commit a855634
* Sat Oct  5 2024 tonyj@suse.de
- perf dso: Add reference count checking and accessor functions
  (perf-sp7-v6.11-userspace-update).
- Refresh
  patches.suse/tools-perf-Fix-the-string-match-for-tmp-perf-PID.map-files-in-dso__load.patch.
- commit 61f87f1
* Sat Oct  5 2024 tonyj@suse.de
- perf dsos: Switch hand crafted code to bsearch()
  (perf-sp7-v6.11-userspace-update).
- commit b72e7dc
* Sat Oct  5 2024 tonyj@suse.de
- perf dsos: Remove __dsos__findnew_link_by_longname_id()
  (perf-sp7-v6.11-userspace-update).
- commit 214e528
* Sat Oct  5 2024 tonyj@suse.de
- perf dsos: Remove __dsos__addnew()
  (perf-sp7-v6.11-userspace-update).
- commit ffd8881
* Sat Oct  5 2024 tonyj@suse.de
- perf dsos: Switch backing storage to array from rbtree/list
  (perf-sp7-v6.11-userspace-update).
- commit 23884e7
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events amd: Add Zen 5 mapping
  (perf-sp7-v6.11-userspace-update).
- commit 4a9347c
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events amd: Add Zen 5 metrics
  (perf-sp7-v6.11-userspace-update).
- commit c8b3a82
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events amd: Add Zen 5 uncore events
  (perf-sp7-v6.11-userspace-update).
- commit eda5a8a
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events amd: Add Zen 5 core events
  (perf-sp7-v6.11-userspace-update).
- commit dafc909
* Sat Oct  5 2024 tonyj@suse.de
- perf trace: Disable syscall augmentation with record
  (perf-sp7-v6.11-userspace-update).
- commit 79f3f27
* Sat Oct  5 2024 tonyj@suse.de
- perf test pmu: Test all sysfs PMU event names are the same case
  (perf-sp7-v6.11-userspace-update).
- commit 691d5a4
* Sat Oct  5 2024 tonyj@suse.de
- perf test pmu: Add an eagerly loaded event test
  (perf-sp7-v6.11-userspace-update).
- commit 62c95bf
* Sat Oct  5 2024 tonyj@suse.de
- perf test pmu: Refactor format test and exposed test APIs
  (perf-sp7-v6.11-userspace-update).
- commit 5d27a82
* Sat Oct  5 2024 tonyj@suse.de
- perf test pmu-events: Make it clearer that pmu-events tests
  JSON events (perf-sp7-v6.11-userspace-update).
- commit e5bc240
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Remove check_invariants() from maps__lock()
  (perf-sp7-v6.11-userspace-update).
- commit 1dc7793
* Sat Oct  5 2024 tonyj@suse.de
- perf cs-etm: Improve version detection and error reporting
  (perf-sp7-v6.11-userspace-update).
- commit 7cade0a
* Sat Oct  5 2024 tonyj@suse.de
- perf cs-etm: Remove repeated fetches of the ETM PMU
  (perf-sp7-v6.11-userspace-update).
- commit 273d30d
* Sat Oct  5 2024 tonyj@suse.de
- perf cs-etm: Use struct perf_cpu as much as possible
  (perf-sp7-v6.11-userspace-update).
- commit d62688c
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Check kind of stack variables
  (perf-sp7-v6.11-userspace-update).
- commit ee6c6fd
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Handle multi regs in find_data_type_block()
  (perf-sp7-v6.11-userspace-update).
- commit 1d4b346
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Check memory access with two registers
  (perf-sp7-v6.11-userspace-update).
- commit 83b67d5
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Handle direct global variable access
  (perf-sp7-v6.11-userspace-update).
- commit 540729d
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Collect global variables in advance
  (perf-sp7-v6.11-userspace-update).
- commit f6fb97c
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Add die_collect_global_vars()
  (perf-sp7-v6.11-userspace-update).
- commit b02f57a
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Reintroduce -p/--parallel and make -S/--sequential
  the default (perf-sp7-v6.11-userspace-update).
- commit 63c6ac1
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Fix data type profiling on stdio
  (perf-sp7-v6.11-userspace-update).
- commit 619a8ba
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Pretend scandirat is missing with msan
  (perf-sp7-v6.11-userspace-update).
- commit d717574
* Sat Oct  5 2024 tonyj@suse.de
- perf record: Fix comment misspellings
  (perf-sp7-v6.11-userspace-update).
- commit ff8b62e
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Update DSO binary type when trying build-id
  (perf-sp7-v6.11-userspace-update).
- commit 0ef34ca
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Fallback disassemble to objdump when capstone
  fails (perf-sp7-v6.11-userspace-update).
- commit c48f784
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Check if 'struct
  annotation_source' was allocated on 'perf report' TUI
  (perf-sp7-v6.11-userspace-update).
- commit 4a37881
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Add a new test for 'perf annotate'
  (perf-sp7-v6.11-userspace-update).
- commit 34b00a6
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Tidy the setting of the default event name
  (perf-sp7-v6.11-userspace-update).
- commit b56a7ac
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Minor grouping tidy up
  (perf-sp7-v6.11-userspace-update).
- commit 851001c
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-event: Constify event_symbol arrays
  (perf-sp7-v6.11-userspace-update).
- commit dc4e5e2
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Improvements to modifier parsing
  (perf-sp7-v6.11-userspace-update).
- commit 51767a6
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Inline parse_events_evlist_error
  (perf-sp7-v6.11-userspace-update).
- commit a13e09c
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Improve error message for bad numbers
  (perf-sp7-v6.11-userspace-update).
- commit e4e2279
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Inline parse_events_update_lists
  (perf-sp7-v6.11-userspace-update).
- commit aa00f1b
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Prefer sysfs/JSON hardware events over legacy
  (perf-sp7-v6.11-userspace-update).
- commit a34cac8
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Constify parse_events_add_numeric
  (perf-sp7-v6.11-userspace-update).
- commit 5658557
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Handle PE_TERM_HW in name_or_raw
  (perf-sp7-v6.11-userspace-update).
- commit 3b70649
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Legacy cache names on all PMUs and lower
  priority (perf-sp7-v6.11-userspace-update).
- commit 7160903
* Sat Oct  5 2024 tonyj@suse.de
- perf tests parse-events: Use "branches" rather than
  "cache-references" (perf-sp7-v6.11-userspace-update).
- commit 0eadf07
* Sat Oct  5 2024 tonyj@suse.de
- perf pmu: Refactor perf_pmu__match()
  (perf-sp7-v6.11-userspace-update).
- commit ea94239
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Avoid copying an empty list
  (perf-sp7-v6.11-userspace-update).
- commit 044704c
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Directly pass PMU to parse_events_add_pmu()
  (perf-sp7-v6.11-userspace-update).
- commit 675b5dc
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Factor out '<event_or_pmu>/.../' parsing
  (perf-sp7-v6.11-userspace-update).
- commit ce7e49b
* Sat Oct  5 2024 tonyj@suse.de
- perf scripts python: Add a script to run instances of 'perf
  script' in parallel (perf-sp7-v6.11-userspace-update).
- commit 1e75c2c
* Sat Oct  5 2024 tonyj@suse.de
- perf tests shell kprobes: Add missing description as used by
  'perf test' output (perf-sp7-v6.11-userspace-update).
- commit 7fb9a3a
* Sat Oct  5 2024 tonyj@suse.de
- Revert "tools headers: Remove almost unused copy of uapi/stat.h,
  add few conditional defines" (perf-sp7-v6.11-userspace-update).
- commit 5df09e0
* Sat Oct  5 2024 tonyj@suse.de
- perf probe-event: Better error message for a too-long probe name
  (perf-sp7-v6.11-userspace-update).
- commit 15f35f8
* Sat Oct  5 2024 tonyj@suse.de
- perf probe-event: Un-hardcode sizeof(buf)
  (perf-sp7-v6.11-userspace-update).
- commit e9f19a0
* Sat Oct  5 2024 tonyj@suse.de
- perf stat: Add new field in stat_config to enable hardware
  aware grouping (perf-sp7-v6.11-userspace-update).
- commit 382ce78
* Sat Oct  5 2024 tonyj@suse.de
- perf genelf: Fix compiling with libelf on rv32
  (perf-sp7-v6.11-userspace-update).
- commit 769afc9
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events arm64: AmpereOne/AmpereOneX:
  Mark L1D_CACHE_INVAL impacted by errata
  (perf-sp7-v6.11-userspace-update).
- commit 7c9eb2c
* Sat Oct  5 2024 tonyj@suse.de
- perf test bpf-counters: Add test for BPF event modifier
  (perf-sp7-v6.11-userspace-update).
- commit b4a6149
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Enable configs required
  for test_uprobe_from_different_cu.sh
  (perf-sp7-v6.11-userspace-update).
- commit 5ca5e0e
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Add weight output fields
  (perf-sp7-v6.11-userspace-update).
- commit a9f2f76
* Sat Oct  5 2024 tonyj@suse.de
- perf hist: Add weight fields to hist entry stats
  (perf-sp7-v6.11-userspace-update).
- commit 01ab25f
* Sat Oct  5 2024 tonyj@suse.de
- perf hist: Move histogram related code to hist.h
  (perf-sp7-v6.11-userspace-update).
- commit 3a8a56a
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Handle RSP if it's not the FB register
  (perf-sp7-v6.11-userspace-update).
- commit c603bfc
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Check variable address range properly
  (perf-sp7-v6.11-userspace-update).
- commit 46be0f9
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Check pointer offset when checking variables
  (perf-sp7-v6.11-userspace-update).
- commit cffc424
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Improve debug message with location info
  (perf-sp7-v6.11-userspace-update).
- commit 00be595
* Sat Oct  5 2024 tonyj@suse.de
- perf bench uprobe: Add uretprobe variant of uprobe benchmarks
  (perf-sp7-v6.11-userspace-update).
- commit 8f28691
* Sat Oct  5 2024 tonyj@suse.de
- perf trace beauty: Add shellcheck to scripts
  (perf-sp7-v6.11-userspace-update).
- commit 03b3db4
* Sat Oct  5 2024 tonyj@suse.de
- perf util: Add shellcheck to generate-cmdlist.sh
  (perf-sp7-v6.11-userspace-update).
- commit ce4e03c
* Sat Oct  5 2024 tonyj@suse.de
- perf arch x86: Add shellcheck to build
  (perf-sp7-v6.11-userspace-update).
- commit 8f7bb77
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Add shellcheck to tools/perf scripts
  (perf-sp7-v6.11-userspace-update).
- commit 9e204b4
* Sat Oct  5 2024 tonyj@suse.de
- perf list: Escape '\r' in JSON output
  (perf-sp7-v6.11-userspace-update).
- commit c376983
* Sat Oct  5 2024 tonyj@suse.de
- perf dsos: Switch more loops to dsos__for_each_dso()
  (perf-sp7-v6.11-userspace-update).
- commit 7a8b3fa
* Sat Oct  5 2024 tonyj@suse.de
- perf dso: Move dso functions out of dsos.c
  (perf-sp7-v6.11-userspace-update).
- commit e3097ee
* Sat Oct  5 2024 tonyj@suse.de
- perf dsos: Introduce dsos__for_each_dso()
  (perf-sp7-v6.11-userspace-update).
- commit 44d27e6
* Sat Oct  5 2024 tonyj@suse.de
- perf dsos: Tidy reference counting and locking
  (perf-sp7-v6.11-userspace-update).
- commit 48e0106
* Sat Oct  5 2024 tonyj@suse.de
- perf dsos: Attempt to better abstract DSOs internals
  (perf-sp7-v6.11-userspace-update).
- commit 244ebc2
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Skip DSOs not found
  (perf-sp7-v6.11-userspace-update).
- commit 3e49aea
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Do not collect sample histogram unnecessarily
  (perf-sp7-v6.11-userspace-update).
- commit abf7b36
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Add a menu item to annotate data type in TUI
  (perf-sp7-v6.11-userspace-update).
- commit 1918c56
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Support event group display in TUI
  (perf-sp7-v6.11-userspace-update).
- commit 8a74edc
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add hist_entry__annotate_data_tui()
  (perf-sp7-v6.11-userspace-update).
- commit e5c6257
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add hist_entry__annotate_data_tty()
  (perf-sp7-v6.11-userspace-update).
- commit 6862d77
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Show progress of sample processing
  (perf-sp7-v6.11-userspace-update).
- commit 2fa7daf
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Skip sample histogram for stack canary
  (perf-sp7-v6.11-userspace-update).
- commit bf29024
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Remove dependency on lscpu
  (perf-sp7-v6.11-userspace-update).
- commit 6aa63b5
* Sat Oct  5 2024 tonyj@suse.de
- perf map: Remove kernel map before updating start and end
  addresses (perf-sp7-v6.11-userspace-update).
- commit 98cc3ae
* Sat Oct  5 2024 tonyj@suse.de
- perf metrics: Remove the "No_group" metric group
  (perf-sp7-v6.11-userspace-update).
- commit 4a0947b
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Get rid of symbol__ensure_annotate()
  (perf-sp7-v6.11-userspace-update).
- commit 9be4361
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Do not delete non-asm lines
  (perf-sp7-v6.11-userspace-update).
- commit 1baf51e
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Fix global variable lookup
  (perf-sp7-v6.11-userspace-update).
- commit 78740b9
* Sat Oct  5 2024 tonyj@suse.de
- tools subcmd: Add check_if_command_finished()
  (perf-sp7-v6.11-userspace-update).
- commit 667295b
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Move 'start' field struct to 'struct
  annotated_source' (perf-sp7-v6.11-userspace-update).
- commit 40dd8bb
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Move nr_events struct to 'struct
  annotated_source' (perf-sp7-v6.11-userspace-update).
- commit b2cbb76
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Move 'max_jump_sources' struct to 'struct
  annotated_source' (perf-sp7-v6.11-userspace-update).
- commit e983ebd
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Move 'widths' struct to 'struct annotated_source'
  (perf-sp7-v6.11-userspace-update).
- commit 484751e
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Get rid of offsets array
  (perf-sp7-v6.11-userspace-update).
- commit 57e8638
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Check annotation lines more efficiently
  (perf-sp7-v6.11-userspace-update).
- commit 6ef2bb2
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Introduce annotated_source__get_line()
  (perf-sp7-v6.11-userspace-update).
- commit 4c97e48
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Staticize some local functions
  (perf-sp7-v6.11-userspace-update).
- commit b4fe45f
* Sat Oct  5 2024 tonyj@suse.de
- perf script: Consolidate capstone print functions
  (perf-sp7-v6.11-userspace-update).
- commit 094057e
* Sat Oct  5 2024 tonyj@suse.de
- perf script: Add capstone support for '-F +brstackdisasm'
  (perf-sp7-v6.11-userspace-update).
- commit 2c9d060
* Sat Oct  5 2024 tonyj@suse.de
- perf script: Support 32bit code under 64bit OS with capstone
  (perf-sp7-v6.11-userspace-update).
- commit 9205354
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Fix PAI counter names for s390 virtual machines
  (perf-sp7-v6.11-userspace-update).
- commit c209e22
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Initialize 'arch' variable not to trip some
  - Werror=maybe-uninitialized (perf-sp7-v6.11-userspace-update).
- commit 711491f
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Add LIBTRACEEVENT_DIR build option
  (perf-sp7-v6.11-userspace-update).
- commit 87c8576
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Fix AT_EACCESS undeclared build error
  for system with kernel versions lower than v5.8
  (perf-sp7-v6.11-userspace-update).
- commit 061fd89
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add symbol name when using capstone
  (perf-sp7-v6.11-userspace-update).
- commit 95a3f42
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Use libcapstone to disassemble
  (perf-sp7-v6.11-userspace-update).
- commit 8ecfca7
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Split out util/disasm.c
  (perf-sp7-v6.11-userspace-update).
- commit 94347c0
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add and use ins__is_nop()
  (perf-sp7-v6.11-userspace-update).
- commit ae4164e
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Use ins__is_xxx() if possible
  (perf-sp7-v6.11-userspace-update).
- commit 6ad9998
* Sat Oct  5 2024 tonyj@suse.de
- perf evsel: Use evsel__name_is() helper
  (perf-sp7-v6.11-userspace-update).
- commit 5cc3644
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Honor output options with --data-type
  (perf-sp7-v6.11-userspace-update).
- commit fb0dd69
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Move uapi/linux/vhost.h copy out of the directory
  used to build perf (perf-sp7-v6.11-userspace-update).
- commit a703288
* Sat Oct  5 2024 tonyj@suse.de
- perf dso: Reorder members to save space in 'struct dso'
  (perf-sp7-v6.11-userspace-update).
- commit e9bfe3e
* Sat Oct  5 2024 tonyj@suse.de
- perf lock contention: Trim backtrace by skipping traceiter
  functions (perf-sp7-v6.11-userspace-update).
- commit 7ac1e91
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Remove info metrics erroneously in
  TopdownL1 (perf-sp7-v6.11-userspace-update).
- commit d76274f
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update snowridgex to 1.22
  (perf-sp7-v6.11-userspace-update).
- commit b653d97
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update skylake to v58
  (perf-sp7-v6.11-userspace-update).
- commit f5d8fd2
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update skylakex to 1.33
  (perf-sp7-v6.11-userspace-update).
- commit 0b3b25d
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update sierraforest to 1.02
  (perf-sp7-v6.11-userspace-update).
- commit cca8d2f
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update sapphirerapids to 1.20
  (perf-sp7-v6.11-userspace-update).
- commit 163b8a8
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update meteorlake to 1.08
  (perf-sp7-v6.11-userspace-update).
- commit 7159aa3
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update lunarlake to 1.01
  (perf-sp7-v6.11-userspace-update).
- commit 7a17215
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update icelakex to 1.24
  (perf-sp7-v6.11-userspace-update).
- commit b4bfce3
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update grandridge to 1.02
  (perf-sp7-v6.11-userspace-update).
- commit 18f03e3
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update emeraldrapids to 1.06
  (perf-sp7-v6.11-userspace-update).
- commit b933768
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update cascadelakex to 1.21
  (perf-sp7-v6.11-userspace-update).
- commit 222df87
* Sat Oct  5 2024 tonyj@suse.de
- perf trace: Fix 'newfstatat'/'fstatat' argument pretty printing
  (perf-sp7-v6.11-userspace-update).
- commit 9e3a1db
* Sat Oct  5 2024 tonyj@suse.de
- perf trace: Beautify the 'flags' arg of unlinkat
  (perf-sp7-v6.11-userspace-update).
- commit 4b40a97
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Introduce faccessat2 flags scnprintf routine
  (perf-sp7-v6.11-userspace-update).
- commit 03fa46e
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Introduce scrape script for the 'statx' syscall
  'mask' argument (perf-sp7-v6.11-userspace-update).
- commit eaf8c60
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Introduce scrape script for various fs syscalls
  'flags' arguments (perf-sp7-v6.11-userspace-update).
- commit adb9236
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Run tests in parallel by default
  (perf-sp7-v6.11-userspace-update).
- commit 8e4cc80
* Sat Oct  5 2024 tonyj@suse.de
- perf help: Lower levenshtein penality for deleting character
  (perf-sp7-v6.11-userspace-update).
- commit e59e5e3
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Suggest inbuilt commands for unknown command
  (perf-sp7-v6.11-userspace-update).
- commit 9d9542b
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Read child test 10 times a second rather than 1
  (perf-sp7-v6.11-userspace-update).
- commit 2222a9c
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Use a single fd for the child process out/err
  (perf-sp7-v6.11-userspace-update).
- commit 2b84697
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Stat output per thread of just the parent process
  (perf-sp7-v6.11-userspace-update).
- commit 7c4d9a0
* Sat Oct  5 2024 tonyj@suse.de
- perf list: Give more details about raw event encodings
  (perf-sp7-v6.11-userspace-update).
- commit c34690f
* Sat Oct  5 2024 tonyj@suse.de
- perf list: Allow wordwrap to wrap on commas
  (perf-sp7-v6.11-userspace-update).
- commit bace88f
* Sat Oct  5 2024 tonyj@suse.de
- perf pmu: Drop "default_core" from alias names
  (perf-sp7-v6.11-userspace-update).
- commit 71df427
* Sat Oct  5 2024 tonyj@suse.de
- perf list: Add tracepoint encoding to detailed output
  (perf-sp7-v6.11-userspace-update).
- commit 232ef81
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Introduce scrape script for 'clone' syscall
  'flags' argument (perf-sp7-v6.11-userspace-update).
- commit 63ff8c5
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Do not retry for invalid types
  (perf-sp7-v6.11-userspace-update).
- commit 504d627
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add a cache for global variable types
  (perf-sp7-v6.11-userspace-update).
- Update
  patches.suse/tools-perf-Fix-the-string-match-for-tmp-perf-PID.map-files-in-dso__load.patch
  (git-fixes, perf-sp7-v6.11-userspace-update).
- commit c0d968a
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add stack canary type
  (perf-sp7-v6.11-userspace-update).
- commit 50a2886
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Handle ADD instructions
  (perf-sp7-v6.11-userspace-update).
- commit 964225e
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Support general per-cpu access
  (perf-sp7-v6.11-userspace-update).
- commit fa8fd73
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Track instructions with a this-cpu variable
  (perf-sp7-v6.11-userspace-update).
- commit fb91153
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Handle this-cpu variables in kernel
  (perf-sp7-v6.11-userspace-update).
- commit 376a023
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Parse x86 segment register location
  (perf-sp7-v6.11-userspace-update).
- commit 9d7721b
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Check register state for type
  (perf-sp7-v6.11-userspace-update).
- commit ef91018
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Implement instruction tracking
  (perf-sp7-v6.11-userspace-update).
- commit a67a85b
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Handle call instructions
  (perf-sp7-v6.11-userspace-update).
- commit 18e0393
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Handle global variable access
  (perf-sp7-v6.11-userspace-update).
- commit 63e3420
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add get_global_var_type()
  (perf-sp7-v6.11-userspace-update).
- commit b926e01
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add update_insn_state()
  (perf-sp7-v6.11-userspace-update).
- commit 8c059a0
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Maintain variable type info
  (perf-sp7-v6.11-userspace-update).
- commit 983f4db
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add debug messages
  (perf-sp7-v6.11-userspace-update).
- commit 55581a1
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add annotate_get_basic_blocks()
  (perf-sp7-v6.11-userspace-update).
- commit 7f41ee0
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Introduce 'struct data_loc_info'
  (perf-sp7-v6.11-userspace-update).
- commit 44bf563
* Sat Oct  5 2024 tonyj@suse.de
- perf map: Add map__objdump_2rip()
  (perf-sp7-v6.11-userspace-update).
- commit 275e02a
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Add die_find_func_rettype()
  (perf-sp7-v6.11-userspace-update).
- commit e664e72
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Handle type transfer for memory access
  (perf-sp7-v6.11-userspace-update).
- commit c2eaa29
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Add die_collect_vars()
  (perf-sp7-v6.11-userspace-update).
- commit 26fe07c
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Remove unused pc argument
  (perf-sp7-v6.11-userspace-update).
- commit 3b7e9f9
* Sat Oct  5 2024 tonyj@suse.de
- perf cpumap: Use perf_cpu_map__for_each_cpu when possible
  (perf-sp7-v6.11-userspace-update).
- commit 82776bd
* Sat Oct  5 2024 tonyj@suse.de
- perf stat: Remove duplicate cpus_map_matched function
  (perf-sp7-v6.11-userspace-update).
- commit 5f6922e
* Sat Oct  5 2024 tonyj@suse.de
- perf arm64 header: Remove unnecessary CPU map get and put
  (perf-sp7-v6.11-userspace-update).
- commit 467cabf
* Sat Oct  5 2024 tonyj@suse.de
- perf cpumap: Clean up use of
  perf_cpu_map__has_any_cpu_or_is_empty
  (perf-sp7-v6.11-userspace-update).
- commit a7b448a
* Sat Oct  5 2024 tonyj@suse.de
- perf intel-pt/intel-bts: Switch
  perf_cpu_map__has_any_cpu_or_is_empty use
  (perf-sp7-v6.11-userspace-update).
- commit 2f5d615
* Sat Oct  5 2024 tonyj@suse.de
- perf arm-spe/cs-etm: Directly iterate CPU maps
  (perf-sp7-v6.11-userspace-update).
- commit d027c97
* Sat Oct  5 2024 tonyj@suse.de
- libperf cpumap: Ensure empty cpumap is NULL from alloc
  (perf-sp7-v6.11-userspace-update).
- commit c56a36f
* Sat Oct  5 2024 tonyj@suse.de
- libperf cpumap: Add any, empty and min helpers
  (perf-sp7-v6.11-userspace-update).
- commit f1695b2
* Sat Oct  5 2024 tonyj@suse.de
- perf docs arm_spe: Clarify more SPE requirements related to KPTI
  (perf-sp7-v6.11-userspace-update).
- commit bab2d80
* Sat Oct  5 2024 tonyj@suse.de
- tools headers: Remove almost unused copy of uapi/stat.h,
  add few conditional defines (perf-sp7-v6.11-userspace-update).
- commit 793895a
* Sat Oct  5 2024 tonyj@suse.de
- tools headers: Remove now unused copies
  of uapi/{fcntl,openat2}.h and asm/fcntl.h
  (perf-sp7-v6.11-userspace-update).
- commit b14c756
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Use the system linux/fcntl.h instead of a copy
  from the kernel (perf-sp7-v6.11-userspace-update).
- commit 2741aa1
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Move prctl.h files (uapi/linux and
  x86's) copy out of the directory used to build perf
  (perf-sp7-v6.11-userspace-update).
- commit 16269c5
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Stop using the copy of uapi/linux/prctl.h
  (perf-sp7-v6.11-userspace-update).
- commit 49805b2
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Move arch/x86/include/asm/irq_vectors.h
  copy out of the directory used to build perf
  (perf-sp7-v6.11-userspace-update).
- commit af1ffaa
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Move uapi/sound/asound.h copy out of the directory
  used to build perf (perf-sp7-v6.11-userspace-update).
- commit ebbf787
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Move uapi/linux/usbdevice_fs.h copy out of the
  directory used to build perf (perf-sp7-v6.11-userspace-update).
- commit 179e598
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Move uapi/linux/mount.h copy out of the directory
  used to build perf (perf-sp7-v6.11-userspace-update).
- commit 34f25b1
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Don't include uapi/linux/mount.h, use sys/mount.h
  instead (perf-sp7-v6.11-userspace-update).
- commit 68a2010
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Move uapi/linux/fs.h copy out of the directory
  used to build perf (perf-sp7-v6.11-userspace-update).
- commit f908142
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Fix dependency of tables using uapi/linux/mount.h
  (perf-sp7-v6.11-userspace-update).
- commit 831e34d
* Sat Oct  5 2024 tonyj@suse.de
- perf c2c: Fix a punctuation (perf-sp7-v6.11-userspace-update).
- commit 03c2a29
* Sat Oct  5 2024 tonyj@suse.de
- perf trace: Collect sys_nanosleep first argument
  (perf-sp7-v6.11-userspace-update).
- commit 81684d0
* Sat Oct  5 2024 tonyj@suse.de
- x86/insn: Add support for APX EVEX to the instruction decoder
  logic (perf-sp7-v6.11-userspace-update).
- commit f0e00cc
* Sat Oct  5 2024 tonyj@suse.de
- x86/insn: Add support for REX2 prefix to the instruction
  decoder logic (perf-sp7-v6.11-userspace-update).
- commit c9d3540
* Sat Oct  5 2024 tonyj@suse.de
- bitops: make BYTES_TO_BITS() treewide-available
  (perf-sp7-v6.11-userspace-update).
- commit f9980d7
* Sat Oct  5 2024 tonyj@suse.de
- perf riscv: Fix the warning due to the incompatible type
  (perf-sp7-v6.11-userspace-update).
- commit e8c236f
* Sat Oct  5 2024 tonyj@suse.de
- tools/include: Sync arm64 asm/cputype.h with the kernel sources
  (perf-sp7-v6.11-userspace-update).
- commit 22bf8d7
* Sat Oct  5 2024 tonyj@suse.de
- tools/include: Sync uapi/sound/asound.h with the kernel sources
  (perf-sp7-v6.11-userspace-update).
- commit 8250b8a
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Make sure to call symbol__annotate2() in TUI
  (perf-sp7-v6.11-userspace-update).
- commit a4494ef
* Sat Oct  5 2024 tonyj@suse.de
- riscv: andes: Support specifying symbolic firmware and hardware
  raw events (perf-sp7-v6.11-userspace-update).
- commit c4c7f30
* Sat Oct  5 2024 tonyj@suse.de
- net: remove {revc,send}msg_copy_msghdr() from exports
  (perf-sp7-v6.11-userspace-update).
- commit fe3409e
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add comments in the data structures
  (perf-sp7-v6.11-userspace-update).
- commit 9f18c0c
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Remove sym_hist.addr array
  (perf-sp7-v6.11-userspace-update).
- Delete
  patches.suse/perf-local-check-alloc-histogram-return.patch.
- commit 11612fc
* Sat Oct  5 2024 tiwai@suse.de
- ALSA: hda/generic: Drop obsoleted obey_preferred_dacs flag
  (stable-fixes).
- commit dba2309
* Sat Oct  5 2024 tiwai@suse.de
- ALSA: gus: Fix some error handling paths related to get_bpos()
  usage (git-fixes).
- ASoC: Intel: soc-acpi: arl: Fix some missing empty terminators
  (git-fixes).
- ASoC: Intel: soc-acpi-intel-rpl-match: add missing empty item
  (git-fixes).
- ASoC: cs35l45: Corrects cs35l45_get_clk_freq_id function data
  type (stable-fixes).
- ASoC: topology: Fix incorrect addressing assignments
  (git-fixes).
- ALSA: Fix typos in comments across various files (stable-fixes).
- ALSA: Drop explicit initialization of struct
  i2c_device_id::driver_data to 0 (stable-fixes).
- commit 3b8bf15
* Sat Oct  5 2024 tiwai@suse.de
- ALSA: hda/conexant: Fix conflicting quirk for System76 Pangolin
  (git-fixes).
- ALSA: line6: add hw monitor volume control to POD HD500X
  (stable-fixes).
- ALSA: usb-audio: Add native DSD support for Luxman D-08u
  (stable-fixes).
- ALSA: core: add isascii() check to card ID generator
  (stable-fixes).
- ASoC: qcom: sm8250: add qrb4210-rb2-sndcard compatible string
  (stable-fixes).
- ASoC: imx-card: Set card.owner to avoid a warning calltrace
  if SND=m (git-fixes).
- ASoC: fsl_sai: Enable 'FIFO continue on error' FCONT bit
  (stable-fixes).
- ASoC: codecs: lpass-rx-macro: add missing
  CDC_RX_BCL_VBAT_RF_PROC2 to default regs values (stable-fixes).
- ASoC: atmel: mchp-pdmc: Skip ALSA restoration if substream
  runtime is uninitialized (git-fixes).
- ASoC: amd: yc: Add quirk for HP Dragonfly pro one
  (stable-fixes).
- Revert "ALSA: hda: Conditionally use snooping for AMD HDMI"
  (stable-fixes).
- ALSA: hda/realtek: Add a quirk for HP Pavilion 15z-ec200
  (stable-fixes).
- ALSA: silence integer wrapping warning (stable-fixes).
- ALSA: Reorganize kerneldoc parameter names (stable-fixes).
- ALSA: hda/realtek: Fix the push button function for the ALC257
  (git-fixes).
- ALSA: hda/conexant: fix some typos (stable-fixes).
- ALSA: mixer_oss: Remove some incorrect kfree_const() usages
  (git-fixes).
- ALSA: hda/realtek: Add quirk for Huawei MateBook 13 KLV-WX9
  (stable-fixes).
- ALSA: usb-audio: Add delay quirk for VIVO USB-C HEADSET
  (stable-fixes).
- ALSA: hda/tas2781: Add new quirk for Lenovo Y990 Laptop
  (stable-fixes).
- ALSA: hda/realtek: fix mute/micmute LED for HP mt645 G8
  (stable-fixes).
- commit 1cdc743
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Calculate instruction overhead using hashmap
  (perf-sp7-v6.11-userspace-update).
- commit d8c722b
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add a hashmap for symbol histogram
  (perf-sp7-v6.11-userspace-update).
- commit ef6a95d
* Sat Oct  5 2024 tonyj@suse.de
- perf threads: Reduce table size from 256 to 8
  (perf-sp7-v6.11-userspace-update).
- commit 8b600e3
* Sat Oct  5 2024 tonyj@suse.de
- perf threads: Switch from rbtree to hashmap
  (perf-sp7-v6.11-userspace-update).
- commit 63a4253
* Sat Oct  5 2024 tonyj@suse.de
- perf threads: Move threads to its own files
  (perf-sp7-v6.11-userspace-update).
- commit 211d6c7
* Sat Oct  5 2024 tonyj@suse.de
- perf machine: Move machine's threads into its own abstraction
  (perf-sp7-v6.11-userspace-update).
- commit c489a22
* Sat Oct  5 2024 tonyj@suse.de
- perf machine: Move fprintf to for_each loop and a callback
  (perf-sp7-v6.11-userspace-update).
- commit 684d193
* Sat Oct  5 2024 tonyj@suse.de
- perf trace: Ignore thread hashing in summary
  (perf-sp7-v6.11-userspace-update).
- commit 492fd60
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Sort child tasks by tid
  (perf-sp7-v6.11-userspace-update).
- commit ddd87ab
* Sat Oct  5 2024 tonyj@suse.de
- perf version: Display availability of OpenCSD support
  (perf-sp7-v6.11-userspace-update).
- commit 72f37bb
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Add umasks/occ_sel to PCU events
  (perf-sp7-v6.11-userspace-update).
- commit 111c537
* Sat Oct  5 2024 tonyj@suse.de
- perf map: Fix map reference count issues
  (perf-sp7-v6.11-userspace-update).
- commit a46954a
* Sat Oct  5 2024 tonyj@suse.de
- perf lock contention: Account contending locks too
  (perf-sp7-v6.11-userspace-update).
- commit cb08f17
* Sat Oct  5 2024 tonyj@suse.de
- perf metrics: Fix segv for metrics with no events
  (perf-sp7-v6.11-userspace-update).
- commit 35a19ad
* Sat Oct  5 2024 tonyj@suse.de
- perf metrics: Fix metric matching
  (perf-sp7-v6.11-userspace-update).
- commit f14340b
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Fix spelling mistake "curent" -> "current"
  (perf-sp7-v6.11-userspace-update).
- commit 628174f
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Use TEST_FAIL in the TEST_ASSERT macros instead of -1
  (perf-sp7-v6.11-userspace-update).
- commit f971118
* Sat Oct  5 2024 tonyj@suse.de
- perf data convert: Fix segfault when converting to json when
  cpu_desc isn't set (perf-sp7-v6.11-userspace-update).
- commit 0ffb75b
* Sat Oct  5 2024 tonyj@suse.de
- perf bpf: Check that the minimal vmlinux.h installed is the
  latest one (perf-sp7-v6.11-userspace-update).
- commit fd952d3
* Sat Oct  5 2024 tonyj@suse.de
- treewide: remove meaningless assignments in Makefiles
  (perf-sp7-v6.11-userspace-update).
- commit 02c0002
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Add option to run tests in parallel
  (perf-sp7-v6.11-userspace-update).
- commit 2535f0a
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Run time generate shell test suites
  (perf-sp7-v6.11-userspace-update).
- commit f37444d
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Use scandirat for shell script finding
  (perf-sp7-v6.11-userspace-update).
- commit 9826aa3
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Rename builtin-test-list and add missed header guard
  (perf-sp7-v6.11-userspace-update).
- commit 159f3a9
* Sat Oct  5 2024 tonyj@suse.de
- tools subcmd: Add a no exec function call option
  (perf-sp7-v6.11-userspace-update).
- commit e3045d4
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Avoid fork in perf_has_symbol test
  (perf-sp7-v6.11-userspace-update).
- commit 9a9eca5
* Sat Oct  5 2024 tonyj@suse.de
- perf list: Add scandirat compatibility function
  (perf-sp7-v6.11-userspace-update).
- commit e052f90
* Sat Oct  5 2024 tonyj@suse.de
- perf thread_map: Skip exited threads when scanning /proc
  (perf-sp7-v6.11-userspace-update).
- commit 8b8e732
* Sat Oct  5 2024 tonyj@suse.de
- perf stat: Fix metric-only aggregation index
  (perf-sp7-v6.11-userspace-update).
- commit 7ff1676
* Sat Oct  5 2024 tonyj@suse.de
- perf metrics: Compute unmerged uncore metrics individually
  (perf-sp7-v6.11-userspace-update).
- commit 5e1d8d8
* Sat Oct  5 2024 tonyj@suse.de
- perf stat: Pass fewer metric arguments
  (perf-sp7-v6.11-userspace-update).
- commit e343df5
* Sat Oct  5 2024 tonyj@suse.de
- perf: script: prefer capstone to XED
  (perf-sp7-v6.11-userspace-update).
- commit cb74f1f
* Sat Oct  5 2024 tonyj@suse.de
- perf: script: add field 'disasm' to display mnemonic
  instructions (perf-sp7-v6.11-userspace-update).
- commit 9708c42
* Sat Oct  5 2024 tonyj@suse.de
- perf: util: use capstone disasm engine to show assembly
  instructions (perf-sp7-v6.11-userspace-update).
- commit f6fef58
* Sat Oct  5 2024 tonyj@suse.de
- perf: build: introduce the libcapstone
  (perf-sp7-v6.11-userspace-update).
- commit 3f89b75
* Sat Oct  5 2024 tonyj@suse.de
- perf list: For metricgroup only list include description
  (perf-sp7-v6.11-userspace-update).
- commit 1754e78
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Fixup module symbol end address properly
  (perf-sp7-v6.11-userspace-update).
- commit 4150205
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update tigerlake TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
- commit 0b4ffc2
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update skylakex TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
- commit 21a6bad
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update skylake TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
- commit da9c412
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update sapphirerapids TMA metrics
  to 4.7 (perf-sp7-v6.11-userspace-update).
- commit 5673ea8
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update sandybridge TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
- commit 0787b21
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update rocketlake TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
- commit edeac0e
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update jaketown TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
- commit 350eab4
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update ivytown TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
- commit 878f418
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update ivybridge TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
- commit c2f01e7
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update icelakex TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
- commit 52468a9
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update icelake TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
- commit 2fe55ea
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update haswellx TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
- commit 7352ed3
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update haswell TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
- commit 1f35711
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update cascadelakex TMA metrics to
  4.7 (perf-sp7-v6.11-userspace-update).
- commit 95a8a88
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update broadwellx TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
- commit 3e1de0b
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update broadwellde TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
- commit fca7583
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update broadwell TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
- commit f20a7bf
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update alderlake TMA metrics to 4.7
  (perf-sp7-v6.11-userspace-update).
- commit 8edecce
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update tigerlake events to v1.15
  (perf-sp7-v6.11-userspace-update).
- commit 0950f5c
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update skylake events to v58
  (perf-sp7-v6.11-userspace-update).
- commit aff81bf
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update sierraforst events to v1.01
  (perf-sp7-v6.11-userspace-update).
- commit b30edac
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update rocketlake events to v1.02
  (perf-sp7-v6.11-userspace-update).
- commit 69c3843
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update meteorlake events to v1.07
  (perf-sp7-v6.11-userspace-update).
- commit 22ad470
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update icelake events to v1.21
  (perf-sp7-v6.11-userspace-update).
- commit f99e7b6
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update haswell events to v35
  (perf-sp7-v6.11-userspace-update).
- commit 9b5e733
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update grandridge events to v1.01
  (perf-sp7-v6.11-userspace-update).
- commit afe6552
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update emeraldrapids events to v1.03
  (perf-sp7-v6.11-userspace-update).
- commit f11d0d9
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update broadwell events to v29
  (perf-sp7-v6.11-userspace-update).
- commit 1e2960e
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update alderlaken events to v1.24
  (perf-sp7-v6.11-userspace-update).
- commit 256a040
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update alderlake events to v1.24
  (perf-sp7-v6.11-userspace-update).
- commit de98637
* Sat Oct  5 2024 tonyj@suse.de
- perf augmented_raw_syscalls.bpf: Move 'struct timespec64'
  to vmlinux.h (perf-sp7-v6.11-userspace-update).
- commit 6be69b4
* Sat Oct  5 2024 tonyj@suse.de
- perf testsuite: Install kprobe tests and common files
  (perf-sp7-v6.11-userspace-update).
- commit 8cb54e9
* Sat Oct  5 2024 tonyj@suse.de
- perf testsuite: Add test for kprobe handling
  (perf-sp7-v6.11-userspace-update).
- commit 9dcb054
* Sat Oct  5 2024 tonyj@suse.de
- perf testsuite: Add common output checking helpers
  (perf-sp7-v6.11-userspace-update).
- commit 2077996
* Sat Oct  5 2024 tonyj@suse.de
- perf testsuite: Add test case for perf probe
  (perf-sp7-v6.11-userspace-update).
- commit 3717bc3
* Sat Oct  5 2024 tonyj@suse.de
- perf testsuite: Add initialization script for shell tests
  (perf-sp7-v6.11-userspace-update).
- commit b13d44f
* Sat Oct  5 2024 tonyj@suse.de
- perf testsuite: Add common setting for shell tests
  (perf-sp7-v6.11-userspace-update).
- commit 45f63ec
* Sat Oct  5 2024 tonyj@suse.de
- perf testsuite: Add common regex patters
  (perf-sp7-v6.11-userspace-update).
- commit 2f0aa29
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Enable Symbols test to work with a current module
  dso (perf-sp7-v6.11-userspace-update).
- commit e4b5174
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Cleanup perf register configuration
  (perf-sp7-v6.11-userspace-update).
- commit f1cc88c
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-regs: Introduce a weak function
  arch__sample_reg_masks() (perf-sp7-v6.11-userspace-update).
- commit 9249cea
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-regs: Always build perf register functions
  (perf-sp7-v6.11-userspace-update).
- commit 9f36f40
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Remove unused CONFIG_PERF_REGS
  (perf-sp7-v6.11-userspace-update).
- commit bcc47bb
* Sat Oct  5 2024 tonyj@suse.de
- perf expr: Allow NaN to be a valid number
  (perf-sp7-v6.11-userspace-update).
- commit d162030
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Locking tidy up of nr_maps
  (perf-sp7-v6.11-userspace-update).
- commit 5149292
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Hide maps internals
  (perf-sp7-v6.11-userspace-update).
- commit 3725249
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Get map before returning in maps__find_next_entry
  (perf-sp7-v6.11-userspace-update).
- commit 40e0ea5
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Get map before returning in maps__find_by_name
  (perf-sp7-v6.11-userspace-update).
- commit 86680cb
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Get map before returning in maps__find
  (perf-sp7-v6.11-userspace-update).
- commit fb8183e
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Switch from rbtree to lazily sorted array for
  addresses (perf-sp7-v6.11-userspace-update).
- commit 59df4a2
* Sat Oct  5 2024 tonyj@suse.de
- perf stat: Support per-cluster aggregation
  (perf-sp7-v6.11-userspace-update).
- commit 665ad21
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Remove misleading comments on map functions
  (perf-sp7-v6.11-userspace-update).
- commit 8b77892
* Sat Oct  5 2024 tonyj@suse.de
- perf sched: Move curr_pid and cpu_last_switched
  initialization to perf_sched__{lat|map|replay}()
  (perf-sp7-v6.11-userspace-update).
- commit 1cba676
* Sat Oct  5 2024 tonyj@suse.de
- perf sched: Move curr_thread initialization to perf_sched__map()
  (perf-sp7-v6.11-userspace-update).
- commit 44ec584
* Sat Oct  5 2024 tonyj@suse.de
- perf sched: Fix memory leak in perf_sched__map()
  (perf-sp7-v6.11-userspace-update).
- commit c905a84
* Sat Oct  5 2024 tonyj@suse.de
- perf sched: Move start_work_mutex and work_done_wait_mutex
  initialization to perf_sched__replay()
  (perf-sp7-v6.11-userspace-update).
- commit ef6a20a
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Skip metric w/o event name on arm64 in stat STD
  output linter (perf-sp7-v6.11-userspace-update).
- commit a890916
* Sat Oct  5 2024 tonyj@suse.de
- perf symbols: Slightly improve module file executable section
  mappings (perf-sp7-v6.11-userspace-update).
- commit 36dc783
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Make it possible to see perf's kernel and module
  memory mappings (perf-sp7-v6.11-userspace-update).
- commit 060e8f2
* Sat Oct  5 2024 tonyj@suse.de
- perf record: Display data size on pipe mode
  (perf-sp7-v6.11-userspace-update).
- commit 06742b1
* Sat Oct  5 2024 tonyj@suse.de
- perf script: Print source line for each jump in brstackinsn
  (perf-sp7-v6.11-userspace-update).
- commit 78d2b2a
* Sat Oct  5 2024 tonyj@suse.de
- perf kvm powerpc: Fix build (perf-sp7-v6.11-userspace-update).
- commit a72f9c5
* Sat Oct  5 2024 tonyj@suse.de
- tools: perf: Expose sample ID / stream ID to python scripts
  (perf-sp7-v6.11-userspace-update).
- commit 0ddb218
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Print all errors
  (perf-sp7-v6.11-userspace-update).
- commit 64e2b3a
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Improve error location of terms cloned from
  an event (perf-sp7-v6.11-userspace-update).
- commit e8d55d5
* Sat Oct  5 2024 tonyj@suse.de
- perf tsc: Add missing newlines to debug statements
  (perf-sp7-v6.11-userspace-update).
- commit 36c0cde
* Sat Oct  5 2024 tonyj@suse.de
- perf Documentation: Add some more hints to tips.txt
  (perf-sp7-v6.11-userspace-update).
- commit e51a7e4
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Simplify metric value validation test final report
  (perf-sp7-v6.11-userspace-update).
- commit 0a52c8e
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Prevent segfault with --no-parent
  (perf-sp7-v6.11-userspace-update).
- commit ddcf901
* Sat Oct  5 2024 tonyj@suse.de
- perf evsel: Rename get_states() to parse_task_states() and
  make it public (perf-sp7-v6.11-userspace-update).
- commit c3737a8
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Add -H short option for --hierarchy
  (perf-sp7-v6.11-userspace-update).
- commit 023e19b
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Skip test_arm_callgraph_fp.sh if unwinding isn't
  built in (perf-sp7-v6.11-userspace-update).
- commit 7310351
* Sat Oct  5 2024 tonyj@suse.de
- perf version: Display availability of HAVE_DWARF_UNWIND_SUPPORT
  (perf-sp7-v6.11-userspace-update).
- commit 87bb34f
* Sat Oct  5 2024 tonyj@suse.de
- perf mem: Clean up perf_pmus__num_mem_pmus()
  (perf-sp7-v6.11-userspace-update).
- commit 9cff7c9
* Sat Oct  5 2024 tonyj@suse.de
- perf mem: Clean up perf_mem_events__record_args()
  (perf-sp7-v6.11-userspace-update).
- commit fa98574
* Sat Oct  5 2024 tonyj@suse.de
- perf mem: Clean up is_mem_loads_aux_event()
  (perf-sp7-v6.11-userspace-update).
- commit f614a0e
* Sat Oct  5 2024 tonyj@suse.de
- perf mem: Clean up perf_mem_event__supported()
  (perf-sp7-v6.11-userspace-update).
- commit 0b01d6c
* Sat Oct  5 2024 tonyj@suse.de
- perf mem: Clean up perf_mem_events__name()
  (perf-sp7-v6.11-userspace-update).
- commit cf8ec42
* Sat Oct  5 2024 tonyj@suse.de
- perf mem: Clean up perf_mem_events__ptr()
  (perf-sp7-v6.11-userspace-update).
- commit 6e782b2
* Sat Oct  5 2024 tonyj@suse.de
- perf mem: Add mem_events into the supported perf_pmu
  (perf-sp7-v6.11-userspace-update).
- commit 66dc45f
* Sat Oct  5 2024 tonyj@suse.de
- perf sched: Commit to evsel__taskstate() to parse task state
  info (perf-sp7-v6.11-userspace-update).
- commit 7ec66bf
* Sat Oct  5 2024 tonyj@suse.de
- perf util: Add evsel__taskstate() to parse the task state info
  instead (perf-sp7-v6.11-userspace-update).
- commit c7669a5
* Sat Oct  5 2024 tonyj@suse.de
- perf util: Add helpers to parse task state string from
  libtraceevent (perf-sp7-v6.11-userspace-update).
- commit 18e4870
* Sat Oct  5 2024 tonyj@suse.de
- perf sched: Sync state char array with the kernel
  (perf-sp7-v6.11-userspace-update).
- commit ba59deb
* Sat Oct  5 2024 tonyj@suse.de
- perf data: Minor code style alignment cleanup
  (perf-sp7-v6.11-userspace-update).
- commit adcbdd7
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Check allowed DWARF Ops
  (perf-sp7-v6.11-userspace-update).
- commit fc3427a
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Support stack variables
  (perf-sp7-v6.11-userspace-update).
- commit 5accf4e
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Add die_get_cfa()
  (perf-sp7-v6.11-userspace-update).
- commit 3ab0bed
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Support global variables
  (perf-sp7-v6.11-userspace-update).
- commit 3a537d9
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Handle PC-relative addressing
  (perf-sp7-v6.11-userspace-update).
- commit 553327a
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add stack operation pseudo type
  (perf-sp7-v6.11-userspace-update).
- commit 9b2d0cc
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Handle array style accesses
  (perf-sp7-v6.11-userspace-update).
- commit 462e787
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Handle macro fusion on x86
  (perf-sp7-v6.11-userspace-update).
- commit 280cc98
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Parse 'lock' prefix from llvm-objdump
  (perf-sp7-v6.11-userspace-update).
- commit 0960119
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Check whether pkg-config is installed when
  libtraceevent is linked (perf-sp7-v6.11-userspace-update).
- commit 3156123
* Sat Oct  5 2024 tonyj@suse.de
- perf test: raise limit to 20 percent for
  perf_stat_--bpf-counters_test (perf-sp7-v6.11-userspace-update).
- commit 29fd3a5
* Sat Oct  5 2024 tonyj@suse.de
- tools headers: Update the copy of x86's mem{cpy,set}_64.S used
  in 'perf bench' (perf-sp7-v6.11-userspace-update).
- commit ee5f579
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Alderlake/sapphirerapids metric fixes
  (perf-sp7-v6.11-userspace-update).
- commit 25e65b7
* Sat Oct  5 2024 tonyj@suse.de
- tools headers UAPI: Sync kvm headers with the kernel sources
  (perf-sp7-v6.11-userspace-update).
- commit 26c143c
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Fix calloc() arguments to address error introduced
  in gcc-14 (perf-sp7-v6.11-userspace-update).
- commit 058afa7
* Sat Oct  5 2024 tonyj@suse.de
- perf top: Remove needless malloc(0) call that triggers
  - Walloc-size (perf-sp7-v6.11-userspace-update).
- commit 622f845
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Make minimal shellcheck version to v0.6.0
  (perf-sp7-v6.11-userspace-update).
- commit ccdb5ce
* Sat Oct  5 2024 tonyj@suse.de
- perf test shell daemon: Make signal test less racy
  (perf-sp7-v6.11-userspace-update).
- commit d303878
* Sat Oct  5 2024 tonyj@suse.de
- perf test shell script: Fix test for python being disabled
  (perf-sp7-v6.11-userspace-update).
- commit e3b8bca
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Workaround debug output in list test
  (perf-sp7-v6.11-userspace-update).
- commit 38c4765
* Sat Oct  5 2024 tonyj@suse.de
- perf list: Add output file option
  (perf-sp7-v6.11-userspace-update).
- commit 70474c0
* Sat Oct  5 2024 tonyj@suse.de
- perf list: Switch error message to pr_err() to respect debug
  settings (-v) (perf-sp7-v6.11-userspace-update).
- commit f05a539
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Fix 'perf script' tests on s390
  (perf-sp7-v6.11-userspace-update).
- blacklist.conf:
- commit 91dc465
* Sat Oct  5 2024 tonyj@suse.de
- perf test: test case 'Setup struct perf_event_attr' fails on
  s390 on z/vm (perf-sp7-v6.11-userspace-update).
- commit 4e00d3b
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Add perf script test
  (perf-sp7-v6.11-userspace-update).
- commit 07d5177
* Sat Oct  5 2024 tonyj@suse.de
- perf TUI: Don't ignore job control
  (perf-sp7-v6.11-userspace-update).
- commit 8bb9496
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update sapphirerapids events to v1.17
  (perf-sp7-v6.11-userspace-update).
- commit 734fd42
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update icelakex events to v1.23
  (perf-sp7-v6.11-userspace-update).
- commit 0b1d9dc
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Update emeraldrapids events to v1.02
  (perf-sp7-v6.11-userspace-update).
- commit 903548a
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events intel: Alderlake/rocketlake metric fixes
  (perf-sp7-v6.11-userspace-update).
- commit 856f482
* Sat Oct  5 2024 tonyj@suse.de
- perf x86 test: Add hybrid test for conflicting legacy/sysfs
  event (perf-sp7-v6.11-userspace-update).
- commit bffa836
* Sat Oct  5 2024 tonyj@suse.de
- perf x86 test: Update hybrid expectations
  (perf-sp7-v6.11-userspace-update).
- commit d4b57cc
* Sat Oct  5 2024 tonyj@suse.de
- perf record: Reduce memory for
  recording PERF_RECORD_LOST_SAMPLES event
  (perf-sp7-v6.11-userspace-update).
- commit f7bbafc
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add --insn-stat option for debugging
  (perf-sp7-v6.11-userspace-update).
- commit 8b81c8e
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add --type-stat option for debugging
  (perf-sp7-v6.11-userspace-update).
- commit f3b94d3
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Support event group display
  (perf-sp7-v6.11-userspace-update).
- commit 5cef258
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add --data-type option
  (perf-sp7-v6.11-userspace-update).
- commit 7faf677
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Add 'symoff' sort key
  (perf-sp7-v6.11-userspace-update).
- commit 151f4c9
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Add 'typeoff' sort key
  (perf-sp7-v6.11-userspace-update).
- commit ce2b031
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Update sample histogram for type
  (perf-sp7-v6.11-userspace-update).
- commit 4a7b0a3
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add member field in the data type
  (perf-sp7-v6.11-userspace-update).
- commit 6295d47
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Support data type profiling
  (perf-sp7-v6.11-userspace-update).
- commit aabd6de
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Add 'type' sort key
  (perf-sp7-v6.11-userspace-update).
- commit f4940fa
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Implement hist_entry__get_data_type()
  (perf-sp7-v6.11-userspace-update).
- commit 893e05e
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Add annotate_get_insn_location()
  (perf-sp7-v6.11-userspace-update).
- commit dc9cf85
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Factor out evsel__get_arch()
  (perf-sp7-v6.11-userspace-update).
- commit 5d3c3fd
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add dso->data_types tree
  (perf-sp7-v6.11-userspace-update).
- commit 37c8265
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate-data: Add find_data_type() to get type from
  memory access (perf-sp7-v6.11-userspace-update).
- commit 607468a
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-regs: Add get_dwarf_regnum()
  (perf-sp7-v6.11-userspace-update).
- commit c568d4d
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Factor out die_get_typename_from_type()
  (perf-sp7-v6.11-userspace-update).
- commit f6a7d36
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Fix up overlaps during fixup_end
  (perf-sp7-v6.11-userspace-update).
- commit 460ed22
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Reduce scope of map_rb_node and maps internals
  (perf-sp7-v6.11-userspace-update).
- commit 29fc0e2
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Add find next entry to give entry after the given
  map (perf-sp7-v6.11-userspace-update).
- commit 0f052c3
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Add maps__load_first()
  (perf-sp7-v6.11-userspace-update).
- commit 1e039fd
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Rename clone to copy from
  (perf-sp7-v6.11-userspace-update).
- commit 6af11b8
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Do simple merge if given map doesn't overlap
  (perf-sp7-v6.11-userspace-update).
- commit 68e9332
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Refactor maps__fixup_overlappings()
  (perf-sp7-v6.11-userspace-update).
- commit 135855a
* Sat Oct  5 2024 tonyj@suse.de
- perf debug: Expose debug file (perf-sp7-v6.11-userspace-update).
- commit a8dc391
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Add remove maps function to remove a map based on
  callback (perf-sp7-v6.11-userspace-update).
- commit ff35550
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Reduce scope of maps__for_each_entry()
  (perf-sp7-v6.11-userspace-update).
- commit ff2d05b
* Sat Oct  5 2024 tonyj@suse.de
- perf vdso: Use function to add missing maps lock
  (perf-sp7-v6.11-userspace-update).
- commit 7919686
* Sat Oct  5 2024 tonyj@suse.de
- perf unwind: Use function to add missing maps lock
  (perf-sp7-v6.11-userspace-update).
- commit d482564
* Sat Oct  5 2024 tonyj@suse.de
- perf scripts python arm-cs-trace-disasm.py: Do not ignore
  disam first sample (perf-sp7-v6.11-userspace-update).
- commit e876d6c
* Sat Oct  5 2024 tonyj@suse.de
- perf scripts python arm-cs-trace-disasm.py: Set start vm addr
  of exectable file to 0 (perf-sp7-v6.11-userspace-update).
- commit d79ace7
* Sat Oct  5 2024 tonyj@suse.de
- perf archive: Add new option '--unpack' to expand tarballs
  (perf-sp7-v6.11-userspace-update).
- commit 7d0055a
* Sat Oct  5 2024 tonyj@suse.de
- perf archive: Add new option '--all' to pack perf.data with DSOs
  (perf-sp7-v6.11-userspace-update).
- commit c627110
* Sat Oct  5 2024 tonyj@suse.de
- perf thread: Use function to add missing maps lock
  (perf-sp7-v6.11-userspace-update).
- commit 01906c9
* Sat Oct  5 2024 tonyj@suse.de
- perf synthetic-events: Use function to add missing maps lock
  (perf-sp7-v6.11-userspace-update).
- commit 4199317
* Sat Oct  5 2024 tonyj@suse.de
- perf symbol: Use function to add missing maps lock
  (perf-sp7-v6.11-userspace-update).
- commit bf8ab2b
* Sat Oct  5 2024 tonyj@suse.de
- perf probe-event: Use function to add missing maps lock
  (perf-sp7-v6.11-userspace-update).
- commit b52684e
* Sat Oct  5 2024 tonyj@suse.de
- perf machine: Use function to add missing maps lock
  (perf-sp7-v6.11-userspace-update).
- commit f258b94
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Use function to add missing maps lock
  (perf-sp7-v6.11-userspace-update).
- commit 20b6ec8
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Use function to add missing maps lock
  (perf-sp7-v6.11-userspace-update).
- commit fd2b28b
* Sat Oct  5 2024 tonyj@suse.de
- perf events x86: Use function to add missing lock
  (perf-sp7-v6.11-userspace-update).
- commit 4ac9811
* Sat Oct  5 2024 tonyj@suse.de
- perf maps: Add maps__for_each_map to iterate maps holding the
  lock (perf-sp7-v6.11-userspace-update).
- commit 9655c32
* Sat Oct  5 2024 tonyj@suse.de
- perf map: Improve map/unmap parameter names
  (perf-sp7-v6.11-userspace-update).
- commit b8fbc9b
* Sat Oct  5 2024 tonyj@suse.de
- libperf cpumap: Document perf_cpu_map__nr()'s behavior
  (perf-sp7-v6.11-userspace-update).
- commit 840c138
* Sat Oct  5 2024 tonyj@suse.de
- perf top: Avoid repeated function calls to perf_cpu_map__nr()
  (perf-sp7-v6.11-userspace-update).
- commit 5c5dd22
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Make DSO tests a suite rather than individual
  (perf-sp7-v6.11-userspace-update).
- commit e343f07
* Sat Oct  5 2024 tonyj@suse.de
- perf evlist: Move event attributes to after
  the / when uniquefying using the PMU name
  (perf-sp7-v6.11-userspace-update).
- commit 1471580
* Sat Oct  5 2024 tonyj@suse.de
- perf stat: Combine the -A/--no-aggr and --no-merge options
  (perf-sp7-v6.11-userspace-update).
- commit b8c4dab
* Sat Oct  5 2024 tonyj@suse.de
- libperf cpumap: Add for_each_cpu() that skips the "any CPU"
  case (perf-sp7-v6.11-userspace-update).
- commit 587e9b4
* Sat Oct  5 2024 tonyj@suse.de
- libperf cpumap: Replace usage of perf_cpu_map__new(NULL)
  with perf_cpu_map__new_online_cpus()
  (perf-sp7-v6.11-userspace-update).
- commit 6b20ab8
* Sat Oct  5 2024 tonyj@suse.de
- libperf cpumap: Rename perf_cpu_map__empty()
  to perf_cpu_map__has_any_cpu_or_is_empty()
  (perf-sp7-v6.11-userspace-update).
- commit eff5ac4
* Sat Oct  5 2024 tonyj@suse.de
- libperf cpumap: Rename perf_cpu_map__default_new()
  to perf_cpu_map__new_online_cpus() and prefer sysfs
  (perf-sp7-v6.11-userspace-update).
- commit 76a3f21
* Sat Oct  5 2024 tonyj@suse.de
- libperf cpumap: Rename perf_cpu_map__dummy_new() to
  perf_cpu_map__new_any_cpu() (perf-sp7-v6.11-userspace-update).
- commit 4e10ba1
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Get rid of local annotation options
  (perf-sp7-v6.11-userspace-update).
- commit b1cdbee
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Remove remaining usages of local annotation
  options (perf-sp7-v6.11-userspace-update).
- commit 5360788
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Ensure init/exit for global options
  (perf-sp7-v6.11-userspace-update).
- commit e7644eb
* Sat Oct  5 2024 tonyj@suse.de
- perf ui/browser/annotate: Use global annotation_options
  (perf-sp7-v6.11-userspace-update).
- commit c65d268
* Sat Oct  5 2024 tonyj@suse.de
- perf thread: Add missing RC_CHK_EQUAL
  (perf-sp7-v6.11-userspace-update).
- commit bdc1146
* Sat Oct  5 2024 tonyj@suse.de
- perf map: Simplify map_ip/unmap_ip and make 'struct map'
  smaller (perf-sp7-v6.11-userspace-update).
- commit 1193720
* Sat Oct  5 2024 tonyj@suse.de
- perf test shell diff: Skip test if test_loop symbol is missing
  in the perf binary (perf-sp7-v6.11-userspace-update).
- commit 332ef6e
* Sat Oct  5 2024 tonyj@suse.de
- perf symbols: Parse NOTE segments until the build id is found
  (perf-sp7-v6.11-userspace-update).
- commit 4417654
* Sat Oct  5 2024 tonyj@suse.de
- perf record: Be lazier in allocating lost samples buffer
  (perf-sp7-v6.11-userspace-update).
- commit a2faaa0
* Sat Oct  5 2024 tonyj@suse.de
- perf evsel: Fallback to "task-clock" when not system wide
  (perf-sp7-v6.11-userspace-update).
- commit 2fbb999
* Sat Oct  5 2024 tonyj@suse.de
- perf bench sched-seccomp-notify: Fix spelling
  mistake "synchronious" -> "synchronous"
  (perf-sp7-v6.11-userspace-update).
- commit 593a381
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Add basic 'perf diff' test
  (perf-sp7-v6.11-userspace-update).
- commit c71a35e
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Add basic 'perf list --json" test
  (perf-sp7-v6.11-userspace-update).
- commit 068026d
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Use common python setup library
  (perf-sp7-v6.11-userspace-update).
- commit cb1e309
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Shellcheck support for OUTPUT directory
  (perf-sp7-v6.11-userspace-update).
- Refresh
  patches.suse/perf-bpf-Clean-up-the-generated-copied-vmlinux.h.patch.
- commit 86680ba
* Sat Oct  5 2024 tonyj@suse.de
- perf env: Cache the arch specific strerrno function in
  perf_env__arch_strerrno() (perf-sp7-v6.11-userspace-update).
- commit ce9d845
* Sat Oct  5 2024 tonyj@suse.de
- perf env: Introduce perf_env__arch_strerrno()
  (perf-sp7-v6.11-userspace-update).
- commit 41f17c6
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty: Don't use 'find ... -printf' as it isn't available
  in busybox (perf-sp7-v6.11-userspace-update).
- commit cc9348f
* Sat Oct  5 2024 tonyj@suse.de
- libperf: Lazily allocate/size mmap event copy
  (perf-sp7-v6.11-userspace-update).
- commit 1acb176
* Sat Oct  5 2024 tonyj@suse.de
- perf tests sigtrap: Skip if running on a kernel with sleepable
  spinlocks (perf-sp7-v6.11-userspace-update).
- commit 83a3921
* Sat Oct  5 2024 tonyj@suse.de
- perf test sigtrap: Generalize the BTF routine to reuse it in
  this test (perf-sp7-v6.11-userspace-update).
- commit 5d81e68
* Sat Oct  5 2024 tonyj@suse.de
- perf mmap: Lazily initialize zstd streams to save memory when
  not using it (perf-sp7-v6.11-userspace-update).
- commit 92e8a11
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Add die_find_variable_by_addr()
  (perf-sp7-v6.11-userspace-update).
- commit 8297a7d
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Add --debug-file option to redirect debug output
  (perf-sp7-v6.11-userspace-update).
- commit a71674b
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Check if operand has multiple regs
  (perf-sp7-v6.11-userspace-update).
- commit dbdb70c
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Use existing config value for objdump path
  (perf-sp7-v6.11-userspace-update).
- commit c0aac77
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events riscv: add T-HEAD C9xx JSON file
  (perf-sp7-v6.11-userspace-update).
- commit c4f6062
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events: Add skx, clx, icx and spr upi bandwidth
  metric (perf-sp7-v6.11-userspace-update).
- commit 07cfd8d
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Skip branch stack sampling test if brstack_bench
  symbol is missing (perf-sp7-v6.11-userspace-update).
- commit 8fb3097
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Skip Arm64 callgraphs test if leafloop symbol is
  missing (perf-sp7-v6.11-userspace-update).
- commit 51a1e2e
* Sat Oct  5 2024 tonyj@suse.de
- perf tests: Skip record test if test_loop symbol is missing
  (perf-sp7-v6.11-userspace-update).
- commit 6959c5a
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Remove warning on missing raw data for s390
  (perf-sp7-v6.11-userspace-update).
- commit 32c937e
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Add perf binary dependent rule for shellcheck log
  in Makefile.perf (perf-sp7-v6.11-userspace-update).
- Refresh
  patches.suse/perf-bpf-Clean-up-the-generated-copied-vmlinux.h.patch.
- commit 62723f3
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events riscv: Add StarFive Dubhe-90 JSON file
  (perf-sp7-v6.11-userspace-update).
- commit d6744ee
* Sat Oct  5 2024 tonyj@suse.de
- perf tests coresight: Remove unused variables
  (perf-sp7-v6.11-userspace-update).
- commit d0982ea
* Sat Oct  5 2024 tonyj@suse.de
- perf lock: if a strdup-ed string is NULL,the allocated memory
  needs freeing (perf-sp7-v6.11-userspace-update).
- commit 6a0c083
* Sat Oct  5 2024 tonyj@suse.de
- perf parse-events: Make legacy events lower priority than
  sysfs/JSON (perf-sp7-v6.11-userspace-update).
- commit eaa399c
* Sat Oct  5 2024 tonyj@suse.de
- perf cs-etm: Enable itrace option 'T'
  (perf-sp7-v6.11-userspace-update).
- commit d13d558
* Sat Oct  5 2024 tonyj@suse.de
- perf auxtrace: Add 'T' itrace option for timestamp trace
  (perf-sp7-v6.11-userspace-update).
- commit 4589e78
* Sat Oct  5 2024 tonyj@suse.de
- perf script perl: Fail check on dynamic allocation
  (perf-sp7-v6.11-userspace-update).
- commit ac17c86
* Sat Oct  5 2024 tonyj@suse.de
- perf script python: Fail check on dynamic allocation
  (perf-sp7-v6.11-userspace-update).
- commit a58dd0d
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Address python 3.6 DeprecationWarning for string
  scapes (perf-sp7-v6.11-userspace-update).
- commit d60dd87
* Sat Oct  5 2024 tonyj@suse.de
- perf vendor events riscv: Add StarFive Dubhe-80 JSON file
  (perf-sp7-v6.11-userspace-update).
- commit 92c1374
* Sat Oct  5 2024 tonyj@suse.de
- perf report: Add s390 raw data interpretation for PAI counters
  (perf-sp7-v6.11-userspace-update).
- commit 49c1b2f
* Sat Oct  5 2024 tonyj@suse.de
- perf probe: Convert to check dwarf_getcfi feature
  (perf-sp7-v6.11-userspace-update).
- commit d221ab2
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Add feature check for dwarf_getcfi()
  (perf-sp7-v6.11-userspace-update).
- commit 073c34e
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Add die_find_variable_by_reg() helper
  (perf-sp7-v6.11-userspace-update).
- commit 0085b87
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Add die_get_scopes() alternative to
  dwarf_getscopes() (perf-sp7-v6.11-userspace-update).
- commit 57c60a8
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Move #else block of #ifdef
  HAVE_DWARF_GETLOCATIONS_SUPPORT code to the header file
  (perf-sp7-v6.11-userspace-update).
- commit 6442b01
* Sat Oct  5 2024 tonyj@suse.de
- perf dwarf-aux: Fix die_get_typename() for void *
  (perf-sp7-v6.11-userspace-update).
- commit 7917f67
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Add util/debuginfo. files
  (perf-sp7-v6.11-userspace-update).
- commit 90ea231
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Move raw_comment and raw_func_start fields out of
  'struct ins_operands' (perf-sp7-v6.11-userspace-update).
- commit 40b60f1
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Pass "-l" option to objdump conditionally
  (perf-sp7-v6.11-userspace-update).
- commit 392087d
* Sat Oct  5 2024 tonyj@suse.de
- perf header: Additional note on AMD IBS for max_precise pmu cap
  (perf-sp7-v6.11-userspace-update).
- commit 7ee4fcd
* Sat Oct  5 2024 tonyj@suse.de
- perf bpf: Don't synthesize BPF events when disabled
  (perf-sp7-v6.11-userspace-update).
- commit 8d68631
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Add support for setting objdump binary via perf
  config (perf-sp7-v6.11-userspace-update).
- commit 839930e
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Add option to change objdump binary
  (perf-sp7-v6.11-userspace-update).
- commit 6b73d78
* Sat Oct  5 2024 tonyj@suse.de
- perf tests offcpu: Adjust test case perf record offcpu profiling
  tests for s390 (perf-sp7-v6.11-userspace-update).
- commit 8938b4c
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Add the python_ext_build directory to .gitignore
  (perf-sp7-v6.11-userspace-update).
- commit adaa1f6
* Sat Oct  5 2024 tonyj@suse.de
- perf tests attr: Fix spelling mistake "whic" to "which"
  (perf-sp7-v6.11-userspace-update).
- commit cb80087
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Move offsets array from 'struct annotation' to
  'struct annotated_source' (perf-sp7-v6.11-userspace-update).
- commit 15a3792
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Move some source code related fields
  from 'struct annotation' to 'struct annotated_source'
  (perf-sp7-v6.11-userspace-update).
- commit 22399b5
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Move max_coverage from 'struct annotation' to
  'struct annotated_branch' (perf-sp7-v6.11-userspace-update).
- commit dff36ea
* Sat Oct  5 2024 tonyj@suse.de
- perf annotate: Split branch stack cycles info from 'struct
  annotation' (perf-sp7-v6.11-userspace-update).
- commit 0fae590
* Sat Oct  5 2024 tonyj@suse.de
- perf test: Simplify "object code reading" test
  (perf-sp7-v6.11-userspace-update).
- commit c3d81b1
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Fix spelling mistake "parametrized" ->
  "parameterized" (perf-sp7-v6.11-userspace-update).
- commit d6dd2af
* Sat Oct  5 2024 tonyj@suse.de
- perf build: Warn about missing libelf before warning about
  missing libbpf (perf-sp7-v6.11-userspace-update).
- commit ff822de
* Sat Oct  5 2024 tonyj@suse.de
- perf tests make: Remove the last egrep call, use 'grep -E'
  instead (perf-sp7-v6.11-userspace-update).
- commit 2e65c2a
* Sat Oct  5 2024 tonyj@suse.de
- perf beauty socket/prctl_option: Cope with extended regexp
  complaint by grep (perf-sp7-v6.11-userspace-update).
- commit 294b944
* Sat Oct  5 2024 tonyj@suse.de
- tools headers: Update tools's copy of socket.h header
  (perf-sp7-v6.11-userspace-update).
- commit bd1746c
* Sat Oct  5 2024 tonyj@suse.de
- tools headers UAPI: Update tools's copy of kvm.h header
  (perf-sp7-v6.11-userspace-update).
- commit 1e54b42
* Sat Oct  5 2024 tonyj@suse.de
- tools headers UAPI: Update tools's copy of drm headers
  (perf-sp7-v6.11-userspace-update).
- commit c9fa43d
* Sat Oct  5 2024 tonyj@suse.de
- perf tools: Update copy of libbpf's hashmap.c
  (perf-sp7-v6.11-userspace-update).
- commit aad248b
* Fri Oct  4 2024 jroedel@suse.de
- iommu/vt-d: Move inline helpers to header files (jsc#PED-10968).
- Refresh
  patches.suse/iommu-vt-d-Use-rbtree-to-track-iommu-probed-devices.patch.
- Refresh patches.suse/kabi-padding-for-vmstat-items.patch.
- commit 67017af
* Fri Oct  4 2024 mkoutny@suse.com
- rcu-tasks: Fix show_rcu_tasks_trace_gp_kthread buffer overflow
  (bsc#1226631).
- commit 36faf07
* Fri Oct  4 2024 mwilck@suse.com
- scsi: fnic: Move flush_work initialization out of if block
  (bsc#1230055).
- commit 9b5b899
* Fri Oct  4 2024 mkoutny@suse.com
- rcu: Fix buffer overflow in print_cpu_stall_info()
  (bsc#1226623).
- commit b695829
* Fri Oct  4 2024 jroedel@suse.de
- iommu/sva: Fix SVA handle sharing in multi device case
  (jsc#PED-10968).
- commit 4e6caa7
* Fri Oct  4 2024 jroedel@suse.de
- vfio/virtio: Introduce a vfio driver over virtio devices
  (jsc#PED-10968).
- Update config files.
- supported.conf: Mark virtio-vfio-pci unsupported
- commit ad306c3
* Fri Oct  4 2024 jroedel@suse.de
- virtio-pci: Initialize the supported admin commands
  (jsc#PED-10968).
- Update config files.
- commit 70bc83d
* Fri Oct  4 2024 jroedel@suse.de
- virtio-pci: Introduce admin virtqueue (jsc#PED-10968).
- Refresh
  patches.suse/virtio-reenable-config-if-freezing-device-failed.patch.
- commit ca17a79
* Fri Oct  4 2024 jroedel@suse.de
- vfio/migration: Add debugfs to live migration driver
  (jsc#PED-10968).
- Update config files.
- commit 2cb63fa
* Fri Oct  4 2024 jroedel@suse.de
- iommu: Mark dev_iommu_priv_set() with a lockdep (jsc#PED-10968).
- Refresh
  patches.suse/0002-iommu-vt-d-Fix-NULL-domain-on-device-release.patch.
- Refresh
  patches.suse/iommu-vt-d-Use-rbtree-to-track-iommu-probed-devices.patch.
- commit 5d6f1d9
* Fri Oct  4 2024 jroedel@suse.de
- iommu: Change kconfig around IOMMU_SVA (jsc#PED-10968).
- Update config files.
- commit c2b65fc
* Fri Oct  4 2024 jroedel@suse.de
- iommu: Retire bus ops (jsc#PED-10968).
- Refresh
  patches.suse/kabi-Add-placeholders-to-a-couple-of-important-struc.patch.
- commit a734b63
* Fri Oct  4 2024 jroedel@suse.de
- iommu: Factor out some helpers (jsc#PED-10968).
- Refresh
  patches.suse/iommu-Allow-ops-default_domain-to-work-when-CONFIG_IOMMU_DMA.
- commit 6ccd5b4
* Fri Oct  4 2024 jroedel@suse.de
- iommu/vt-d: Remove unused vcmd interfaces (jsc#PED-10968).
- Refresh
  patches.suse/0002-iommu-vt-d-Fix-NULL-domain-on-device-release.patch.
- commit 096de31
* Fri Oct  4 2024 jroedel@suse.de
- iommu/vt-d: Refactor device_to_iommu() to retrieve iommu
  directly (jsc#PED-10968).
- Refresh
  patches.suse/iommu-vt-d-Use-rbtree-to-track-iommu-probed-devices.patch.
- commit 2f8fbb5
* Fri Oct  4 2024 jroedel@suse.de
- iommu/sva: Restore SVA handle sharing (jsc#PED-10968).
- iommu/arm-smmu-v3: Do not use GFP_KERNEL under as spinlock
  (jsc#PED-10968).
- iommu/vt-d: Fix constant-out-of-range warning (jsc#PED-10968).
- iommu/vt-d: Add missing dirty tracking set for parent domain
  (jsc#PED-10968).
- iommu/vt-d: Wrap the dirty tracking loop to be a helper
  (jsc#PED-10968).
- iommu/vt-d: Remove domain parameter for
  intel_pasid_setup_dirty_tracking() (jsc#PED-10968).
- iommu/vt-d: Add missing device iotlb flush for parent domain
  (jsc#PED-10968).
- iommu/vt-d: Add missing iotlb flush for parent domain
  (jsc#PED-10968).
- iommu/vt-d: Add __iommu_flush_iotlb_psi() (jsc#PED-10968).
- iommu/vt-d: Track nested domains in parent (jsc#PED-10968).
- iommufd/iova_bitmap: Handle recording beyond the mapped pages
  (jsc#PED-10968).
- vfio/virtio: fix virtio-pci dependency (jsc#PED-10968).
- vfio/virtio: Declare virtiovf_pci_aer_reset_done() static
  (jsc#PED-10968).
- vfio/pci: Expose vfio_pci_core_iowrite/read##size()
  (jsc#PED-10968).
- vfio/pci: Expose vfio_pci_core_setup_barmap() (jsc#PED-10968).
- virtio-pci: Introduce APIs to execute legacy IO admin commands
  (jsc#PED-10968).
- virtio-pci: Introduce admin commands (jsc#PED-10968).
- virtio-pci: Introduce admin command sending function
  (jsc#PED-10968).
- virtio: Define feature bit for administration virtqueue
  (jsc#PED-10968).
- vfio/type1: account iommu allocations (jsc#PED-10968).
- vfio/pds: Add multi-region support (jsc#PED-10968).
- vfio/pds: Move seq/ack bitmaps into region struct
  (jsc#PED-10968).
- vfio/pds: Pass region info to relevant functions
  (jsc#PED-10968).
- vfio/pds: Move and rename region specific info (jsc#PED-10968).
- vfio/pds: Only use a single SGL for both seq and ack
  (jsc#PED-10968).
- MAINTAINERS: Add vfio debugfs interface doc link
  (jsc#PED-10968).
- Documentation: add debugfs description for vfio (jsc#PED-10968).
- iommu/vt-d: Add iotlb flush for nested domain (jsc#PED-10968).
- iommufd: Add data structure for Intel VT-d stage-1 cache
  invalidation (jsc#PED-10968).
- iommu: Add iommu_copy_struct_from_user_array helper
  (jsc#PED-10968).
- iommufd: Add IOMMU_HWPT_INVALIDATE (jsc#PED-10968).
- iommu: Add cache_invalidate_user op (jsc#PED-10968).
- iommu/sva: Fix memory leak in iommu_sva_bind_device()
  (jsc#PED-10968).
- acpi: Do not return struct iommu_ops from
  acpi_iommu_configure_id() (jsc#PED-10968).
- iommu: Mark dev_iommu_get() with lockdep (jsc#PED-10968).
- iommu/of: Use -ENODEV consistently in of_iommu_configure()
  (jsc#PED-10968).
- iommmu/of: Do not return struct iommu_ops from
  of_iommu_configure() (jsc#PED-10968).
- iommu: Remove struct iommu_ops *iommu from arch_setup_dma_ops()
  (jsc#PED-10968).
- iommu: Set owner token to SVA domain (jsc#PED-10968).
- mm: Deprecate pasid field (jsc#PED-10968).
- iommu: Support mm PASID 1:n with sva domains (jsc#PED-10968).
- mm: Add structure to keep sva information (jsc#PED-10968).
- iommu: Add mm_get_enqcmd_pasid() helper function
  (jsc#PED-10968).
- iommu/vt-d: Remove mm->pasid in intel_sva_bind_mm()
  (jsc#PED-10968).
- iommu: Extend LPAE page table format to support custom
  allocators (jsc#PED-10968).
- iommu: Allow passing custom allocators to pgtable drivers
  (jsc#PED-10968).
- iommu: Clean up open-coded ownership checks (jsc#PED-10968).
- iommu/arm-smmu: Don't register fwnode for legacy binding
  (jsc#PED-10968).
- iommu: Decouple iommu_domain_alloc() from bus ops
  (jsc#PED-10968).
- iommu: Decouple iommu_present() from bus ops (jsc#PED-10968).
- iommu/amd/pgtbl_v2: Invalidate updated page ranges only
  (jsc#PED-10968).
- iommu/amd: Make domain_flush_pages as global function
  (jsc#PED-10968).
- iommu/amd: Consolidate amd_iommu_domain_flush_complete() call
  (jsc#PED-10968).
- iommu/amd: Refactor device iotlb invalidation code
  (jsc#PED-10968).
- iommu/amd: Refactor IOMMU tlb invalidation code (jsc#PED-10968).
- iommu/amd: Add support to invalidate multiple guest pages
  (jsc#PED-10968).
- iommu/amd: Remove redundant passing of PDE bit (jsc#PED-10968).
- iommu/amd: Remove redundant domain flush from attach_device()
  (jsc#PED-10968).
- iommu/amd: Rename iommu_flush_all_caches() ->
  amd_iommu_flush_all_caches() (jsc#PED-10968).
- iommu/amd: Do not flush IRTE when only updating isRun and
  destination fields (jsc#PED-10968).
- iommu/amd: Set variable amd_dirty_ops to static (jsc#PED-10968).
- iommu/vt-d: Remove unused parameter of
  intel_pasid_setup_pass_through() (jsc#PED-10968).
- iommu/virtio: Add ops->flush_iotlb_all and enable deferred flush
  (jsc#PED-10968).
- iommu/virtio: Make use of ops->iotlb_sync_map (jsc#PED-10968).
- dt-bindings: arm-smmu: Document SM850 GPU SMMU (jsc#PED-10968).
- dt-bindings: arm-smmu: Add compatible for X1E80100 SoC
  (jsc#PED-10968).
- dt-bindings: iommu: arm,smmu: document the SM8650 System MMU
  (jsc#PED-10968).
- dt-bindings: iommu: arm,smmu: document clocks for the SM8350
  GPU SMMU (jsc#PED-10968).
- iommu/arm-smmu: Convert to domain_alloc_paging()
  (jsc#PED-10968).
- iommu/arm-smmu: Pass arm_smmu_domain to internal functions
  (jsc#PED-10968).
- iommu/arm-smmu: Implement IOMMU_DOMAIN_BLOCKED (jsc#PED-10968).
- iommu/arm-smmu: Convert to a global static identity domain
  (jsc#PED-10968).
- iommu/arm-smmu: Reorganize arm_smmu_domain_add_master()
  (jsc#PED-10968).
- iommu/arm-smmu-v3: Remove ARM_SMMU_DOMAIN_NESTED
  (jsc#PED-10968).
- iommu/arm-smmu-v3: Master cannot be NULL in
  arm_smmu_write_strtab_ent() (jsc#PED-10968).
- iommu/arm-smmu-v3: Add a type for the STE (jsc#PED-10968).
- iommu/arm-smmu-v3: disable stall for quiet_cd (jsc#PED-10968).
- iommu/qcom: restore IOMMU state if needed (jsc#PED-10968).
- iommu/arm-smmu-qcom: Add QCM2290 MDSS compatible
  (jsc#PED-10968).
- iommu/arm-smmu-qcom: Add missing GMU entry to match table
  (jsc#PED-10968).
- dt-bindings: iommu: rockchip: Add Rockchip RK3588
  (jsc#PED-10968).
- iommu/apple-dart: Fix spelling mistake "grups" -> "groups"
  (jsc#PED-10968).
- iommu/apple-dart: Use readl instead of readl_relaxed for
  consistency (jsc#PED-10968).
- iommu/apple-dart: Add support for t8103 USB4 DART
  (jsc#PED-10968).
- iommu/apple-dart: Write to all DART_T8020_STREAM_SELECT
  (jsc#PED-10968).
- dt-bindings: iommu: dart: Add t8103-usb4-dart compatible
  (jsc#PED-10968).
- virtio_pci: move structure to a header (jsc#PED-10968).
- virtio_pci: add check for common cfg size (jsc#PED-10968).
- virtio: add definition of VIRTIO_F_NOTIF_CONFIG_DATA feature
  bit (jsc#PED-10968).
- commit bd2789c
* Fri Oct  4 2024 msuchanek@suse.de
- Revert "powerpc: Make virt_to_pfn() a static inline (jsc#PED-11016)."
  This reverts commit d0cb6b3420233c02894f91524b8c83a120864ceb.
  This change is intended to flag virt_to_pfn users passing in wrong type,
  and we have quite a few in the tree.
- commit 3f05b9d
* Fri Oct  4 2024 tiwai@suse.de
- blacklist.conf: move SLE15-SP7 specific entry to its own section
- commit 50831c6
* Fri Oct  4 2024 msuchanek@suse.de
- Replace ALP with SLFO
- Refresh patches.suse/kernel-add-product-identifying-information-to-kernel-build.patch
- Update config files.
- commit 267a9d3
* Fri Oct  4 2024 msuchanek@suse.de
- rpm/release-projects: Add SLFO projects (bsc#1231293).
- commit 9f2c584
* Thu Oct  3 2024 msuchanek@suse.de
- Update patches.suse/powerpc-qspinlock-Fix-deadlock-in-MCS-queue.patch
  (bsc#1230295 ltc#206656 CVE-2024-46797 bsc#1230831).
- commit af09bb2
* Thu Oct  3 2024 mfranc@suse.cz
- KVM: s390: Fix SORTL and DFLTCC instruction format error in
  __insn32_query (git-fixes bsc#1231276).
- commit 39bab2d
* Thu Oct  3 2024 tabraham@suse.com
- s390/mm: Add cond_resched() to cmm_alloc/free_pages()
  (bsc#1228747).
- commit d0c79ab
* Thu Oct  3 2024 pjakobsson@suse.de
- blacklist.conf: c52c35e5b404 accel/ivpu: Return max freq for DRM_IVPU_PARAM_CORE_CLOCK_RATE
- commit c42fa2e
* Thu Oct  3 2024 pjakobsson@suse.de
- Refresh patches.suse/1927-accel-ivpu-avoid-build-failure-with-CONFIG_PM-n.patch (git-fixes)
  Alt-commit
- commit 2df1fee
* Wed Oct  2 2024 dsterba@suse.com
- blacklist.conf: CVE-2024-46833 bsc#1231119: not applicable
  Code to to dump SSU registers not present (added in 8a4bda8cb9e43e
  ("net: hns3: dump more reg info based on ras mod")).
- commit ea16f85
* Wed Oct  2 2024 dsterba@suse.com
- ELF: fix kernel.randomize_va_space double read (CVE-2024-46826 bsc#1231115)
- commit 0519fb0
* Wed Oct  2 2024 dsterba@suse.com
- Update references for patches.suse/ASoC-Intel-soc-acpi-intel-mtl-match-add-missing-empt.patch (CVE-2024-46862 bsc#1231091 git-fixes)
- commit 2b8e71d
* Wed Oct  2 2024 dsterba@suse.com
- Update references for patches.suse/ASoC-Intel-soc-acpi-intel-lnl-match-add-missing-empt.patch (CVE-2024-46863 bsc#1231097 git-fixes).
- commit 030c4b2
* Wed Oct  2 2024 dsterba@suse.com
- net/mlx5: Fix bridge mode operations when there are no VFs (CVE-2024-46857 bsc#1231087)
- commit b20fc2c
* Wed Oct  2 2024 dsterba@suse.com
- netfilter: nft_socket: fix sk refcount leaks (CVE-2024-46855 bsc#1231085)
- commit 6c66212
* Wed Oct  2 2024 tbogendoerfer@suse.de
- net: microchip: vcap: Fix use-after-free error in kunit test
  (CVE-2024-46831 bsc#1231117).
- commit 630e2e8
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu/37xx: Fix interrupt_clear_with_0 WA initialization (drm-backport-placeholder)
- commit 90be63c
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: avoid build failure with CONFIG_PM=n (drm-backport-placeholder)
- commit c23dcdd
* Wed Oct  2 2024 pjakobsson@suse.de
- intel drm: Remove now superfluous sentinel element from ctl_table (drm-backport-placeholder)
- commit f057d9b
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Delete the TODO file (drm-backport-placeholder)
- commit 68b4650
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu/37xx: Remove support for FPGA and simics (drm-backport-placeholder)
- commit 3e2f052
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Do not initialize parameters on power up (drm-backport-placeholder).
- Refresh patches.suse/accel-ivpu-37xx-Fix-hangs-related-to-MMIO-reset.patch.
- commit ec10362
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Print IPC type string instead of number (drm-backport-placeholder)
- commit b5d137e
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Read clock rate only if device is up (drm-backport-placeholder)
- commit a121165
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Fix verbose version of REG_POLL macros (drm-backport-placeholder)
- commit c5a44ed
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Use ratelimited warn and err in IPC/JSM (drm-backport-placeholder)
- commit a2af9b3
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Add ivpu_bo_vaddr() and ivpu_bo_size() (drm-backport-placeholder)
- commit 2970210
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: fix spmu mask creation (drm-backport-placeholder)
- commit 07abb46
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: perform hard-reset upon PCIe AXI drain event (drm-backport-placeholder)
- commit 11ae380
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: fix bug in decoder wait for cs completion (drm-backport-placeholder)
- commit 492eba0
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: remove wrong doc for init_phys_pg_pack_from_userptr (drm-backport-placeholder)
- commit 0ef9fea
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: add missing debugfs function stubs (drm-backport-placeholder)
- commit a02d02a
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: minor cosmetic update to habanalabs.h (drm-backport-placeholder)
- commit a3227f7
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi: remove define used for simulator (drm-backport-placeholder)
- commit baa7260
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: remove leftover code (drm-backport-placeholder)
- commit 3add1bf
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: print device name when it is removed (drm-backport-placeholder)
- commit 2b4cef9
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: remove unused field (drm-backport-placeholder)
- commit e1a50da
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi: remove unused structure definition (drm-backport-placeholder)
- commit 8cc42cc
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: minor cosmetics update to trace file (drm-backport-placeholder)
- commit 386d94e
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: minor cosmetics update to cpucp_if.h (drm-backport-placeholder)
- commit 36c8348
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: trace dma map sgtable (drm-backport-placeholder)
- commit e3721b7
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: add traces for dma mappings (drm-backport-placeholder)
- commit cbef096
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: remove unused asic functions (drm-backport-placeholder)
- commit 1765a46
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: update boot status print (drm-backport-placeholder)
- commit 34ef07d
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: extend preboot timeout when preboot might take (drm-backport-placeholder)
- commit 04f8958
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: add fw status SHUTDOWN_PREP (drm-backport-placeholder)
- commit 5c1e966
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: add debug prints to dump content of SG table for (drm-backport-placeholder)
- commit 3ef70b4
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: add missing offset handling for dma-buf (drm-backport-placeholder)
- commit f7a6990
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: set hl_dmabuf_priv.device_address only when needed (drm-backport-placeholder)
- commit 3d496be
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: fix SG table creation for dma-buf mapping (drm-backport-placeholder)
- commit 86ed9da
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: split user interrupts pending list (drm-backport-placeholder)
- commit 65bcbae
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: optimize timestamp registration handler (drm-backport-placeholder)
- commit b950150
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: fix bug in timestamp interrupt handling (drm-backport-placeholder)
- commit 80b9d5d
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: tiny refactor of hl_map_dmabuf() (drm-backport-placeholder)
- commit 27e179b
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: export dma-buf only if size/offset multiples of (drm-backport-placeholder)
- commit fe499e9
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: use exported size from dma_buf and not from (drm-backport-placeholder)
- commit f796ad5
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: always pass exported size to (drm-backport-placeholder)
- commit 3294143
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: prevent sending heartbeat before events are enabled (drm-backport-placeholder)
- commit 5040efd
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: add eq health check using irq (drm-backport-placeholder)
- commit a88546c
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: handle eq health heartbeat check (drm-backport-placeholder)
- commit 4dcf4b5
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: print power-mode changes (drm-backport-placeholder)
- commit 5953201
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: fix inline doc typos (drm-backport-placeholder)
- commit 5e4a904
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: disable events ioctls on control device (drm-backport-placeholder)
- commit af897ae
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: move cpucp interface to linux/habanalabs (drm-backport-placeholder)
- commit d211dbd
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: include block id in ECC error reporting (drm-backport-placeholder)
- commit 90dd4b9
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: improve etf configuration (drm-backport-placeholder)
- commit 026182a
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: refactor deprecated strncpy (drm-backport-placeholder)
- commit b06dbfa
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: refactor deprecated strncpy to strscpy_pad (drm-backport-placeholder)
- commit f0a70ae
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: fix ETR/ETF flush logic (drm-backport-placeholder)
- commit 8e9c2b3
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2 : remove psoc_arc access (drm-backport-placeholder)
- commit 8147be3
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: prepare to remove cpu_rst_status (drm-backport-placeholder)
- commit ca38abc
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: Move ioctls to the device specific ioctls range (drm-backport-placeholder)
- commit 2be2f89
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: register compute device as an accel device (drm-backport-placeholder)
- commit ccfc2da
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: add info ioctl for engine error reports (drm-backport-placeholder)
- commit aa233bb
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: set default device release watchdog T/O as 30 sec (drm-backport-placeholder)
- commit 082a563
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: handle f/w reserved dram space request (drm-backport-placeholder)
- commit 73758ec
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: fix missing check of kernel ctx (drm-backport-placeholder)
- commit badac14
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: prepare to remove soft_rst_irq (drm-backport-placeholder)
- commit 051f20b
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: unsecure tpc count registers (drm-backport-placeholder)
- commit 7ad0e0d
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi2: un-secure register for engine cores (drm-backport-placeholder)
- commit 5c22a63
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs/gaudi: Add MODULE_FIRMWARE macros (drm-backport-placeholder)
- commit 1575c70
* Wed Oct  2 2024 pjakobsson@suse.de
- accel: make accel_class a static const structure (drm-backport-placeholder)
- commit 3a06aaa
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: dump temperature threshold boot error (drm-backport-placeholder)
- commit 27be81f
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: reset device if scrubbing failed (drm-backport-placeholder)
- commit 70a9b18
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: remove pdev check on idle check (drm-backport-placeholder)
- commit abc97e6
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: fix wait_for_interrupt abortion flow (drm-backport-placeholder)
- commit 38d4972
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: Allow single timestamp registration request at a (drm-backport-placeholder)
- commit 9aa6a6e
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: rename fd_list to hpriv_list (drm-backport-placeholder)
- commit 11fe401
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: call put_pid after hpriv list is updated (drm-backport-placeholder)
- commit 601ebc5
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: print return code when process termination fails (drm-backport-placeholder)
- commit c1d67b1
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: fix standalone preboot descriptor request (drm-backport-placeholder)
- commit 02eae7b
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: handle arc farm razwi (drm-backport-placeholder)
- commit 05680e3
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: stop fetching MME SBTE error cause (drm-backport-placeholder)
- commit f2dba05
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: set device status 'malfunction' while in rmmod (drm-backport-placeholder)
- commit e9242b6
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: print task name upon creation of a user context (drm-backport-placeholder)
- commit 26d2725
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: print task name and request code upon ioctl failure (drm-backport-placeholder)
- commit 5882ff8
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: notify user about undefined opcode event (drm-backport-placeholder)
- commit a401c05
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: update pending reset flags with new reset requests (drm-backport-placeholder)
- commit 8cbf3c7
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/habanalabs: prevent immediate hard reset due to 2 adjacent H/W (drm-backport-placeholder)
- commit f291402
* Wed Oct  2 2024 pjakobsson@suse.de
- fbdev: Replace fb_pgprotect() with pgprot_framebuffer() (drm-backport-placeholder).
- commit 809d5cc
* Wed Oct  2 2024 pjakobsson@suse.de
- arch/m68k: Implement <asm/fb.h> with generic helpers (drm-backport-placeholder)
- commit 3dc7520
* Wed Oct  2 2024 pjakobsson@suse.de
- arch/m68k: Merge variants of fb_pgprotect() into single function (drm-backport-placeholder)
- commit 1271584
* Wed Oct  2 2024 pjakobsson@suse.de
- fbdev: Avoid file argument in fb_pgprotect() (drm-backport-placeholder)
- commit aa58fef
* Wed Oct  2 2024 pjakobsson@suse.de
- drm/i915: Zap some empty lines (drm-backport-placeholder)
- commit 2ecdc43
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Compile ivpu_debugfs.c conditionally (drm-backport-placeholder)
- commit 5c81b42
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Update debugfs to latest changes in DRM (drm-backport-placeholder)
- commit e0aec29
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/qaic: Add QAIC_DETACH_SLICE_BO IOCTL (drm-backport-placeholder)
- commit a037459
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/qaic: Create a function to initialize BO (drm-backport-placeholder)
- commit 5f103ca
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/qaic: Clean up BO during flushing of transfer list (drm-backport-placeholder)
- commit 524e4db
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/qaic: Undo slicing setup done in qaic_attach_slicing_bo() (drm-backport-placeholder)
- commit bc830fc
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/qaic: Declare BO 'sliced' after all the operations are complete (drm-backport-placeholder)
- commit 2901c86
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/qaic: Update BO metadata in a central location (drm-backport-placeholder)
- commit 9749bca
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/qaic: Use devm_drm_dev_alloc() instead of drm_dev_alloc() (drm-backport-placeholder)
- commit 347af6a
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/qaic: Register for PCI driver at the beginning of module init (drm-backport-placeholder)
- commit 2449127
* Wed Oct  2 2024 pjakobsson@suse.de
- drm: bridge: it66121: Simplify probe() (drm-backport-placeholder)
- commit 8c18ef5
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Print information about used workarounds (drm-backport-placeholder)
- commit ec18a83
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Move MMU register definitions to ivpu_mmu.c (drm-backport-placeholder)
- commit 51c30da
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu/37xx: White space cleanup (drm-backport-placeholder)
- commit 7db4f18
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu/37xx: Change register rename leftovers (drm-backport-placeholder)
- commit 77c878f
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Move ivpu_fw_load() to ivpu_fw_init() (drm-backport-placeholder)
- commit c78406a
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Initialize context with SSID = 1 (drm-backport-placeholder)
- commit b9327ce
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Add information about context on failure (drm-backport-placeholder)
- commit e133fc0
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Make ivpu_pm_init() void (drm-backport-placeholder)
- commit db1b911
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Remove duplicated error messages (drm-backport-placeholder)
- commit 5f6fa77
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Move set autosuspend delay to HW specific code (drm-backport-placeholder)
- commit 069ea86
* Wed Oct  2 2024 pjakobsson@suse.de
- accel/ivpu: Annotate struct ivpu_job with __counted_by (drm-backport-placeholder)
- commit eae7ec1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1372-i2c-Add-i2c_get_match_data.patch (drm-backport-placeholder)
- commit 3e98e72
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0002-PCI-Add-pci_is_vga-helper.patch (drm-backport-placeholder)
- commit c6b02da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/string.h-add-array-wrappers-for-v-memdup_user.patch (drm-backport-placeholder)
- commit 0b72fe3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0001-PCI-Add-pci_get_base_class-helper.patch (drm-backport-placeholder)
- commit 3a1d0c6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2012-drm-nouveau-dp-Honor-GSP-link-training-retry-timeout.patch (drm-backport-placeholder)
- commit 717d6eb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2011-nouveau-push-event-block-allowing-out-of-the-fence-c.patch (drm-backport-placeholder)
- commit 05fc83e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2010-nouveau-gsp-always-free-the-alloc-messages-on-r535.patch (drm-backport-placeholder)
- commit 738dfe4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2009-nouveau-gsp-don-t-free-ctrl-messages-on-errors.patch (drm-backport-placeholder)
- commit 70ddcb1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2008-nouveau-gsp-convert-gsp-errors-to-generic-errors.patch (drm-backport-placeholder)
- commit 65234db
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2007-drm-nouveau-gsp-Fix-ACPI-MXDM-MXDS-method-invocation.patch (drm-backport-placeholder)
- commit a8acce7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2006-nouveau-gsp-free-userd-allocation.patch (drm-backport-placeholder)
- commit 5710cf4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2005-nouveau-gsp-free-acpi-object-after-use.patch (drm-backport-placeholder)
- commit 4f6d20d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2004-nouveau-fix-disp-disabling-with-GSP.patch (drm-backport-placeholder)
- commit 85e6cd9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2003-nouveau-gsp-drop-some-acpi-related-debug.patch (drm-backport-placeholder)
- commit 1497082
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2002-nouveau-gsp-add-three-notifier-callbacks-that-we-see.patch (drm-backport-placeholder)
- commit 06bc903
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2001-drm-amd-pm-Use-gpu_metrics_v1_5-for-SMUv13.0.6.patch (drm-backport-placeholder)
- commit 38fb975
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/2000-drm-amd-pm-Add-gpu_metrics_v1_5.patch (drm-backport-placeholder)
- commit b357943
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1999-drm-amd-pm-Add-mem_busy_percent-for-GCv9.4.3-apu.patch (drm-backport-placeholder)
- commit b332265
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-sending-VSC-colorimetry-packets-.patch (drm-backport-placeholder)
- commit 7d4ed45
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-skip-gpu_info-fw-loading-on-navi12.patch (drm-backport-placeholder)
- commit d09e5f7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-add-nv12-bounding-box.patch (drm-backport-placeholder)
- commit 300f1dc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1995-drm-amd-pm-Update-metric-table-for-jpeg-vcn-data.patch (drm-backport-placeholder)
- commit e972b2e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1994-drm-amd-pm-Use-separate-metric-table-for-APU.patch (drm-backport-placeholder)
- commit 907e01b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-pbn_div-need-be-updated-for-hotplug-.patch (drm-backport-placeholder)
- commit 84c36df
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mgag200-Fix-gamma-lut-not-initialized-for-G200ER.patch (drm-backport-placeholder)
- commit 3cbee37
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-ps8640-Fix-size-mismatch-warning-w-len.patch (drm-backport-placeholder)
- commit 6e08806
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-ti-sn65dsi86-Never-store-more-than-msg-si.patch (drm-backport-placeholder)
- commit 506595a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-parade-ps8640-Never-store-more-than-msg-s.patch (drm-backport-placeholder)
- commit beeb008
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/accel-qaic-Implement-quirk-for-SOC_HW_VERSION.patch (drm-backport-placeholder)
- commit a6fe112
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/accel-qaic-Fix-GEM-import-path-code.patch (drm-backport-placeholder)
- commit 8151fbe
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-perf-Update-handling-of-MMIO-triggered-repo.patch (drm-backport-placeholder)
- commit b89a945
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dp-Fix-passing-the-correct-DPCD_REV-for-drm.patch (drm-backport-placeholder)
- commit 1d4e565
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dmc-Don-t-enable-any-pipe-DMC-events.patch (drm-backport-placeholder)
- commit bd6330c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-mtl-Fix-HDMI-DP-PLL-clock-selection.patch (drm-backport-placeholder)
- commit ffada22
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Reject-async-flips-with-bigjoiner.patch (drm-backport-placeholder)
- commit b134555
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-hwmon-Fix-static-analysis-tool-reported-iss.patch (drm-backport-placeholder)
- commit 251cf77
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1982-drm-i915-display-Get-bigjoiner-config-before-dsc-con.patch (drm-backport-placeholder)
- commit 6928942
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-re-create-idle-bo-s-PTE-during-VM-state-m.patch (drm-backport-placeholder)
- commit bf82ef2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1980-drm-amd-display-dereference-variable-before-checking.patch (drm-backport-placeholder)
- commit 243599a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-get-dprefclk-ss-info-from-integratio.patch (drm-backport-placeholder)
- commit d91f7b1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-case-for-dcn35-to-support-usb4-d.patch (drm-backport-placeholder)
- commit c69de3d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1977-drm-amd-display-disable-FPO-and-SubVP-for-older-DMUB.patch (drm-backport-placeholder)
- commit 2b5fb00
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-svm-range-always-mapped-flag-not-working-.patch (drm-backport-placeholder)
- commit 88dd594
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1975-drm-amd-display-Revert-drm-amd-display-Use-channel_w.patch (drm-backport-placeholder)
- commit 574a7b4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1974-drm-nouveau-kms-nv50-Don-t-allow-inheritance-of-head.patch (drm-backport-placeholder)
- commit ee32972
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1973-drm-nouveau-Fixup-gk20a-instobj-hierarchy.patch (drm-backport-placeholder)
- commit 27b216d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1972-drm-panel-ltk050h3146w-Set-burst-mode-for-ltk050h314.patch (drm-backport-placeholder)
- commit 63c5bb3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-edid-also-call-add-modes-in-EDID-connector-updat.patch (drm-backport-placeholder)
- commit da5356a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-crtc-fix-uninitialized-variable-use.patch (drm-backport-placeholder)
- commit c81dca8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-crtc-Fix-uninit-value-bug-in-drm_mode_setcrtc.patch (drm-backport-placeholder)
- commit 2b5c2e1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-Fix-FD-ownership-check-in-drm_master_check_perm.patch (drm-backport-placeholder)
- commit b295314
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1967-drm-amdgpu-warn-when-there-are-still-mappings-when-a.patch (drm-backport-placeholder)
- commit bd58bbc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-tear-down-order-in-amdgpu_vm_pt_free.patch (drm-backport-placeholder)
- commit ec4e243
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1965-drm-amd-Fix-a-probing-order-problem-on-SDMA-2.4.patch (drm-backport-placeholder)
- commit 2110e80
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-sdma5.2-add-begin-end_use-ring-callbacks.patch (drm-backport-placeholder)
- commit 455e2d9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Disable-PSR-SU-on-Parade-0803-TCON-a.patch (drm-backport-placeholder)
- commit 1ac614c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1962-drm-amd-display-Populate-dtbclk-from-bounding-box.patch (drm-backport-placeholder)
- commit e0cd6bf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1961-drm-amd-display-Revert-Fix-conversions-between-bytes.patch (drm-backport-placeholder)
- commit 52d89cf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1960-drm-amdgpu-jpeg-configure-doorbell-for-each-playback.patch (drm-backport-placeholder)
- commit 7700025
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Restore-guard-against-default-backli.patch (drm-backport-placeholder)
- commit 4f73887
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1958-drm-amd-display-fix-hw-rotated-modes-when-PSR-SU-is-.patch (drm-backport-placeholder)
- commit 20d9f57
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1957-drm-amd-pm-fix-pp_-clk_od-typo.patch (drm-backport-placeholder)
- commit 176a85b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1956-drm-amdgpu-fix-buffer-funcs-setting-order-on-suspend.patch (drm-backport-placeholder)
- commit ac8a2df
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-edp-don-t-write-to-DP_LINK_BW_SET-when-usin.patch (drm-backport-placeholder)
- commit 8198ebb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Fix-ADL-tiled-plane-stride-when-the-POT-str.patch (drm-backport-placeholder)
- commit 4d3282f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Fix-intel_atomic_setup_scalers-plane_state-.patch (drm-backport-placeholder)
- commit 485c5ea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Fix-remapped-stride-with-CCS-on-ADL.patch (drm-backport-placeholder)
- commit e9f7fc7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Use-internal-class-when-counting-engine-res.patch (drm-backport-placeholder)
- commit f4364a9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-selftests-Fix-engine-reset-count-storage-fo.patch (drm-backport-placeholder)
- commit ca12fc7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-access-violation-in-mtk_drm_crtc_dm.patch (drm-backport-placeholder)
- commit b59f786
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Add-spinlock-for-setting-vblank-event-i.patch (drm-backport-placeholder)
- commit 4bac9ea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-fix-kernel-oops-if-no-crtc-is-found.patch (drm-backport-placeholder)
- commit e6a6030
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1946-drm-mediatek-mtk_disp_gamma-Fix-breakage-due-to-merg.patch (drm-backport-placeholder)
- commit 84cffe4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/misc-mei-client.c-fix-problem-of-return-EOVERFLOW-in.patch (drm-backport-placeholder)
- commit 3f3392b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/misc-mei-client.c-return-negative-error-code-in-mei_.patch (drm-backport-placeholder)
- commit a775b23
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1943-mei-pxp-fix-mei_pxp_send_message-return-value.patch (drm-backport-placeholder)
- commit b6eaf15
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-exynos-fix-a-wrong-error-checking.patch (drm-backport-placeholder)
- commit 4d9c616
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-exynos-fix-a-potential-error-pointer-dereference.patch (drm-backport-placeholder)
- commit be632f6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1940-drm-amdgpu-fix-buffer-funcs-setting-order-on-suspend.patch (drm-backport-placeholder)
- commit ba734e1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1939-drm-amdgpu-Avoid-querying-DRM-MGCG-status.patch (drm-backport-placeholder)
- commit 3ddc882
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1938-drm-amdgpu-Update-HDP-4.4.2-clock-gating-flags.patch (drm-backport-placeholder)
- commit a2c43ce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Add-NULL-checks-for-function-pointers.patch (drm-backport-placeholder)
- commit 62fb1cd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1936-drm-amdgpu-Restrict-extended-wait-to-PSP-v13.0.6.patch (drm-backport-placeholder)
- commit 1b8ceee
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Increase-frame-warning-limit-with-KA.patch (drm-backport-placeholder)
- commit 9e23557
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1934-drm-amdgpu-optimize-the-printing-order-of-error-data.patch (drm-backport-placeholder)
- commit de78a22
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1933-drm-amdgpu-Update-fw-version-for-boot-time-error-que.patch (drm-backport-placeholder)
- commit 92ab7a3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1932-drm-amd-pm-support-new-mca-smu-error-code-decoding.patch (drm-backport-placeholder)
- commit adfc710
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1931-drm-amd-swsmu-update-smu-v14_0_0-driver-if-version-a.patch (drm-backport-placeholder)
- commit 3c40690
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1930-drm-amd-display-Fix-array-index-out-of-bounds-in-dml.patch (drm-backport-placeholder)
- commit 9868c4f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-monitor-patch-for-specific-eDP.patch (drm-backport-placeholder)
- commit f436375
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1928-drm-amd-display-Use-channel_width-2-for-vram-table-3.patch (drm-backport-placeholder)
- commit 034dfe3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-disable-MCBP-by-default.patch (drm-backport-placeholder)
- commit 2f56b6c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-atomic-helpers-Invoke-end_fb_access-while-owning.patch (drm-backport-placeholder)
- commit 8973743
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-select-CONFIG_VIDEOMODE_HELPERS.patch (drm-backport-placeholder)
- commit 4e89604
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1924-drm-panfrost-Fix-incorrect-updating-of-current-devic.patch (drm-backport-placeholder)
- commit 7495e56
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1923-drm-panfrost-Consider-dma-buf-imported-objects-as-re.patch (drm-backport-placeholder)
- commit a9e6316
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-tu102-flush-all-pdbs-on-vmm-flush.patch (drm-backport-placeholder)
- commit d6799f8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1921-nouveau-gsp-document-some-aspects-of-GSP-RM.patch (drm-backport-placeholder)
- commit a7f5ada
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1920-drm-i915-correct-the-input-parameter-on-_intel_dsb_c.patch (drm-backport-placeholder)
- commit a2c95e4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-mst-Reject-modes-that-require-the-bigjoiner.patch (drm-backport-placeholder)
- commit bae7236
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-mst-Fix-.mode_valid_ctx-return-values.patch (drm-backport-placeholder)
- commit 9f294ee
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Skip-some-timing-checks-on-BXT-GLK-DSI-tran.patch (drm-backport-placeholder)
- commit 1975ac0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1916-drm-i915-Check-pipe-active-state-in-planes-vrr-_-ena.patch (drm-backport-placeholder)
- commit a0da7bd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-prime-Unexport-helpers-for-fd-handle-conv.patch (drm-backport-placeholder)
- commit 2775d36
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Use-another-offset-for-GC-9.4.3-remap.patch (drm-backport-placeholder)
- commit bbbb7f7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1913-drm-amd-display-Fix-some-HostVM-parameters-in-DML.patch (drm-backport-placeholder)
- commit 49e6ee9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Free-gang_ctx_bo-and-wptr_bo-in-pqm_unini.patch (drm-backport-placeholder)
- commit edb096f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Update-EEPROM-I2C-address-for-smu-v13_0_0.patch (drm-backport-placeholder)
- commit f7e088c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1910-drm-amd-display-Allow-DTBCLK-disable-for-DCN35.patch (drm-backport-placeholder)
- commit 3f53a4f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-cat-debugfs-amdgpu_regs_didt-causes-k.patch (drm-backport-placeholder)
- commit 695a07f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Enable-PCIe-PME-from-D3.patch (drm-backport-placeholder)
- commit f23e479
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-fix-a-memleak-in-aldebaran_tables_init.patch (drm-backport-placeholder)
- commit 5c1737d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1906-drm-amdgpu-fix-AGP-addressing-when-GART-is-not-at-0.patch (drm-backport-placeholder)
- commit 3d9aa7c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-update-dcn315-lpddr-pstate-latency.patch (drm-backport-placeholder)
- commit f4d06e6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-ABM-disablement.patch (drm-backport-placeholder)
- commit 779d384
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1903-drm-amd-display-Fix-black-screen-on-video-playback-w.patch (drm-backport-placeholder)
- commit 2e69b66
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1902-drm-amd-display-Fix-conversions-between-bytes-and-KB.patch (drm-backport-placeholder)
- commit d933b58
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Use-common-function-for-IP-version-check.patch (drm-backport-placeholder)
- commit 39a55fc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1900-drm-amd-display-Remove-config-update.patch (drm-backport-placeholder)
- commit 80ced04
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1899-drm-amd-display-Update-DCN35-clock-table-policy.patch (drm-backport-placeholder)
- commit 8bb6df6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-force-toggle-rate-wa-for-first-link-.patch (drm-backport-placeholder)
- commit 9c25db8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-correct-the-amdgpu-runtime-dereference-us.patch (drm-backport-placeholder)
- commit 8238c8d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Update-min-Z8-residency-time-to-2100.patch (drm-backport-placeholder)
- commit 8e63ade
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Remove-min_dst_y_next_start-check-fo.patch (drm-backport-placeholder)
- commit 8f5e1db
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-memory-overflow-in-the-IB-test.patch (drm-backport-placeholder)
- commit 334bfd8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1893-drm-amdgpu-add-init_registers-for-nbio-v7.11.patch (drm-backport-placeholder)
- commit c952328
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Simplify-brightness-initialization.patch (drm-backport-placeholder)
- commit 96af62e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Increase-num-voltage-states-to-40.patch (drm-backport-placeholder)
- commit 495d9a8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1890-drm-amd-display-Do-not-read-DPREFCLK-spread-info-fro.patch (drm-backport-placeholder)
- commit 1eb760a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Use-DRAM-speed-from-validation-for-d.patch (drm-backport-placeholder)
- commit 877ca7d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1888-drm-amd-display-Fix-MPCC-1DLUT-programming.patch (drm-backport-placeholder)
- commit c9851af
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1887-drm-amd-display-Feed-SR-and-Z8-watermarks-into-DML2-.patch (drm-backport-placeholder)
- commit 6268a89
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Force-order-between-a-read-and-write-to-t.patch (drm-backport-placeholder)
- commit 0b33531
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Do-not-issue-gpu-reset-from-nbio-v7_9-bif.patch (drm-backport-placeholder)
- commit 1ca14e6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1884-drm-amd-display-Add-Z8-watermarks-for-DML2-bbox-over.patch (drm-backport-placeholder)
- commit 476fa70
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1883-drm-amdgpu-optimize-RLC-powerdown-notification-on-Va.patch (drm-backport-placeholder)
- commit 04067bd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1882-drm-amd-display-fix-a-pipe-mapping-error-in-dcn32_fp.patch (drm-backport-placeholder)
- commit d67259b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1881-drm-amd-display-Update-DCN35-watermarks.patch (drm-backport-placeholder)
- commit fc6c820
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1880-drm-amdgpu-update-xgmi-num-links-info-post-gc9.4.2.patch (drm-backport-placeholder)
- commit e899246
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1879-drm-amd-display-Add-z-state-support-policy-for-dcn35.patch (drm-backport-placeholder)
- commit a19782b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Include-udelay-when-waiting-for-INBO.patch (drm-backport-placeholder)
- commit c7081db
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-nt36523-fix-return-value-check-in-nt36523_.patch (drm-backport-placeholder)
- commit dc49d4f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-starry-2081101qfh032011-53g-Fine-tune-the-.patch (drm-backport-placeholder)
- commit bcbc778
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1875-nouveau-gsp-replace-zero-length-array-with-flex-arra.patch (drm-backport-placeholder)
- commit 827e9a8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1874-nouveau-gsp-r535-remove-a-stray-unlock-in-r535_gsp_r.patch (drm-backport-placeholder)
- commit 3b43cdd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-find-the-smallest-page-allocation-to-cover-a.patch (drm-backport-placeholder)
- commit e1e6f5f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1872-drm-gpuvm-Fix-deprecated-license-identifier.patch (drm-backport-placeholder)
- commit a478511
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1871-Revert-drm-bridge-panel-Add-a-device-link-between-dr.patch (drm-backport-placeholder)
- commit 20380e8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1870-Revert-drm-bridge-panel-Check-device-dependency-befo.patch (drm-backport-placeholder)
- commit 2c6000f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/dma-buf-fix-check-in-dma_resv_add_fence.patch (drm-backport-placeholder)
- commit 825d339
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1868-drm-bridge-panel-Check-device-dependency-before-mana.patch (drm-backport-placeholder)
- commit e6b776a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Call-intel_pre_plane_updates-also-for-pipes.patch (drm-backport-placeholder)
- commit 94a90ca
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Also-check-for-VGA-converter-in-eDP-probe.patch (drm-backport-placeholder)
- commit ad188f6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gsc-Mark-internal-GSC-engine-with-reserved-.patch (drm-backport-placeholder)
- commit 85de199
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-do-not-clean-GT-table-on-error-path.patch (drm-backport-placeholder)
- commit 2a25c29
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1863-drm-i915-dp_mst-Fix-race-between-connector-registrat.patch (drm-backport-placeholder)
- commit 19e62e3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1862-nouveau-gsp-allocate-enough-space-for-all-channel-id.patch (drm-backport-placeholder)
- commit f81f61a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-boe-tv101wum-nl6-Fine-tune-Himax83102-j02-.patch (drm-backport-placeholder)
- commit 2b26b72
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-ast-Disconnect-BMC-if-physical-connector-is-conn.patch (drm-backport-placeholder)
- commit 0eeff21
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/accel-ivpu-37xx-Fix-hangs-related-to-MMIO-reset.patch (drm-backport-placeholder).
- commit e5f8941
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-vop-Fix-color-for-RGB888-BGR888-format-.patch (drm-backport-placeholder)
- commit 0edaabe
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-simple-Fix-Innolux-G101ICE-L01-timings.patch (drm-backport-placeholder)
- commit b7f852a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-simple-Fix-Innolux-G101ICE-L01-bus-flags.patch (drm-backport-placeholder)
- commit ae8025b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-auo-b101uan08.3-Fine-tune-the-panel-power-.patch (drm-backport-placeholder)
- commit 2b624f2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1855-drm-msm-remove-unnecessary-NULL-check.patch (drm-backport-placeholder)
- commit 0f8cb0e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1854-drm-msm-dp-attach-the-DP-subconnector-property.patch (drm-backport-placeholder)
- commit 2d72070
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1853-drm-msm-dp-don-t-touch-DP-subconnector-property-in-e.patch (drm-backport-placeholder)
- commit 9c56d44
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Add-missing-safe_lut_tbl-in-sc8280xp-cat.patch (drm-backport-placeholder)
- commit 8a3ec85
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1851-drm-msm-remove-exra-drm_kms_helper_poll_init-call.patch (drm-backport-placeholder)
- commit 2b9a5be
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dsi-use-the-correct-VREG_CTRL_1-value-for-4n.patch (drm-backport-placeholder)
- commit a1e39a7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1849-drm-amdgpu-gmc9-disable-AGP-aperture.patch (drm-backport-placeholder)
- commit b236fb6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1848-drm-amdgpu-gmc10-disable-AGP-aperture.patch (drm-backport-placeholder)
- commit 6906582
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1847-drm-amdgpu-gmc11-disable-AGP-aperture.patch (drm-backport-placeholder)
- commit e2da280
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1846-drm-amdgpu-add-a-module-parameter-to-control-the-AGP.patch (drm-backport-placeholder)
- commit 46a69ef
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1845-drm-amdgpu-gmc11-fix-logic-typo-in-AGP-check.patch (drm-backport-placeholder)
- commit 0a6938a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1844-drm-amd-display-Fix-encoder-disable-logic.patch (drm-backport-placeholder)
- commit ec9af34
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Change-the-DMCUB-mailbox-memory-loca.patch (drm-backport-placeholder)
- commit 3569563
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1842-drm-amdgpu-add-and-populate-the-port-num-into-xgmi-t.patch (drm-backport-placeholder)
- commit 0b88d06
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1841-drm-amd-display-Negate-IPS-allow-and-commit-bits.patch (drm-backport-placeholder)
- commit 36533ca
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1840-drm-amd-pm-Don-t-send-unload-message-for-reset.patch (drm-backport-placeholder)
- commit f754848
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1839-drm-amdgpu-fix-ras-err_data-null-pointer-issue-in-am.patch (drm-backport-placeholder)
- commit 655814b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Clear-dpcd_sink_ext_caps-if-not-set.patch (drm-backport-placeholder)
- commit 290b38b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Enable-fast-plane-updates-on-DCN3.2-.patch (drm-backport-placeholder)
- commit 0a44dfc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1836-drm-amd-display-fix-NULL-dereference.patch (drm-backport-placeholder)
- commit f738845
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-a-NULL-pointer-dereference-in-am.patch (drm-backport-placeholder)
- commit 8e8dbaa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1834-drm-amd-display-Add-null-checks-for-8K60-lightup.patch (drm-backport-placeholder)
- commit e9c1f90
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1833-drm-amd-pm-Fill-pcie-error-counters-for-gpu-v1_4.patch (drm-backport-placeholder)
- commit 8adc5a2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1832-drm-amd-pm-Update-metric-table-for-smu-v13_0_6.patch (drm-backport-placeholder)
- commit 445cb91
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-correct-chunk_ptr-to-a-pointer-to-chunk.patch (drm-backport-placeholder)
- commit 2280cb9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-DSC-not-Enabled-on-Direct-MST-Si.patch (drm-backport-placeholder)
- commit 9728c8b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1829-drm-amdgpu-Address-member-ring-not-described-in-amdg.patch (drm-backport-placeholder)
- commit 38e755c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-finalizing-mem_partitions-at-the-end-of-G.patch (drm-backport-placeholder)
- commit 4b2caa6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Do-not-program-VF-copy-regs-in-mmhub-v1.8.patch (drm-backport-placeholder)
- commit ce71c73
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Guard-against-invalid-RPTR-WPTR-bein.patch (drm-backport-placeholder)
- commit 9d02494
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1825-nouveau-don-t-fail-driver-load-if-no-display-hw-pres.patch (drm-backport-placeholder)
- commit 40b7dfc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1824-drm-panel-orientation-quirks-Add-quirk-for-Lenovo-Le.patch (drm-backport-placeholder)
- commit 0590bdc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/nouveau-use-an-rwlock-for-the-event-lock.patch (drm-backport-placeholder)
- commit 10da763
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1822-nouveau-gsp-r535-Fix-a-NULL-vs-error-pointer-bug.patch (drm-backport-placeholder)
- commit 8812e2e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1821-nouveau-gsp-r535-uninitialized-variable-in-r535_gsp_.patch (drm-backport-placeholder)
- commit 51124a0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1820-drm-ci-make-github-dependabot-happy-again.patch (drm-backport-placeholder)
- commit a463ff8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-fsl-diu-fb-mark-wr_reg_wa-static.patch (drm-backport-placeholder)
- commit 8f218a2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1818-fbdev-amifb-Convert-to-platform-remove-callback-retu.patch (drm-backport-placeholder)
- commit 3d6233e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1817-fbdev-amifb-Mark-driver-struct-with-__refdata-to-pre.patch (drm-backport-placeholder)
- commit eb65401
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1816-fbdev-hyperv_fb-fix-uninitialized-local-variable-use.patch (drm-backport-placeholder)
- commit 941dbb9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1815-fbdev-omapfb-tpd12s015-Convert-to-platform-remove-ca.patch (drm-backport-placeholder)
- commit 79965f5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1814-fbdev-omapfb-tfp410-Convert-to-platform-remove-callb.patch (drm-backport-placeholder)
- commit 67305e8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1813-fbdev-omapfb-sharp-ls037v7dw01-Convert-to-platform-r.patch (drm-backport-placeholder)
- commit 685f4b8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1812-fbdev-omapfb-opa362-Convert-to-platform-remove-callb.patch (drm-backport-placeholder)
- commit 671220e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1811-fbdev-omapfb-hdmi-Convert-to-platform-remove-callbac.patch (drm-backport-placeholder)
- commit b43ac6e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1810-fbdev-omapfb-dvi-Convert-to-platform-remove-callback.patch (drm-backport-placeholder)
- commit 531b41c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1809-fbdev-omapfb-dsi-cm-Convert-to-platform-remove-callb.patch (drm-backport-placeholder)
- commit 905fd04
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1808-fbdev-omapfb-dpi-Convert-to-platform-remove-callback.patch (drm-backport-placeholder)
- commit e816425
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1807-fbdev-omapfb-analog-tv-Convert-to-platform-remove-ca.patch (drm-backport-placeholder)
- commit e96b227
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1806-fbdev-atmel_lcdfb-Convert-to-platform-remove-callbac.patch (drm-backport-placeholder)
- commit a34ffa6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1805-fbdev-omapfb-tpd12s015-Don-t-put-.remove-in-.exit.te.patch (drm-backport-placeholder)
- commit 1adb5d6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1804-fbdev-omapfb-tfp410-Don-t-put-.remove-in-.exit.text-.patch (drm-backport-placeholder)
- commit 3d2e4f2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1803-fbdev-omapfb-sharp-ls037v7dw01-Don-t-put-.remove-in-.patch (drm-backport-placeholder)
- commit ae4087d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1802-fbdev-omapfb-opa362-Don-t-put-.remove-in-.exit.text-.patch (drm-backport-placeholder)
- commit 09fb84f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1801-fbdev-omapfb-hdmi-Don-t-put-.remove-in-.exit.text-an.patch (drm-backport-placeholder)
- commit 93a8c75
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1800-fbdev-omapfb-dvi-Don-t-put-.remove-in-.exit.text-and.patch (drm-backport-placeholder)
- commit 2af8b63
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1799-fbdev-omapfb-dsi-cm-Don-t-put-.remove-in-.exit.text-.patch (drm-backport-placeholder)
- commit 060155f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1798-fbdev-omapfb-dpi-Don-t-put-.remove-in-.exit.text-and.patch (drm-backport-placeholder)
- commit 873206a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1797-fbdev-omapfb-analog-tv-Don-t-put-.remove-in-.exit.te.patch (drm-backport-placeholder)
- commit 59794ef
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1796-fbdev-atmel_lcdfb-Stop-using-platform_driver_probe.patch (drm-backport-placeholder)
- commit ab9fbc0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-imsttfb-fix-double-free-in-probe.patch (drm-backport-placeholder)
- commit d335c9b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1793-fbdev-viafb-use-new-array-copying-wrapper.patch (drm-backport-placeholder)
- commit 4e52886
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-omapfb-Drop-unused-remove-function.patch (drm-backport-placeholder)
- commit b0775f9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1791-fbdev-offb-Simplify-offb_init_fb.patch (drm-backport-placeholder)
- commit 4dd7487
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1790-fbdev-omapfb-Replace-custom-memparse-implementation.patch (drm-backport-placeholder)
- commit 2b4e7fb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1789-fbdev-omapfb-Do-not-shadow-error-code-from-platform_.patch (drm-backport-placeholder)
- commit 10a99a7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-error-handling-in-amdgpu_vm_init.patch (drm-backport-placeholder)
- commit 222e5f7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-possible-null-pointer-dereference.patch (drm-backport-placeholder)
- commit 4d709ad
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1786-drm-amdgpu-move-UVD-and-VCE-sched-entity-init-after-.patch (drm-backport-placeholder)
- commit e5ba288
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1785-drm-amdgpu-move-kfd_resume-before-the-ip-late-init.patch (drm-backport-placeholder)
- commit c090160
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1784-drm-amd-Explicitly-check-for-GFXOFF-to-be-enabled-fo.patch (drm-backport-placeholder)
- commit 45e1c29
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1783-drm-amdgpu-Change-WREG32_RLC-to-WREG32_SOC15_RLC-whe.patch (drm-backport-placeholder)
- commit 4010299
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1782-drm-amdgpu-Use-correct-KIQ-MEC-engine-for-gfx9.4.3-v.patch (drm-backport-placeholder)
- commit 331ff70
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1781-drm-amdgpu-add-smu-v13.0.6-pcs-xgmi-ras-error-query-.patch (drm-backport-placeholder)
- commit ecfed5c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-software-pci_unplug-on-some-chips.patch (drm-backport-placeholder)
- commit 7cf99b0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1779-drm-amd-display-remove-duplicated-argument.patch (drm-backport-placeholder)
- commit 22cc396
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1778-drm-amdgpu-correct-mca-debugfs-dump-reg-list.patch (drm-backport-placeholder)
- commit 07ca02e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1777-drm-amdgpu-correct-acclerator-check-architecutre-dum.patch (drm-backport-placeholder)
- commit 2bf473b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1776-drm-amdgpu-add-pcs-xgmi-v6.4.0-ras-support.patch (drm-backport-placeholder)
- commit 7f42e9a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1775-drm-amdgpu-Change-extended-scope-MTYPE-on-GC-9.4.3.patch (drm-backport-placeholder)
- commit 67754fd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1774-drm-amdgpu-disable-smu-v13.0.6-mca-debug-mode-by-def.patch (drm-backport-placeholder)
- commit 73d72e3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1773-drm-amdgpu-Support-multiple-error-query-modes.patch (drm-backport-placeholder)
- commit b3acd46
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1772-drm-amdgpu-refine-smu-v13.0.6-mca-dump-driver.patch (drm-backport-placeholder)
- commit 7a2f62b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1771-drm-amdgpu-Do-not-program-PF-only-regs-in-hdp_v4_0.c.patch (drm-backport-placeholder)
- commit d8ba6df
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1770-drm-amdgpu-Skip-PCTL0_MMHUB_DEEPSLEEP_IB-write-in-jp.patch (drm-backport-placeholder)
- commit 5411e38
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1769-drm-amd-Resolve-Sphinx-unexpected-indentation-warnin.patch (drm-backport-placeholder)
- commit 2894a83
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1768-drm-amdgpu-correct-smu-v13.0.6-umc-ras-error-check.patch (drm-backport-placeholder)
- commit b44b5e1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1767-drm-amdgpu-Add-xcc-param-to-SRIOV-kiq-write-and-WREG.patch (drm-backport-placeholder)
- commit c18b955
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1766-drm-amdgpu-Add-flag-to-enable-indirect-RLCG-access-f.patch (drm-backport-placeholder)
- commit 8bce7ba
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1765-drm-amd-pm-raise-the-deep-sleep-clock-threshold-for-.patch (drm-backport-placeholder)
- commit 98d96dd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1764-drm-amdgpu-correct-amdgpu-ip-block-rev-info.patch (drm-backport-placeholder)
- commit 6178d6f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1763-drm-amd-pm-Hide-pp_dpm_pcie-device-attribute.patch (drm-backport-placeholder)
- commit 46abdf7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1762-drm-amdgpu-Don-t-warn-for-unsupported-set_xgmi_plpd_.patch (drm-backport-placeholder)
- commit 95a07ae
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-lower-CS-errors-to-debug-severity.patch (drm-backport-placeholder)
- commit 938872a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-error-handling-in-amdgpu_bo_list_get.patch (drm-backport-placeholder)
- commit 4b8a9fb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1759-drm-amdgpu-fix-AGP-init-order.patch (drm-backport-placeholder)
- commit 410096a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1758-drm-amdgpu-add-RAS-reset-query-operations-for-XGMI-v.patch (drm-backport-placeholder)
- commit 5dc945d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1757-drm-amdgpu-handle-extra-UE-register-entries-for-gfx-.patch (drm-backport-placeholder)
- commit 86c43c8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1756-drm-amd-pm-not-stop-rlc-for-IMU-enabled-APUs-when-su.patch (drm-backport-placeholder)
- commit c13947b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1755-drm-amd-display-avoid-variable-reinitialization.patch (drm-backport-placeholder)
- commit b5b6ae4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1754-drm-amd-pm-Hide-irrelevant-pm-device-attributes.patch (drm-backport-placeholder)
- commit 77f70c5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1753-drm-amdgpu-Fix-sdma-4.4.2-doorbell-rptr-wptr-init.patch (drm-backport-placeholder)
- commit 547e377
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1752-drm-amdgpu-soc21-add-mode2-asic-reset-for-SMU-IP-v14.patch (drm-backport-placeholder)
- commit fb01dfb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1751-drm-amd-display-Set-stream-s-DP-test-pattern-upon-te.patch (drm-backport-placeholder)
- commit 5f79ee0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1750-drm-amd-display-Fix-handling-duplicate-planes-on-one.patch (drm-backport-placeholder)
- commit f91d387
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1749-drm-amd-display-For-cursor-P-State-allow-for-SubVP.patch (drm-backport-placeholder)
- commit 6f2efb2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1748-drm-amd-display-Enable-physymclk-RCO.patch (drm-backport-placeholder)
- commit 8ccea14
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1747-drm-amd-display-Remove-references-to-unused-dml-arch.patch (drm-backport-placeholder)
- commit cb8c1e9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1746-drm-amd-display-Promote-DAL-to-3.2.259.patch (drm-backport-placeholder)
- commit 25b9753
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1745-drm-amd-display-save-and-restore-mall-state-when-app.patch (drm-backport-placeholder)
- commit 7aa6005
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1744-drm-amd-display-Remove-unused-duplicate-register-def.patch (drm-backport-placeholder)
- commit 77526d6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1743-drm-amd-display-Create-optc.h-file.patch (drm-backport-placeholder)
- commit 38795dc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1742-drm-amd-display-Disable-OTG-for-mode-timing-switch-o.patch (drm-backport-placeholder)
- commit e813c20
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1741-drm-amd-display-Revise-Replay-Desync-Error-IRQ-handl.patch (drm-backport-placeholder)
- commit f7e88fe
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1740-drm-amd-display-FW-Promotion-Release-0.0.190.0.patch (drm-backport-placeholder)
- commit 5e66503
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1739-drm-amd-display-3.2.258.patch (drm-backport-placeholder)
- commit 03e68bf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1738-drm-amd-display-Add-missing-dml2-init-value-for-dcn3.patch (drm-backport-placeholder)
- commit 019ed03
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1737-drm-amd-display-Fix-OTG-disable-workaround-logic.patch (drm-backport-placeholder)
- commit a7f1be1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1736-drm-amd-display-amend-HPD-handler-for-Replay.patch (drm-backport-placeholder)
- commit 7722189
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1735-drm-amd-display-Introduce-flag-for-disabling-Replay-.patch (drm-backport-placeholder)
- commit fa78426
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1734-drm-amd-display-DCN35-Disable-cm-power-optimization.patch (drm-backport-placeholder)
- commit 549e986
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1733-drm-amd-display-Update-DP-HPO-MSA-with-colorimetry-f.patch (drm-backport-placeholder)
- commit d1e84ae
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1732-drm-amd-display-Update-test-link-rate-DPCD-bit-field.patch (drm-backport-placeholder)
- commit d929376
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1731-drm-amd-display-Allow-16-max_slices-for-DP2-DSC.patch (drm-backport-placeholder)
- commit afb4c9c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1730-drm-amd-display-Enable-more-IPS-options.patch (drm-backport-placeholder)
- commit 0eda1c7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1729-drm-amd-display-Enable-RCO-options-for-dcn35.patch (drm-backport-placeholder)
- commit af64d1d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1728-drm-amd-display-Fix-FRL-assertion-on-boot.patch (drm-backport-placeholder)
- commit c2a56db
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1727-drm-amd-display-Fix-missing-blendTF-programming.patch (drm-backport-placeholder)
- commit e891c26
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1726-drm-amd-display-3.2.257.patch (drm-backport-placeholder)
- commit 3fda35d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1725-drm-amd-display-decouple-dmcub-execution-to-reduce-l.patch (drm-backport-placeholder)
- commit 2d14274
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1724-drm-amd-display-FW-Promotion-Release-0.0.189.0.patch (drm-backport-placeholder)
- commit 0e81842
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1723-drm-amd-display-On-boot-disable-domain22-force-power.patch (drm-backport-placeholder)
- commit e85d154
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1722-drm-amd-Disable-XNACK-on-SRIOV-environment.patch (drm-backport-placeholder)
- commit 65ee264
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-qxl-prevent-memory-leak.patch (drm-backport-placeholder)
- commit 48a6aaf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-syncobj-fix-DRM_SYNCOBJ_WAIT_FLAGS_WAIT_AVAILABL.patch (drm-backport-placeholder)
- commit e825914
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-vc4-tests-Fix-UAF-in-the-mock-helpers.patch (drm-backport-placeholder)
- commit 0296503
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-tc-Fix-Wformat-truncation-in-intel_tc_port_.patch (drm-backport-placeholder)
- commit 0b36905
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Fix-potential-spectre-vulnerability.patch (drm-backport-placeholder)
- commit 40ef414
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Bump-GLK-CDCLK-frequency-when-driving-multi.patch (drm-backport-placeholder)
- commit ccda583
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1715-drm-i915-mtl-Apply-notify_guc-to-all-GTs.patch (drm-backport-placeholder)
- commit 91fa30c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-mtl-Support-HBR3-rate-with-C10-phy-and-eDP-.patch (drm-backport-placeholder)
- commit 634b2ff
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Flush-WC-GGTT-only-on-required-platforms.patch (drm-backport-placeholder)
- commit d3e2e4d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-mtl-avoid-stringop-overflow-warning.patch (drm-backport-placeholder)
- commit 7604e0e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1710-drm-amd-display-Enable-fast-update-on-blendTF-change.patch (drm-backport-placeholder)
- commit 19a413a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1709-drm-amd-display-Fix-blend-LUT-programming.patch (drm-backport-placeholder)
- commit dc461d8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1708-drm-amd-display-Program-plane-color-setting-correctl.patch (drm-backport-placeholder)
- commit 1057157
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1707-drm-amdgpu-Query-and-report-boot-status.patch (drm-backport-placeholder)
- commit a22e214
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1706-drm-amdgpu-Add-psp-v13-function-to-query-boot-status.patch (drm-backport-placeholder)
- commit fa6c2ec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1705-drm-amd-swsmu-remove-fw-version-check-in-sw_init.patch (drm-backport-placeholder)
- commit 199afef
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1704-drm-amd-swsmu-update-smu-v14_0_0-driver-if-and-metri.patch (drm-backport-placeholder)
- commit 5b0d61f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1703-drm-amdgpu-Add-C2PMSG_109-126-reg-field-shift-masks.patch (drm-backport-placeholder)
- commit eb0b46b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1702-drm-amdgpu-Optimize-the-asic-type-fix-code.patch (drm-backport-placeholder)
- commit 5cc59fd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-GRBM-read-timeout-when-do-mes_self_te.patch (drm-backport-placeholder)
- commit fb6c05d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1700-drm-amdgpu-check-recovery-status-of-xgmi-hive-in-ras.patch (drm-backport-placeholder)
- commit fdffdda
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1699-drm-amd-pm-only-check-sriov-vf-flag-once-when-creati.patch (drm-backport-placeholder)
- commit dad8673
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1698-drm-amdgpu-Attach-eviction-fence-on-alloc.patch (drm-backport-placeholder)
- commit 0f55aa7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1697-drm-amdkfd-Improve-amdgpu_vm_handle_moved.patch (drm-backport-placeholder)
- commit ec7f943
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1696-drm-amd-display-Increase-frame-warning-limit-with-KA.patch (drm-backport-placeholder)
- commit ef4f084
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1694-drm-amdkfd-Update-cache-info-for-GFX-9.4.3.patch (drm-backport-placeholder)
- commit 4b7c6fc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1693-drm-amdkfd-Populate-cache-info-for-GFX-9.4.3.patch (drm-backport-placeholder)
- commit 62b1d39
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1692-drm-amdgpu-don-t-put-MQDs-in-VRAM-on-ARM-ARM64.patch (drm-backport-placeholder)
- commit 5e1adca
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-smu13-drop-compute-workload-workaround.patch (drm-backport-placeholder)
- commit 19fff18
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-add-a-retry-for-IP-discovery-init.patch (drm-backport-placeholder)
- commit a05cd18
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1689-drm-amdgpu-ungate-power-gating-when-system-suspend.patch (drm-backport-placeholder)
- commit f6a2004
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1688-drm-radeon-replace-1-element-arrays-with-flexible-ar.patch (drm-backport-placeholder)
- commit b1de745
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1687-drm-amd-Fix-UBSAN-array-index-out-of-bounds-for-Powe.patch (drm-backport-placeholder)
- commit d10ecea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-don-t-use-pci_is_thunderbolt_attached.patch (drm-backport-placeholder)
- commit da76d90
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1685-drm-amdgpu-don-t-use-ATRM-for-external-devices.patch (drm-backport-placeholder)
- commit 64ff67c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-gfx10-11-use-memcpy_to-fromio-for-MQDs.patch (drm-backport-placeholder)
- commit e3cc200
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1683-drm-amdgpu-use-mode-2-reset-for-RAS-poison-consumpti.patch (drm-backport-placeholder)
- commit 784480f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1682-drm-amdgpu-doorbell-range-should-be-set-when-gpu-rec.patch (drm-backport-placeholder)
- commit 4977b2d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1681-drm-amd-pm-Return-0-as-default-min-power-limit-for-l.patch (drm-backport-placeholder)
- commit 4941763
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1680-drm-amdgpu-remove-unused-macro-HW_REV.patch (drm-backport-placeholder)
- commit 0f04de1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-Fix-error-of-MACO-flag-setting-code.patch (drm-backport-placeholder)
- commit 7845973
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1678-drm-amdgpu-Fix-the-vram-base-start-address.patch (drm-backport-placeholder)
- commit 94be1ac
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1677-drm-amdgpu-set-XGMI-IP-version-manually-for-v6_4.patch (drm-backport-placeholder)
- commit 473c65b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1676-drm-amdgpu-add-unmap-latency-when-gfx11-set-kiq-reso.patch (drm-backport-placeholder)
- commit 3aafe8e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1675-drm-amd-pm-fix-the-high-voltage-and-temperature-issu.patch (drm-backport-placeholder)
- commit 56c2996
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1674-drm-amdgpu-remove-amdgpu_mes_self_test-in-gpu-recove.patch (drm-backport-placeholder)
- commit 83f902b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1673-drm-amdgpu-Drop-deferred-error-in-uncorrectable-erro.patch (drm-backport-placeholder)
- commit be22722
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1672-drm-amd-pm-Fix-warnings.patch (drm-backport-placeholder)
- commit 1ffba89
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1671-drm-amdgpu-check-RAS-supported-first-in-ras_reset_er.patch (drm-backport-placeholder)
- commit 783f849
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1670-drm-ssd130x-Fix-possible-uninitialized-usage-of-crtc.patch (drm-backport-placeholder)
- commit 8aa31d3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1669-drm-renesas-shmobile-Add-DT-support.patch (drm-backport-placeholder)
- commit 9a7a97f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1668-drm-renesas-shmobile-Atomic-conversion-part-3.patch (drm-backport-placeholder)
- commit 3c7f343
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1667-drm-renesas-shmobile-Remove-internal-CRTC-state-trac.patch (drm-backport-placeholder)
- commit 75a0f77
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1666-drm-renesas-shmobile-Use-suspend-resume-helpers.patch (drm-backport-placeholder)
- commit 3a4d9f5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1665-drm-renesas-shmobile-Atomic-conversion-part-2.patch (drm-backport-placeholder)
- commit 47a88f8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1664-drm-renesas-shmobile-Atomic-conversion-part-1.patch (drm-backport-placeholder)
- commit 6d5224b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1663-drm-renesas-shmobile-Cleanup-encoder.patch (drm-backport-placeholder)
- commit 71cd164
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1662-drm-renesas-shmobile-Shutdown-the-display-on-remove.patch (drm-backport-placeholder)
- commit 4573217
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1661-drm-renesas-shmobile-Turn-vblank-on-off-when-enablin.patch (drm-backport-placeholder)
- commit 30c441d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1660-drm-renesas-shmobile-Wait-for-page-flip-when-turning.patch (drm-backport-placeholder)
- commit 7bd52dd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1659-drm-renesas-shmobile-Move-shmob_drm_crtc_finish_page.patch (drm-backport-placeholder)
- commit 5920440
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1658-drm-renesas-shmobile-Use-drm_crtc_handle_vblank.patch (drm-backport-placeholder)
- commit 1c71fa8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1657-drm-renesas-shmobile-Rename-shmob_drm_plane.plane.patch (drm-backport-placeholder)
- commit dd2a435
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1656-drm-renesas-shmobile-Rename-shmob_drm_connector.conn.patch (drm-backport-placeholder)
- commit 5196f45
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1655-drm-renesas-shmobile-Rename-shmob_drm_crtc.crtc.patch (drm-backport-placeholder)
- commit 7a8abcf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1654-drm-renesas-shmobile-Unify-plane-allocation.patch (drm-backport-placeholder)
- commit f9fae93
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1653-drm-renesas-shmobile-Move-interface-handling-to-conn.patch (drm-backport-placeholder)
- commit 6b3bf38
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1652-drm-renesas-shmobile-Use-media-bus-formats-in-platfo.patch (drm-backport-placeholder)
- commit ef816c4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1650-drm-renesas-shmobile-Use-struct-videomode-in-platfor.patch (drm-backport-placeholder)
- commit cf2a483
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1649-drm-renesas-shmobile-Replace-.dev_private-with-conta.patch (drm-backport-placeholder)
- commit b33cdec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1648-drm-renesas-shmobile-Convert-container-helpers-to-st.patch (drm-backport-placeholder)
- commit a5ecc4e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1647-drm-renesas-shmobile-Embed-drm_device-in-shmob_drm_d.patch (drm-backport-placeholder)
- commit 600b220
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1646-drm-renesas-shmobile-Use-drmm_universal_plane_alloc.patch (drm-backport-placeholder)
- commit 8fef2c6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1645-drm-renesas-shmobile-Remove-custom-plane-destroy-cal.patch (drm-backport-placeholder)
- commit f19dbfa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1644-drm-renesas-shmobile-Convert-to-use-devm_request_irq.patch (drm-backport-placeholder)
- commit 5fe0c37
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1643-drm-renesas-shmobile-Improve-error-handling.patch (drm-backport-placeholder)
- commit c4137f8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1642-drm-renesas-shmobile-Remove-support-for-SYS-panels.patch (drm-backport-placeholder)
- commit 30aaf69
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1641-drm-renesas-shmobile-Rename-input-clocks.patch (drm-backport-placeholder)
- commit 29fed93
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1640-drm-renesas-shmobile-Don-t-set-display-info-width-an.patch (drm-backport-placeholder)
- commit 5893e8c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1639-drm-renesas-shmobile-Remove-backlight-support.patch (drm-backport-placeholder)
- commit f517f6d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1638-drm-renesas-shmobile-Improve-shmob_drm_format_info-t.patch (drm-backport-placeholder)
- commit ad78ff4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1637-drm-renesas-shmobile-Add-missing-YCbCr-formats.patch (drm-backport-placeholder)
- commit 3b46706
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1636-drm-renesas-shmobile-Use-p4cc-to-print-fourcc-code.patch (drm-backport-placeholder)
- commit b0fdbdb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1635-drm-renesas-shmobile-Restore-indentation-of-shmob_dr.patch (drm-backport-placeholder)
- commit 39b0202
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1634-drm-renesas-shmobile-Add-support-for-Runtime-PM.patch (drm-backport-placeholder)
- commit 15ab280
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1633-drm-renesas-shmobile-Correct-encoder-connector-types.patch (drm-backport-placeholder)
- commit d47515e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1632-drm-renesas-shmobile-Fix-ARGB32-overlay-format-typo.patch (drm-backport-placeholder)
- commit 26f5c12
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1631-drm-renesas-shmobile-Fix-overlay-plane-disable.patch (drm-backport-placeholder)
- commit 49f05f7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1630-nouveau-gsp-add-some-basic-registry-entries.patch (drm-backport-placeholder)
- commit f41b6cb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1629-nouveau-gsp-fix-message-signature.patch (drm-backport-placeholder)
- commit 0c66cc6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1628-nouveau-gsp-move-to-535.113.01.patch (drm-backport-placeholder)
- commit 852f38b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1627-nouveau-disp-fix-post-gsp-build-on-32-bit-arm.patch (drm-backport-placeholder)
- commit efb20fc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1626-nouveau-fix-r535-build-on-32-bit-arm.patch (drm-backport-placeholder)
- commit 00a6920
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1625-drm-nouveau-ofa-r535-initial-support.patch (drm-backport-placeholder)
- commit 5d1af5c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1624-drm-nouveau-nvjpg-r535-initial-support.patch (drm-backport-placeholder)
- commit d072793
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1623-drm-nouveau-nvenc-r535-initial-support.patch (drm-backport-placeholder)
- commit f24a1bf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1622-drm-nouveau-nvdec-r535-initial-support.patch (drm-backport-placeholder)
- commit e4d6b57
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1621-drm-nouveau-gr-r535-initial-support.patch (drm-backport-placeholder)
- commit d397dc0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1620-drm-nouveau-ce-r535-initial-support.patch (drm-backport-placeholder)
- commit fd2e0da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1619-drm-nouveau-fifo-r535-initial-support.patch (drm-backport-placeholder)
- commit 99cd131
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1618-drm-nouveau-disp-r535-initial-support.patch (drm-backport-placeholder)
- commit 0f7c6fa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1617-drm-nouveau-mmu-r535-initial-support.patch (drm-backport-placeholder)
- commit f150dfd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1616-drm-nouveau-gsp-r535-add-interrupt-handling.patch (drm-backport-placeholder)
- commit 27fd8be
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1615-drm-nouveau-gsp-r535-add-support-for-rm-alloc.patch (drm-backport-placeholder)
- commit ecb5384
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1614-drm-nouveau-gsp-r535-add-support-for-rm-control.patch (drm-backport-placeholder)
- commit 0622a75
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1613-drm-nouveau-gsp-r535-add-support-for-booting-GSP-RM.patch (drm-backport-placeholder)
- commit 18147be
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1612-drm-nouveau-nvkm-support-loading-fws-into-sg_table.patch (drm-backport-placeholder)
- commit e1299b2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1611-drm-nouveau-kms-tu102-disable-vbios-parsing-when-run.patch (drm-backport-placeholder)
- commit fe4ef31
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1610-drm-nouveau-sec2-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 579b31d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1609-drm-nouveau-nvenc-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 2fa768c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1608-drm-nouveau-nvdec-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit cac7475
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1607-drm-nouveau-gr-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 5908821
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1606-drm-nouveau-fifo-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 913a2e2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1605-drm-nouveau-disp-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 82f355a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1604-drm-nouveau-ce-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 5467b14
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1603-drm-nouveau-vfn-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit c243306
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1602-drm-nouveau-top-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit c55cbb1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1601-drm-nouveau-therm-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit a197419
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1600-drm-nouveau-privring-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 4dc4441
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1599-drm-nouveau-pmu-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 98b89e3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1598-drm-nouveau-mmu-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 2e68a5a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1597-drm-nouveau-mc-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit dfff1b2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1596-drm-nouveau-ltc-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 7cfa058
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1595-drm-nouveau-imem-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 19b8d9b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1594-drm-nouveau-i2c-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit b632ccd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1593-drm-nouveau-gpio-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 9e07f6d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1592-drm-nouveau-fuse-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 2b8f25a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1591-drm-nouveau-fb-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 4929c02
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1590-drm-nouveau-fault-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit faa56f9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1589-drm-nouveau-devinit-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit ee811c9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1588-drm-nouveau-bus-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit b6caecb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1587-drm-nouveau-bar-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 7aa78b9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1586-drm-nouveau-acr-tu102-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit 2cbd4c4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1585-drm-nouveau-gsp-prepare-for-GSP-RM.patch (drm-backport-placeholder)
- commit d5ecbec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1584-drm-nouveau-nvkm-bump-maximum-number-of-NVJPG.patch (drm-backport-placeholder)
- commit 022f1ce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1583-drm-nouveau-nvkm-bump-maximum-number-of-NVDEC.patch (drm-backport-placeholder)
- commit 9f74378
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1582-drm-nouveau-mmu-tu102-remove-write-to-0x100e68-durin.patch (drm-backport-placeholder)
- commit 880fcf5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1581-hyperv-avoid-dependency-on-screen_info.patch (drm-backport-placeholder)
- commit 5618be9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/vga16fb-drop-powerpc-support.patch (drm-backport-placeholder)
- commit 3bdc63f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1579-vgacon-remove-screen_info-dependency.patch (drm-backport-placeholder)
- commit 44607c4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1578-dummycon-limit-Arm-console-size-hack-to-footbridge.patch (drm-backport-placeholder)
- commit b1cc365
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1577-vgacon-rework-Kconfig-dependencies.patch (drm-backport-placeholder)
- commit 55268c2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1576-mei-me-emit-error-only-if-reset-was-unexpected.patch (drm-backport-placeholder)
- commit 31caa68
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1575-misc-mei-main.c-fix-kernel-doc-warnings.patch (drm-backport-placeholder)
- commit f3050a3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1574-misc-mei-interrupt.c-fix-kernel-doc-warnings.patch (drm-backport-placeholder)
- commit 190c9dd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1573-misc-mei-hw-me.c-fix-kernel-doc-warnings.patch (drm-backport-placeholder)
- commit 519087b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1572-misc-mei-hbm.c-fix-kernel-doc-warnings.patch (drm-backport-placeholder)
- commit b6ab136
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1571-misc-mei-dma-ring.c-fix-kernel-doc-warnings.patch (drm-backport-placeholder)
- commit e31c27c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1570-misc-mei-client.c-fix-kernel-doc-warnings.patch (drm-backport-placeholder)
- commit 47d1e42
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1569-misc-mei-hw.h-fix-kernel-doc-warnings.patch (drm-backport-placeholder)
- commit 5e3142b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1568-mei-docs-fix-spelling-errors.patch (drm-backport-placeholder)
- commit 3f908bc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1567-mei-docs-add-missing-entries-to-kdoc-in-struct-mei_c.patch (drm-backport-placeholder)
- commit 44ab196
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1566-mei-docs-use-correct-structures-name-in-kdoc.patch (drm-backport-placeholder)
- commit 579d6c9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1565-mei-update-mei-pxp-s-component-interface-with-timeou.patch (drm-backport-placeholder)
- commit ccf8888
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1564-mei-pxp-re-enable-client-on-errors.patch (drm-backport-placeholder)
- commit 3c2f6c9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1563-mei-pxp-recover-from-recv-fail-under-memory-pressure.patch (drm-backport-placeholder)
- commit 17316a5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1562-mei-bus-add-send-and-recv-api-with-timeout.patch (drm-backport-placeholder)
- commit 6810b7e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1561-mei-fix-doc-typos.patch (drm-backport-placeholder)
- commit 8c32a59
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/backlight-pwm_bl-Disable-PWM-on-shutdown-suspend-and.patch (drm-backport-placeholder)
- commit 0a01233
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1559-drm-qxl-Use-pci_is_vga-to-identify-VGA-devices.patch (drm-backport-placeholder)
- commit f3dc70d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1558-drm-virtio-Use-pci_is_vga-to-identify-VGA-devices.patch (drm-backport-placeholder)
- commit e1aaf16
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1557-drm-radeon-Use-pci_get_base_class-to-reduce-duplicat.patch (drm-backport-placeholder)
- commit 4bc990f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1556-drm-amdgpu-Use-pci_get_base_class-to-reduce-duplicat.patch (drm-backport-placeholder)
- commit a51462f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1555-drm-nouveau-Use-pci_get_base_class-to-reduce-duplica.patch (drm-backport-placeholder)
- commit 3d579cc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-stifb-Make-the-STI-next-font-pointer-a-32-bit-.patch (drm-backport-placeholder)
- commit b767d25
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Remove-unused-variables-from-amdgpu_show_.patch (drm-backport-placeholder)
- commit 641a080
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Remove-duplicate-fdinfo-fields.patch (drm-backport-placeholder)
- commit 87978a6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1549-drm-amd-amdgpu-avoid-to-disable-gfxhub-interrupt-whe.patch (drm-backport-placeholder)
- commit 5f54e16
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1548-drm-amdgpu-Add-EXT_COHERENT-support-for-APU-and-NUMA.patch (drm-backport-placeholder)
- commit 1da13cf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1547-drm-amdgpu-Retrieve-CE-count-from-ce_count_lo_chip-i.patch (drm-backport-placeholder)
- commit af4fa6d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1546-drm-amdgpu-Identify-data-parity-error-corrected-in-r.patch (drm-backport-placeholder)
- commit e148189
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1545-drm-amdgpu-Fix-typo-in-IP-discovery-parsing.patch (drm-backport-placeholder)
- commit 4e51867
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1544-drm-amd-display-fix-S-G-display-enablement.patch (drm-backport-placeholder)
- commit 21a252f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1543-drm-amdxcp-fix-amdxcp-unloads-incompletely.patch (drm-backport-placeholder)
- commit f923485
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1542-drm-amd-amdgpu-fix-the-GPU-power-print-error-in-pm-i.patch (drm-backport-placeholder)
- commit 545c72f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1541-drm-amdgpu-Use-pcie-domain-of-xcc-acpi-objects.patch (drm-backport-placeholder)
- commit 81b6fec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1539-drm-amdgpu-Add-a-read-to-GFX-v9.4.3-ring-test.patch (drm-backport-placeholder)
- commit 18483a3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1538-drm-amd-pm-call-smu_cmn_get_smc_version-in-is_mode1_.patch (drm-backport-placeholder)
- commit 7c966ea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1537-drm-amdgpu-get-RAS-poison-status-from-DF-v4_6_2.patch (drm-backport-placeholder)
- commit bead3e8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1536-drm-amdgpu-Use-discovery-table-s-subrevision.patch (drm-backport-placeholder)
- commit 7e8dac8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1535-drm-amd-display-3.2.256.patch (drm-backport-placeholder)
- commit e852dad
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1534-drm-amd-display-add-interface-to-query-SubVP-status.patch (drm-backport-placeholder)
- commit 2646b1a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1533-drm-amd-display-Read-before-writing-Backlight-Mode-S.patch (drm-backport-placeholder)
- commit f87390e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1532-drm-amd-display-Disable-SYMCLK32_SE-RCO-on-DCN314.patch (drm-backport-placeholder)
- commit 9df826c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1531-drm-amd-display-Fix-shaper-using-bad-LUT-params.patch (drm-backport-placeholder)
- commit bc76ae4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1530-drm-amd-display-add-null-check-for-invalid-opps.patch (drm-backport-placeholder)
- commit e1ba9c8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1529-drm-amd-display-Update-FAMS-sequence-for-DCN30-DCN32.patch (drm-backport-placeholder)
- commit 090506f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1528-drm-amd-display-fix-num_ways-overflow-error.patch (drm-backport-placeholder)
- commit 7f6bc3c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1527-drm-amd-display-Add-prefix-for-plane-functions.patch (drm-backport-placeholder)
- commit 3dcddb9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1526-drm-amd-display-Add-prefix-to-amdgpu-crtc-functions.patch (drm-backport-placeholder)
- commit b0838a3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1525-drm-amd-display-Correct-enum-typo.patch (drm-backport-placeholder)
- commit 3817688
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1524-drm-amd-display-Set-emulated-sink-type-to-HDMI-accor.patch (drm-backport-placeholder)
- commit 43503cd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1523-drm-amd-display-Revert-drm-amd-display-allow-edp-upd.patch (drm-backport-placeholder)
- commit a929ee8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1522-drm-amd-display-Fix-HDMI-framepack-3D-test-issue.patch (drm-backport-placeholder)
- commit 189009e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1521-drm-amd-display-Fix-IPS-handshake-for-idle-optimizat.patch (drm-backport-placeholder)
- commit 518ff39
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1520-drm-amd-display-implement-map-dc-pipe-with-callback-.patch (drm-backport-placeholder)
- commit 95c91b4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1519-drm-amd-display-add-pipe-resource-management-callbac.patch (drm-backport-placeholder)
- commit 303a98a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Reduce-default-backlight-min-from-5-.patch (drm-backport-placeholder)
- commit 8b5f6d6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1517-drm-amd-display-Update-SDP-VSC-colorimetry-from-DP-t.patch (drm-backport-placeholder)
- commit d53ee0c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1516-drm-amd-display-Add-a-check-for-idle-power-optimizat.patch (drm-backport-placeholder)
- commit be52f5e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1515-drm-amd-display-Revert-Improve-x86-and-dmub-ips-hand.patch (drm-backport-placeholder)
- commit 982dee2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1514-drm-amd-display-Fix-MST-Multi-Stream-Not-Lighting-Up.patch (drm-backport-placeholder)
- commit 58daace
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1513-drm-amd-Explicitly-disable-ASPM-when-dynamic-switchi.patch (drm-backport-placeholder)
- commit aba4b47
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1512-drm-amd-Move-AMD_IS_APU-check-for-ASPM-into-top-leve.patch (drm-backport-placeholder)
- commit e9aa6e3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Disable-PP_PCIE_DPM_MASK-when-dynamic-speed-.patch (drm-backport-placeholder)
- commit 4314b20
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1510-Revert-drm-amdkfd-Use-partial-migrations-in-GPU-page.patch (drm-backport-placeholder)
- commit 2b04d66
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1509-Revert-drm-amdkfd-remove-unused-code.patch (drm-backport-placeholder)
- commit 6416146
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1508-drm-amd-display-Fix-copyright-notice-in-DC-code.patch (drm-backport-placeholder)
- commit dd415d0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1507-drm-amd-display-Fix-copyright-notice-in-DML2-code.patch (drm-backport-placeholder)
- commit 22210d4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1506-drm-amd-display-Add-missing-copyright-notice-in-DMUB.patch (drm-backport-placeholder)
- commit fb86f54
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1505-drm-amdgpu-remove-restriction-of-sriov-max_pfn-on-Ve.patch (drm-backport-placeholder)
- commit 133d9d9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1504-drm-amdkfd-Address-remap_list-not-described-in-svm_r.patch (drm-backport-placeholder)
- commit 53b1761
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-a-null-pointer-access-when-the-smc_rr.patch (drm-backport-placeholder)
- commit a3ca0b4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1502-drm-amdgpu-bypass-RAS-error-reset-in-some-conditions.patch (drm-backport-placeholder)
- commit 56b946a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1501-drm-amdgpu-enable-RAS-poison-mode-for-APU.patch (drm-backport-placeholder)
- commit e1b3fdf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1500-drm-amdgpu-vpe-correct-queue-stop-programing.patch (drm-backport-placeholder)
- commit 2c3407f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1499-drm-amd-display-Fix-DMUB-errors-introduced-by-DML2.patch (drm-backport-placeholder)
- commit a982700
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Remove-power-sequencing-check.patch (drm-backport-placeholder)
- commit db18f04
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1497-drm-amd-display-Set-the-DML2-attribute-to-false-in-a.patch (drm-backport-placeholder)
- commit 644e21d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1496-drm-amd-pm-Fix-the-return-value-in-default-case.patch (drm-backport-placeholder)
- commit d4ff88b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1495-drm-amdgpu-Add-API-to-get-full-IP-version.patch (drm-backport-placeholder)
- commit 6740914
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1494-drm-amdgpu-add-tmz-support-for-GC-IP-v11.5.0.patch (drm-backport-placeholder)
- commit b244c18
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1493-drm-amd-pm-drop-unneeded-dpm-features-disablement-fo.patch (drm-backport-placeholder)
- commit 2a87a3e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1492-drm-amdgpu-modify-if-condition-in-nbio_v7_7.c.patch (drm-backport-placeholder)
- commit ed9b790
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Fix-shift-out-of-bounds-issue.patch (drm-backport-placeholder)
- commit 7440146
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1490-drm-amdgpu-refine-ras-error-kernel-log-print.patch (drm-backport-placeholder)
- commit b5c9108
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1489-drm-amdgpu-fix-find-ras-error-node-error.patch (drm-backport-placeholder)
- commit a7434e4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1488-drm-amd-display-reprogram-det-size-while-seamless-bo.patch (drm-backport-placeholder)
- commit 8108f3e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1487-drm-amd-pm-record-mca-debug-mode-in-RAS.patch (drm-backport-placeholder)
- commit b0d9eef
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1486-drm-amdgpu-move-buffer-funcs-setting-up-a-level.patch (drm-backport-placeholder)
- commit 2844708
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1485-drm-sched-Convert-the-GPU-scheduler-to-variable-numb.patch (drm-backport-placeholder)
- commit d05a1eb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1484-drm-ci-docs-add-step-about-how-to-request-privileges.patch (drm-backport-placeholder)
- commit 6dd6c37
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1483-drm-ci-do-not-automatically-retry-on-error.patch (drm-backport-placeholder)
- commit 1886ed1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1482-drm-ci-export-kernel-config.patch (drm-backport-placeholder)
- commit ecbb0b6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1481-drm-ci-increase-i915-job-timeout-to-1h30m.patch (drm-backport-placeholder)
- commit 1135799
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1480-drm-ci-add-subset-1-gfx-to-LAVA_TAGS-and-adjust-shar.patch (drm-backport-placeholder)
- commit bb28334
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1478-drm-ci-uprev-IGT-and-make-sure-core_getversion-is-ru.patch (drm-backport-placeholder)
- commit 04ad731
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1477-drm-ci-add-helper-script-update-xfails.py.patch (drm-backport-placeholder)
- commit 6a88806
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1476-drm-ci-fix-DEBIAN_ARCH-and-get-amdgpu-probing.patch (drm-backport-placeholder)
- commit 330e597
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1475-drm-ci-uprev-mesa-version-fix-container-build-crosvm.patch (drm-backport-placeholder)
- commit aafd198
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1474-drm-ci-Enable-CONFIG_BACKLIGHT_CLASS_DEVICE.patch (drm-backport-placeholder)
- commit 3421df0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1473-drm-ci-force-enable-CONFIG_MSM_MMCC_8996-as-built-in.patch (drm-backport-placeholder)
- commit 7a2381e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1472-drm-ci-pick-up-external-fixes-from-the-merge-target-.patch (drm-backport-placeholder)
- commit d8f04b6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1471-drm-doc-ci-Require-more-context-for-flaky-tests.patch (drm-backport-placeholder)
- commit 75879db
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1470-drm-doc-document-DRM_IOCTL_MODE_CREATE_DUMB.patch (drm-backport-placeholder)
- commit e4bb7d2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1469-drm-rockchip-vop-Add-NV15-NV20-and-NV30-support.patch (drm-backport-placeholder)
- commit 346cf46
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1468-drm-fourcc-Add-NV20-and-NV30-YUV-formats.patch (drm-backport-placeholder)
- commit 06d0672
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1467-drm-rockchip-vop2-rename-window-formats-to-show-wind.patch (drm-backport-placeholder)
- commit a90a0e5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1466-drm-rockchip-vop2-Add-more-supported-10bit-formats.patch (drm-backport-placeholder)
- commit ab3a7ba
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-vop2-remove-the-unsupported-format-of-c.patch (drm-backport-placeholder)
- commit 71aae13
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1464-drm-rockchip-vop-fix-format-bpp-calculation.patch (drm-backport-placeholder)
- commit f964bfa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1463-drm-bridge-synopsys-dw-mipi-dsi-Fix-hcomponent-lbcc-.patch (drm-backport-placeholder)
- commit 67bd022
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1462-drm-client-Convert-drm_client_buffer_addfb-to-drm_mo.patch (drm-backport-placeholder)
- commit b525eef
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1461-drm-doc-use-cross-references-for-macros.patch (drm-backport-placeholder)
- commit ebf8450
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-vc4-fix-typo.patch (drm-backport-placeholder)
- commit 60fa54f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1459-drm-panel-ili9882t-Avoid-blurred-screen-from-fast-sl.patch (drm-backport-placeholder)
- commit 8db1331
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1458-drm-panel-ili9882t-Break-out-as-separate-driver.patch (drm-backport-placeholder)
- commit adb4c13
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1457-drm-ast-Move-register-constants-to-ast_reg.h.patch (drm-backport-placeholder)
- commit 76303e1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1456-drm-ast-Rename-AST_IO_MISC_PORT_READ-to-AST_IO_VGAMR.patch (drm-backport-placeholder)
- commit 0442df5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1455-drm-ast-Rename-AST_IO_INPUT_STATUS1_READ-to-AST_IO_V.patch (drm-backport-placeholder)
- commit da7e737
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1454-drm-ast-Rename-AST_IO_CRTC_PORT-to-AST_IO_VGACRI.patch (drm-backport-placeholder)
- commit f0281c6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1453-drm-ast-Rename-AST_IO_GR_PORT-to-AST_IO_VGAGRI.patch (drm-backport-placeholder)
- commit 2603d37
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1452-drm-ast-Rename-AST_IO_DAC_DATA-to-AST_IO_VGAPDR.patch (drm-backport-placeholder)
- commit ca07bee
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1451-drm-ast-Rename-AST_IO_DAC_INDEX_WRITE-to-AST_IO_VGAD.patch (drm-backport-placeholder)
- commit f1c0167
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1450-drm-ast-Rename-AST_IO_DAC_INDEX_READ-to-AST_IO_VGADR.patch (drm-backport-placeholder)
- commit 111abd3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1449-drm-ast-Rename-AST_IO_SEQ_PORT-to-AST_IO_VGASRI.patch (drm-backport-placeholder)
- commit 527fee9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1448-drm-ast-Rename-AST_IO_VGA_ENABLE_PORT-to-AST_IO_VGAE.patch (drm-backport-placeholder)
- commit 660f78b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1447-drm-ast-Rename-AST_IO_MISC_PORT_WRITE-to-AST_IO_VGAM.patch (drm-backport-placeholder)
- commit 6a8ab3e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1446-drm-ast-Rename-AST_IO_AR_PORT_WRITE-to-AST_IO_VGAARI.patch (drm-backport-placeholder)
- commit c2ab2ef
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1445-fbdev-vt8623fb-Initialize-fb_ops-to-fbdev-I-O-memory.patch (drm-backport-placeholder)
- commit 0b033c2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1444-fbdev-viafb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit 89adb0b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1443-fbdev-vga16fb-Initialize-fb_ops-to-fbdev-I-O-memory-.patch (drm-backport-placeholder)
- commit 2b0b95d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1442-fbdev-vermilionfb-Initialize-fb_ops-to-fbdev-I-O-mem.patch (drm-backport-placeholder)
- commit 64524dc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1441-fbdev-tridentfb-Initialize-fb_ops-to-fbdev-I-O-memor.patch (drm-backport-placeholder)
- commit 10b60c5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1440-fbdev-tgafb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit 41fd8ab
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1439-fbdev-tdfxfb-Initialize-fb_ops-to-fbdev-I-O-memory-h.patch (drm-backport-placeholder)
- commit 1a51d67
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1438-fbdev-sunxvr500-Initialize-fb_ops-to-fbdev-I-O-memor.patch (drm-backport-placeholder)
- commit 13566ec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1437-fbdev-stifb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit 941c9d3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1436-fbdev-sm712fb-Initialize-fb_ops-to-fbdev-I-O-memory-.patch (drm-backport-placeholder)
- commit b07a5a0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1435-fbdev-sm501fb-Initialize-fb_ops-to-fbdev-I-O-memory-.patch (drm-backport-placeholder)
- commit 348c203
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1434-fbdev-sisfb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit 5fe470d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1433-fbdev-savagefb-Initialize-fb_ops-to-fbdev-I-O-memory.patch (drm-backport-placeholder)
- commit 7b93fa2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1432-fbdev-sa1100fb-Initialize-fb_ops-to-fbdev-I-O-memory.patch (drm-backport-placeholder)
- commit 89e208f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1431-fbdev-s3fb-Initialize-fb_ops-to-fbdev-I-O-memory-hel.patch (drm-backport-placeholder)
- commit 7105b32
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1430-fbdev-s1d13xxxfb-Initialize-fb_ops-to-fbdev-I-O-memo.patch (drm-backport-placeholder)
- commit 16b5203
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1429-fbdev-rivafb-Initialize-fb_ops-to-fbdev-I-O-memory-h.patch (drm-backport-placeholder)
- commit d785625
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1428-fbdev-radeon-Initialize-fb_ops-to-fbdev-I-O-memory-h.patch (drm-backport-placeholder)
- commit da2971c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1427-fbdev-pvr2fb-Initialize-fb_ops-to-fbdev-I-O-memory-h.patch (drm-backport-placeholder)
- commit ec872f7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1426-fbdev-pm3fb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit c7d7763
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1425-fbdev-pm2fb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit 9c650db
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1424-fbdev-omapfb-Initialize-fb_ops-to-fbdev-I-O-memory-h.patch (drm-backport-placeholder)
- commit 95cd010
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1423-fbdev-nvidiafb-Initialize-fb_ops-to-fbdev-I-O-memory.patch (drm-backport-placeholder)
- commit 61a4ccc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1422-fbdev-neofb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit ce437b0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1421-fbdev-matroxfb-Initialize-fb_ops-to-fbdev-I-O-memory.patch (drm-backport-placeholder)
- commit 2ec3193
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1420-fbdev-intelfb-Initialize-fb_ops-to-fbdev-I-O-memory-.patch (drm-backport-placeholder)
- commit 4e075d2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1419-fbdev-imsttfb-Initialize-fb_ops-to-fbdev-I-O-memory-.patch (drm-backport-placeholder)
- commit 7850876
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1418-fbdev-i810fb-Initialize-fb_ops-to-fbdev-I-O-memory-h.patch (drm-backport-placeholder)
- commit 5360c4a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1417-fbdev-hpfb-Initialize-fb_ops-to-fbdev-I-O-memory-hel.patch (drm-backport-placeholder)
- commit 328b12d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1416-fbdev-hitfb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit 624b2e0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1415-fbdev-hgafb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit dfccfa4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1414-fbdev-gbefb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit 3827800
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1413-fbdev-ep93xx-fb-Initialize-fb_ops-to-fbdev-I-O-memor.patch (drm-backport-placeholder)
- commit 123bf75
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1412-fbdev-dnfb-Initialize-fb_ops-to-fbdev-I-O-memory-hel.patch (drm-backport-placeholder)
- commit 8604436
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1411-fbdev-cyber2000fb-Initialize-fb_ops-to-fbdev-I-O-mem.patch (drm-backport-placeholder)
- commit b1bfe78
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1410-fbdev-controlfb-Initialize-fb_ops-to-fbdev-I-O-memor.patch (drm-backport-placeholder)
- commit e9547cd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1409-fbdev-cobalt-lcd-Initialize-fb_ops-to-fbdev-I-O-memo.patch (drm-backport-placeholder)
- commit e14036b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1408-fbdev-cirrusfb-Initialize-fb_ops-to-fbdev-I-O-memory.patch (drm-backport-placeholder)
- commit b27df38
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1407-fbdev-au1100fb-Initialize-fb_ops-to-fbdev-I-O-memory.patch (drm-backport-placeholder)
- commit 4acf2b2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1406-fbdev-atyfb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit 416e368
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1405-fbdev-atafb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit 016700d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1404-fbdev-arkfb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit eedf32c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1403-fbdev-amifb-Initialize-fb_ops-to-fbdev-I-O-memory-he.patch (drm-backport-placeholder)
- commit b300ff6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1402-fbdev-amba-clcd-Initialize-fb_ops-to-fbdev-I-O-memor.patch (drm-backport-placeholder)
- commit 3d3cf02
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1401-fbdev-68328fb-Initialize-fb_ops-to-fbdev-I-O-memory-.patch (drm-backport-placeholder)
- commit f8d530a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1400-fbdev-Provide-I-O-memory-helpers-as-module.patch (drm-backport-placeholder)
- commit 0d6c505
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1399-drm-ssd130x-Add-support-for-the-SSD132x-OLED-control.patch (drm-backport-placeholder)
- commit 106c45d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1398-drm-ssd130x-Rename-commands-that-are-shared-across-c.patch (drm-backport-placeholder)
- commit f77b00e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1397-drm-ssd130x-Add-a-controller-family-id-to-the-device.patch (drm-backport-placeholder)
- commit 03783ee
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1396-drm-ssd130x-Replace-.page_height-field-in-device-inf.patch (drm-backport-placeholder)
- commit ec836df
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1395-drm-gpuvm-Dual-licence-the-drm_gpuvm-code-GPL-2.0-OR.patch (drm-backport-placeholder)
- commit e1e8e62
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1394-Documentation-gpu-Add-a-VM_BIND-async-document.patch (drm-backport-placeholder)
- commit 7dfacea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1393-drm-panel-st7703-Add-Powkiddy-RGB30-Panel-Support.patch (drm-backport-placeholder)
- commit 2c177af
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1392-drm-rockchip-remove-NR_LAYERS-macro-on-vop2.patch (drm-backport-placeholder)
- commit 637131c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-remove-unused-struct-in-vop2.patch (drm-backport-placeholder)
- commit 04b1815
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-Fix-type-promotion-bug-in-rockchip_gem_.patch (drm-backport-placeholder)
- commit 60202b4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-lt9611uxc-fix-the-race-in-the-error-path.patch (drm-backport-placeholder)
- commit eb86635
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1388-drm-bridge-imx-Add-i.MX93-MIPI-DSI-support.patch (drm-backport-placeholder)
- commit de2c0b8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1387-drm-bridge-synopsys-dw-mipi-dsi-Disable-HSTX-and-LPR.patch (drm-backport-placeholder)
- commit f660d5f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1386-drm-bridge-synopsys-dw-mipi-dsi-Set-minimum-lane-byt.patch (drm-backport-placeholder)
- commit ac32254
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1385-drm-bridge-synopsys-dw-mipi-dsi-Use-pixel-clock-rate.patch (drm-backport-placeholder)
- commit e3a79fa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1384-drm-bridge-synopsys-dw-mipi-dsi-Add-mode-fixup-suppo.patch (drm-backport-placeholder)
- commit 7512a0d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1383-drm-bridge-synopsys-dw-mipi-dsi-Force-input-bus-flag.patch (drm-backport-placeholder)
- commit 0ea487c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1382-drm-bridge-synopsys-dw-mipi-dsi-Add-input-bus-format.patch (drm-backport-placeholder)
- commit 87eb65d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1381-drm-bridge-synopsys-dw-mipi-dsi-Add-dw_mipi_dsi_get_.patch (drm-backport-placeholder)
- commit 589f7f4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1380-drm-adv7511-Add-hpd_override_enable-variable-to-stru.patch (drm-backport-placeholder)
- commit f4615d6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1379-drm-adv7511-Add-link_config-variable-to-struct-adv75.patch (drm-backport-placeholder)
- commit 292afbe
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1378-drm-adv7511-Add-has_dsi-variable-to-struct-adv7511_c.patch (drm-backport-placeholder)
- commit d3c9e9e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1377-drm-adv7511-Add-reg_cec_offset-variable-to-struct-ad.patch (drm-backport-placeholder)
- commit 7178fdc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1376-drm-adv7511-Add-supply_names-and-num_supplies-variab.patch (drm-backport-placeholder)
- commit 214fa8e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1375-drm-adv7511-Add-max_lane_freq_khz-variable-to-struct.patch (drm-backport-placeholder)
- commit 5ee1fdd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1374-drm-adv7511-Add-max_mode_clock_khz-variable-to-struc.patch (drm-backport-placeholder)
- commit b80a170
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1373-drm-adv7511-Add-struct-adv7511_chip_info-and-use-i2c.patch (drm-backport-placeholder)
- commit 911498d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1371-drm-panel-st7703-Fix-timings-when-entering-exiting-s.patch (drm-backport-placeholder)
- commit 515cb79
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-st7703-Pick-different-reset-sequence.patch (drm-backport-placeholder)
- commit c508fbb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1369-drm-ssd130x-Fix-atomic_check-for-disabled-planes.patch (drm-backport-placeholder)
- commit c67ea32
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1368-drm-bridge-megachips-stdpxxxx-ge-b850v3-fw-switch-to.patch (drm-backport-placeholder)
- commit 43564d9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1367-drm-amd-display-Fix-stack-size-issue-on-DML2.patch (drm-backport-placeholder)
- commit ec05d62
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1366-drm-amd-display-Reduce-stack-size-by-splitting-funct.patch (drm-backport-placeholder)
- commit da42a98
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1365-drm-amdkfd-remap-unaligned-svm-ranges-that-have-spli.patch (drm-backport-placeholder)
- commit 6787855
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1364-drm-amdgpu-Create-version-number-for-coredumps.patch (drm-backport-placeholder)
- commit 4c350ad
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1363-drm-amdgpu-Move-coredump-code-to-amdgpu_reset-file.patch (drm-backport-placeholder)
- commit 65b496a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1362-drm-amdgpu-Encapsulate-all-device-reset-info.patch (drm-backport-placeholder)
- commit 8da3021
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1361-drm-amdgpu-support-the-port-num-info-based-on-the-ca.patch (drm-backport-placeholder)
- commit ac7f640
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1360-drm-amdgpu-prepare-the-output-buffer-for-GET_PEER_LI.patch (drm-backport-placeholder)
- commit e691c7e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1359-drm-amdgpu-drop-status-query-reset-for-GCEA-9.4.3-an.patch (drm-backport-placeholder)
- commit b8e7080
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1358-drm-amdgpu-update-the-xgmi-ta-interface-header.patch (drm-backport-placeholder)
- commit 6975620
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1357-drm-amdgpu-add-set-get-mca-debug-mode-operations.patch (drm-backport-placeholder)
- commit d09b1e0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1356-drm-amdgpu-replace-reset_error_count-with-amdgpu_ras.patch (drm-backport-placeholder)
- commit c700be0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1355-drm-amdgpu-add-clockgating-support-for-NBIO-v7.7.1.patch (drm-backport-placeholder)
- commit c8d1c3a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1354-drm-amdgpu-fix-missing-stuff-in-NBIO-v7.11.patch (drm-backport-placeholder)
- commit 8201f8d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1353-drm-amdgpu-Enable-RAS-feature-by-default-for-APU.patch (drm-backport-placeholder)
- commit 2b52433
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1352-drm-amdgpu-fix-typo-for-amdgpu-ras-error-data-print.patch (drm-backport-placeholder)
- commit f702602
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1351-drm-amd-amdgpu-vcn-Add-RB-decouple-feature-under-SRI.patch (drm-backport-placeholder)
- commit c0bb87a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1350-drm-amd-amdgpu-vcn-Add-RB-decouple-feature-under-SRI.patch (drm-backport-placeholder)
- commit 7eac718
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1349-drm-amd-amdgpu-vcn-Add-RB-decouple-feature-under-SRI.patch (drm-backport-placeholder)
- commit 40fa6f3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1348-drm-amd-amdgpu-vcn-Add-RB-decouple-feature-under-SRI.patch (drm-backport-placeholder)
- commit d649d28
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1347-drm-amdgpu-Fix-delete-nodes-that-have-been-relesed.patch (drm-backport-placeholder)
- commit 0100dd3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1346-drm-amdgpu-Enable-mca-debug-mode-mode-when-ras-enabl.patch (drm-backport-placeholder)
- commit 8317d45
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1345-drm-amdgpu-Add-UVD_VCPU_INT_EN2-to-dpg-sram.patch (drm-backport-placeholder)
- commit fbcc67a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1344-drm-amd-display-Respect-CONFIG_FRAME_WARN-0-in-DML2.patch (drm-backport-placeholder)
- commit 39f464e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1343-drm-amd-display-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 88c1251
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1342-drm-amd-display-Simplify-bool-conversion.patch (drm-backport-placeholder)
- commit 5eb799f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1341-drm-amd-display-Remove-unneeded-semicolon.patch (drm-backport-placeholder)
- commit afdc70a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1340-drm-amd-display-Remove-duplicated-include-in-dce110_.patch (drm-backport-placeholder)
- commit ace3762
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1339-drm-amd-display-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 9e12d01
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-Handle-non-terminated-overdrive-commands.patch (drm-backport-placeholder)
- commit 9cca535
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1337-drm-amdgpu-Enable-software-RAS-in-vcn-v4_0_3.patch (drm-backport-placeholder)
- commit ccf16d8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1336-drm-amdgpu-define-ras_reset_error_count-function.patch (drm-backport-placeholder)
- commit 0962246
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1335-drm-amdkfd-remove-unused-code.patch (drm-backport-placeholder)
- commit 52e5d7f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1334-drm-amd-pm-Support-for-getting-power1_cap_min-value.patch (drm-backport-placeholder)
- commit c3b2da2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1333-drm-amdgpu-Log-UE-corrected-by-replay-as-correctable.patch (drm-backport-placeholder)
- commit eee37a3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1332-drm-amdgpu-Workaround-to-skip-kiq-ring-test-during-r.patch (drm-backport-placeholder)
- commit 614c575
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1331-drm-amd-display-Fix-a-handful-of-spelling-mistakes-i.patch (drm-backport-placeholder)
- commit 5716322
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1330-drm-amdkfd-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 6c43d37
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1329-drm-amd-display-Remove-brackets-in-macro-to-conform-.patch (drm-backport-placeholder)
- commit 777818a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1328-drm-amd-Read-IMU-FW-version-from-scratch-register-du.patch (drm-backport-placeholder)
- commit 9030781
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1327-drm-amd-Don-t-parse-IMU-ucode-version-if-it-won-t-be.patch (drm-backport-placeholder)
- commit 8a16877
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1326-drm-amd-Move-microcode-init-step-to-early_init.patch (drm-backport-placeholder)
- commit 0a71826
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-update-retry-times-for-psp-BL-wait.patch (drm-backport-placeholder)
- commit 37423d3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1324-drm-amd-Add-missing-kernel-doc-for-prepare_suspend.patch (drm-backport-placeholder)
- commit 48a9fcc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1323-drm-amdgpu-update-to-the-latest-GC-11.5-headers.patch (drm-backport-placeholder)
- commit 558b9d7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-Fix-a-memory-leak-on-an-error-path.patch (drm-backport-placeholder)
- commit 481af1a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1321-drm-amdgpu-mes11-remove-aggregated-doorbell-code.patch (drm-backport-placeholder)
- commit e9251ec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1320-drm-amdgpu-Add-hive-ras-recovery-check.patch (drm-backport-placeholder)
- commit 86e29ea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1319-drm-amd-display-Add-missing-lines-of-code-in-dc.c.patch (drm-backport-placeholder)
- commit d6cd7c8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amdgpu-Program-xcp_ctl-registers-as-neede.patch (drm-backport-placeholder)
- commit 4c15a00
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1317-drm-amdgpu-umsch-add-suspend-and-resume-callback.patch (drm-backport-placeholder)
- commit 3aaa1f4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1316-drm-amdgpu-pm-update-SMU-13.0.0-PMFW-version-check.patch (drm-backport-placeholder)
- commit 8ef115f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-vmwgfx_surface.c-copy-user-array-safely.patch (drm-backport-placeholder)
- commit 644ee87
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm_lease.c-copy-user-array-safely.patch (drm-backport-placeholder)
- commit bf80560
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1312-drm-msm-a7xx-actually-use-a7xx-state-registers.patch (drm-backport-placeholder)
- commit 9eed746
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1311-drm-msm-dpu-enable-writeback-on-SM8550.patch (drm-backport-placeholder)
- commit a7dc4ee
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1310-drm-msm-dpu-sm8550-remove-unused-VIG-and-DMA-clock-c.patch (drm-backport-placeholder)
- commit e8ddd23
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1309-drm-msm-dpu-move-setup_force_clk_ctrl-handling-into-.patch (drm-backport-placeholder)
- commit d283a6f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1308-drm-msm-dpu-add-setup_clk_force_ctrl-op-to-sspp-wb.patch (drm-backport-placeholder)
- commit 8260504
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1307-drm-msm-dpu-create-a-dpu_hw_clk_force_ctrl-helper.patch (drm-backport-placeholder)
- commit 8139e6d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1306-drm-msm-a6xx-Fix-up-QMP-handling.patch (drm-backport-placeholder)
- commit 62bf62c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dsi-free-TX-buffer-in-unbind.patch (drm-backport-placeholder)
- commit 3e8f61e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dsi-use-msm_gem_kernel_put-to-free-TX-buffer.patch (drm-backport-placeholder)
- commit 3db8800
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1303-drm-msm-dp-use-correct-lifetime-device-for-devm_drm_.patch (drm-backport-placeholder)
- commit 5e00220
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1302-drm-msm-hdmi-use-correct-lifetime-device-for-devm_dr.patch (drm-backport-placeholder)
- commit b05e8cf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1301-drm-msm-dsi-use-correct-lifetime-device-for-devm_drm.patch (drm-backport-placeholder)
- commit bf44fe7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1300-drm-msm-fix-fault-injection-support.patch (drm-backport-placeholder)
- commit 1ed03c9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1299-drm-msm-carve-out-KMS-code-from-msm_drv.c.patch (drm-backport-placeholder)
- commit 1aa3d26
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1298-drm-msm-make-fb-debugfs-file-available-only-in-KMS-c.patch (drm-backport-placeholder)
- commit 1e553a3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1297-drm-msm-only-register-kms-debug-file-if-KMS-is-used.patch (drm-backport-placeholder)
- commit 564caa0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1296-drm-msm-switch-to-drmm_mode_config_init.patch (drm-backport-placeholder)
- commit 00da7c2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1295-drm-msm-rename-msm_drv_shutdown-to-msm_kms_shutdown.patch (drm-backport-placeholder)
- commit f37c308
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1294-drm-msm-remove-shutdown-callback-from-msm_platform_d.patch (drm-backport-placeholder)
- commit dcd45f1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1293-drm-msm-rename-msm_pm_prepare-complete-to-note-the-K.patch (drm-backport-placeholder)
- commit 2379b42
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1292-drm-msm-drop-pm-ops-from-the-headless-msm-driver.patch (drm-backport-placeholder)
- commit 4310440
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1291-drm-msm-remove-msm_drm_private-bridges-field.patch (drm-backport-placeholder)
- commit 4a8978f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1290-drm-msm-dp-switch-to-devm_drm_bridge_add.patch (drm-backport-placeholder)
- commit e6f030d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1289-drm-msm-dp-move-pdev-from-struct-dp_display_private-.patch (drm-backport-placeholder)
- commit 9957934
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1288-drm-msm-hdmi-switch-to-devm_drm_bridge_add.patch (drm-backport-placeholder)
- commit 6fac89e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1287-drm-msm-dsi-switch-to-devm_drm_bridge_add.patch (drm-backport-placeholder)
- commit cafc005
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1286-drm-msm-mdp5-move-resource-allocation-to-the-_probe-.patch (drm-backport-placeholder)
- commit 2d42f5c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1285-drm-msm-mdp4-move-resource-allocation-to-the-_probe-.patch (drm-backport-placeholder)
- commit 218c1f4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1284-drm-msm-dpu-move-resource-allocation-to-the-_probe-f.patch (drm-backport-placeholder)
- commit a65d2ca
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1283-drm-msm-allow-passing-struct-msm_kms-to-msm_drv_prob.patch (drm-backport-placeholder)
- commit 2749351
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1282-drm-msm-adreno-Add-A635-speedbin-0xac-A643.patch (drm-backport-placeholder)
- commit 25dbf48
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1281-drm-msm-adreno-Add-ZAP-firmware-name-to-A635.patch (drm-backport-placeholder)
- commit 5c23b2b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-a6xx-Fix-unknown-speedbin-case.patch (drm-backport-placeholder)
- commit c731449
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-adreno-Fix-SM6375-GPU-ID.patch (drm-backport-placeholder)
- commit 4422ce4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1278-drm-msm-a6xx-Poll-for-GBIF-unhalt-status-in-hw_init.patch (drm-backport-placeholder)
- commit ec2aec2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1277-drm-msm-a6xx-Add-A740-support.patch (drm-backport-placeholder)
- commit 8c6ec49
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1276-drm-msm-a6xx-Add-A730-support.patch (drm-backport-placeholder)
- commit 5a81b9f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1275-drm-msm-a6xx-Mostly-implement-A7xx-gpu_state.patch (drm-backport-placeholder)
- commit ad64dd7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1274-drm-msm-a6xx-Send-ACD-state-to-QMP-at-GMU-resume.patch (drm-backport-placeholder)
- commit 84fdaa1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1273-drm-msm-a6xx-Add-skeleton-A7xx-support.patch (drm-backport-placeholder)
- commit d91b2c3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1272-drm-msm-a6xx-Add-missing-regs-for-A7XX.patch (drm-backport-placeholder)
- commit 4cfb592
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1271-drm-msm-dp-support-setting-the-DP-subconnector-type.patch (drm-backport-placeholder)
- commit f2e2e2c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1270-drm-msm-dp-Remove-error-message-when-downstream-port.patch (drm-backport-placeholder)
- commit fc9f106
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1269-drm-msm-dp-Inline-dp_display_is_sink_count_zero.patch (drm-backport-placeholder)
- commit a3b8396
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1268-drm-msm-dpu-move-INTF-tearing-checks-to-dpu_encoder_.patch (drm-backport-placeholder)
- commit 4f9665b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1267-drm-msm-dpu-drop-useless-check-from-dpu_encoder_phys.patch (drm-backport-placeholder)
- commit 4d5f92c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1266-drm-msm-dpu-drop-DPU_INTF_TE-feature-flag.patch (drm-backport-placeholder)
- commit 0a3873d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1265-drm-msm-dpu-enable-INTF-TE-operations-only-when-supp.patch (drm-backport-placeholder)
- commit 71978ef
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1264-drm-msm-dpu-inline-_setup_intf_ops.patch (drm-backport-placeholder)
- commit 95621d1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1263-drm-msm-dpu-drop-the-DPU_PINGPONG_TE-flag.patch (drm-backport-placeholder)
- commit aeba5b7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1262-drm-msm-dpu-enable-PINGPONG-TE-operations-only-when-.patch (drm-backport-placeholder)
- commit 27a3965
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1261-drm-msm-dpu-inline-_setup_pingpong_ops.patch (drm-backport-placeholder)
- commit 3a7281d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dp-skip-validity-check-for-DP-CTS-EDID-check.patch (drm-backport-placeholder)
- commit 251cdad
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1259-drm-msm-dp-Remove-dp_display_is_ds_bridge.patch (drm-backport-placeholder)
- commit 8815ef2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1258-drm-msm-dp-Inline-dp_link_parse_sink_count.patch (drm-backport-placeholder)
- commit e736a50
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1257-drm-msm-dp-Simplify-with-drm_dp_-max_link_rate-max_l.patch (drm-backport-placeholder)
- commit 3e32ac3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1256-drm-msm-dp-Remove-aux_cfg_update_done-and-related-co.patch (drm-backport-placeholder)
- commit 12d6e6d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1255-drm-msm-dp-Remove-dead-code-related-to-downstream-ca.patch (drm-backport-placeholder)
- commit e8f58d9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1254-drm-msm-dp-Use-drm_dp_read_sink_count-helper.patch (drm-backport-placeholder)
- commit 8afda81
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1253-drm-msm-dp-Replace-open-coded-drm_dp_read_dpcd_caps.patch (drm-backport-placeholder)
- commit d470d2e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1252-drm-msm-dsi-Enable-widebus-for-DSI.patch (drm-backport-placeholder)
- commit c58796e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1251-drm-msm-dsi-Add-DATABUS_WIDEN-MDP_CTRL2-bit.patch (drm-backport-placeholder)
- commit c618f24
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1250-drm-msm-dpu-Enable-widebus-for-DSI-INTF.patch (drm-backport-placeholder)
- commit dacaab5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1249-drm-msm-dpu-Move-setting-of-dpu_enc-wide_bus_en-to-a.patch (drm-backport-placeholder)
- commit 9c97da6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1248-drm-msm-Remove-unnecessary-NULL-values.patch (drm-backport-placeholder)
- commit c3a4d2f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1247-drm-msm-dpu-shift-IRQ-indices-by-1.patch (drm-backport-placeholder)
- commit 6c98f07
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1246-drm-msm-dpu-stop-using-raw-IRQ-indices-in-the-kernel.patch (drm-backport-placeholder)
- commit 6fe6d10
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1245-drm-msm-dpu-stop-using-raw-IRQ-indices-in-the-kernel.patch (drm-backport-placeholder)
- commit 147ee30
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1244-drm-msm-dpu-make-the-irq-table-size-static.patch (drm-backport-placeholder)
- commit 8c99e6c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1243-drm-msm-dpu-add-helper-to-get-IRQ-related-data.patch (drm-backport-placeholder)
- commit d6045d6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1242-drm-msm-dpu-extract-dpu_core_irq_is_valid-helper.patch (drm-backport-placeholder)
- commit 0ac9aa2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1241-drm-msm-dpu-remove-irq_idx-argument-from-IRQ-callbac.patch (drm-backport-placeholder)
- commit c2b8941
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-mtk_dsi-Fix-NO_EOT_PACKET-settings-hand.patch (drm-backport-placeholder)
- commit aae14b1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1239-drm-mediatek-aal-Compress-of_device_id-entries-and-a.patch (drm-backport-placeholder)
- commit fa6cd0e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1238-drm-mediatek-gamma-Add-kerneldoc-for-struct-mtk_disp.patch (drm-backport-placeholder)
- commit c3b9c8d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1237-drm-mediatek-aal-Add-kerneldoc-for-struct-mtk_disp_a.patch (drm-backport-placeholder)
- commit fe502a3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1236-drm-mediatek-gamma-Program-gamma-LUT-type-for-descen.patch (drm-backport-placeholder)
- commit 5f0b13d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1235-drm-mediatek-gamma-Make-sure-relay-mode-is-disabled.patch (drm-backport-placeholder)
- commit 0efdd7e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1234-drm-mediatek-gamma-Add-support-for-MT8195.patch (drm-backport-placeholder)
- commit 2a92992
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1233-drm-mediatek-gamma-Add-support-for-12-bit-LUT.patch (drm-backport-placeholder)
- commit 5aa3308
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1232-drm-mediatek-gamma-Support-multi-bank-gamma-LUT.patch (drm-backport-placeholder)
- commit 472121e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1231-drm-mediatek-De-commonize-disp_aal-disp_gamma-gamma_.patch (drm-backport-placeholder)
- commit 6b2cc2e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1230-drm-mediatek-aal-Use-bitfield-macros.patch (drm-backport-placeholder)
- commit 3922b22
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1229-drm-mediatek-gamma-Use-bitfield-macros.patch (drm-backport-placeholder)
- commit 8a2d31a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1228-drm-mediatek-gamma-Enable-the-Gamma-LUT-table-only-a.patch (drm-backport-placeholder)
- commit 3e03527
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1227-drm-mediatek-gamma-Improve-and-simplify-HW-LUT-calcu.patch (drm-backport-placeholder)
- commit a65aa50
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1226-drm-mediatek-gamma-Support-SoC-specific-LUT-size.patch (drm-backport-placeholder)
- commit a7ecee9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1225-drm-mediatek-gamma-Reduce-indentation-in-mtk_gamma_s.patch (drm-backport-placeholder)
- commit 2093c6f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1224-drm-mediatek-gamma-Adjust-mtk_drm_gamma_set_common-p.patch (drm-backport-placeholder)
- commit bbd10ff
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-iommu-fault-during-crtc-enabling.patch (drm-backport-placeholder)
- commit 76b0e57
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-iommu-fault-by-swapping-FBs-after-u.patch (drm-backport-placeholder)
- commit 8e2949b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1221-drm-mediatek-Support-dynamic-selection-of-MT8188-VDO.patch (drm-backport-placeholder)
- commit eb8fe77
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1220-drm-mediatek-dsi-Support-dynamic-connector-selection.patch (drm-backport-placeholder)
- commit a8b44cb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1219-drm-mediatek-dpi-Support-dynamic-connector-selection.patch (drm-backport-placeholder)
- commit a3a0e55
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1218-drm-mediatek-Add-connector-dynamic-selection-capabil.patch (drm-backport-placeholder)
- commit fb9db48
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1217-drm-mediatek-Add-encoder_index-interface-for-mtk_ddp.patch (drm-backport-placeholder)
- commit 302f238
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-using-wrong-drm-private-data-to-bin.patch (drm-backport-placeholder)
- commit 7a00e6b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Add-crtc-path-enum-for-all_drm_priv-arr.patch (drm-backport-placeholder)
- commit e326afb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Add-mmsys_dev_num-to-mt8188-vdosys0-dri.patch (drm-backport-placeholder)
- commit 42e6ba3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1213-drm-mediatek-dsi-Add-mode_valid-callback-to-DSI-brid.patch (drm-backport-placeholder)
- commit 7628001
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-dp-fix-memory-leak-on-get_edid-callback-fcaf976.patch (drm-backport-placeholder)
- commit a61deda
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-dp-fix-memory-leak-on-get_edid-callback.patch (drm-backport-placeholder)
- commit ae4beae
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1210-drm-mediatek-dp-Add-support-MT8188-dp-edp-function.patch (drm-backport-placeholder)
- commit 451fa4e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1209-drm-mediatek-dp-Add-the-audio-divider-to-mtk_dp_data.patch (drm-backport-placeholder)
- commit 02a7c40
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1208-drm-mediatek-dp-Add-the-audio-packet-flag-to-mtk_dp_.patch (drm-backport-placeholder)
- commit 93d1c24
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-coverity-issue-with-unintentional-i.patch (drm-backport-placeholder)
- commit a48b99b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1206-drm-mediatek-Add-mt8188-dsi-compatible-to-mtk_dsi.c.patch (drm-backport-placeholder)
- commit 3e9f104
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1205-drm-mediatek-dsi-Add-dsi-cmdq_ctl-to-send-panel-init.patch (drm-backport-placeholder)
- commit 7b12c18
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1204-drm-i915-mtl-Don-t-set-PIPE_CONTROL_FLUSH_L3.patch (drm-backport-placeholder)
- commit 48fcf70
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1203-drm-i915-Prevent-potential-null-ptr-deref-in-engine_.patch (drm-backport-placeholder)
- commit 8f36aaf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1202-drm-i915-Enable-GuC-TLB-invalidations-for-MTL.patch (drm-backport-placeholder)
- commit 5cad52d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1201-drm-i915-gt-Increase-sleep-in-gt_tlb-selftest-sanity.patch (drm-backport-placeholder)
- commit a1ed873
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1200-drm-i915-No-TLB-invalidation-on-wedged-GT.patch (drm-backport-placeholder)
- commit cc8001b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1199-drm-i915-No-TLB-invalidation-on-suspended-GT.patch (drm-backport-placeholder)
- commit 02808c7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1198-drm-i915-Define-and-use-GuC-and-CTB-TLB-invalidation.patch (drm-backport-placeholder)
- commit c929c0c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1197-drm-i915-guc-Add-CT-size-delay-helper.patch (drm-backport-placeholder)
- commit b962c9a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1196-drm-i915-Add-GuC-TLB-Invalidation-device-info-flags.patch (drm-backport-placeholder)
- commit 45e119c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1195-drm-i915-pxp-Clean-up-zero-initializers.patch (drm-backport-placeholder)
- commit cb2aa09
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1194-drm-i915-guc-Clean-up-zero-initializers.patch (drm-backport-placeholder)
- commit da7c996
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1193-drm-i915-mtl-Remove-the-force_probe-requirement-for-.patch (drm-backport-placeholder)
- commit 640d531
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1192-drm-i915-pci-Clean-up-zero-initializers.patch (drm-backport-placeholder)
- commit ba7bc84
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1191-drm-i915-hdcp-Clean-up-zero-initializers.patch (drm-backport-placeholder)
- commit 8cd499f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1190-drm-i915-display-Clean-up-zero-initializers.patch (drm-backport-placeholder)
- commit 1bfe05b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1189-drm-i915-dp-Remove-unused-DSC-caps-from-intel_dp.patch (drm-backport-placeholder)
- commit a1790d6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1188-drm-i915-dp_mst-Use-connector-DSC-DPCD-in-intel_dp_m.patch (drm-backport-placeholder)
- commit 7b8e6da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1187-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_dsc_c.patch (drm-backport-placeholder)
- commit ffa8347
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1186-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_mode_.patch (drm-backport-placeholder)
- commit b5086f4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1185-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_dsc_g.patch (drm-backport-placeholder)
- commit b565727
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1184-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_dsc_s.patch (drm-backport-placeholder)
- commit 6d769a4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1183-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_dsc_c.patch (drm-backport-placeholder)
- commit a1dc6b3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1182-drm-i915-dp-Pass-only-the-required-DSC-DPCD-to-intel.patch (drm-backport-placeholder)
- commit 9d9c62f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1181-drm-i915-dp-Pass-only-the-required-i915-to-intel_dp_.patch (drm-backport-placeholder)
- commit 4e48fbd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1180-drm-i915-dp-Pass-connector-DSC-DPCD-to-drm_dp_dsc_si.patch (drm-backport-placeholder)
- commit 8fb8b08
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1179-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_dsc_m.patch (drm-backport-placeholder)
- commit eaea88a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1178-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_suppo.patch (drm-backport-placeholder)
- commit 9c87b9f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1177-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_suppo.patch (drm-backport-placeholder)
- commit 2f2b015
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1176-drm-i915-dp-Use-connector-DSC-DPCD-in-intel_dp_dsc_c.patch (drm-backport-placeholder)
- commit 4fb6240
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1175-drm-i915-dp-Use-connector-DSC-DPCD-in-i915_dsc_fec_s.patch (drm-backport-placeholder)
- commit 5f0d4e7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1174-drm-i915-dp-Use-i915-intel-connector-local-variables.patch (drm-backport-placeholder)
- commit df8e9b7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1173-drm-i915-dp_mst-Set-connector-DSC-capabilities-and-d.patch (drm-backport-placeholder)
- commit ad3da54
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1172-drm-i915-dp-Store-DSC-DPCD-capabilities-in-the-conne.patch (drm-backport-placeholder)
- commit c023bae
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1171-drm-i915-dp-Sanitize-DPCD-revision-check-in-intel_dp.patch (drm-backport-placeholder)
- commit f9871c9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1170-drm-i915-dsb-Re-instate-DSB-for-LUT-updates.patch (drm-backport-placeholder)
- commit 3369e1e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1169-drm-i915-dsb-Correct-DSB-command-buffer-cache-cohere.patch (drm-backport-placeholder)
- commit 5b1f059
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1168-drm-i915-dsb-Allocate-command-buffer-from-local-memo.patch (drm-backport-placeholder)
- commit 98018e0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1167-drm-i915-lnl-Remove-watchdog-timers-for-PSR.patch (drm-backport-placeholder)
- commit b3ab97a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1166-drm-i915-Add-new-DG2-PCI-IDs.patch (drm-backport-placeholder)
- commit cd40680
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1164-drm-amd-swsmu-update-smu-v14_0_0-header-files-and-me.patch (drm-backport-placeholder)
- commit 3a5c238
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1163-drm-amdgpu-add-RAS-error-info-support-for-umc_v12_0.patch (drm-backport-placeholder)
- commit 477d878
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1162-drm-amdgpu-add-RAS-error-info-support-for-mmhub_v1_8.patch (drm-backport-placeholder)
- commit 4ce035f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1161-drm-amdgpu-add-RAS-error-info-support-for-gfx_v9_4_3.patch (drm-backport-placeholder)
- commit 2e1cb63
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1160-drm-amdgpu-add-RAS-error-info-support-for-sdma_v4_4_.patch (drm-backport-placeholder)
- commit abbaf06
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1159-drm-amdgpu-add-ras_err_info-to-identify-RAS-error-so.patch (drm-backport-placeholder)
- commit 2f16b00
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1158-drm-amdgpu-flush-the-correct-vmid-tlb-for-specific-p.patch (drm-backport-placeholder)
- commit f438d48
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1157-drm-amdgpu-make-err_data-structure-built-in-for-ras_.patch (drm-backport-placeholder)
- commit 092f7e0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1156-drm-amdgpu-disable-GFXOFF-and-PG-during-compute-for-.patch (drm-backport-placeholder)
- commit 60615a7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1155-drm-amdgpu-umsch-fix-missing-stuff-during-rebase.patch (drm-backport-placeholder)
- commit d270d7f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1154-drm-amdgpu-umsch-correct-IP-version-format.patch (drm-backport-placeholder)
- commit 64b23fc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1153-drm-amdgpu-don-t-use-legacy-invalidation-on-MMHUB-v3.patch (drm-backport-placeholder)
- commit e26f3b4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1152-drm-amdgpu-correct-NBIO-v7.11-programing.patch (drm-backport-placeholder)
- commit 53c43fd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-fix-a-possible-null-pointer-dereference.patch (drm-backport-placeholder)
- commit 3c9a582
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1150-drm-amdgpu-Correctly-use-bo_va-ref_count-in-compute-.patch (drm-backport-placeholder)
- commit 6a5d5a6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1149-drm-amd-pm-Add-P2S-tables-for-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit a7e0065
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1148-drm-amdgpu-Add-support-to-load-P2S-tables.patch (drm-backport-placeholder)
- commit 7a68229
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1147-drm-amdgpu-Update-PSP-interface-header.patch (drm-backport-placeholder)
- commit a9421dc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1146-drm-amdgpu-Avoid-FRU-EEPROM-access-on-APU.patch (drm-backport-placeholder)
- commit 499ab59
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1145-drm-amdgpu-save-VCN-instances-init-info-before-jpeg-.patch (drm-backport-placeholder)
- commit 5131deb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1144-Revert-drm-amd-display-Skip-entire-amdgpu_dm-build-i.patch (drm-backport-placeholder)
- commit d12257f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1143-Revert-drm-amd-display-Create-one-virtual-connector-.patch (drm-backport-placeholder)
- commit 9a534ed
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1142-Revert-drm-amd-display-Disable-virtual-links.patch (drm-backport-placeholder)
- commit 2a3f7f2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1141-Revert-drm-amd-display-Initialize-writeback-connecto.patch (drm-backport-placeholder)
- commit 4fe1bde
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1140-Revert-drm-amd-display-Skip-writeback-connector-when.patch (drm-backport-placeholder)
- commit 651849b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1139-Revert-drm-amd-display-Return-drm_connector-from-fin.patch (drm-backport-placeholder)
- commit 69596da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1138-Revert-drm-amd-display-Use-drm_connector-in-create_s.patch (drm-backport-placeholder)
- commit f1d3d36
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1137-drm-amd-pm-drop-most-smu_cmn_get_smc_version-in-smu.patch (drm-backport-placeholder)
- commit de89cdf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1136-drm-amd-pm-Add-reset-option-for-fan_ctrl-on-smu-13.0.patch (drm-backport-placeholder)
- commit d3f1361
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1135-drm-amd-pm-Add-reset-option-for-fan_ctrl-interfaces.patch (drm-backport-placeholder)
- commit 6afc55d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1134-Revert-drm-amd-display-Create-amdgpu_dm_wb_connector.patch (drm-backport-placeholder)
- commit 0f71bad
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1133-Revert-drm-amd-display-Create-fake-sink-and-stream-f.patch (drm-backport-placeholder)
- commit b527831
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1132-Revert-drm-amd-display-Hande-writeback-request-from-.patch (drm-backport-placeholder)
- commit f84d2d3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1131-Revert-drm-amd-display-Add-writeback-enable-disable-.patch (drm-backport-placeholder)
- commit d9425f7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1130-Revert-drm-amd-display-Fix-writeback_info-never-got-.patch (drm-backport-placeholder)
- commit aa02757
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1129-Revert-drm-amd-display-Validate-hw_points_num-before.patch (drm-backport-placeholder)
- commit 1cba33e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1128-Revert-drm-amd-display-Fix-writeback_info-is-not-rem.patch (drm-backport-placeholder)
- commit 106299b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1127-Revert-drm-amd-display-Add-writeback-enable-field-wb.patch (drm-backport-placeholder)
- commit e33c069
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1126-Revert-drm-amd-display-Setup-for-mmhubbub3_warmup_mc.patch (drm-backport-placeholder)
- commit e5dad02
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1125-Revert-drm-amd-display-Add-new-set_fc_enable-to-stru.patch (drm-backport-placeholder)
- commit 6079a29
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1124-Revert-drm-amd-display-Disable-DWB-frame-capture-to-.patch (drm-backport-placeholder)
- commit 1a95460
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1123-drm-amd-display-Revert-drm-amd-display-Use-drm_conne.patch (drm-backport-placeholder)
- commit 8aeceea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1122-drm-amdgpu-Expose-ras-version-schema-info.patch (drm-backport-placeholder)
- commit b9b5ab8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1121-drm-amdgpu-Read-PSPv13-OS-version-from-register.patch (drm-backport-placeholder)
- commit ef1a9da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1120-drm-amd-display-add-missing-NULL-check-for-DML2.patch (drm-backport-placeholder)
- commit 59342fd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1119-drm-amdgpu-umsch-enable-doorbell-for-umsch.patch (drm-backport-placeholder)
- commit c08e96f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1118-drm-amd-display-make-dc_set_power_state-return-type-.patch (drm-backport-placeholder)
- commit 456e22f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1117-drm-amd-display-Destroy-DC-context-while-keeping-DML.patch (drm-backport-placeholder)
- commit efa9eaa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1116-drm-amd-display-Catch-errors-from-drm_atomic_helper_.patch (drm-backport-placeholder)
- commit 550eb5f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1115-drm-amd-Split-up-UVD-suspend-into-prepare-and-suspen.patch (drm-backport-placeholder)
- commit 7414227
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1114-drm-amd-Add-concept-of-running-prepare_suspend-seque.patch (drm-backport-placeholder)
- commit 9e17ca3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1113-drm-amd-Evict-resources-during-PM-ops-prepare-callba.patch (drm-backport-placeholder)
- commit 583eaf7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1112-drm-amdgpu-enable-GFX-IP-v11.5.0-CG-and-PG-support.patch (drm-backport-placeholder)
- commit 43fe8a6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1111-drm-amdgpu-add-support-to-power-up-down-UMSCH-by-SMU.patch (drm-backport-placeholder)
- commit 993ea0d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1110-drm-amdgpu-add-power-up-down-UMSCH-ppt-callback.patch (drm-backport-placeholder)
- commit 23ad513
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1109-drm-amdgpu-add-support-to-powerup-VPE-by-SMU.patch (drm-backport-placeholder)
- commit 9665217
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1108-drm-amdgpu-discovery-add-SMU-14-support.patch (drm-backport-placeholder)
- commit ece703d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1107-drm-amd-swsmu-add-smu14-ip-support.patch (drm-backport-placeholder)
- commit 47fd328
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1106-drm-amd-swsmu-add-smu-v14_0_0-pmfw-if-file.patch (drm-backport-placeholder)
- commit 4da9220
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1105-drm-amd-swsmu-add-smu-v14_0_0-ppsmc-file.patch (drm-backport-placeholder)
- commit f41e781
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1104-drm-amdgpu-swsmu-add-smu-v14_0_0-driver-if-file.patch (drm-backport-placeholder)
- commit ff7ae8f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1103-drm-amdgpu-umsch-power-on-off-UMSCH-by-DLDO.patch (drm-backport-placeholder)
- commit a5a0b1d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1102-drm-amdgpu-umsch-fix-psp-frontdoor-loading.patch (drm-backport-placeholder)
- commit 478c074
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1101-drm-amdgpu-Increase-IP-discovery-region-size.patch (drm-backport-placeholder)
- commit 501fe09
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1100-drm-amd-pm-Use-gpu_metrics_v1_4-for-SMUv13.0.6.patch (drm-backport-placeholder)
- commit 12cc7b5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1099-drm-amd-pm-Add-gpu_metrics_v1_4.patch (drm-backport-placeholder)
- commit 9420a42
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1098-drm-amd-pm-Update-metric-table-for-smu-v13_0_6.patch (drm-backport-placeholder)
- commit cd6a712
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1097-drm-amdgpu-Return-EINVAL-when-MMSCH-init-status-inco.patch (drm-backport-placeholder)
- commit 01c1268
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1096-drm-amd-pm-wait-for-completion-of-the-EnableGfxImu-c.patch (drm-backport-placeholder)
- commit 9eeddcf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1095-drm-amdgpu-vpe-fix-insert_nop-ops.patch (drm-backport-placeholder)
- commit 8a6869c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1094-drm-amdgpu-Address-member-gart_placement-not-describ.patch (drm-backport-placeholder)
- commit 51e32c0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1093-drm-amdgpu-vpe-align-with-mcbp-changes.patch (drm-backport-placeholder)
- commit 20f27ce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1092-drm-amdgpu-vpe-remove-IB-end-boundary-requirement.patch (drm-backport-placeholder)
- commit 892b694
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1091-drm-amdgpu-Improve-MES-responsiveness-during-oversub.patch (drm-backport-placeholder)
- commit 6bec14f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1090-drm-amdgpu-discovery-enable-DCN-3.5.0-support.patch (drm-backport-placeholder)
- commit 1747285
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-get-doorbell-s-absolute-offset-based-on-t.patch (drm-backport-placeholder)
- commit 6d0a40c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1088-drm-amd-display-3.2.255.patch (drm-backport-placeholder)
- commit 6b904e7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1087-drm-amd-display-Disable-virtual-links.patch (drm-backport-placeholder)
- commit 57753a4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1086-drm-amd-display-Disable-SubVP-if-test-pattern-is-ena.patch (drm-backport-placeholder)
- commit 2c3aed6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1085-drm-amd-display-Refactor-DPG-test-pattern-logic-for-.patch (drm-backport-placeholder)
- commit c16096a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1084-drm-amd-display-Don-t-set-dpms_off-for-seamless-boot.patch (drm-backport-placeholder)
- commit c408014
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1083-drm-amd-display-Refactor-HWSS-into-component-folder.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Delete patches.suse/drm-amd-display-Fix-DPSTREAM-CLK-on-and-off-sequence.patch.
- Delete patches.suse/drm-amd-display-Prevent-crash-when-disable-stream.patch.
- commit 4e9356d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1082-drm-amd-display-Revert-drm-amd-display-Add-a-check-f.patch (drm-backport-placeholder)
- commit da41ead
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1081-drm-amdgpu-add-hub-ctx_distance-in-setup_vmid_config.patch (drm-backport-placeholder)
- commit 8f17512
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Don-t-use-fsleep-for-PSR-exit-waits.patch (drm-backport-placeholder)
- commit 2f35b52
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1079-drm-amd-display-Update-cursor-limits-based-on-SW-cur.patch (drm-backport-placeholder)
- commit 11b5f16
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1078-drm-amd-display-Update-dml-ssb-from-pmfw-clock-table.patch (drm-backport-placeholder)
- commit bd5cd15
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1077-drm-amd-display-Update-stream-mask.patch (drm-backport-placeholder)
- commit c1c0325
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1076-drm-amd-display-Revert-drm-amd-display-remove-duplic.patch (drm-backport-placeholder)
- commit 9bf9ac5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1075-drm-amd-display-Modify-Vmin-default-value.patch (drm-backport-placeholder)
- commit f04f3d4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1074-drm-amd-display-Update-pmfw_driver_if-new-structure.patch (drm-backport-placeholder)
- commit bacd32d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1073-drm-amd-display-VSIF-v3-set-Max-Refresh-Rate.patch (drm-backport-placeholder)
- commit 400392b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1072-drm-amd-display-Modify-SMU-message-logs.patch (drm-backport-placeholder)
- commit 37aa8ea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1070-drm-amd-display-enable-S-G-display-for-for-recent-AP.patch (drm-backport-placeholder)
- commit df25c7e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1069-Documentation-amdgpu-Add-FRU-attribute-details.patch (drm-backport-placeholder)
- commit d5a943c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1068-drm-amdgpu-Add-more-FRU-field-information.patch (drm-backport-placeholder)
- commit 9081f30
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1067-drm-amdgpu-Refactor-FRU-product-information.patch (drm-backport-placeholder)
- commit 35d94bd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1066-drm-amdgpu-enable-FRU-device-for-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit 13dadc2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1065-drm-amdgpu-update-ib-start-and-size-alignment.patch (drm-backport-placeholder)
- commit 4a4cee0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1064-drm-amd-display-add-check-in-validate_only-in-dml2.patch (drm-backport-placeholder)
- commit de210cc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1063-drm-amd-display-Port-replay-vblank-logic-to-DML2.patch (drm-backport-placeholder)
- commit abcf194
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1062-drm-amd-display-Modify-Pipe-Selection-for-Policy-for.patch (drm-backport-placeholder)
- commit 2bc7060
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1061-drm-amd-display-correct-dml2-input-and-dlg_refclk.patch (drm-backport-placeholder)
- commit 53cdc93
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1060-drm-amd-display-Fix-Chroma-Surface-height-width-init.patch (drm-backport-placeholder)
- commit 2d63bab
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1059-drm-amd-display-Move-stereo-timing-check-to-helper.patch (drm-backport-placeholder)
- commit 255af34
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1058-drm-amd-display-Split-pipe-for-stereo-timings.patch (drm-backport-placeholder)
- commit 9a2fa4f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1057-drm-amd-display-Use-fixed-DET-Buffer-Size.patch (drm-backport-placeholder)
- commit 40c117b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1056-drm-amd-display-Handle-multiple-streams-sourcing-sam.patch (drm-backport-placeholder)
- commit dd1c567
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1055-drm-amd-display-Add-z8_marks-in-dml.patch (drm-backport-placeholder)
- commit 79feb35
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1054-drm-amd-display-Add-DCN35-DML2-support.patch (drm-backport-placeholder)
- commit c6ec561
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1053-drm-amd-display-Introduce-DML2.patch (drm-backport-placeholder)
- commit 0b02d91
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1052-drm-amd-display-Move-dml-code-under-CONFIG_DRM_AMD_D.patch (drm-backport-placeholder)
- commit 2a7f6e8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1051-drm-amd-display-Move-bw_fixed-from-DML-folder.patch (drm-backport-placeholder)
- commit 7b7a055
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1050-drm-amd-display-Move-custom_float-from-DML-folder.patch (drm-backport-placeholder)
- commit 393f7b5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1049-drm-amd-display-Move-dce_calcs-from-DML-folder.patch (drm-backport-placeholder)
- commit 6cfb232
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1048-drm-amdgpu-Enable-SMU-13.0.0-optimizations-when-ROCm.patch (drm-backport-placeholder)
- commit 70a3617
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1047-drm-amd-display-Move-the-memory-allocation-out-of-dc.patch (drm-backport-placeholder)
- commit 49b7be9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1046-drm-amd-display-Move-the-memory-allocation-out-of-dc.patch (drm-backport-placeholder)
- commit bf6d1f5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1045-drm-amd-display-Add-a-warning-if-the-FPU-is-used-out.patch (drm-backport-placeholder)
- commit 30ccdab
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Fix-UBSAN-array-index-out-of-bounds-for-Pola.patch (drm-backport-placeholder)
- commit 104b4e9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1043-drm-radeon-Fix-UBSAN-array-index-out-of-bounds-for-R.patch (drm-backport-placeholder)
- commit d31138a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1041-drm-amdgpu-Annotate-struct-amdgpu_bo_list-with-__cou.patch (drm-backport-placeholder)
- commit 1cc5a99
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1040-drm-amdgpu-Drop-unnecessary-return-statements.patch (drm-backport-placeholder)
- commit 1addaf9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1039-Documentation-amdgpu-Add-board-info-details.patch (drm-backport-placeholder)
- commit d535b07
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1038-drm-amdgpu-Add-sysfs-attribute-to-get-board-info.patch (drm-backport-placeholder)
- commit 57fe387
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1037-drm-amdgpu-Get-package-types-for-smuio-v13.0.patch (drm-backport-placeholder)
- commit 6f0122c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1036-drm-amdgpu-Add-more-smuio-v13.0.3-package-types.patch (drm-backport-placeholder)
- commit d474e9e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1035-drm-amdgpu-fix-ip-count-query-for-xcp-partitions.patch (drm-backport-placeholder)
- commit 90df5f1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1034-drm-amd-pm-Remove-set-df-cstate-for-SMUv13.0.6.patch (drm-backport-placeholder)
- commit 39fd799
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1033-drm-amdgpu-Move-package-type-enum-to-amdgpu_smuio.patch (drm-backport-placeholder)
- commit 37e230a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1032-drm-amdgpu-Fix-complex-macros-error.patch (drm-backport-placeholder)
- commit d802475
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1031-drm-amdkfd-Use-partial-migrations-in-GPU-page-faults.patch (drm-backport-placeholder)
- commit e2d8f95
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1030-drm-amd-display-Simplify-the-per-CPU-usage.patch (drm-backport-placeholder)
- commit 9d807d8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1029-drm-amd-display-Remove-migrate_en-dis-from-dc_fpu_be.patch (drm-backport-placeholder)
- commit 6953e2a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1028-drm-amdgpu-amdgpu_drm.h-fix-comment-typos.patch (drm-backport-placeholder)
- commit 08b3c6f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1027-drm-amdgpu-refine-fault-cache-updates.patch (drm-backport-placeholder)
- commit 696399c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1026-drm-amdgpu-add-new-INFO-ioctl-query-for-the-last-GPU.patch (drm-backport-placeholder)
- commit 20e76eb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1025-drm-amd-pm-Add-GC-v9.4.3-thermal-limits-to-hwmon.patch (drm-backport-placeholder)
- commit 5db8ff3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1024-drm-amd-pm-Add-throttle-limit-for-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit 8c874e9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1023-drm-amd-display-3.2.254.patch (drm-backport-placeholder)
- commit d6f7606
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1022-drm-amd-display-Adjust-code-style-for-hw_sequencer.h.patch (drm-backport-placeholder)
- commit 2c3773d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1021-drm-amd-display-Adjust-code-style-for-dmub_cmd.h.patch (drm-backport-placeholder)
- commit 4eafb1d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1020-drm-amd-display-Update-DMUB-cmd-header.patch (drm-backport-placeholder)
- commit 165b320
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1019-drm-amd-display-Add-a-check-for-idle-power-optimizat.patch (drm-backport-placeholder)
- commit 074d4ea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-use-full-update-for-clip-size-increa.patch (drm-backport-placeholder)
- commit db8536d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1017-drm-amd-display-Clean-up-code-warnings.patch (drm-backport-placeholder)
- commit 29080c5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1016-drm-amd-display-Make-driver-backwards-compatible-wit.patch (drm-backport-placeholder)
- commit cc236ec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-refactor-ILR-to-make-it-work.patch (drm-backport-placeholder)
- commit eef5c25
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1014-drm-amd-display-remove-duplicated-edp-relink-to-fast.patch (drm-backport-placeholder)
- commit 4123077
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1013-drm-amd-display-enable-dsc_clk-even-if-dsc_pg-disabl.patch (drm-backport-placeholder)
- commit f3240b8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1012-drm-amdkfd-Fix-EXT_COHERENT-memory-allocation-crash.patch (drm-backport-placeholder)
- commit 9bfc9d3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1011-drm-amdgpu-ratelimited-override-pte-flags-messages.patch (drm-backport-placeholder)
- commit ab2b261
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-Null-check-for-DPP-resource.patch (drm-backport-placeholder)
- commit 467a900
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1009-drm-amd-Drop-all-hand-built-MIN-and-MAX-macros-in-th.patch (drm-backport-placeholder)
- commit 97d6fba
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Update-update_pcie_parameters-functions-to-u.patch (drm-backport-placeholder)
- commit 4a563c0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Bail-from-dm_check_crtc_cursor-if-no.patch (drm-backport-placeholder)
- commit ff15f16
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amd-display-Enable-Replay-for-static-scre.patch (drm-backport-placeholder)
- commit 8957dd5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1005-drm-amdgpu-cache-gpuvm-fault-information-for-gmc7.patch (drm-backport-placeholder)
- commit dc2095c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1004-drm-amdgpu-add-cached-GPU-fault-structure-to-vm-stru.patch (drm-backport-placeholder)
- commit ba7708b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Refactor-dm_get_plane_scale-helper.patch (drm-backport-placeholder)
- commit 35130a4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1002-drm-amdgpu-Use-ttm_pages_limit-to-override-vram-repo.patch (drm-backport-placeholder)
- commit accd498
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1001-drm-amdgpu-Rework-KFD-memory-max-limits.patch (drm-backport-placeholder)
- commit 2b11f14
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/1000-drm-amdgpu-gmc11-set-gart-placement-GC11.patch (drm-backport-placeholder)
- commit 99cd905
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0999-drm-amdgpu-gmc-add-a-way-to-force-a-particular-place.patch (drm-backport-placeholder)
- commit 8a70d53
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0998-drm-amd-display-fix-problems-in-power_helper.patch (drm-backport-placeholder)
- commit cb3d3c3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0997-drm-amdgpu-correct-gpu-clock-counter-query-on-cyan-s.patch (drm-backport-placeholder)
- commit bd0c114
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0996-drm-amd-display-Disable-DWB-frame-capture-to-emulate.patch (drm-backport-placeholder)
- commit bd59d79
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0995-drm-amd-display-Add-new-set_fc_enable-to-struct-dwbc.patch (drm-backport-placeholder)
- commit 91ba0c3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0994-drm-amd-display-Setup-for-mmhubbub3_warmup_mcif-with.patch (drm-backport-placeholder)
- commit 907f2c4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0993-drm-amd-display-Add-writeback-enable-field-wb_enable.patch (drm-backport-placeholder)
- commit 0c702d6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0992-drm-amd-display-Fix-writeback_info-is-not-removed.patch (drm-backport-placeholder)
- commit f64bfbb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0991-drm-amd-display-Validate-hw_points_num-before-using-.patch (drm-backport-placeholder)
- commit f207336
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0990-drm-amd-display-Fix-writeback_info-never-got-updated.patch (drm-backport-placeholder)
- commit 1c17a5a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0989-drm-amd-display-Add-writeback-enable-disable-in-dc.patch (drm-backport-placeholder)
- commit abd4fdd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0988-drm-amd-display-Hande-writeback-request-from-userspa.patch (drm-backport-placeholder)
- commit df0d48f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0987-drm-amd-display-Create-fake-sink-and-stream-for-writ.patch (drm-backport-placeholder)
- commit 4f19066
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0986-drm-amd-display-Create-amdgpu_dm_wb_connector.patch (drm-backport-placeholder)
- commit ee1b822
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0985-drm-amd-display-Use-drm_connector-in-create_validate.patch (drm-backport-placeholder)
- commit c0a3087
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0984-drm-amd-display-Address-srf_updates-not-described-in.patch (drm-backport-placeholder)
- commit 294a601
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0983-drm-amd-pm-delete-dead-code.patch (drm-backport-placeholder)
- commit 79db3a0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0982-drm-amd-display-Use-drm_connector-in-create_stream_f.patch (drm-backport-placeholder)
- commit c142f9d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0981-drm-amdkfd-drop-struct-kfd_cu_info.patch (drm-backport-placeholder)
- commit d3cf3a9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0980-drm-amd-display-Return-drm_connector-from-find_first.patch (drm-backport-placeholder)
- commit d934e9f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0979-drm-amdkfd-reduce-stack-size-in-kfd_topology_add_dev.patch (drm-backport-placeholder)
- commit cdbeb52
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-update-retry-times-for-psp-vmbx-wait.patch (drm-backport-placeholder)
- commit 70f1d62
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0977-drm-amd-display-Skip-writeback-connector-when-we-get.patch (drm-backport-placeholder)
- commit a9b8709
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0976-drm-amdgpu-exit-directly-if-gpu-reset-fails.patch (drm-backport-placeholder)
- commit 9639c1f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0975-drm-amd-pm-Disallow-managing-power-profiles-on-SRIOV.patch (drm-backport-placeholder)
- commit 7ae8a4b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Check-all-enabled-planes-in-dm_check.patch (drm-backport-placeholder)
- commit 4d92cae
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0972-drm-amd-display-Initialize-writeback-connector.patch (drm-backport-placeholder)
- commit 5c3560d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0971-drm-amd-Move-microcode-init-from-sw_init-to-early_in.patch (drm-backport-placeholder)
- commit 0de5a9f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0970-drm-amd-Move-microcode-init-from-sw_init-to-early_in.patch (drm-backport-placeholder)
- commit 2abd844
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0969-drm-amd-Move-microcode-init-from-sw_init-to-early_in.patch (drm-backport-placeholder)
- commit c20d5ce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0968-drm-amd-Move-microcode-init-from-sw_init-to-early_in.patch (drm-backport-placeholder)
- commit 5593399
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0967-drm-amd-Move-microcode-init-from-sw_init-to-early_in.patch (drm-backport-placeholder)
- commit 35d7a83
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0966-drm-amd-Move-microcode-init-from-sw_init-to-early_in.patch (drm-backport-placeholder)
- commit fbe9e5a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0964-drm-amd-display-Create-one-virtual-connector-in-DC.patch (drm-backport-placeholder)
- commit 441bbab
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0963-drm-amd-Drop-error-message-about-failing-to-load-SDM.patch (drm-backport-placeholder)
- commit c4e6b9b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0962-drm-amd-pm-fix-the-print_clk_levels-issue-for-SMU-v1.patch (drm-backport-placeholder)
- commit 4544668
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0961-drm-amd-pm-deprecate-allow_xgmi_power_down-interface.patch (drm-backport-placeholder)
- commit abfd6ed
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0960-drm-amd-pm-integrate-plpd-allow-disallow-into-select.patch (drm-backport-placeholder)
- commit 0df41f7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0959-drm-amd-pm-init-plpd_mode-properly-for-different-asi.patch (drm-backport-placeholder)
- commit 457af13
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0958-drm-amd-display-Remove-unused-DPCD-declarations.patch (drm-backport-placeholder)
- commit 15fa8ba
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0957-drm-amd-display-Skip-entire-amdgpu_dm-build-if-CONFI.patch (drm-backport-placeholder)
- commit a8146e5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0956-drm-amd-Limit-seamless-boot-by-default-to-APUs.patch (drm-backport-placeholder)
- commit 0c7fbe6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0955-drm-amd-Drop-error-message-about-failing-to-load-DMU.patch (drm-backport-placeholder)
- commit 30ce299
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Handle-errors-from-svm-validate-and-map.patch (drm-backport-placeholder)
- commit db326f2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0953-drm-amd-pm-add-xgmi_plpd_policy-sysfs-node-for-user-.patch (drm-backport-placeholder)
- commit 33a5935
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0952-drm-amd-pm-add-xgmi-plpd-mode-selecting-interface-fo.patch (drm-backport-placeholder)
- commit d810913
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0951-drm-amd-pm-add-plpd_mode-in-smu_context-to-indicate-.patch (drm-backport-placeholder)
- commit 46856f1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0950-drm-amd-pm-update-pmfw-headers-for-version-85.73.0.patch (drm-backport-placeholder)
- commit 395f3c9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0949-drm-amdgpu-Add-description-for-AMD_IP_BLOCK_TYPE_VPE.patch (drm-backport-placeholder)
- commit ab0d87f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0948-drm-amd-display-Change-dc_set_power_state-to-bool-in.patch (drm-backport-placeholder)
- commit 86d169f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0947-drm-amdgpu-gmc11-disable-AGP-on-GC-11.5.patch (drm-backport-placeholder)
- commit 4b947d6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-not-to-save-bo-in-the-case-of-RAS-err_eve.patch (drm-backport-placeholder)
- commit f665467
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0945-drm-amd-Propagate-failures-in-dc_set_power_state.patch (drm-backport-placeholder)
- commit 723dc8e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0944-drm-amd-display-set-stream-gamut-remap-matrix-to-MPC.patch (drm-backport-placeholder)
- commit 0e2884c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0943-drm-amdgpu-gmc-set-a-default-disable-value-for-AGP.patch (drm-backport-placeholder)
- commit ea75ba5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0942-drm-amdgpu-gmc6-8-properly-disable-the-AGP-aperture.patch (drm-backport-placeholder)
- commit df1ecad
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0941-drm-amdgpu-Expose-physical-id-of-device-in-XGMI-hive.patch (drm-backport-placeholder)
- commit 2b1bd78
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0940-drm-amd-display-Break-after-finding-supported-vlevel.patch (drm-backport-placeholder)
- commit badb3a8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0939-drm-amd-display-Update-OPP-counter-from-new-interfac.patch (drm-backport-placeholder)
- commit 104313f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0938-drm-amd-display-augment-display-clock-in-dc_cap-stru.patch (drm-backport-placeholder)
- commit 83b709d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0937-drm-amd-display-3.2.253.patch (drm-backport-placeholder)
- commit 2e8b78e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0936-drm-amd-display-fix-incorrect-odm-change-detection-l.patch (drm-backport-placeholder)
- commit 935af65
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0935-drm-amd-display-add-primary-pipe-check-when-building.patch (drm-backport-placeholder)
- commit 75292af
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0934-drm-amd-display-add-get-primary-dpp-pipe-resource-in.patch (drm-backport-placeholder)
- commit 9752728
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0933-drm-amd-display-add-missing-function-pointer-for-DCN.patch (drm-backport-placeholder)
- commit e55167d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0932-drm-amd-display-Rename-DisableMinDispClkODM-in-dc_co.patch (drm-backport-placeholder)
- commit 9d7266e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0931-drm-amdgpu-vpe-fix-truncation-warnings.patch (drm-backport-placeholder)
- commit b425c50
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0930-drm-amd-display-Improve-code-style-on-bios_parser2.patch (drm-backport-placeholder)
- commit 657953a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0929-drm-amd-display-Remove-unwanted-drm-edid-references.patch (drm-backport-placeholder)
- commit 192f1a2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0928-drm-amd-display-switch-DC-over-to-the-new-DRM-loggin.patch (drm-backport-placeholder)
- commit cbf2773
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0927-drm-amd-display-skip-audio-config-for-virtual-signal.patch (drm-backport-placeholder)
- commit db6857f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0926-drm-amd-pm-Add-reset-option-for-fan_curve-on-smu13_0.patch (drm-backport-placeholder)
- commit f1b0a2e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0925-drm-amd-display-block-MPO-if-it-prevents-pstate-supp.patch (drm-backport-placeholder)
- commit eea0089
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0924-drm-amd-display-Fix-DP2.0-timing-sync.patch (drm-backport-placeholder)
- commit b26d421
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0923-drm-amd-display-Improve-x86-and-dmub-ips-handshake.patch (drm-backport-placeholder)
- commit 4743188
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0922-drm-amd-display-remove-guaranteed-viewports-limitati.patch (drm-backport-placeholder)
- commit 40a0bd8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0921-drm-amd-display-add-new-windowed-mpo-odm-minimal-tra.patch (drm-backport-placeholder)
- commit be88dfc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0920-drm-amd-display-reset-stream-slice-count-for-new-ODM.patch (drm-backport-placeholder)
- commit c4f6000
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0919-drm-amd-display-determine-fast-update-only-before-co.patch (drm-backport-placeholder)
- commit 0362669
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0918-drm-amd-display-remove-unused-mmhub_reg_offsets.patch (drm-backport-placeholder)
- commit 743ed39
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-fix-some-race-conditions-in-vram-buffer-a.patch (drm-backport-placeholder)
- commit d984388
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0916-drm-amdkfd-Move-dma-unmapping-after-TLB-flush.patch (drm-backport-placeholder)
- commit 1b2ce10
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0915-drm-amdgpu-further-move-TLB-hw-workarounds-a-layer-u.patch (drm-backport-placeholder)
- commit afc5d1c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0914-drm-amdgpu-rework-lock-handling-for-flush_tlb-v2.patch (drm-backport-placeholder)
- commit 72d9135
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0913-drm-amdgpu-drop-error-return-from-flush_gpu_tlb_pasi.patch (drm-backport-placeholder)
- commit c567026
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0912-drm-amdgpu-fix-and-cleanup-gmc_v11_0_flush_gpu_tlb_p.patch (drm-backport-placeholder)
- commit 98cae8e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0911-drm-amdgpu-cleanup-gmc_v10_0_flush_gpu_tlb_pasid.patch (drm-backport-placeholder)
- commit 46481dc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0910-drm-amdgpu-fix-and-cleanup-gmc_v9_0_flush_gpu_tlb_pa.patch (drm-backport-placeholder)
- commit f47a5fa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0909-drm-amdgpu-fix-and-cleanup-gmc_v8_0_flush_gpu_tlb_pa.patch (drm-backport-placeholder)
- commit f341b5c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0908-drm-amdgpu-fix-and-cleanup-gmc_v7_0_flush_gpu_tlb_pa.patch (drm-backport-placeholder)
- commit 7e997e0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0907-drm-amdgpu-cleanup-gmc_v11_0_flush_gpu_tlb.patch (drm-backport-placeholder)
- commit 6582315
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0906-drm-amdgpu-rework-gmc_v10_0_flush_gpu_tlb-v2.patch (drm-backport-placeholder)
- commit 03c9103
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0905-drm-amdgpu-change-if-condition-for-bad-channel-bitma.patch (drm-backport-placeholder)
- commit e80a3f2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0904-drm-amdgpu-fix-value-of-some-UMC-parameters-for-UMC-.patch (drm-backport-placeholder)
- commit df542cc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0903-drm-amd-display-fix-some-style-issues.patch (drm-backport-placeholder)
- commit a9429cf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0902-drm-amdkfd-Don-t-use-sw-fault-filter-if-retry-cam-en.patch (drm-backport-placeholder)
- commit b3a21da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0901-drm-amdgpu-fix-and-cleanup-gmc_v9_0_flush_gpu_tlb.patch (drm-backport-placeholder)
- commit 02514f9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0900-gpu-drm-amd-display-fix-kernel-doc-warnings.patch (drm-backport-placeholder)
- commit 4db853b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Increase-IH-soft-ring-size-for-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit 86c1219
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0898-drm-amdgpu-Restore-partition-mode-after-reset.patch (drm-backport-placeholder)
- commit 250ed02
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0897-drm-amd-display-3.2.252.patch (drm-backport-placeholder)
- commit 285122a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0896-drm-amd-display-Drop-unused-link-FPGA-code.patch (drm-backport-placeholder)
- commit 5c62d2d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0895-drm-amd-display-Enable-DCN-low-mem-power-by-default.patch (drm-backport-placeholder)
- commit c0ff201
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0894-drm-amd-display-Expand-DML-to-better-support-replay.patch (drm-backport-placeholder)
- commit 62ca3fe
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0893-drm-amd-display-Use-optc32-instead-of-optc30-in-DC.patch (drm-backport-placeholder)
- commit d5dfcf8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0892-drm-amd-display-Optimize-OLED-T7-delay.patch (drm-backport-placeholder)
- commit ab76da7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Remove-svm-range-validated_once-flag.patch (drm-backport-placeholder)
- commit 57831a4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0890-drm-amdgpu-Add-more-fields-to-IP-version.patch (drm-backport-placeholder)
- commit 8ba6f69
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0889-drm-amdgpu-print-channel-index-for-UMC-bad-page.patch (drm-backport-placeholder)
- commit bfb9122
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0888-drm-amdkfd-Separate-dma-unmap-and-free-of-dma-addres.patch (drm-backport-placeholder)
- commit 3356a28
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0887-drm-amd-pm-Remove-SMUv13.0.6-unsupported-feature.patch (drm-backport-placeholder)
- commit 6999d2d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0886-drm-amd-pm-Round-Q10-format-values-in-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit 0fa3f72
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0885-drm-amdgpu-update-IP-count-INFO-query.patch (drm-backport-placeholder)
- commit e361dba
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0884-drm-amdgpu-Fix-false-positive-error-log.patch (drm-backport-placeholder)
- commit a82ed5c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0883-drm-amdgpu-jpeg-skip-set-pg-for-sriov.patch (drm-backport-placeholder)
- commit be5405c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0882-drm-amd-display-3.2.251.patch (drm-backport-placeholder)
- commit 4a9531b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0881-drm-amd-display-FW-Promotion-Release-0.0.183.0.patch (drm-backport-placeholder)
- commit 77d3941
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0880-drm-amd-display-Fix-MST-recognizes-connected-display.patch (drm-backport-placeholder)
- commit 28b6dc4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0879-drm-amd-display-fix-some-non-initialized-register-ma.patch (drm-backport-placeholder)
- commit f095a35
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0878-drm-amd-display-Enable-replay-for-dcn35.patch (drm-backport-placeholder)
- commit bf23081
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0877-drm-amd-display-Add-option-to-flip-ODM-optimization.patch (drm-backport-placeholder)
- commit 05c878b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0876-drm-amd-display-disable-IPS.patch (drm-backport-placeholder)
- commit 6de347a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0875-drm-amd-display-Add-IPS-control-flag.patch (drm-backport-placeholder)
- commit cd124e2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0874-drm-amd-display-Update-driver-and-IPS-interop.patch (drm-backport-placeholder)
- commit 2d61198
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0873-drm-amd-display-Correct-z8-watermark-mask.patch (drm-backport-placeholder)
- commit 160084c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0872-drm-amd-display-STREAM_MAPPER_CONTROL-register-offse.patch (drm-backport-placeholder)
- commit 4a2e675
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0871-drm-amd-display-Update-pipe-resource-interfaces-for-.patch (drm-backport-placeholder)
- commit ca7d703
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0870-drm-amd-display-Add-DPIA-Link-Encoder-Assignment-Fix.patch (drm-backport-placeholder)
- commit cf7dd57
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0869-drm-amd-display-fix-static-screen-detection-setting-.patch (drm-backport-placeholder)
- commit bec4870
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0868-drm-amd-display-Add-pointer-check-before-function-ca.patch (drm-backport-placeholder)
- commit 0a8f3ec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0867-drm-amd-display-Enable-DCLK_DS-from-driver-by-defaul.patch (drm-backport-placeholder)
- commit f56ce17
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0866-drm-amd-display-Add-DCN35-case-for-dc_clk_mgr_create.patch (drm-backport-placeholder)
- commit bcb3f10
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0865-drm-amd-display-Add-z8_marks-related-in-dml-for-DCN3.patch (drm-backport-placeholder)
- commit 6484f76
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0864-drm-amd-display-Fix-dig-register-undefined.patch (drm-backport-placeholder)
- commit 81b272d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0863-drm-amd-display-Temporarily-disable-clock-gating.patch (drm-backport-placeholder)
- commit 4eb8487
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0862-drm-amd-display-disable-clock-gating-logic.patch (drm-backport-placeholder)
- commit 4ec9771
* Wed Oct  2 2024 mhocko@suse.com
- vmalloc: modify the alloc_vmap_area() error message for better
  diagnostics (jsc#PED-10978).
- mm: mmap: no need to call khugepaged_enter_vma() for stack
  (jsc#PED-10978).
- commit 41e1775
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0861-drm-amd-display-Add-reset-for-SYMCLKC_FE_SRC_SEL.patch (drm-backport-placeholder)
- commit 5d61108
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0860-drm-amdgpu-Rework-coredump-to-use-memory-dynamically.patch (drm-backport-placeholder)
- commit d29c789
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0859-drm-amd-display-Remove-unused-display_content_suppor.patch (drm-backport-placeholder)
- commit 42d17eb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0858-drm-amd-display-Hook-up-content-type-property-for-HD.patch (drm-backport-placeholder)
- commit 772e669
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0857-drm-amdgpu-Fix-vbios-version-string-search.patch (drm-backport-placeholder)
- commit 5159ea7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0856-drm-amd-pm-add-smu_13_0_6-mca-dump-support.patch (drm-backport-placeholder)
- commit e3d135d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0855-drm-amd-pm-update-smu_v13_0_6-ppsmc-header.patch (drm-backport-placeholder)
- commit fc1f1f0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0854-drm-amdgpu-Add-EXT_COHERENT-memory-allocation-flags.patch (drm-backport-placeholder)
- commit 0522afc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0853-drm-amdkfd-fix-add-queue-process-context-clear-witho.patch (drm-backport-placeholder)
- commit f5f32b8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0852-drm-amdgpu-add-amdgpu-mca-debug-sysfs-support.patch (drm-backport-placeholder)
- commit 8e23c2c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0851-drm-amdgpu-add-VPE-IP-discovery-info-to-HW-IP-info-q.patch (drm-backport-placeholder)
- commit 2a4bc26
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0850-drm-amdgpu-add-amdgpu-smu-mca-dump-feature-support.patch (drm-backport-placeholder)
- commit a307a89
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0849-Documentation-amdgpu-Modify-pp_dpm_-clk-details.patch (drm-backport-placeholder)
- commit 4b4ca53
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0848-drm-amd-Enable-seamless-boot-by-default-on-newer-ASI.patch (drm-backport-placeholder)
- commit 6ee1e9e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0847-drm-amd-Add-a-module-parameter-for-seamless-boot.patch (drm-backport-placeholder)
- commit 2614876
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0846-drm-amd-Add-HDP-flush-during-jpeg-init.patch (drm-backport-placeholder)
- commit 3f7bb87
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0845-drm-amd-Move-seamless-boot-check-out-of-display.patch (drm-backport-placeholder)
- commit e851c14
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0844-drm-amd-Drop-special-case-for-yellow-carp-without-di.patch (drm-backport-placeholder)
- commit d2e9356
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0843-drm-amd-pm-Fix-GFX-deep-sleep-clock-reporting.patch (drm-backport-placeholder)
- commit 91bd61e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0842-drm-amd-pm-Fix-clock-reporting-for-SMUv13.0.6.patch (drm-backport-placeholder)
- commit 4e309ab
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0841-drm-amdgpu-Use-function-for-IP-version-check.patch (drm-backport-placeholder)
- commit f14897c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0840-drm-amdgpu-add-remap_hdp_registers-callback-for-nbio.patch (drm-backport-placeholder)
- commit 036a506
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0839-drm-amdgpu-add-vcn_doorbell_range-callback-for-nbio-.patch (drm-backport-placeholder)
- commit 024ba61
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0838-drm-amdgpu-Create-an-option-to-disable-soft-recovery.patch (drm-backport-placeholder)
- commit 176c905
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0837-drm-amdgpu-Merge-debug-module-parameters.patch (drm-backport-placeholder)
- commit 9d01d78
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0836-drm-amd-display-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit f9e83fb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0835-drm-amd-display-add-skip_implict_edp_power_control-f.patch (drm-backport-placeholder)
- commit d002876
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0834-drm-amd-display-minior-logging-improvements.patch (drm-backport-placeholder)
- commit 4119bce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0833-drm-amd-display-do-not-skip-ODM-minimal-transition-b.patch (drm-backport-placeholder)
- commit acca476
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0832-drm-amd-display-move-odm-power-optimization-decision.patch (drm-backport-placeholder)
- commit d90a3fc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-add-seamless-pipe-topology-transitio.patch (drm-backport-placeholder)
- commit 5511701
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0830-drm-amd-display-3.2.250.patch (drm-backport-placeholder)
- commit c080a5e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0829-drm-amd-display-fix-some-non-initialized-register-ma.patch (drm-backport-placeholder)
- commit 780f066
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0828-drm-amd-display-Add-check-for-vrr_active_fixed.patch (drm-backport-placeholder)
- commit 8dfe361
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0827-drm-amd-display-dc-cleanup-for-tests.patch (drm-backport-placeholder)
- commit 539ed0d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0826-drm-amdgpu-add-type-conversion-for-gc-info.patch (drm-backport-placeholder)
- commit 43d9b68
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0825-drm-amd-display-Drop-unused-registers.patch (drm-backport-placeholder)
- commit 5f26388
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0824-drm-amd-display-add-dp-dto-programming-function-to-d.patch (drm-backport-placeholder)
- commit fbb68fb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0823-drm-amd-display-only-allow-ODM-power-optimization-if.patch (drm-backport-placeholder)
- commit 6a50a3d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0822-drm-amd-display-do-not-attempt-ODM-power-optimizatio.patch (drm-backport-placeholder)
- commit b7c360c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0821-drm-amd-display-remove-a-function-that-does-complex-.patch (drm-backport-placeholder)
- commit 58ce987
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0820-drm-amd-display-Add-DCHUBBUB-callback-to-report-MALL.patch (drm-backport-placeholder)
- commit d5159ce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0819-drm-amd-display-Add-new-logs-for-AutoDPMTest.patch (drm-backport-placeholder)
- commit 15242ef
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0818-drm-amd-display-support-main-link-off-before-specifi.patch (drm-backport-placeholder)
- commit cbef097
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0817-drm-amdgpu-Rename-KGD_MAX_QUEUES-to-AMDGPU_MAX_QUEUE.patch (drm-backport-placeholder)
- commit 541fa07
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0816-drm-amd-display-do-not-block-ODM-OPM-on-one-side-of-.patch (drm-backport-placeholder)
- commit 82c2b1a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0815-drm-amd-display-Fix-DML-calculation-errors.patch (drm-backport-placeholder)
- commit fe52a90
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0814-drm-amdgpu-print-more-address-info-of-UMC-bad-page.patch (drm-backport-placeholder)
- commit e20176d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0813-drm-amd-display-FW-Promotion-Release-0.0.181.0.patch (drm-backport-placeholder)
- commit 89905a5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0812-drm-amd-display-set-default-return-value-for-ODM-Com.patch (drm-backport-placeholder)
- commit 6831a5e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Don-t-lock-phantom-pipe-on-disabling.patch (drm-backport-placeholder)
- commit 14307df
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Blank-phantom-OTG-before-enabling.patch (drm-backport-placeholder)
- commit 59a633c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0809-drm-amdgpu-add-channel-index-table-for-UMC-v12.patch (drm-backport-placeholder)
- commit 648bc73
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0808-drm-amd-pm-enable-smu_v13_0_6-mca-debug-mode-when-UM.patch (drm-backport-placeholder)
- commit 54250ce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0807-drm-amd-pm-update-smu_v13_0_6-smu-header.patch (drm-backport-placeholder)
- commit c8d2d25
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0806-drm-amdgpu-add-address-conversion-for-UMC-v12.patch (drm-backport-placeholder)
- commit 0f17e0d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0805-drm-amdgpu-Use-default-reset-method-handler.patch (drm-backport-placeholder)
- commit b060793
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0804-drm-amd-Fix-the-flag-setting-code-for-interrupt-requ.patch (drm-backport-placeholder)
- commit 563ad77
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0803-drm-amdgpu-fix-unsigned-error-codes.patch (drm-backport-placeholder)
- commit 69e57c8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0802-drm-amd-display-clean-up-one-inconsistent-indenting.patch (drm-backport-placeholder)
- commit e17278f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0801-drm-amdgpu-Add-umc-v12_0-ras-functions.patch (drm-backport-placeholder)
- commit 7e90d24
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-refclk-reporting-for-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit 2ee338e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0799-drm-amdgpu-Correct-se_num-and-reg_inst-for-gfx-v9_4_.patch (drm-backport-placeholder)
- commit b5fd1a3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0798-drm-amdgpu-Add-only-valid-firmware-version-nodes.patch (drm-backport-placeholder)
- commit 527ebc5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0797-drm-amdgpu-fix-incompatible-types-in-conditional-exp.patch (drm-backport-placeholder)
- commit a3eee31
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0796-drm-amdgpu-Use-min_t-to-replace-min.patch (drm-backport-placeholder)
- commit f8cc692
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0795-drm-amd-Add-umc-v12_0_0-ip-headers.patch (drm-backport-placeholder)
- commit d2509bd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0794-drm-amdgpu-Update-amdgpu_device_indirect_r-wreg_ext.patch (drm-backport-placeholder)
- commit 4e6f6fe
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0793-drm-amdgpu-Add-RREG64_PCIE_EXT-WREG64_PCIE_EXT-funct.patch (drm-backport-placeholder)
- commit 63bd830
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0792-drm-amdgpu-Declare-array-with-strings-as-pointers-co.patch (drm-backport-placeholder)
- commit 0e18296
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0791-amdgpu-pm-Optimize-emit_clock_levels-for-aldebaran-p.patch (drm-backport-placeholder)
- commit a765805
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0790-amdgpu-pm-Optimize-emit_clock_levels-for-aldebaran-p.patch (drm-backport-placeholder)
- commit 7360e8b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0789-amdgpu-pm-Optimize-emit_clock_levels-for-aldebaran-p.patch (drm-backport-placeholder)
- commit 99b2412
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0788-amdgpu-pm-Replace-print_clock_levels-with-emit_clock.patch (drm-backport-placeholder)
- commit caa6b5a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0787-drm-amd-display-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 7c674a7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0786-drm-amd-display-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit fc8a120
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0785-drm-amd-display-clean-up-one-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 2ed1f65
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0784-drm-amd-display-clean-up-one-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 70cbc93
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0783-drm-amd-display-Remove-duplicated-include-in-dcn35_c.patch (drm-backport-placeholder)
- commit 40fd8ec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0782-drm-amd-display-Remove-duplicated-include-in-dcn35_h.patch (drm-backport-placeholder)
- commit 77e918d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0781-drm-amd-display-Remove-duplicated-include-in-dcn35_o.patch (drm-backport-placeholder)
- commit dc0a9b5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0780-drm-amd-display-Remove-duplicated-include-in-dcn35_r.patch (drm-backport-placeholder)
- commit b8be0af
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0779-drm-amdgpu-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 076ff57
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0778-drm-amdgpu-calling-address-translation-functions-to-.patch (drm-backport-placeholder)
- commit d7258cf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0777-drm-amd-pm-only-poweron-off-vcn-jpeg-when-they-are-v.patch (drm-backport-placeholder)
- commit 3739f0d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-remove-useless-check-in-should_enabl.patch (drm-backport-placeholder)
- commit 6cca041
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0775-Revert-drm-amd-pm-disable-the-SMU13-OD-feature-suppo.patch (drm-backport-placeholder)
- commit d012d60
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0774-drm-amd-pm-add-fan-minimum-pwm-OD-setting-support-fo.patch (drm-backport-placeholder)
- commit 8f18be3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0773-drm-amd-pm-add-fan-target-temperature-OD-setting-sup.patch (drm-backport-placeholder)
- commit 1177f97
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0772-drm-amd-pm-add-fan-acoustic-target-OD-setting-suppor.patch (drm-backport-placeholder)
- commit 176a9b1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0771-drm-amdgpu-update-SET_HW_RESOURCES-definition-for-UM.patch (drm-backport-placeholder)
- commit 64310da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0770-drm-amdgpu-add-amdgpu_umsch_mm-module-parameter.patch (drm-backport-placeholder)
- commit 8f504ed
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0769-drm-amdgpu-discovery-enable-UMSCH-4.0-in-IP-discover.patch (drm-backport-placeholder)
- commit 1a4dba4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0768-drm-amdgpu-add-PSP-loading-support-for-UMSCH.patch (drm-backport-placeholder)
- commit cff1a46
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0767-drm-amdgpu-reserve-mmhub-engine-3-for-UMSCH-FW.patch (drm-backport-placeholder)
- commit b664093
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0766-drm-amdgpu-add-VPE-queue-submission-test.patch (drm-backport-placeholder)
- commit 45f55dc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0765-drm-amdgpu-add-selftest-framework-for-UMSCH.patch (drm-backport-placeholder)
- commit 41ac370
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0764-drm-amdgpu-enable-UMSCH-scheduling-for-VPE.patch (drm-backport-placeholder)
- commit 2ff3fbd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0763-drm-amdgpu-add-initial-support-for-UMSCH.patch (drm-backport-placeholder)
- commit 363bd49
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0762-drm-amdgpu-add-UMSCH-4.0-api-definition.patch (drm-backport-placeholder)
- commit e70fbb4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0761-drm-amdgpu-add-UMSCH-firmware-header-definition.patch (drm-backport-placeholder)
- commit e5b489e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0760-drm-amdgpu-add-UMSCH-RING-TYPE-definition.patch (drm-backport-placeholder)
- commit f444e78
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0759-drm-amd-pm-add-fan-acoustic-limit-OD-setting-support.patch (drm-backport-placeholder)
- commit 3e2476e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0758-drm-amd-pm-add-fan-temperature-pwm-curve-OD-setting-.patch (drm-backport-placeholder)
- commit 2d03fc8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0757-drm-amdgpu-jpeg-initialize-number-of-jpeg-ring.patch (drm-backport-placeholder)
- commit 1944262
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0756-drm-amdgpu-revise-the-device-initialization-sequence.patch (drm-backport-placeholder)
- commit 23c9d35
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0755-drm-amd-pm-introduce-a-new-set-of-OD-interfaces.patch (drm-backport-placeholder)
- commit 1ed3c22
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0754-drm-amdgpu-add-UMSCH-IP-BLOCK-TYPE-definition.patch (drm-backport-placeholder)
- commit 7728d4d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0753-amdgpu-pm-Optimize-emit_clock_levels-for-arcturus-pa.patch (drm-backport-placeholder)
- commit c783ebf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0752-drm-amdgpu-add-UMSCH-4.0-register-headers.patch (drm-backport-placeholder)
- commit 3771b70
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0751-drm-amdgpu-enable-PG-flags-for-VCN.patch (drm-backport-placeholder)
- commit 23dd088
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0750-drm-amdgpu-discovery-add-VCN-4.0.5-Support.patch (drm-backport-placeholder)
- commit 80abbfd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0749-drm-amdgpu-soc21-Add-video-cap-query-support-for-VCN.patch (drm-backport-placeholder)
- commit 5e2bfce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0748-drm-amdgpu-enable-CG-and-PG-flags-for-VCN.patch (drm-backport-placeholder)
- commit 008b6d9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0747-drm-amdgpu-add-VCN_4_0_5-firmware-support.patch (drm-backport-placeholder)
- commit 653d004
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0746-drm-amdgpu-jpeg-add-jpeg-support-for-VCN4_0_5.patch (drm-backport-placeholder)
- commit 37d8735
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0745-drm-amdgpu-add-VCN4-ip-block-support.patch (drm-backport-placeholder)
- commit 88f5bad
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0744-drm-amdgpu-add-vcn-4_0_5-header-files.patch (drm-backport-placeholder)
- commit 9eac2f1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0743-drm-amdgpu-fix-VPE-front-door-loading-issue.patch (drm-backport-placeholder)
- commit 43f4607
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0742-drm-amdgpu-add-VPE-FW-version-query-support.patch (drm-backport-placeholder)
- commit bac80ea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0741-drm-amdgpu-enable-VPE-for-VPE-6.1.0.patch (drm-backport-placeholder)
- commit 87de70a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0740-drm-amdgpu-add-user-space-CS-support-for-VPE.patch (drm-backport-placeholder)
- commit 4ccf342
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0739-drm-amdgpu-add-PSP-loading-support-for-VPE.patch (drm-backport-placeholder)
- commit 9d6f1c5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0738-drm-amdgpu-add-VPE-6.1.0-support.patch (drm-backport-placeholder)
- commit 49bd001
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0737-drm-amdgpu-add-nbio-7.11-callback-for-VPE.patch (drm-backport-placeholder)
- commit 91f4db4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0736-drm-amdgpu-add-nbio-callback-for-VPE.patch (drm-backport-placeholder)
- commit 116a638
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0735-drm-amdgpu-add-PSP-FW-TYPE-for-VPE.patch (drm-backport-placeholder)
- commit 55ba0de
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0734-drm-amdgpu-add-UCODE-ID-for-VPE.patch (drm-backport-placeholder)
- commit 47a7f65
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0733-drm-amdgpu-add-support-for-VPE-firmware-name-decodin.patch (drm-backport-placeholder)
- commit 0ce94bf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0732-drm-amdgpu-add-doorbell-index-for-VPE.patch (drm-backport-placeholder)
- commit 2f5284d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0731-drm-amdgpu-add-irq-src-id-definitions-for-VPE.patch (drm-backport-placeholder)
- commit ccae9c9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0730-drm-amdgpu-add-IH-CLIENT-ID-for-VPE.patch (drm-backport-placeholder)
- commit 6113d3c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0729-drm-amdgpu-add-HWID-for-VPE.patch (drm-backport-placeholder)
- commit a656153
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0728-drm-amdgpu-add-VPE-firmware-interface.patch (drm-backport-placeholder)
- commit f5c6a0f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0727-drm-amdgpu-add-VPE-firmware-header-definition.patch (drm-backport-placeholder)
- commit 4c6e5be
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0726-drm-amdgpu-add-VPE-HW-IP-BLOCK-definition.patch (drm-backport-placeholder)
- commit 7e317bb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0725-drm-amdgpu-add-VPE-IP-BLOCK-definition.patch (drm-backport-placeholder)
- commit aa40004
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0724-drm-amdgpu-add-VPE-RING-TYPE-definition.patch (drm-backport-placeholder)
- commit 3ad6be3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0723-drm-amdgpu-add-VPE-HW-IP-definition.patch (drm-backport-placeholder)
- commit 28de44b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0722-drm-amdgpu-add-VPE-6.1.0-header-files.patch (drm-backport-placeholder)
- commit 603f630
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0721-drm-amdgpu-Fix-printk_ratelimit-with-DRM_ERROR_RATEL.patch (drm-backport-placeholder)
- commit 371e060
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0720-drm-amdgpu-Use-READ_ONCE-when-reading-the-values-in-.patch (drm-backport-placeholder)
- commit 25f514f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0719-drm-amdgpu-remove-unused-parameter-in-amdgpu_vmid_gr.patch (drm-backport-placeholder)
- commit 0db40b7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0718-drm-amdkfd-Replace-pr_err-with-dev_err.patch (drm-backport-placeholder)
- commit 460586d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0717-amdgpu-pm-Optimize-emit_clock_levels-for-arcturus-pa.patch (drm-backport-placeholder)
- commit af9ff49
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0716-amdgpu-pm-Optimize-emit_clock_levels-for-arcturus-pa.patch (drm-backport-placeholder)
- commit f094c8e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0715-drm-amd-display-Adjust-kdoc-for-optc35_set_odm_combi.patch (drm-backport-placeholder)
- commit c4aaf8d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0714-drm-amd-Simplify-the-bo-size-check-funciton.patch (drm-backport-placeholder)
- commit 9f267de
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-ratelimited-SQ-interrupt-messages.patch (drm-backport-placeholder)
- commit c0d275e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0712-drm-amdgpu-access-RLC_SPM_MC_CNTL-through-MMIO-in-SR.patch (drm-backport-placeholder)
- commit f63225d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0711-drm-amd-amdgpu-sdma_v6_0-Demote-a-bunch-of-half-comp.patch (drm-backport-placeholder)
- commit d152308
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0710-drm-amd-display-Add-DCN35-DM-Support.patch (drm-backport-placeholder)
- commit 6db1b28
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0709-drm-amd-display-Add-DCN35-CORE.patch (drm-backport-placeholder)
- commit 04f4b49
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0708-drm-amd-display-Add-DCN35-blocks-to-Makefile.patch (drm-backport-placeholder)
- commit 49a7c70
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0707-drm-amd-display-Add-DCN35-DML.patch (drm-backport-placeholder)
- commit f3aa0b5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0706-drm-amd-display-Add-DCN35-Resource.patch (drm-backport-placeholder)
- commit 3d02831
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0705-drm-amd-display-Add-DCN35-init.patch (drm-backport-placeholder)
- commit be798e0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0704-drm-amd-display-Add-DCN35-DMUB.patch (drm-backport-placeholder)
- commit 26d8463
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0703-drm-amd-display-Add-DCN35-IRQ.patch (drm-backport-placeholder)
- commit 6af522f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0702-drm-amd-display-Add-DCN35-CLK_MGR.patch (drm-backport-placeholder)
- commit bf422b9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0701-drm-amd-display-Add-DCN35-HWSEQ.patch (drm-backport-placeholder)
- commit e09d13f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0700-drm-amd-display-Add-DCN35-DSC.patch (drm-backport-placeholder)
- commit 58cde12
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0699-drm-amd-display-Add-DCN35-MMHUBBUB.patch (drm-backport-placeholder)
- commit c3b0e1e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0698-drm-amd-display-Add-DCN35-HUBBUB.patch (drm-backport-placeholder)
- commit dc6b14e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0697-drm-amd-display-Add-DCN35-HUBP.patch (drm-backport-placeholder)
- commit 81db8e3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0696-drm-amd-display-Add-DCN35-DWB.patch (drm-backport-placeholder)
- commit a9c3296
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0695-drm-amd-display-Add-DCN35-DPP.patch (drm-backport-placeholder)
- commit fd82aee
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0694-drm-amd-display-Add-DCN35-OPP.patch (drm-backport-placeholder)
- commit 28fef9b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0693-drm-amd-display-Add-DCN35-OPTC.patch (drm-backport-placeholder)
- commit 7e1473a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0692-drm-amd-display-Add-DCN35-PG_CNTL.patch (drm-backport-placeholder)
- commit e68fc10
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0691-drm-amd-display-Add-DCN35-DIO.patch (drm-backport-placeholder)
- commit b607258
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0690-drm-amd-display-Add-DCN35-DCCG.patch (drm-backport-placeholder)
- commit 0abddce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0689-drm-amd-display-Add-DCN35-GPIO.patch (drm-backport-placeholder)
- commit 9c0dc6c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0688-drm-amd-display-Add-DCN35-BIOS-command-table-support.patch (drm-backport-placeholder)
- commit 448d481
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0687-drm-amd-display-Update-dc.h-for-DCN35-support.patch (drm-backport-placeholder)
- commit f685c07
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0686-drm-amd-display-Update-DCN32-for-DCN35-support.patch (drm-backport-placeholder)
- commit 598fb1e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0685-drm-amd-display-Update-DCN314-for-DCN35-support.patch (drm-backport-placeholder)
- commit 20afb98
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0684-drm-amd-display-Update-DCN31-for-DCN35-support.patch (drm-backport-placeholder)
- commit 9386ac9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0683-drm-amd-display-Update-DCN30-for-DCN35-support.patch (drm-backport-placeholder)
- commit dceb229
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0682-drm-amd-display-Update-DCN20-for-DCN35-support.patch (drm-backport-placeholder)
- commit 328817d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0681-drm-amd-display-Update-DCN10-for-DCN35-support.patch (drm-backport-placeholder)
- commit bd25735
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0680-drm-amd-display-Update-DCE-for-DCN35-support.patch (drm-backport-placeholder)
- commit 5c30c19
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0679-drm-amd-display-Add-DCN35-family-information.patch (drm-backport-placeholder)
- commit 6a8fca7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0678-drm-amd-display-Add-dcn35-register-header-files.patch (drm-backport-placeholder)
- commit a06c658
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-Remove-the-references-of-radeon_gem_-prea.patch (drm-backport-placeholder)
- commit d3e82ce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0676-drm-amd-display-Fix-up-kdoc-format-for-dc_set_edp_po.patch (drm-backport-placeholder)
- commit 3c13c6f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0675-drm-amd-display-3.2.249.patch (drm-backport-placeholder)
- commit 20c3591
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0674-drm-amd-display-fix-pipe-topology-logging-error.patch (drm-backport-placeholder)
- commit 6a8a15c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0673-drm-amd-display-Add-debugfs-interface-for-ODM-combin.patch (drm-backport-placeholder)
- commit 3734eb9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0672-drm-amd-display-correct-z8_watermark-16bit-to-20bit-.patch (drm-backport-placeholder)
- commit 1170707
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0671-drm-amd-display-Fix-incorrect-comment.patch (drm-backport-placeholder)
- commit 1f7b8fb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0670-drm-amd-display-Skip-dmub-memory-flush-when-not-need.patch (drm-backport-placeholder)
- commit b886745
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0669-drm-amd-display-add-pipe-topology-update-log.patch (drm-backport-placeholder)
- commit b93d2da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0668-drm-amd-display-switch-to-new-ODM-policy-for-windowe.patch (drm-backport-placeholder)
- commit e33487c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0667-drm-amd-display-use-new-pipe-allocation-interface-in.patch (drm-backport-placeholder)
- commit 026b4b2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0666-drm-amd-display-add-more-pipe-resource-interfaces.patch (drm-backport-placeholder)
- commit d03b0f3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0665-drm-amd-display-add-new-resource-interfaces-to-updat.patch (drm-backport-placeholder)
- commit de71902
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0664-drm-amd-display-add-new-resource-interface-for-acqui.patch (drm-backport-placeholder)
- commit 513031a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0663-drm-amd-display-rename-function-to-add-otg-master-fo.patch (drm-backport-placeholder)
- commit c8cafa7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0662-drm-amd-display-add-comments-to-add-plane-functions.patch (drm-backport-placeholder)
- commit a273de9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0661-drm-amd-display-Add-support-for-1080p-SubVP-to-reduc.patch (drm-backport-placeholder)
- commit 172a93d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0660-drm-amdgpu-add-header-files-for-MP-14.0.0.patch (drm-backport-placeholder)
- commit 5fd08be
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-amdgpu-amdgpu_doorbell_mgr-Correct-misdocume.patch (drm-backport-placeholder)
- commit ccc736b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0658-drm-amd-amdgpu-imu_v11_0-Increase-buffer-size-to-ens.patch (drm-backport-placeholder)
- commit 31e800d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0657-drm-amd-amdgpu-amdgpu_sdma-Increase-buffer-size-to-a.patch (drm-backport-placeholder)
- commit f62d9ee
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0656-drm-amd-amdgpu-amdgpu_ras-Increase-buffer-size-to-ac.patch (drm-backport-placeholder)
- commit 798edbb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0655-drm-amd-amdgpu-amdgpu_device-Provide-suitable-descri.patch (drm-backport-placeholder)
- commit 4647ce5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0654-drm-radeon-radeon_ttm-Remove-unused-variable-rbo-fro.patch (drm-backport-placeholder)
- commit c84ae9b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0653-drm-amd-Fix-spelling-mistake-throtting-throttling.patch (drm-backport-placeholder)
- commit 593d8e4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0652-drm-amdgpu-Use-kvzalloc-to-simplify-code.patch (drm-backport-placeholder)
- commit 4031700
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0651-drm-amdgpu-Remove-amdgpu_bo_list_array_entry.patch (drm-backport-placeholder)
- commit e14b426
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0650-drm-amdgpu-Remove-a-redundant-sanity-check.patch (drm-backport-placeholder)
- commit 2468669
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0649-drm-amdgpu-Explicitly-add-a-flexible-array-at-the-en.patch (drm-backport-placeholder)
- commit 8ed9a24
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0648-drm-amdgpu-Allow-issue-disable-gfx-ras-cmd-to-firmwa.patch (drm-backport-placeholder)
- commit 69ac427
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0647-amdgpu-pm-Replace-print_clock_levels-with-emit_clock.patch (drm-backport-placeholder)
- commit 3c5f767
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0646-drm-amd-pm-fulfill-the-support-for-SMU13-pp_dpm_dcef.patch (drm-backport-placeholder)
- commit 0ce312d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0645-drm-amd-pm-correct-SMU13-gfx-voltage-related-OD-sett.patch (drm-backport-placeholder)
- commit 4e6c470
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0644-drm-amdgpu-pm-Remove-the-duplicate-dpm-status-check.patch (drm-backport-placeholder)
- commit 89cba8e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0643-drm-amd-pm-Vangogh-Get-average_-from-average-field-o.patch (drm-backport-placeholder)
- commit 16ab0cc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0642-drm-amd-pm-Fixes-incorrect-type-in-amdgpu_hwmon_show.patch (drm-backport-placeholder)
- commit 2905ace
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0641-drm-amd-pm-fix-error-flow-in-sensor-fetching.patch (drm-backport-placeholder)
- commit fa9c2e9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0640-drm-amdgpu-Fix-kcalloc-over-kzalloc-in-gmc_v9_0_init.patch (drm-backport-placeholder)
- commit ff08a05
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0639-drm-amdkfd-Share-the-original-BO-for-GTT-mapping.patch (drm-backport-placeholder)
- commit 184a289
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0638-drm-amd-display-3.2.248.patch (drm-backport-placeholder)
- commit 0c44920
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0637-drm-amd-display-FW-Promotion-Release-0.0.180.0.patch (drm-backport-placeholder)
- commit 4abeea4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0636-drm-amd-display-ensure-FS-is-enabled-before-sending-.patch (drm-backport-placeholder)
- commit d7cc7b1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0635-drm-amd-display-add-check-for-PMFW-hard-min-request-.patch (drm-backport-placeholder)
- commit b2948ed
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0634-drm-amd-display-Save-addr-update-in-scratch-before-f.patch (drm-backport-placeholder)
- commit 3e3c839
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0633-drm-amdgpu-add-gfxhub-11.5.0-support.patch (drm-backport-placeholder)
- commit dfbfdde
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0632-drm-amdgpu-enable-gmc11-for-GC-11.5.0.patch (drm-backport-placeholder)
- commit d186b64
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0631-drm-amdgpu-add-mmhub-3.3.0-support.patch (drm-backport-placeholder)
- commit 7352ae7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0630-drm-amdgpu-add-mmhub-3.3.0-headers.patch (drm-backport-placeholder)
- commit 7a1ecac
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0629-drm-amdgpu-discovery-enable-gfx11-for-GC-11.5.0.patch (drm-backport-placeholder)
- commit 0665893
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0628-drm-amdgpu-discovery-enable-mes-block-for-gc-11.5.0.patch (drm-backport-placeholder)
- commit 78f0047
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0627-drm-amdgpu-add-mes-firmware-support-for-gc_11_5_0.patch (drm-backport-placeholder)
- commit 98141ea
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0626-drm-amdgpu-add-imu-firmware-support-for-gc_11_5_0.patch (drm-backport-placeholder)
- commit 836aefd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0625-drm-amdkfd-add-KFD-support-for-GC-11.5.0.patch (drm-backport-placeholder)
- commit d134b72
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0624-drm-amdgpu-add-golden-setting-for-gc_11_5_0.patch (drm-backport-placeholder)
- commit d031f6b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0623-drm-amdgpu-gfx11-initialize-gfx11.5.0.patch (drm-backport-placeholder)
- commit cbe5a97
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0622-drm-amdgpu-gmc11-initialize-GMC-for-GC-11.5.0-memory.patch (drm-backport-placeholder)
- commit 31da162
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0621-drm-amdgpu-add-gc-headers-for-gc-11.5.0.patch (drm-backport-placeholder)
- commit a25e323
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0620-drm-amdgpu-discovery-add-nbio-7.11.0-support.patch (drm-backport-placeholder)
- commit 0d95262
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0619-drm-amdgpu-add-nbio-7.11-support.patch (drm-backport-placeholder)
- commit 6cbcfb0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0618-drm-amdgpu-add-nbio-7.11-registers.patch (drm-backport-placeholder)
- commit 233f2a2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0617-drm-amdgpu-discovery-enable-soc21-support.patch (drm-backport-placeholder)
- commit 7fa58cc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0616-drm-amdgpu-soc21-add-initial-GC-11.5.0-soc21-support.patch (drm-backport-placeholder)
- commit e85afa4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0615-drm-amdgpu-add-new-AMDGPU_FAMILY-definition.patch (drm-backport-placeholder)
- commit 0727429
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0614-drm-amdgpu-use-6.1.0-register-offset-for-HDP-CLK_CNT.patch (drm-backport-placeholder)
- commit 34a3023
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0612-drm-amd-display-Write-flip-addr-to-scratch-reg-for-s.patch (drm-backport-placeholder)
- commit 0c4f4fb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0611-drm-amd-display-Enable-runtime-register-offset-init-.patch (drm-backport-placeholder)
- commit 5a7fced
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Refactor-edp-power-control.patch (drm-backport-placeholder)
- commit e26b954
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0609-drm-amd-display-PQ-regamma-end-point.patch (drm-backport-placeholder)
- commit 35ff1de
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0608-drm-amd-display-PQ-tail-accuracy.patch (drm-backport-placeholder)
- commit 15152fc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0607-drm-amd-display-Expose-mall-capability.patch (drm-backport-placeholder)
- commit 9f81d33
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0606-drm-amd-display-Fix-useless-else-if-in-display_mode_.patch (drm-backport-placeholder)
- commit d2952de
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0605-drm-radeon-Cleanup-radeon-radeon_fence.c.patch (drm-backport-placeholder)
- commit 12ad026
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0604-drm-amd-display-Fix-unnecessary-conversion-to-bool-i.patch (drm-backport-placeholder)
- commit c7fdad2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0603-drm-amdgpu-Keep-reset-handlers-shared.patch (drm-backport-placeholder)
- commit 9c50b98
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0602-drm-amd-amdgpu-Use-kmemdup-to-simplify-kmalloc-and-m.patch (drm-backport-placeholder)
- commit 45276a0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0601-accel-habanalabs-change-Greco-to-Gaudi2.patch (drm-backport-placeholder)
- commit 20c594c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0600-accel-habanalabs-add-tsc-clock-sampling-to-clock-syn.patch (drm-backport-placeholder)
- commit 1448c00
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0599-drm-i915-More-use-of-GT-specific-print-helpers.patch (drm-backport-placeholder)
- commit 69ca090
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0598-drm-i915-gt-More-use-of-GT-specific-print-helpers.patch (drm-backport-placeholder)
- commit c488014
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0597-drm-i915-guc-Enable-WA-14018913170.patch (drm-backport-placeholder)
- commit 892762d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0596-drm-i915-guc-Annotate-struct-ct_incoming_msg-with-__.patch (drm-backport-placeholder)
- commit e3127a7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0595-drm-i915-guc-Update-recommended-version-to-70.12.1-f.patch (drm-backport-placeholder)
- commit 54cfa92
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0594-drm-i915-guc-Suppress-ignoring-reset-notification-me.patch (drm-backport-placeholder)
- commit 8157f9f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0593-drm-i915-Clarify-type-evolution-of-uabi_node-uabi_en.patch (drm-backport-placeholder)
- commit 1afac83
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0592-drm-i915-Enable-GGTT-updates-with-binder-in-MTL.patch (drm-backport-placeholder)
- commit d0dadb8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0591-drm-i915-Toggle-binder-context-ready-status.patch (drm-backport-placeholder)
- commit 9764239
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0590-drm-i915-Implement-GGTT-update-method-with-MI_UPDATE.patch (drm-backport-placeholder)
- commit 2d821d4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0589-drm-i915-Parameterize-binder-context-creation.patch (drm-backport-placeholder)
- commit 04c0676
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0588-drm-i915-Implement-for_each_sgt_daddr_next.patch (drm-backport-placeholder)
- commit 82a1074
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0587-drm-i915-Create-a-kernel-context-for-GGTT-updates.patch (drm-backport-placeholder)
- commit 8450355
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0586-drm-i915-Lift-runtime-pm-acquire-callbacks-out-of-in.patch (drm-backport-placeholder)
- commit 6bf63fd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0585-drm-i915-gem-Make-i915_gem_shrinker-multi-gt-aware.patch (drm-backport-placeholder)
- commit 8450b44
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0584-drm-i915-mtl-Skip-MCR-ops-for-ring-fault-register.patch (drm-backport-placeholder)
- commit 3dad69c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0583-drm-i915-Clean-steer-semaphore-on-resume.patch (drm-backport-placeholder)
- commit 7e02bb1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0582-drm-i915-Introduce-the-intel_gt_resume_early.patch (drm-backport-placeholder)
- commit 04bd1e8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0581-drm-i915-Introduce-intel_gt_mcr_lock_sanitize.patch (drm-backport-placeholder)
- commit b526610
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0580-drm-i915-dsi-Add-some-debug-logging-to-mipi_exec_i2c.patch (drm-backport-placeholder)
- commit 146c1a5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0579-drm-i915-vlv_dsi-Add-DMI-quirk-for-backlight-control.patch (drm-backport-placeholder)
- commit 3176eeb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0578-drm-i915-vlv_dsi-Add-DMI-quirk-for-wrong-I2C-bus-and.patch (drm-backport-placeholder)
- commit 9f203c0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0577-drm-i915-vlv_dsi-Add-DMI-quirk-for-wrong-panel-model.patch (drm-backport-placeholder)
- commit b3b5971
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0576-drm-i915-Remove-the-module-parameter-fastboot.patch (drm-backport-placeholder)
- commit 0670db8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0575-drm-i915-hdcp-Move-common-message-filling-function-t.patch (drm-backport-placeholder)
- commit a29c310
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0574-drm-i915-hdcp-Move-checks-for-gsc-health-status.patch (drm-backport-placeholder)
- commit bb6d32f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0573-drm-i915-display-Use-correct-method-to-free-crtc_sta.patch (drm-backport-placeholder)
- commit 4927343
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0572-drm-i915-display-Use-intel_crtc_destroy_state-instea.patch (drm-backport-placeholder)
- commit 94d9127
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0571-drm-i915-enable-W-1-warnings-by-default.patch (drm-backport-placeholder)
- commit 49d9a11
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0570-drm-i915-drop-Wall-and-related-disables-from-cflags-.patch (drm-backport-placeholder)
- commit de06077
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0569-drm-i915-gvt-move-structs-intel_gvt_irq_info-and-int.patch (drm-backport-placeholder)
- commit edb2501
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0568-drm-i915-gvt-move-struct-engine_mmio-to-mmio_context.patch (drm-backport-placeholder)
- commit 32eadca
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0567-drm-i915-gvt-don-t-include-gvt.h-from-intel_gvt_mmio.patch (drm-backport-placeholder)
- commit 6127278
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0566-drm-i915-gvt-remove-unused-to_gvt-and-reduce-include.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit c4119b5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0565-drm-i915-xe2lpd-update-the-scaler-feature-capability.patch (drm-backport-placeholder)
- commit a3968b6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0564-drm-i915-xe2lpd-update-the-dsc-feature-capability.patch (drm-backport-placeholder)
- commit 674128d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0563-drm-i915-xe2lpd-display-capability-register-definiti.patch (drm-backport-placeholder)
- commit 6bda643
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0562-drm-i915-Add-wrapper-for-getting-display-step.patch (drm-backport-placeholder)
- commit c327d0d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0561-drm-i915-display-Free-crtc_state-in-verify_crtc_stat.patch (drm-backport-placeholder)
- commit 54e55cf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0560-drm-i915-Fix-VLV-color-state-readout.patch (drm-backport-placeholder)
- commit 48c499e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0559-drm-i915-uapi-fix-doc-typos.patch (drm-backport-placeholder)
- commit da340e8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0558-drm-i915-ddi-Remove-redundant-intel_connector-NULL-c.patch (drm-backport-placeholder)
- commit 4012e39
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0557-drm-i915-s-dev_priv-i915-in-the-state-checker.patch (drm-backport-placeholder)
- commit 779bb0c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0556-drm-i915-s-pipe_config-crtc_state-in-the-state-check.patch (drm-backport-placeholder)
- commit 31c78bc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0555-drm-i915-Simplify-the-state-checker-calling-convetio.patch (drm-backport-placeholder)
- commit e26795c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0554-drm-i915-Constify-remainder-of-the-state-checker.patch (drm-backport-placeholder)
- commit 19ad54d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0553-drm-i915-Simplify-snps-c10x-DPLL-state-checker-calli.patch (drm-backport-placeholder)
- commit 3b9155d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0552-drm-i915-Constify-the-snps-c10x-PLL-state-checkers.patch (drm-backport-placeholder)
- commit 6a67ce5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0551-drm-i915-Simplify-watermark-state-checker-calling-co.patch (drm-backport-placeholder)
- commit d01d80d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0550-drm-i915-Constify-watermark-state-checker.patch (drm-backport-placeholder)
- commit a924473
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0549-drm-i915-Simplify-DPLL-state-checker-calling-convent.patch (drm-backport-placeholder)
- commit c6b2f41
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0548-drm-i915-Constify-the-crtc-states-in-the-DPLL-checke.patch (drm-backport-placeholder)
- commit 32c1aaa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0547-drm-i915-Stop-clobbering-old-crtc-state-during-state.patch (drm-backport-placeholder)
- commit 333e583
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0546-drm-i915-psr-Unify-PSR-pre-post-plane-update-hooks.patch (drm-backport-placeholder)
- commit 205582c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0545-drm-i915-fbc-Remove-pointless-stride-is-multiple-of-.patch (drm-backport-placeholder)
- commit e9d7e3b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0544-drm-i915-fbc-Split-plane-pixel-format-checks-per-pla.patch (drm-backport-placeholder)
- commit 76ae3ff
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0543-drm-i915-fbc-Split-plane-rotation-checks-per-platfor.patch (drm-backport-placeholder)
- commit 4bbfcd0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0542-drm-i915-fbc-Split-plane-tiling-checks-per-platform.patch (drm-backport-placeholder)
- commit fb0800c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0541-drm-i915-fbc-Split-plane-stride-checks-per-platform.patch (drm-backport-placeholder)
- commit c6cf442
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0540-drm-i915-fbc-Remove-ancient-16k-plane-stride-limit.patch (drm-backport-placeholder)
- commit fb12771
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0539-drm-i915-pmu-Use-local64_try_cmpxchg-in-i915_pmu_eve.patch (drm-backport-placeholder)
- commit a25093b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0538-drm-i915-display-Created-exclusive-version-of-vga-de.patch (drm-backport-placeholder)
- commit e536c55
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0537-drm-i915-dp_mst-Make-sure-pbn_div-is-up-to-date-afte.patch (drm-backport-placeholder)
- commit 3f85e68
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0536-drm-i915-display-lspcon-Increase-LSPCON-mode-settle-.patch (drm-backport-placeholder)
- commit ef92e02
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0535-drm-i915-gt-remove-i915-gt0-in-favour-of-i915-gt-0.patch (drm-backport-placeholder)
- commit 78b05f3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0534-drm-i915-allocate-i915-gt0-dynamically.patch (drm-backport-placeholder)
- commit d22c768
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0533-drm-i915-mocs-use-to_gt-instead-of-direct-i915-gt.patch (drm-backport-placeholder)
- commit 07184a2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0532-drm-i915-s-dev_priv-i915-in-the-shared_dpll-code.patch (drm-backport-placeholder)
- commit 6f2be0c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0531-drm-i915-Introduce-for_each_shared_dpll.patch (drm-backport-placeholder)
- commit c049db7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0530-drm-i915-Decouple-I915_NUM_PLLS-from-PLL-IDs.patch (drm-backport-placeholder)
- commit 9c2ac47
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0529-drm-i915-Stop-requiring-PLL-index-PLL-ID.patch (drm-backport-placeholder)
- commit 2a9284f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0528-drm-i915-separate-subplatform-init-and-runtime-featu.patch (drm-backport-placeholder)
- commit 7b73bf6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0527-drm-i915-separate-display-runtime-info-init.patch (drm-backport-placeholder)
- commit b540cd3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0526-drm-i915-move-display-info-related-macros-to-display.patch (drm-backport-placeholder)
- commit b919aa9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0525-drm-i915-convert-INTEL_DISPLAY_ENABLED-into-a-functi.patch (drm-backport-placeholder)
- commit c28a651
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0524-drm-i915-lnl-update-the-supported-plane-formats-with.patch (drm-backport-placeholder)
- commit 92e8e53
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0523-drm-i915-lnl-possibility-to-enable-FBC-on-first-thre.patch (drm-backport-placeholder)
- commit 2f7942c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Add-missing-GSCCS-documentation.patch (drm-backport-placeholder)
- commit ead43ee
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Add-missing-CCS-documentation.patch (drm-backport-placeholder)
- commit 245c5ff
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0520-drm-i915-Abstract-display-info-away-during-probe.patch (drm-backport-placeholder)
- commit 74be68a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0519-drm-i915-display-Include-i915_active-header-in-front.patch (drm-backport-placeholder)
- commit 3c0f806
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0518-drm-i915-display-add-I915-conditional-build-to-vlv_d.patch (drm-backport-placeholder)
- commit 15f20a4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0517-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit 158739b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0516-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit 1a35f90
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0515-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit 894ea78
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0514-drm-i915-display-add-I915-conditional-build-to-g4x_h.patch (drm-backport-placeholder)
- commit e7d3c42
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0513-drm-i915-display-add-I915-conditional-build-to-i9xx_.patch (drm-backport-placeholder)
- commit a4df461
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0512-drm-i915-display-add-I915-conditional-build-to-vlv_d.patch (drm-backport-placeholder)
- commit cea3710
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0511-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit 35ee5b9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0510-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit 87134ce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0509-drm-i915-display-add-I915-conditional-build-to-g4x_d.patch (drm-backport-placeholder)
- commit c918644
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0508-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit 86258f9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0507-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit 96f41df
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0506-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit f453c61
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0505-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit 20ccaca
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0504-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit 06949bb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0503-drm-i915-display-add-I915-conditional-build-to-i9xx_.patch (drm-backport-placeholder)
- commit f950eae
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0502-drm-i915-display-add-I915-conditional-build-to-hsw_i.patch (drm-backport-placeholder)
- commit ee09a06
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0501-drm-i915-display-add-I915-conditional-build-to-intel.patch (drm-backport-placeholder)
- commit 8e22420
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0500-drm-i915-define-I915-during-i915-driver-build.patch (drm-backport-placeholder)
- commit 023efa5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0499-drm-simpledrm-Fix-power-domain-device-link-validity-.patch (drm-backport-placeholder)
- commit 268b3b3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0498-drm-Replace-drm_framebuffer-plane-size-functions-wit.patch (drm-backport-placeholder)
- commit a21d931
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0497-drm-Remove-plane-hsub-vsub-alignment-requirement-for.patch (drm-backport-placeholder)
- commit 87f5925
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0496-drm-tegra-gem-Do-not-return-NULL-in-tegra_bo_mmap.patch (drm-backport-placeholder)
- commit c49a532
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0495-drm-tegra-Zero-initialize-iosys_map.patch (drm-backport-placeholder)
- commit 411d932
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/gpu-host1x-Correct-allocated-size-for-contexts.patch (drm-backport-placeholder)
- commit e587fdd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0493-gpu-host1x-Syncpoint-interrupt-sharding.patch (drm-backport-placeholder)
- commit c546a96
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0492-gpu-host1x-Enable-system-suspend-callbacks.patch (drm-backport-placeholder)
- commit 1f614da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0491-gpu-host1x-Stop-CDMA-before-suspending.patch (drm-backport-placeholder)
- commit 70f8e46
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0490-gpu-host1x-Add-locking-in-channel-allocation.patch (drm-backport-placeholder)
- commit f7ef107
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0489-drm-tegra-hub-Increase-buffer-size-to-ensure-all-pos.patch (drm-backport-placeholder)
- commit 8d3fe41
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0488-drm-tegra-Remove-two-unused-function-declarations.patch (drm-backport-placeholder)
- commit 286c2bc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0487-drm-tegra-Remove-surplus-else-after-return.patch (drm-backport-placeholder)
- commit f9deea7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0486-drm-bridge_connector-implement-oob_hotplug_event.patch (drm-backport-placeholder)
- commit d207ee6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0485-drm-bridge_connector-stop-filtering-events-in-drm_br.patch (drm-backport-placeholder)
- commit 2cf61b9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0483-drm-i915-Update-DRIVER_DATE-to-20230929.patch (drm-backport-placeholder)
- commit 85a2101
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0482-drm-i915-Warn-on-if-set-frontbuffer-return-value-is-.patch (drm-backport-placeholder)
- commit 4071d59
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0481-drm-i915-fdi-Recompute-state-for-affected-CRTCs-on-F.patch (drm-backport-placeholder)
- commit 5821664
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0480-drm-i915-fdi-Improve-FDI-BW-sharing-between-pipe-B-a.patch (drm-backport-placeholder)
- commit 741c621
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0479-drm-i915-Add-helpers-for-BW-management-on-shared-dis.patch (drm-backport-placeholder)
- commit 430e235
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0478-drm-i915-Factor-out-a-helper-to-check-compute-all-th.patch (drm-backport-placeholder)
- commit 334fdd3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0477-drm-i915-Rename-intel_modeset_all_pipes-to-intel_mod.patch (drm-backport-placeholder)
- commit 021f7b4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0476-drm-i915-Add-helper-to-modeset-a-set-of-pipes.patch (drm-backport-placeholder)
- commit db682fa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0475-drm-i915-dp-Limit-the-output-link-bpp-in-DSC-mode.patch (drm-backport-placeholder)
- commit 4aea637
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0474-drm-i915-dp-Update-the-link-bpp-limits-for-DSC-mode.patch (drm-backport-placeholder)
- commit b8cc349
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0473-drm-i915-dp-Skip-computing-a-non-DSC-link-config-if-.patch (drm-backport-placeholder)
- commit ac50d96
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0472-drm-i915-dp-Track-the-pipe-and-link-bpp-limits-separ.patch (drm-backport-placeholder)
- commit 56c9fe1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0471-drm-i915-dp-Factor-out-helpers-to-compute-the-link-l.patch (drm-backport-placeholder)
- commit a311fb4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0470-drm-i915-dsb-Use-DEwake-to-combat-PkgC-latency.patch (drm-backport-placeholder)
- commit 1c086e9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0469-drm-i915-Introduce-intel_crtc_scanline_to_hw.patch (drm-backport-placeholder)
- commit deb9ecc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0468-drm-i915-Introduce-skl_watermark_max_latency.patch (drm-backport-placeholder)
- commit 017e90b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0467-drm-i915-dsb-Evade-transcoder-undelayed-vblank-when-.patch (drm-backport-placeholder)
- commit ce94e1e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0466-drm-i915-dsb-Use-non-posted-register-writes-for-lega.patch (drm-backport-placeholder)
- commit 036dab9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0465-drm-i915-dsb-Load-LUTs-using-the-DSB-during-vblank.patch (drm-backport-placeholder)
- commit f853bbd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0464-drm-i915-dsb-Don-t-use-DSB-to-load-the-LUTs-during-f.patch (drm-backport-placeholder)
- commit 6a907a7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0463-drm-i915-dsb-Add-support-for-non-posted-DSB-register.patch (drm-backport-placeholder)
- commit 1e257a6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0462-drm-i915-dsb-Introduce-intel_dsb_reg_write_masked.patch (drm-backport-placeholder)
- commit 88db2ba
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0461-drm-i915-dsb-Introduce-intel_dsb_noop.patch (drm-backport-placeholder)
- commit 68eb3ff
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0460-drm-i915-dsb-Define-the-contents-of-some-intstructio.patch (drm-backport-placeholder)
- commit bfa66c6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0459-drm-i915-dsb-Define-more-DSB-bits.patch (drm-backport-placeholder)
- commit d1d0d58
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0458-drm-i915-dsb-Use-non-locked-register-access.patch (drm-backport-placeholder)
- commit bebc84d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0457-drm-i915-cx0-prefer-forward-declarations-over-includ.patch (drm-backport-placeholder)
- commit 8ce7b7e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0456-drm-i915-dp-refactor-aux_ch_name.patch (drm-backport-placeholder)
- commit 4b28adb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0455-drm-i915-irq-Clear-GFX_MSTR_IRQ-as-part-of-IRQ-reset.patch (drm-backport-placeholder)
- commit 0d34e3c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0454-drm-i915-display-Print-display-info-inside-driver-di.patch (drm-backport-placeholder)
- commit 6da3162
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0453-drm-i915-bios-Fixup-h-vsync_end-instead-of-h-vtotal.patch (drm-backport-placeholder)
- commit 4d39642
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0452-drm-i915-lnl-Start-using-CDCLK-through-PLL.patch (drm-backport-placeholder)
- commit 872d0f8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0451-drm-i915-xe2lpd-Add-DC-state-support.patch (drm-backport-placeholder)
- commit ac8cc96
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0450-drm-i915-xe2lpd-Add-display-power-well.patch (drm-backport-placeholder)
- commit 3034380
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0449-drm-i915-lnl-Add-CDCLK-table.patch (drm-backport-placeholder)
- commit fe8c342
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0448-drm-i915-lnl-Add-gmbus-ddc-support.patch (drm-backport-placeholder)
- commit 549d6d0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0447-drm-i915-xe2lpd-Extend-Wa_15010685871.patch (drm-backport-placeholder)
- commit c7b5d59
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0446-drm-i915-xe2lpd-Add-support-for-HPD.patch (drm-backport-placeholder)
- commit f31a92e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0445-drm-i915-xe2lpd-Enable-odd-size-and-panning-for-plan.patch (drm-backport-placeholder)
- commit 4f196b2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0444-drm-i915-xe2lpd-Read-pin-assignment-from-IOM.patch (drm-backport-placeholder)
- commit 6d18710
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0443-drm-i915-xe2lpd-Handle-port-AUX-interrupts.patch (drm-backport-placeholder)
- commit 5405f4d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0442-drm-i915-xe2lpd-Re-order-DP-AUX-regs.patch (drm-backport-placeholder)
- commit f38b453
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0441-drm-i915-display-Use-_PICK_EVEN_2RANGES-in-DP-AUX-re.patch (drm-backport-placeholder)
- commit 35be3a7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0440-drm-i915-display-Fix-style-and-conventions-for-DP-AU.patch (drm-backport-placeholder)
- commit edc8fb5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0439-drm-i915-xe2lpd-Register-DE_RRMR-has-been-removed.patch (drm-backport-placeholder)
- commit 6f3784c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0438-drm-i915-xe2lpd-Don-t-try-to-program-PLANE_AUX_DIST.patch (drm-backport-placeholder)
- commit 91017fe
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0437-drm-i915-xe2lpd-Treat-cursor-plane-as-regular-plane-.patch (drm-backport-placeholder)
- commit 3be7827
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0436-drm-i915-xe2lpd-Add-fake-PCH.patch (drm-backport-placeholder)
- commit 1297b20
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0435-drm-i915-Re-order-if-else-ladder-in-intel_detect_pch.patch (drm-backport-placeholder)
- commit 6091379
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0434-drm-i915-display-Remove-FBC-capability-from-fused-of.patch (drm-backport-placeholder)
- commit 1d243e2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0433-drm-i915-xe2lpd-FBC-is-now-supported-on-all-pipes.patch (drm-backport-placeholder)
- commit 541c55a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0432-drm-i915-lnl-Add-display-definitions.patch (drm-backport-placeholder)
- commit 992f730
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0431-drm-i915-xelpdp-Add-XE_LPDP_FEATURES.patch (drm-backport-placeholder)
- commit 77c1516
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0430-Revert-drm-i915-mst-Populate-connector-ddc.patch (drm-backport-placeholder)
- commit 24fca24
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0429-drm-i915-add-a-note-about-fec_enable-with-128b-132b.patch (drm-backport-placeholder)
- commit 57bbb78
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0428-drm-i915-Implement-transcoder-LRR-for-TGL.patch (drm-backport-placeholder)
- commit 5fe612f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0427-drm-i915-Assert-that-VRR-is-off-during-vblank-evasio.patch (drm-backport-placeholder)
- commit fa700d5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0426-drm-i915-Update-VRR-parameters-in-fastset.patch (drm-backport-placeholder)
- commit 8afcf94
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0425-drm-i915-Disable-VRR-during-seamless-M-N-changes.patch (drm-backport-placeholder)
- commit 7f53ef9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0424-drm-i915-Validate-that-the-timings-are-within-the-VR.patch (drm-backport-placeholder)
- commit b2940fe
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0423-drm-i915-Relocate-is_in_vrr_range.patch (drm-backport-placeholder)
- commit d36f941
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0422-drm-i915-Optimize-out-redundant-M-N-updates.patch (drm-backport-placeholder)
- commit 435b9d0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0421-drm-i915-Adjust-seamless_m_n-flag-behaviour.patch (drm-backport-placeholder)
- commit 3647489
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0420-drm-i915-Enable-VRR-later-during-fastsets.patch (drm-backport-placeholder)
- commit 7aaed24
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0419-drm-i915-Extract-intel_crtc_vblank_evade_scanlines.patch (drm-backport-placeholder)
- commit 0f7574c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0418-drm-i915-Change-intel_pipe_update_-start-end-calling.patch (drm-backport-placeholder)
- commit 5f3cea9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0417-drm-i915-Move-psr-unlock-out-from-the-pipe-update-cr.patch (drm-backport-placeholder)
- commit 6bc15cd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0416-drm-i915-dsi-let-HW-maintain-CLK_POST.patch (drm-backport-placeholder)
- commit 7626644
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0415-drm-i915-cx0-Add-step-for-programming-msgbus-timer.patch (drm-backport-placeholder)
- commit a8d5437
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0414-drm-i915-dp_mst-Tune-down-error-message-during-paylo.patch (drm-backport-placeholder)
- commit 204cae9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0413-drm-i915-Remove-runtime-suspended-boolean-from-intel.patch (drm-backport-placeholder)
- commit 85200f2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0412-drm-i915-move-intel_display_device_probe-one-level-h.patch (drm-backport-placeholder)
- commit f3807d4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0411-drm-i915-display-call-gmdid-display-probe-at-a-highe.patch (drm-backport-placeholder)
- commit 3d8537f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0410-drm-i915-move-more-of-the-display-probe-to-display-c.patch (drm-backport-placeholder)
- commit 4594291
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0409-drm-i915-dpt-replace-GEM_BUG_ON-with-drm_WARN_ON.patch (drm-backport-placeholder)
- commit a9db01f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0408-drm-i915-fb-replace-GEM_WARN_ON-with-drm_WARN_ON.patch (drm-backport-placeholder)
- commit de64f17
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0407-drm-i915-fbc-replace-GEM_BUG_ON-to-drm_WARN_ON.patch (drm-backport-placeholder)
- commit ec8883c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0406-drm-i915-sdvo-Constify-mapping-structs.patch (drm-backport-placeholder)
- commit 9645317
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0405-drm-i915-hdmi-Remove-old-i2c-symlink.patch (drm-backport-placeholder)
- commit 901d850
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0404-drm-i915-hdmi-Nuke-hdmi-ddc_bus.patch (drm-backport-placeholder)
- commit ed1b569
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0403-drm-i915-hdmi-Use-connector-ddc-everwhere.patch (drm-backport-placeholder)
- commit 3ad9d65
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0402-drm-i915-mst-Populate-connector-ddc.patch (drm-backport-placeholder)
- commit 8ca10d4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0401-drm-i915-dp-Populate-connector-ddc.patch (drm-backport-placeholder)
- commit 989b6f7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0400-drm-i915-dvo-Populate-connector-ddc.patch (drm-backport-placeholder)
- commit 461b856
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0399-drm-i915-crt-Populate-connector-ddc.patch (drm-backport-placeholder)
- commit 7f572b4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0398-drm-i915-lvds-Populate-connector-ddc.patch (drm-backport-placeholder)
- commit 4aa0ea8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0397-drm-i915-Call-the-DDC-bus-i2c-adapter-ddc.patch (drm-backport-placeholder)
- commit 52c8818
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0396-drm-sysfs-Register-ddc-symlink-later.patch (drm-backport-placeholder)
- commit 8ffca88
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0395-drm-Reorder-drm_sysfs_connector_remove-vs.-drm_debug.patch (drm-backport-placeholder)
- commit 3e24f4e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0394-drm-i915-dsc-Fix-pic_width-readout.patch (drm-backport-placeholder)
- commit 7f23b93
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Introduce-crtc_state-enhanced_framing.patch (drm-backport-placeholder)
- commit 0886fa3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0392-drm-i915-Reduce-combo-PHY-log-spam.patch (drm-backport-placeholder)
- commit e9221f7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0391-drm-i915-Stop-spamming-the-logs-with-PLL-state.patch (drm-backport-placeholder)
- commit 6c046a5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0390-drm-i915-Split-some-long-lines-in-hsw_fdi_link_train.patch (drm-backport-placeholder)
- commit 3d9e013
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Fix-FEC-state-dump.patch (drm-backport-placeholder)
- commit 046fcca
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0388-drm-i915-Fix-FEC-pipe-A-vs.-DDI-A-mixup.patch (drm-backport-placeholder)
- commit 34c6758
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0387-drm-i915-mst-Read-out-FEC-state.patch (drm-backport-placeholder)
- commit d8a53cd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0386-drm-i915-gt-rename-DBG-to-GTT_TRACE.patch (drm-backport-placeholder)
- commit 44b08f4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0385-drm-i915-dsc-use-REG_BIT-REG_GENMASK-and-friends-for.patch (drm-backport-placeholder)
- commit 0c6a99c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0384-drm-i915-dsc-add-the-PPS-number-to-the-register-cont.patch (drm-backport-placeholder)
- commit fb048ef
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0383-drm-i915-dsc-clean-up-pps-comments.patch (drm-backport-placeholder)
- commit b8e1589
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0382-drm-i915-dsc-drop-redundant-0-assignments.patch (drm-backport-placeholder)
- commit 5a57f74
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0381-drm-i915-dsc-rename-pps-write-to-intel_dsc_pps_write.patch (drm-backport-placeholder)
- commit 5bebf7c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0380-drm-i915-dsc-have-intel_dsc_pps_read-return-the-valu.patch (drm-backport-placeholder)
- commit 836c1fb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0379-drm-i915-dsc-have-intel_dsc_pps_read_and_verify-retu.patch (drm-backport-placeholder)
- commit 2111f74
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0378-drm-i915-dsc-improve-clarity-of-the-pps-reg-read-wri.patch (drm-backport-placeholder)
- commit 94712b2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0377-drm-i915-display-Apply-workarounds-during-display-in.patch (drm-backport-placeholder)
- commit 170f2a7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0376-drm-i915-display-Extract-display-workarounds-from-cl.patch (drm-backport-placeholder)
- commit 1a9b7b2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0375-drm-i915-adlp-Stop-calling-gen12lp_init_clock_gating.patch (drm-backport-placeholder)
- commit 0beb54d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0374-drm-i915-Stop-forcing-clock-gating-init-for-future-p.patch (drm-backport-placeholder)
- commit a062d80
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0373-drm-i915-dsb-Don-t-use-indexed-writes-when-byte-enab.patch (drm-backport-placeholder)
- commit 2231bc9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0372-drm-i915-dsb-Avoid-corrupting-the-first-register-wri.patch (drm-backport-placeholder)
- commit 301c053
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0371-drm-i915-dsb-Dump-the-DSB-command-buffer-when-DSB-fa.patch (drm-backport-placeholder)
- commit ba51bdd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0370-drm-i915-Constify-LUT-entries-in-checker.patch (drm-backport-placeholder)
- commit b493d8a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0369-drm-i915-cx0-Check-and-increase-msgbus-timeout-thres.patch (drm-backport-placeholder)
- commit 12b3835
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0368-drm-i915-add-trailing-newlines-to-msgs.patch (drm-backport-placeholder)
- commit a1b2905
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0367-drm-i915-psr-Add-psr-sink-error-status-into-sink-sta.patch (drm-backport-placeholder)
- commit b365dc2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0366-drm-i915-tc-remove-fia-from-intel_tc_port_fia_max_la.patch (drm-backport-placeholder)
- commit 74094e8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0365-drm-i915-tc-move-legacy-code-out-of-the-main-_max_la.patch (drm-backport-placeholder)
- commit f45ca33
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0364-drm-i915-tc-make-intel_tc_port_get_lane_mask-static.patch (drm-backport-placeholder)
- commit 132ee57
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0363-drm-i915-tc-rename-mtl_tc_port_get_pin_assignment_ma.patch (drm-backport-placeholder)
- commit 8dcbb4a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0362-drm-i915-display-Compare-the-readout-dsc-pps-params.patch (drm-backport-placeholder)
- commit 2b30021
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0361-drm-i915-vdsc-Fill-the-intel_dsc_get_pps_config-func.patch (drm-backport-placeholder)
- commit dd5f189
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0360-drm-i915-vdsc-Remove-unused-dsc-registers.patch (drm-backport-placeholder)
- commit b0f31c3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0359-drm-i915-vdsc-Add-function-to-write-in-PPS-register.patch (drm-backport-placeholder)
- commit 5abb790
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0358-drm-i915-vdsc-Add-function-to-read-any-PPS-register.patch (drm-backport-placeholder)
- commit 00e13fb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0357-drm-i915-vdsc-Add-func-to-get-no.-of-vdsc-instances-.patch (drm-backport-placeholder)
- commit 67fcdec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0356-drm-i915-vdsc-Add-a-check-for-dsc-split-cases.patch (drm-backport-placeholder)
- commit 3b3367b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0355-drm-i915-vdsc-Refactor-dsc-register-field-macro.patch (drm-backport-placeholder)
- commit da7826d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0354-drm-i915-Handle-dma-fences-in-dirtyfb-callback.patch (drm-backport-placeholder)
- commit f5493db
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0353-drm-i915-Add-new-frontbuffer-tracking-interface-to-q.patch (drm-backport-placeholder)
- commit eb7da7e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0352-drm-i915-psr-Clear-frontbuffer-busy-bits-on-flip.patch (drm-backport-placeholder)
- commit 3e24e9c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0351-drm-i915-fbc-Clear-frontbuffer-busy-bits-on-flip.patch (drm-backport-placeholder)
- commit acab271
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0350-drm-i915-cec-switch-to-setting-physical-address-dire.patch (drm-backport-placeholder)
- commit fd37be7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0349-drm-cec-add-drm_dp_cec_attach-as-the-non-edid-versio.patch (drm-backport-placeholder)
- commit 6fd7b5d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0348-drm-edid-parse-source-physical-address.patch (drm-backport-placeholder)
- commit 62d75a9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0347-drm-i915-display-use-drm_edid_is_digital.patch (drm-backport-placeholder)
- commit bb46e44
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0346-drm-edid-add-drm_edid_is_digital.patch (drm-backport-placeholder)
- commit aec21a4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0345-drm-i915-hdcp-Use-correct-aux-for-capability-check-s.patch (drm-backport-placeholder)
- commit f369159
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0344-drm-i915-hdcp-Use-intel_connector-as-argument-for-hd.patch (drm-backport-placeholder)
- commit cd8ddb8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0343-drm-i915-add-minimal-i915_gem_object_frontbuffer.h.patch (drm-backport-placeholder)
- commit e121efa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0342-drm-i915-mtl-Add-TC-port-lockdep-assert-to-AUX-power.patch (drm-backport-placeholder)
- commit 528c3ae
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0341-drm-i915-dp-Drop-redundant-AUX-power-get-put-in-inte.patch (drm-backport-placeholder)
- commit 4299295
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0340-drm-i915-dg2-Add-support-for-new-DG2-G12-revid-0x1.patch (drm-backport-placeholder)
- commit c9cd13e
* Wed Oct  2 2024 dwagner@suse.de
- nvme-pci: qdepth 1 quirk (git-fixes).
- commit ee2b909
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0339-drivers-drm-i915-Honor-limits-max_bpp-while-computin.patch (drm-backport-placeholder)
- commit c7935ff
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0338-drm-display-dp-Assume-8-bpc-support-when-DSC-is-supp.patch (drm-backport-placeholder)
- commit ed2393d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0337-drm-i915-psr-Apply-Wa_14015648006-for-all-display-14.patch (drm-backport-placeholder)
- commit 80db97d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0336-drm-i915-sdvo-Print-out-the-i2c-pin-and-slave-addres.patch (drm-backport-placeholder)
- commit 02be643
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0335-drm-i915-sdvo-Rework-DDC-bus-handling.patch (drm-backport-placeholder)
- commit 4c85555
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0334-drm-i915-sdvo-Get-rid-of-the-per-connector-i2c-symli.patch (drm-backport-placeholder)
- commit 8e5854f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0333-drm-i915-sdvo-Nuke-the-duplicate-sdvo-port.patch (drm-backport-placeholder)
- commit 6bbe353
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0332-drm-i915-sdvo-Initialize-the-encoder-earlier.patch (drm-backport-placeholder)
- commit edc812b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0331-drm-i915-sdvo-Nuke-attached_output-tracking.patch (drm-backport-placeholder)
- commit 07644ad
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0330-drm-i915-hdcp-Adjust-timeout-for-read-in-DPMST-Scena.patch (drm-backport-placeholder)
- commit 8145c1e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0329-drm-i915-hdcp-Send-the-correct-aux-for-DPMST-HDCP-sc.patch (drm-backport-placeholder)
- commit 13ef37d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0328-drm-i915-hdcp-Propagate-aux-info-in-DP-HDCP-function.patch (drm-backport-placeholder)
- commit 8712f73
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0327-drm-i915-hdcp-Use-intel_connector-argument-in-intel_.patch (drm-backport-placeholder)
- commit a853ef1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0326-drm-i915-color-move-pre-SKL-gamma-and-CSC-enable-rea.patch (drm-backport-placeholder)
- commit da0f867
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0325-drm-i915-color-move-SKL-gamma-and-CSC-enable-read-to.patch (drm-backport-placeholder)
- commit af7c795
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0324-drm-i915-move-ILK-CSC-mode-read-to-intel_color.patch (drm-backport-placeholder)
- commit aaf180a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0323-drm-i915-move-HSW-gamma-mode-read-to-intel_color.patch (drm-backport-placeholder)
- commit cdac7db
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0322-drm-i915-color-move-CHV-CGM-pipe-mode-read-to-intel_.patch (drm-backport-placeholder)
- commit bdb9ab1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0321-drm-i915-regs-split-out-intel_color_regs.h.patch (drm-backport-placeholder)
- commit 856a1bc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0320-drm-i915-display-configure-SDP-split-for-DP-MST.patch (drm-backport-placeholder)
- commit 2a09843
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0319-drm-i915-display-update-intel_dp_has_audio-to-suppor.patch (drm-backport-placeholder)
- commit 0440756
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0318-drm-i915-vma-constify-unbind_fence_ops.patch (drm-backport-placeholder)
- commit a5a82dd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0317-drm-i915-rpl-Update-pci-ids-for-RPL-P-U.patch (drm-backport-placeholder)
- commit 6275468
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0316-drm-i915-sdvo-Fail-gracefully-if-the-TV-dotclock-is-.patch (drm-backport-placeholder)
- commit 2eb507b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0315-drm-i915-sdvo-Pick-the-TV-dotclock-from-adjusted_mod.patch (drm-backport-placeholder)
- commit 2932dd6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0314-drm-i915-Fully-populate-crtc_state-dpll.patch (drm-backport-placeholder)
- commit fe3b0e0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0313-drm-i915-Don-t-warn-about-zero-N-P-in-_calc_dpll_par.patch (drm-backport-placeholder)
- commit ecf6968
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0312-drm-i915-sdvo-s-sdvo_inputs_mask-sdvo_num_inputs.patch (drm-backport-placeholder)
- commit a66f948
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0311-drm-i915-sdvo-Protect-macro-args.patch (drm-backport-placeholder)
- commit 817c1d2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0310-drm-i915-sdvo-Issue-SetTargetOutput-prior-to-GetAtta.patch (drm-backport-placeholder)
- commit 18c00d7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0309-drm-i915-display-add-lock-while-printing-frontbuffer.patch (drm-backport-placeholder)
- commit 34fc41a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0308-drm-i915-display-combine-DP-audio-compute-config-ste.patch (drm-backport-placeholder)
- commit 5f82879
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0307-drm-i915-display-remove-redundant-parameter-from-sdp.patch (drm-backport-placeholder)
- commit 8d6002e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-display-Eliminate-IS_METEORLAKE-checks.patch (drm-backport-placeholder)
- commit 8d17045
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Eliminate-IS_MTL_DISPLAY_STEP.patch (drm-backport-placeholder)
- commit ba27276
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0304-drm-i915-display-Remove-unused-POWER_DOMAIN_MODESET.patch (drm-backport-placeholder)
- commit 1a856b4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0303-drm-i915-dp-Check-if-force_dsc_output_format-is-poss.patch (drm-backport-placeholder)
- commit 10bfe7c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0302-drm-i915-dp-Check-src-sink-compressed-bpp-limit-for-.patch (drm-backport-placeholder)
- commit 8b57b61
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0301-drm-i915-dp-Get-optimal-link-config-to-have-best-com.patch (drm-backport-placeholder)
- commit 89ebe80
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0300-drm-i915-dp-Separate-out-function-to-get-compressed-.patch (drm-backport-placeholder)
- commit 40a2ca0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0299-drm-i915-dp-Add-DSC-BPC-BPP-constraints-while-select.patch (drm-backport-placeholder)
- commit a991f1e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0298-drm-i915-dp-Separate-out-functions-for-edp-DP-for-co.patch (drm-backport-placeholder)
- commit b0bc691
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0297-drm-i915-dp-Rename-helper-to-get-DSC-max-pipe_bpp.patch (drm-backport-placeholder)
- commit acbddb4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0296-drm-i915-dp-Avoid-left-shift-of-DSC-output-bpp-by-4.patch (drm-backport-placeholder)
- commit 6f804f2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0295-drm-i915-dp-Check-min-bpc-DSC-limits-for-dsc_force_b.patch (drm-backport-placeholder)
- commit aa28297
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0294-drm-i915-dp-Add-functions-to-get-min-max-src-input-b.patch (drm-backport-placeholder)
- commit 284c152
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0293-drm-i915-dp-Avoid-forcing-DSC-BPC-for-MST-case.patch (drm-backport-placeholder)
- commit fea3a84
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0292-drm-i915-dp-Remove-extra-logs-for-printing-DSC-info.patch (drm-backport-placeholder)
- commit 234a4be
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0291-drm-i915-intel_cdclk-Add-vdsc-with-bigjoiner-constra.patch (drm-backport-placeholder)
- commit ce276e0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0290-drm-i915-dp-Update-Bigjoiner-interface-bits-for-comp.patch (drm-backport-placeholder)
- commit 07e8727
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0289-drm-i915-dp-Use-consistent-name-for-link-bpp-and-com.patch (drm-backport-placeholder)
- commit 02334bd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0288-drm-i915-dp_mst-Use-output_format-to-get-the-final-l.patch (drm-backport-placeholder)
- commit 40ebf8d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0287-drm-i915-dp-Move-compressed-bpp-check-with-420-forma.patch (drm-backport-placeholder)
- commit 6d550a5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0286-drm-i915-dp-Consider-output_format-while-computing-d.patch (drm-backport-placeholder)
- commit 35bf8b0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0285-drm-i915-Eliminate-has_4tile-feature-flag.patch (drm-backport-placeholder)
- commit 1f7399b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0284-drm-i915-selftest-Simplify-Y-major-tiling-in-blit-se.patch (drm-backport-placeholder)
- commit c30f848
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dg2-Drop-pre-production-display-workarounds.patch (drm-backport-placeholder)
- commit 0826b04
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dg2-Recognize-pre-production-hardware.patch (drm-backport-placeholder)
- commit 34c7ca9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0281-drm-i915-cx0-Program-vswing-only-for-owned-lanes.patch (drm-backport-placeholder)
- commit 2fbe5da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0280-drm-i915-cx0-Enable-disable-TX-only-for-owned-PHY-la.patch (drm-backport-placeholder)
- commit 0fd190c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0279-drm-i915-Simplify-intel_cx0_program_phy_lane-with-lo.patch (drm-backport-placeholder)
- commit 60f8dcc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0278-drm-i915-cx0-Add-intel_cx0_get_owned_lane_mask.patch (drm-backport-placeholder)
- commit b24e0c7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0277-drm-i915-display-Remove-unused-POWER_DOMAIN_MASK.patch (drm-backport-placeholder)
- commit 53d03da
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0276-drm-i915-pxp-Optimize-GET_PARAM-PXP_STATUS.patch (drm-backport-placeholder)
- commit eb980ff
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0275-drm-i915-pxp-mtl-intel_pxp_init_hw-needs-runtime-pm-.patch (drm-backport-placeholder)
- commit 95ebb77
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0274-drm-i915-dp-Fix-LT-debug-print-in-SDP-CRC-enable.patch (drm-backport-placeholder)
- commit 98b8193
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0273-drm-i915-vdsc-Fix-first_line_bpg_offset-calculation.patch (drm-backport-placeholder)
- commit 4311bc5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0272-drm-i915-Don-t-change-the-status-of-forced-connector.patch (drm-backport-placeholder)
- commit 89c494b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0271-drm-i915-Don-t-change-the-status-of-forced-connector.patch (drm-backport-placeholder)
- commit b1ffc47
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0270-drm-i915-Avoid-endless-HPD-poll-detect-loop-via-runt.patch (drm-backport-placeholder)
- commit d2fcf09
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0269-drm-i915-Do-not-disable-preemption-for-resets.patch (drm-backport-placeholder)
- commit 6a3d44a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0268-drm-i915-perf-Remove-gtt_offset-from-stream-oa_buffe.patch (drm-backport-placeholder)
- commit 133e76b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0267-drm-i915-Add-Wa_18028616096.patch (drm-backport-placeholder)
- commit 0b694f2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0266-drm-i915-gem-remove-inlines-from-i915_gem_execbuffer.patch (drm-backport-placeholder)
- commit 5364abc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0265-drm-i915-gt-remove-a-static-inline-that-requires-inc.patch (drm-backport-placeholder)
- commit 911ddb9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0264-drm-i915-gt-Update-RC6-mask-for-mtl_drpc.patch (drm-backport-placeholder)
- commit 30a485e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0263-drm-i915-refactor-deprecated-strncpy.patch (drm-backport-placeholder)
- commit 5d9f762
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0262-drm-i915-lrc-User-PXP-contexts-requires-runalone-bit.patch (drm-backport-placeholder)
- commit 29635d3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0261-drm-i915-pxp-mtl-Update-pxp-firmware-packet-size.patch (drm-backport-placeholder)
- commit a945b8f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0260-drm-i915-pxp-mtl-Update-pxp-firmware-response-timeou.patch (drm-backport-placeholder)
- commit 43653d6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0259-drm-i915-huc-silence-injected-failure-in-the-load-vi.patch (drm-backport-placeholder)
- commit ce6c435
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0258-drm-i915-Add-Wa_18022495364.patch (drm-backport-placeholder)
- commit 6dec89f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0257-drm-i915-gt-skip-WA-verification-for-GEN7_MISCCPCTL-.patch (drm-backport-placeholder)
- commit 1b772b2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0256-drm-i915-Run-relevant-bits-of-debugfs-drop_caches-pe.patch (drm-backport-placeholder)
- commit 922c2ac
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0255-drm-i915-mtl-Drop-Wa_14017240301.patch (drm-backport-placeholder)
- commit 7b714b4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0254-drm-i915-Add-Wa_14015150844.patch (drm-backport-placeholder)
- commit dd71a0f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0253-drm-i915-gt-Wait-longer-for-tasks-in-migrate-selftes.patch (drm-backport-placeholder)
- commit 11be646
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-mtl-Update-workaround-14016712196.patch (drm-backport-placeholder)
- commit 990ce97
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0251-drm-i915-gsc-define-gsc-fw.patch (drm-backport-placeholder)
- commit 312ab65
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0250-drm-i915-mtl-Adding-DeviceID-for-Arrowlake-S-under-M.patch (drm-backport-placeholder)
- commit f1b69ac
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0249-drm-i915-guc-Force-a-reset-on-internal-GuC-error.patch (drm-backport-placeholder)
- commit 483a278
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Replace-several-IS_METEORLAKE-with-proper-I.patch (drm-backport-placeholder)
- commit 07aada1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-mtl-Eliminate-subplatforms.patch (drm-backport-placeholder)
- commit 84404d2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Eliminate-IS_MTL_MEDIA_STEP.patch (drm-backport-placeholder)
- commit 01eaa1a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Eliminate-IS_MTL_GRAPHICS_STEP.patch (drm-backport-placeholder)
- commit b2254b6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-xelpg-Call-Xe_LPG-workaround-functions-base.patch (drm-backport-placeholder)
- commit 22cddb2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-xelpmp-Don-t-assume-workarounds-extend-to-f.patch (drm-backport-placeholder)
- commit 8e6f26e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Consolidate-condition-for-Wa_22011802037.patch (drm-backport-placeholder)
- commit 2537546
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dg2-Drop-Wa_16011777198.patch (drm-backport-placeholder)
- commit 4bd1473
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Tidy-workaround-definitions.patch (drm-backport-placeholder)
- commit 9ed1f64
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dg2-Drop-pre-production-GT-workarounds.patch (drm-backport-placeholder)
- commit e970a88
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0238-drm-i915-selftests-Align-igt_spinner_create_request-.patch (drm-backport-placeholder)
- commit e734481
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0237-drm-i915-dg2-Remove-Wa_15010599737.patch (drm-backport-placeholder)
- commit d12a0e7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0236-drm-panel-ltk050h3146w-add-support-for-Leadtek-LTK05.patch (drm-backport-placeholder)
- commit 21fd0d0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0235-drm-panel-ltk050h3146w-add-mipi_dsi_device.mode_flag.patch (drm-backport-placeholder)
- commit b7e2391
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0232-drm-rockchip-dsi-Use-devm_platform_get_and_ioremap_r.patch (drm-backport-placeholder)
- commit 9fadd11
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0231-drm-rockchip-remove-redundant-of_match_ptr.patch (drm-backport-placeholder)
- commit 71a478f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-cdn-dp-Fix-some-error-handling-paths-in.patch (drm-backport-placeholder)
- commit 9e04dfb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0229-drm-rockchip-vop2-Convert-to-use-maple-tree-register.patch (drm-backport-placeholder)
- commit 7f1bc22
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0228-drm-rockchip-vop2-Demote-message-in-mod_supported-to.patch (drm-backport-placeholder)
- commit 30b00dd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0227-Documentation-gpu-fix-Panfrost-documentation-build-w.patch (drm-backport-placeholder)
- commit ad7d451
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0226-drm-panel-simple-allow-LVDS-format-override.patch (drm-backport-placeholder)
- commit 372b1a1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0225-drm-bridge-samsung-dsim-calculate-porches-in-Hz.patch (drm-backport-placeholder)
- commit 7ff2bb5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0224-drm-bridge-samsung-dsim-adjust-porches-by-rounding-u.patch (drm-backport-placeholder)
- commit eb42dbe
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0223-drm-bridge-samsung-dsim-update-PLL-reference-clock.patch (drm-backport-placeholder)
- commit c5c31f5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0222-drm-bridge-samsung-dsim-reread-ref-clock-before-conf.patch (drm-backport-placeholder)
- commit 53ba316
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0221-drm-bridge-samsung-dsim-add-more-mipi-dsi-device-deb.patch (drm-backport-placeholder)
- commit ca3e30a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0220-drm-exynos-dsi-Convert-to-platform-remove-callback-r.patch (drm-backport-placeholder)
- commit dd0d75a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0219-drm-amd-display-Fix-mst-hub-unplug-warning.patch (drm-backport-placeholder)
- commit 487d45c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0218-drm-panel-nv3051d-Add-Support-for-Anbernic-351V.patch (drm-backport-placeholder)
- commit 1aef014
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0217-drm-dp-switch-drm_dp_downstream_-helpers-to-struct-d.patch (drm-backport-placeholder)
- commit feaf30b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0216-drm-v3d-Annotate-struct-v3d_perfmon-with-__counted_b.patch (drm-backport-placeholder)
- commit 1c0f386
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0215-drm-vmwgfx-Annotate-struct-vmw_surface_dirty-with-__.patch (drm-backport-placeholder)
- commit 8a69dd6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0214-drm-virtio-Annotate-struct-virtio_gpu_object_array-w.patch (drm-backport-placeholder)
- commit 013baec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0213-drm-vc4-Annotate-struct-vc4_perfmon-with-__counted_b.patch (drm-backport-placeholder)
- commit f49474f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0212-drm-nouveau-pm-Annotate-struct-nvkm_perfdom-with-__c.patch (drm-backport-placeholder)
- commit 4ea6193
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0211-drm-msm-dpu-Annotate-struct-dpu_hw_intr-with-__count.patch (drm-backport-placeholder)
- commit 97758dd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0210-drm-i915-selftests-Annotate-struct-perf_series-with-.patch (drm-backport-placeholder)
- commit bdca5bb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0209-drm-amdgpu-discovery-Annotate-struct-ip_hw_instance-.patch (drm-backport-placeholder)
- commit 55c089a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0208-drm-amd-pm-Annotate-struct-smu10_voltage_dependency_.patch (drm-backport-placeholder)
- commit 36eccc9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0207-drm-panfrost-Implement-generic-DRM-object-RSS-report.patch (drm-backport-placeholder)
- commit 9f4f163
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0206-drm-drm_file-Add-DRM-obj-s-RSS-reporting-function-fo.patch (drm-backport-placeholder)
- commit 8b4e65b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0205-drm-panfrost-Add-fdinfo-support-for-memory-stats.patch (drm-backport-placeholder)
- commit 55d13e9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0204-drm-panfrost-Add-fdinfo-support-GPU-load-metrics.patch (drm-backport-placeholder)
- commit a19739c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0203-drm-panfrost-Add-cycle-count-GPU-register-definition.patch (drm-backport-placeholder)
- commit 37fd991
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0202-drm-vblank-Warn-when-silently-cancelling-vblank-work.patch (drm-backport-placeholder)
- commit 1f4f1c3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0201-drm-doc-Document-DRM-device-reset-expectations.patch (drm-backport-placeholder)
- commit 0873aad
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0200-drm-panel-Add-driver-for-BOE-RM692E5-AMOLED-panel.patch (drm-backport-placeholder)
- commit 137a4a1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0199-drm-panel-ili9322-Convert-to-use-maple-tree-register.patch (drm-backport-placeholder)
- commit fa0b8b2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0198-drm-panel-ili9322-Remove-redundant-volatle_reg-opera.patch (drm-backport-placeholder)
- commit d0ae28b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0197-drm-bridge-sn65dsi83-Convert-to-use-maple-tree-regis.patch (drm-backport-placeholder)
- commit f6e6ef7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0196-drm-bridge-lt9211-Convert-to-use-maple-tree-register.patch (drm-backport-placeholder)
- commit 3a65930
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0195-drm-bridge-icn6211-Convert-to-use-maple-tree-registe.patch (drm-backport-placeholder)
- commit dc273ee
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0194-drm-bridge-tc358767-Convert-to-use-maple-tree-regist.patch (drm-backport-placeholder)
- commit 4febe7f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0193-drm-bridge-dpc3433-Convert-to-use-maple-tree-registe.patch (drm-backport-placeholder)
- commit 8f3c88f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0192-drm-bridge-adv7511-Convert-to-use-maple-tree-registe.patch (drm-backport-placeholder)
- commit f7424ff
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0191-drm-tests-Add-new-format-conversion-tests-to-better-.patch (drm-backport-placeholder)
- commit 1986e58
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0190-drm-tests-Add-calls-to-drm_fb_blit-on-supported-form.patch (drm-backport-placeholder)
- commit e40bc40
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0189-drm-bridge-lt9611uxc-use-drm_bridge_get_edid-instead.patch (drm-backport-placeholder)
- commit 462e1d5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0188-drm-bridge-use-drm_bridge_get_edid-instead-of-using-.patch (drm-backport-placeholder)
- commit f0a33c0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0187-drm-nouveau-kms-nv50-hide-unused-variables.patch (drm-backport-placeholder)
- commit 6868587
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0186-drm-gpuvm-doc-fix-filename-references.patch (drm-backport-placeholder)
- commit 7ee0a46
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0185-drm-gma500-refactor-deprecated-strncpy.patch (drm-backport-placeholder)
- commit 7fa8b55
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0184-drm-nouveau-uvmm-rename-umgr-to-base.patch (drm-backport-placeholder)
- commit 61554ce
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0183-drm-gpuvm-allow-building-as-module.patch (drm-backport-placeholder)
- commit 6a33214
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0182-drm-gpuvm-rename-struct-drm_gpuva_manager-to-struct-.patch (drm-backport-placeholder)
- commit e48cc37
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0181-drm-imx-dcss-Call-drm_atomic_helper_shutdown-at-shut.patch (drm-backport-placeholder)
- commit 58af456
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0180-drm-bridge-Add-200ms-delay-to-wait-FW-HPD-status-sta.patch (drm-backport-placeholder)
- commit b8e93ef
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0179-drm-simpledrm-Add-support-for-multiple-power-domains.patch (drm-backport-placeholder)
- commit 78ea874
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0178-accel-qaic-Remove-size-field-from-struct-qaic_bo.patch (drm-backport-placeholder)
- commit 9301957
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0177-drm-ssd130x-Drop-_helper-prefix-from-struct-drm_-_he.patch (drm-backport-placeholder)
- commit ac0f11b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-edid-Fixup-h-vsync_end-instead-of-h-vtotal.patch (drm-backport-placeholder)
- commit 877591b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0175-drm-hisilicon-kirin-Call-drm_atomic_helper_shutdown-.patch (drm-backport-placeholder)
- commit 4a1ad57
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-Call-drm_atomic_helper_shutdown-at-shutdown-remo.patch (drm-backport-placeholder)
- commit 1f5e65f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0173-drm-ssd130x-Call-drm_atomic_helper_shutdown-at-remov.patch (drm-backport-placeholder)
- commit 803ba63
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0172-drm-vc4-Call-drm_atomic_helper_shutdown-at-shutdown-.patch (drm-backport-placeholder)
- commit 968b78b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0171-drm-Call-drm_atomic_helper_shutdown-at-shutdown-time.patch (drm-backport-placeholder)
- commit 266e11c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0170-drm-armada-Call-drm_atomic_helper_shutdown-at-shutdo.patch (drm-backport-placeholder)
- commit ca0c97e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0169-drm-bridge-panel-Fix-device-link-for-DRM_BRIDGE_ATTA.patch (drm-backport-placeholder)
- commit 21315fe
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-Update-file-owner-during-use.patch (drm-backport-placeholder)
- commit efa039d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0167-drm-bridge-tc358768-Attempt-to-fix-DSI-horizontal-ti.patch (drm-backport-placeholder)
- commit bd4901c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-Fix-tc358768_ns_to_cnt.patch (drm-backport-placeholder)
- commit 08c5dd3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-Clean-up-clock-period-code.patch (drm-backport-placeholder)
- commit 4f75fdb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-Rename-dsibclk-to-hsbyteclk.patch (drm-backport-placeholder)
- commit 54360bc
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-Use-dev-for-dbg-prints-not-priv-.patch (drm-backport-placeholder)
- commit af89ad1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-Print-logical-values-not-raw-reg.patch (drm-backport-placeholder)
- commit 4482458
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-Use-struct-videomode.patch (drm-backport-placeholder)
- commit 92bbd2a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0160-drm-bridge-tc358768-Cleanup-PLL-calculations.patch (drm-backport-placeholder)
- commit 2fe3b48
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-Fix-bit-updates.patch (drm-backport-placeholder)
- commit 49de390
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0158-drm-bridge-tc358768-Default-to-positive-h-v-syncs.patch (drm-backport-placeholder)
- commit fabed63
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-Fix-use-of-uninitialized-variabl.patch (drm-backport-placeholder)
- commit 6b68a4e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0156-drm-tegra-rgb-Parameterize-V-and-H-sync-polarities.patch (drm-backport-placeholder)
- commit 3faf1f2
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0155-drm-bridge-analogix-anx78xx-Add-missing-definition.patch (drm-backport-placeholder)
- commit 8c422f7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0154-drm-nouveau-kms-nv50-disable-dcb-parsing.patch (drm-backport-placeholder)
- commit d972515
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0153-drm-nouveau-kms-nv50-create-outputs-based-on-nvkm-in.patch (drm-backport-placeholder)
- commit ae7687e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0152-drm-nouveau-kms-nv50-create-connectors-based-on-nvkm.patch (drm-backport-placeholder)
- commit ce0a9f6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0151-drm-nouveau-kms-nv50-name-aux-channels-after-their-c.patch (drm-backport-placeholder)
- commit d1fcbaf
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0150-drm-nouveau-kms-nv50-create-heads-after-outps-conns.patch (drm-backport-placeholder)
- commit 914b3ac
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0149-drm-nouveau-kms-nv50-create-heads-based-on-nvkm-head.patch (drm-backport-placeholder)
- commit 91b2d02
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0148-drm-nouveau-disp-nv50-skip-DCB_OUTPUT_TV.patch (drm-backport-placeholder)
- commit ababa6a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0147-drm-nouveau-disp-move-outp-init-fini-paths-to-chipse.patch (drm-backport-placeholder)
- commit 98d49d0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0146-drm-nouveau-disp-move-outp-conn-construction-to-chip.patch (drm-backport-placeholder)
- commit 50fb938
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0145-drm-nouveau-disp-add-dp-mst-id-get-put-methods.patch (drm-backport-placeholder)
- commit e7bb467
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0144-drm-nouveau-disp-add-dp-sst-config-method.patch (drm-backport-placeholder)
- commit 7445a27
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0143-drm-nouveau-disp-move-link-training-out-of-superviso.patch (drm-backport-placeholder)
- commit 0981cf1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0142-drm-nouveau-disp-add-dp-train-method.patch (drm-backport-placeholder)
- commit 67b9500
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0141-drm-nouveau-kms-nv50-fixup-sink-D3-before-tearing-do.patch (drm-backport-placeholder)
- commit 6687dd7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0140-drm-nouveau-kms-nv50-flush-mst-disables-together.patch (drm-backport-placeholder)
- commit c900d94
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0139-drm-nouveau-kms-nv50-split-DP-disable-enable-into-tw.patch (drm-backport-placeholder)
- commit 7231ea8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0138-drm-nouveau-disp-add-dp-rates-method.patch (drm-backport-placeholder)
- commit 1084860
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0137-drm-nouveau-disp-add-dp-aux-xfer-method.patch (drm-backport-placeholder)
- commit e59d021
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0136-drm-nouveau-disp-move-dp-aux-pwr-method-to-HAL.patch (drm-backport-placeholder)
- commit b28a385
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0135-drm-nouveau-disp-add-hdmi-audio-hal-function.patch (drm-backport-placeholder)
- commit bfdd0a4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0134-drm-nouveau-disp-add-output-lvds-config-method.patch (drm-backport-placeholder)
- commit 8b53532
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0133-drm-nouveau-disp-add-output-backlight-control-method.patch (drm-backport-placeholder)
- commit 0706d37
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0132-drm-nouveau-disp-remove-SOR-routing-updates-from-sup.patch (drm-backport-placeholder)
- commit 1f427ab
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0131-drm-nouveau-disp-release-outputs-post-modeset.patch (drm-backport-placeholder)
- commit eac15d4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0130-drm-nouveau-disp-move-hdmi-disable-out-of-release.patch (drm-backport-placeholder)
- commit 819cced
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0129-drm-nouveau-disp-add-output-hdmi-config-method.patch (drm-backport-placeholder)
- commit b52f194
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0128-drm-nouveau-kms-nv50-move-audio-enable-post-modeset.patch (drm-backport-placeholder)
- commit 940d316
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0127-drm-nouveau-kms-nv50-keep-output-state-around-until-.patch (drm-backport-placeholder)
- commit ab3b987
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0126-drm-nouveau-kms-nv50-remove-nv_encoder.audio.connect.patch (drm-backport-placeholder)
- commit a7b225a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0125-drm-nouveau-kms-nv50-pull-some-common-init-out-of-OR.patch (drm-backport-placeholder)
- commit 98117bb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0124-drm-nouveau-disp-update-SOR-routing-immediately-on-a.patch (drm-backport-placeholder)
- commit 25cf50e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0123-drm-nouveau-disp-add-acquire_sor-pior.patch (drm-backport-placeholder)
- commit 7479654
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0122-drm-nouveau-disp-add-acquire_dac.patch (drm-backport-placeholder)
- commit 6bdf0e6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0121-drm-nouveau-disp-shuffle-to-make-upcoming-diffs-pret.patch (drm-backport-placeholder)
- commit ed196d5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0120-drm-nouveau-kms-Add-INHERIT-ioctl-to-nvkm-nvif-for-r.patch (drm-backport-placeholder)
- commit e7d217d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0119-drm-nouveau-disp-rename-internal-output-acquire-rele.patch (drm-backport-placeholder)
- commit 8e99750
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0118-drm-nouveau-disp-add-output-method-to-fetch-edid.patch (drm-backport-placeholder)
- commit 74742ec
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0117-drm-nouveau-disp-add-output-detect-method.patch (drm-backport-placeholder)
- commit 64b4c56
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0116-drm-nouveau-disp-rearrange-output-methods.patch (drm-backport-placeholder)
- commit 45bb760
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0115-drm-nouveau-kms-nv50-fix-mst-payload-alloc-fail-cras.patch (drm-backport-placeholder)
- commit 9c16cb6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0114-drm-nouveau-mmu-gp100-always-invalidate-TLBs-at-CACH.patch (drm-backport-placeholder)
- commit 6d1690a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0113-drm-nouveau-gr-gf100-lose-contents-of-global-ctxbufs.patch (drm-backport-placeholder)
- commit 2ec0c5e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0112-drm-nouveau-imem-support-allocations-not-preserved-a.patch (drm-backport-placeholder)
- commit e360940
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0111-drm-nouveau-devinit-tu102-remove-attempt-at-loading-.patch (drm-backport-placeholder)
- commit b21d6b3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0110-drm-dp_mst-Tune-down-error-message-during-payload-ad.patch (drm-backport-placeholder)
- commit 2db7fde
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0109-drm-dp_mst-Sanitize-error-return-during-payload-addi.patch (drm-backport-placeholder)
- commit 93aadd4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0108-drm-dp_mst-Fix-NULL-dereference-during-payload-addit.patch (drm-backport-placeholder)
- commit 8ad1a07
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0107-drm-bridge-dw-hdmi-cec-Add-arbitration-lost-event.patch (drm-backport-placeholder)
- commit 6cbf86a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0106-drm-nouveau-pm-refactor-deprecated-strncpy.patch (drm-backport-placeholder)
- commit 41b53c3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0105-drm-nouveau-core-refactor-deprecated-strncpy.patch (drm-backport-placeholder)
- commit dbb9a58
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0104-drm-nouveau-nvif-refactor-deprecated-strncpy.patch (drm-backport-placeholder)
- commit 8131282
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0103-drm-komeda-add-NV12-format-to-support-writeback-laye.patch (drm-backport-placeholder)
- commit 927bf1e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-it66121-get_edid-callback-must-not-return.patch (drm-backport-placeholder)
- commit ee18df9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0101-drm-ssd130x-Store-the-HW-buffer-in-the-driver-privat.patch (drm-backport-placeholder)
- commit 3caf178
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0100-drm-debugfs-Fix-drm_debugfs_remove_files-stub.patch (drm-backport-placeholder)
- commit 6633c4c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0099-drm-amd-display-Fix-Wuninitialized-in-dm_helpers_dp_.patch (drm-backport-placeholder)
- commit 938cdf6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0098-drm-ingenic-Call-drm_atomic_helper_shutdown-at-shutd.patch (drm-backport-placeholder)
- commit 97f592b
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0097-drm-imx-ipuv3-Call-drm_atomic_helper_shutdown-at-shu.patch (drm-backport-placeholder)
- commit 189a8b9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0096-drm-atomic-helper-drm_atomic_helper_shutdown-NULL-sh.patch (drm-backport-placeholder)
- commit 9966d0a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0095-drm-panel-otm8009a-Don-t-double-check-prepared-enabl.patch (drm-backport-placeholder)
- commit 6c290e7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0094-drm-panel-s6e63m0-Don-t-store-check-prepared-enabled.patch (drm-backport-placeholder)
- commit 53bd6c1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0093-drm-panel-Don-t-store-check-prepared-enabled-for-sim.patch (drm-backport-placeholder)
- commit 47ba132
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0092-drm-i915-Move-the-size-computations-to-drm-buddy.patch (drm-backport-placeholder)
- commit 2d7091a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0091-drm-amdgpu-Move-the-size-computations-to-drm-buddy.patch (drm-backport-placeholder)
- commit ae9de70
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0090-drm-buddy-Improve-contiguous-memory-allocation.patch (drm-backport-placeholder)
- commit 3039e96
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0089-fbdev-core-Clean-up-include-statements-in-fbmem.c.patch (drm-backport-placeholder)
- commit 04a4b28
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0088-fbdev-core-Remove-empty-internal-helpers-from-fb_log.patch (drm-backport-placeholder)
- commit 1f063a9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0087-fbdev-core-Move-logo-functions-into-separate-source-.patch (drm-backport-placeholder)
- commit d488b52
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0086-fbdev-core-Unexport-logo-helpers.patch (drm-backport-placeholder)
- commit 4cb4ec3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0085-fbdev-core-Fix-style-of-code-for-boot-up-logo.patch (drm-backport-placeholder)
- commit 883127c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0084-fbdev-mmp-mmpfb-Do-not-display-boot-up-logo.patch (drm-backport-placeholder)
- commit d7afb16
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0083-fbdev-au1200fb-Do-not-display-boot-up-logo.patch (drm-backport-placeholder)
- commit fd6234a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0082-drm-ssd130x-Use-bool-for-ssd130x_deviceinfo-flags.patch (drm-backport-placeholder)
- commit 074f42e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-ssd130x-Fix-screen-clearing.patch (drm-backport-placeholder)
- commit d4306c6
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0080-drm-ssd130x-Print-the-PWM-s-label-instead-of-its-num.patch (drm-backport-placeholder)
- commit 947af41
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0079-drm-shmobile-Convert-to-platform-remove-callback-ret.patch (drm-backport-placeholder)
- commit 8dd9c6c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0078-drm-msm-Convert-to-platform-remove-callback-returnin.patch (drm-backport-placeholder)
- commit 1b8c5bd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0077-drm-ingenic-Convert-to-platform-remove-callback-retu.patch (drm-backport-placeholder)
- commit 6766518
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0076-drm-imx-ipuv3-Convert-to-platform-remove-callback-re.patch (drm-backport-placeholder)
- commit 0704c9d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0075-drm-mst-Refactor-the-flow-for-payload-allocation-rem.patch (drm-backport-placeholder)
- commit e7ca92a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0074-drm-mst-delete-unnecessary-case-in-drm_dp_add_payloa.patch (drm-backport-placeholder)
- commit de2c8aa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0073-drm-tests-Zero-initialize-fourccs_out.patch (drm-backport-placeholder)
- commit b1deec5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0072-drm-debugfs-Add-inline-to-drm_debugfs_dev_init-to-su.patch (drm-backport-placeholder)
- commit 6d2aae4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0071-drm-doc-rfc-Mark-GPU-VA-as-complete.patch (drm-backport-placeholder)
- commit 109f558
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0070-drm-doc-rfc-Mark-DRM_VM_BIND-as-complete.patch (drm-backport-placeholder)
- commit 341c6eb
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0069-drm-doc-rfc-Mark-Dev_coredump-as-completed.patch (drm-backport-placeholder)
- commit fa63776
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0068-drm-doc-rfc-No-STAGING-out-of-drivers-staging.patch (drm-backport-placeholder)
- commit 671183f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0067-drm-connector-document-DRM_MODE_COLORIMETRY_COUNT.patch (drm-backport-placeholder)
- commit e73a804
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0066-drm-bridge-Drop-CONFIG_OF-conditionals-around-of_nod.patch (drm-backport-placeholder)
- commit 2cc7315
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0065-drm-bridge-Drop-conditionals-around-of_node-pointers.patch (drm-backport-placeholder)
- commit dfe7bb4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0064-drm-bridge-analogix-anx78xx-Drop-ID-table.patch (drm-backport-placeholder)
- commit 25d8c37
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-lt8912b-Add-missing-drm_bridge_attach-cal.patch (drm-backport-placeholder)
- commit f66ee7e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-lt8912b-Manually-disable-HPD-only-if-it-w.patch (drm-backport-placeholder)
- commit e5833be
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-lt8912b-Fix-crash-on-bridge-detach.patch (drm-backport-placeholder)
- commit 4d10590
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-lt8912b-Fix-bridge_detach.patch (drm-backport-placeholder)
- commit c81aa9f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0058-drm-bridge-it66121-Extend-match-support-for-OF-table.patch (drm-backport-placeholder)
- commit b9136c3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0057-fbdev-hyperv_fb-Use-fb_ops-helpers-for-deferred-I-O.patch (drm-backport-placeholder)
- commit 138b05c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0056-fbdev-Add-Kconfig-macro-FB_IOMEM_HELPERS_DEFERRED.patch (drm-backport-placeholder)
- commit 350b801
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0055-fbdev-udlfb-Use-fb_ops-helpers-for-deferred-I-O.patch (drm-backport-placeholder)
- commit eddea00
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0054-fbdev-smscufx-Use-fb_ops-helpers-for-deferred-I-O.patch (drm-backport-placeholder)
- commit 0f4d18a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0053-drm-virtio-Remove-unused-function-declarations.patch (drm-backport-placeholder)
- commit b48b690
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0052-drm-debugfs-rework-drm_debugfs_create_files-implemen.patch (drm-backport-placeholder)
- commit 657f4af
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0051-drm-debugfs-remove-dev-debugfs_list-and-debugfs_mute.patch (drm-backport-placeholder)
- commit 60f63b9
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0050-drm-debugfs-rework-debugfs-directory-creation-v5.patch (drm-backport-placeholder)
- commit 996b913
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-komeda-drop-all-currently-held-locks-if-deadlock.patch (drm-backport-placeholder)
- commit de6d8e3
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0048-drm-debugfs-disallow-debugfs-access-when-device-isn-.patch (drm-backport-placeholder)
- commit 42bd7aa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0047-drm-debugfs-drop-debugfs_init-for-the-render-and-acc.patch (drm-backport-placeholder)
- commit 4370c9d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0046-fbdev-tcx-Use-initializer-macro-for-struct-fb_ops.patch (drm-backport-placeholder)
- commit 9d9a3bd
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0045-fbdev-p9100-Use-initializer-macro-for-struct-fb_ops.patch (drm-backport-placeholder)
- commit cab1401
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0044-fbdev-leo-Use-initializer-macro-for-struct-fb_ops.patch (drm-backport-placeholder)
- commit cbc83c7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0043-fbdev-ffb-Use-initializer-macro-for-struct-fb_ops.patch (drm-backport-placeholder)
- commit 454f18d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0042-fbdev-cg6-Use-initializer-macro-for-struct-fb_ops.patch (drm-backport-placeholder)
- commit 7746956
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0041-fbdev-cg3-Use-initializer-macro-for-struct-fb_ops.patch (drm-backport-placeholder)
- commit 35fbbe4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0040-fbdev-cg14-Use-initializer-macro-for-struct-fb_ops.patch (drm-backport-placeholder)
- commit 862f06a
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0039-fbdev-bw2-Use-initializer-macro-for-struct-fb_ops.patch (drm-backport-placeholder)
- commit 62d0cfa
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0038-fbdev-sbus-Add-initializer-macros-and-Kconfig-tokens.patch (drm-backport-placeholder)
- commit 872983d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0037-fbdev-sbus-Forward-declare-all-necessary-structures-.patch (drm-backport-placeholder)
- commit 6107103
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0036-fbdev-sbus-Build-sbuslib.o-if-CONFIG_FB_SBUS-has-bee.patch (drm-backport-placeholder)
- commit c02a04e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0035-drm-tests-Add-KUnit-tests-for-drm_fb_memcpy.patch (drm-backport-placeholder)
- commit 30ced55
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0034-drm-tests-Add-multi-plane-support-to-conversion_buf_.patch (drm-backport-placeholder)
- commit 37c58f1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0033-drm-tests-Add-KUnit-tests-for-drm_fb_build_fourcc_li.patch (drm-backport-placeholder)
- commit e54e04c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0032-drm-tests-Add-KUnit-tests-for-drm_fb_clip_offset.patch (drm-backport-placeholder)
- commit 7691fe4
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0031-drm-tests-Add-KUnit-tests-for-drm_fb_swab.patch (drm-backport-placeholder)
- commit 28f7d63
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0030-drm-tests-Test-default-pitch-fallback.patch (drm-backport-placeholder)
- commit 960d721
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0029-drm-repaper-fix-Wvoid-pointer-to-enum-cast-warning.patch (drm-backport-placeholder)
- commit 45cf471
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0028-drm-gma500-Remove-unused-declarations.patch (drm-backport-placeholder)
- commit 329ba2c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-gma500-Fix-call-trace-when-psb_gem_mm_init-fails.patch (drm-backport-placeholder)
- commit bdd3dd5
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0026-drm-gma500-remove-duplicate-macro-definitions.patch (drm-backport-placeholder)
- commit 529a672
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0025-doc-uapi-Add-document-describing-dma-buf-semantics.patch (drm-backport-placeholder)
- commit 7ca2906
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0024-drm-panfrost-Do-not-check-for-0-return-after-calling.patch (drm-backport-placeholder)
- commit d7572a1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-Fix-kernel-doc-typo-in-desc-of-output_bus.patch (drm-backport-placeholder)
- commit 69d132d
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0022-drm-panel-Add-driver-for-JDI-LPM102A188A.patch (drm-backport-placeholder)
- commit b5a1a00
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0021-drm-panel-JDI-LT070ME05000-drop-broken-link.patch (drm-backport-placeholder)
- commit 6cdc67e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0020-drm-panel-simple-Add-support-for-Mitsubishi-AA084XE0.patch (drm-backport-placeholder)
- commit 0083a3e
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0019-drm-bridge-panel-Add-a-device-link-between-drm-devic.patch (drm-backport-placeholder)
- commit bc1d184
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-vop2-Add-missing-call-to-crtc-reset-hel.patch (drm-backport-placeholder)
- commit b19bda7
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-vop2-Don-t-crash-for-invalid-duplicate_.patch (drm-backport-placeholder)
- commit e03015c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-vop-Fix-call-to-crtc-reset-helper.patch (drm-backport-placeholder)
- commit 6b09458
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0015-drm-rockchip-vop-Use-cleanup-helper-directly-as-dest.patch (drm-backport-placeholder)
- commit 1d9908f
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-vop-Fix-reset-of-state-in-duplicate-sta.patch (drm-backport-placeholder)
- commit fa53a2c
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-loongson-Fix-error-handling-in-lsdc_pixel_pll_se.patch (drm-backport-placeholder)
- commit a059163
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0012-drm-bridge-lvds-codec-Implement-atomic_get_input_bus.patch (drm-backport-placeholder)
- commit 7671113
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-samsung-dsim-Fix-waiting-for-empty-cmd-tr.patch (drm-backport-placeholder)
- commit 6ad19e1
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-for-GENERIC_PHY_MIPI_DPHY-also-select-GEN.patch (drm-backport-placeholder)
- commit 2122ed8
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0008-accel-ivpu-Document-DRM_IVPU_PARAM_CAPABILITIES.patch (drm-backport-placeholder)
- commit 8af2cf0
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0007-drm-rockchip-dsi-Add-rv1126-MIPI-DSI-support.patch (drm-backport-placeholder)
- commit f605056
* Wed Oct  2 2024 pjakobsson@suse.de
- Update patches.suse/0006-drm-rockchip-vop-Add-rv1126-vop_lite-support.patch (drm-backport-placeholder)
- commit 3f99f13
* Wed Oct  2 2024 tiwai@suse.de
- ALSA: hda/generic: Unconditionally prefer preferred_dacs pairs
  (bsc#1219803).
- commit 020b49a
* Tue Oct  1 2024 msuchanek@suse.de
- powerpc/code-patching: Add generic memory patching
  (bsc#1194869).
- powerpc/code-patching: Perform hwsync in __patch_instruction()
  in case of failure (bsc#1194869).
- commit 33b01a6
* Tue Oct  1 2024 oneukum@suse.com
- usbnet: fix cyclical race on disconnect with work queue
  (git-fixes).
- Refresh
  patches.suse/0002-Add-a-void-suse_kabi_padding-placeholder-to-some-USB.patch.
- commit 8272f2d
* Tue Oct  1 2024 dsterba@suse.com
- apparmor: fix possible NULL pointer dereference (CVE-2024-46721 bsc#1230710)
- commit 2d35a7c
* Tue Oct  1 2024 oneukum@suse.com
- i3c: master: support to adjust first broadcast address speed
  (jsc#PED-10702).
- commit 192a460
* Tue Oct  1 2024 msuchanek@suse.de
- blacklist.conf: ff2e185cf73d powerpc/pseries: Enforce hcall result
  buffer validity and size
  Only works with clang
- commit cd964d8
* Tue Oct  1 2024 oneukum@suse.com
- i3c: master: Enhance i3c_bus_type visibility for device
  searching & event monitoring (jsc#PED-10702).
- commit a2f0df9
* Tue Oct  1 2024 oneukum@suse.com
- i3c: Make i3c_bus_type const (jsc#PED-10702).
- commit f58db15
* Tue Oct  1 2024 oneukum@suse.com
- i3c: master: Enable runtime PM for master controller
  (jsc#PED-10702).
- commit e01c1d7
* Tue Oct  1 2024 oneukum@suse.com
- i3c: master: add enable(disable) hot join in sys entry
  (jsc#PED-10702).
- commit 2bff927
* Tue Oct  1 2024 oneukum@suse.com
- i3c: master: Fix build error (jsc#PED-10702).
- commit f6f86c8
* Tue Oct  1 2024 oneukum@suse.com
- i3c: Add fallback method for GETMXDS CCC (jsc#PED-10702).
- commit 3ce09f9
* Tue Oct  1 2024 msuchanek@suse.de
- powerpc/64: Convert patch_instruction() to patch_u32()
  (bsc#1194869).
- powerpc/boot: Only free if realloc() succeeds (bsc#1194869).
- powerpc/boot: Handle allocation failure in simple_realloc()
  (bsc#1194869).
- powerpc/xics: Check return value of kasprintf in
  icp_native_map_one_cpu (bsc#1194869).
- powerpc/vdso: Fix VDSO data access when running in a non-root
  time namespace (bsc#1194869).
- commit 0dec2e8
* Tue Oct  1 2024 tbogendoerfer@suse.de
- net: mana: Improve mana_set_channels() in low mem conditions
  (bsc#1230289).
- net: mana: Implement get_ringparam/set_ringparam for mana
  (bsc#1229891).
- net: dpaa: Pad packets to ETH_ZLEN (CVE-2024-46854 bsc#1231084).
- ice: move netif_queue_set_napi to rtnl-protected sections
  (CVE-2024-46766 bsc#1230762).
- ice: Add netif_device_attach/detach into PF reset flow
  (CVE-2024-46770 bsc#1230763).
- bonding: change ipsec_lock from spin lock to mutex
  (CVE-2024-46678 bsc#1230550).
- bonding: extract the use of real_device into local variable
  (CVE-2024-46678 bsc#1230550).
- bonding: implement xdo_dev_state_free and call it after deletion
  (CVE-2024-46678 bsc#1230550).
- commit 9ee67ad
* Tue Oct  1 2024 oneukum@suse.com
- i3c: Add support for bus enumeration & notification
  (jsc#PED-10702).
- commit 6812158
* Tue Oct  1 2024 oneukum@suse.com
- i3c: master: Inherit DMA masks and parameters from parent device
  (jsc#PED-10702).
- commit e40b49d
* Tue Oct  1 2024 pmladek@suse.com
- printk: Export match_devname_and_update_preferred_console()
  (bsc#1229741).
- commit 1ad32a8
* Tue Oct  1 2024 oneukum@suse.com
- i3c: master: Fix SETDASA process (jsc#PED-10702).
- commit 41b03a5
* Tue Oct  1 2024 msuchanek@suse.de
- powerpc/xmon: Fix disassembly CPU feature checks (bsc#1065729).
- commit c675509
* Tue Oct  1 2024 oneukum@suse.com
- power: supply: sbs-manager: Remove class argument from
  i2c_mux_add_adapter() (jsc#PED-10702).
- commit d070c7f
* Tue Oct  1 2024 tiwai@suse.de
- ACPICA: executer/exsystem: Don't nag user about every Stall()
  violating the spec (git-fixes).
- ACPICA: Implement ACPI_WARNING_ONCE and ACPI_ERROR_ONCE
  (stable-fixes).
- commit f94e799
* Tue Oct  1 2024 tiwai@suse.de
- platform/x86: int3472: make common part a separate module
  (git-fixes).
- supported.conf:
- commit 2169815
* Tue Oct  1 2024 tiwai@suse.de
- serial: 8250: omap: Cleanup on error in request_irq (git-fixes).
- Bluetooth: btintel_pcie: Allocate memory for driver private data
  (git-fixes).
- wifi: mac80211: Check for missing VHT elements only for 5 GHz
  (git-fixes).
- wifi: iwlwifi: mvm: allow ESR when we the ROC expires
  (git-fixes).
- ASoC: Intel: soc-acpi-intel-mtl-match: add missing empty item
  (git-fixes).
- ASoC: Intel: soc-acpi-intel-lnl-match: add missing empty item
  (git-fixes).
- commit 2a26c38
* Tue Oct  1 2024 lhenriques@suse.de
- cachefiles: fix dentry leak in cachefiles_open_file()
  (bsc#1231183).
- ceph: remove the incorrect Fw reference check when dirtying
  pages (bsc#1231182).
- commit ba82da7
* Tue Oct  1 2024 schwab@suse.de
- rpm/check-for-config-changes: add HAVE_RUST and RUSTC_SUPPORTS_ to IGNORED_CONFIGS_RE
  They depend on SHADOW_CALL_STACK.
- commit 65fa52b
* Tue Oct  1 2024 pjakobsson@suse.de
- blacklist.conf: e835d5144f5e drm/amd/display: Avoid race between dcn35_set_drr() and dc_state_destruct()
- commit 81a7d58
* Tue Oct  1 2024 nik.borisov@suse.com
- x86/fred: Enable FRED right after init_mem_mapping() (git-fixes).
- commit 50422f5
* Tue Oct  1 2024 nik.borisov@suse.com
- x86/fred: Move FRED RSP initialization into a separate function (git-fixes).
- commit 202a097
* Tue Oct  1 2024 nik.borisov@suse.com
- x86/fred: Parse cmdline param "fred=" in cpu_parse_early_param() (git-fixes).
- commit 11cf3ac
* Tue Oct  1 2024 nik.borisov@suse.com
- x86/ioremap: Improve iounmap() address range checks (jsc#PED-10334).
- commit 4db5304
* Tue Oct  1 2024 tiwai@suse.de
- serial: 8250: omap: Cleanup on error in request_irq (git-fixes).
- Bluetooth: btintel_pcie: Allocate memory for driver private data
  (git-fixes).
- wifi: mac80211: Check for missing VHT elements only for 5 GHz
  (git-fixes).
- wifi: iwlwifi: mvm: allow ESR when we the ROC expires
  (git-fixes).
- ASoC: Intel: soc-acpi-intel-mtl-match: add missing empty item
  (git-fixes).
- ASoC: Intel: soc-acpi-intel-lnl-match: add missing empty item
  (git-fixes).
- commit 68827c1
* Tue Oct  1 2024 tiwai@suse.de
- can: mcp251xfd: move mcp251xfd_timestamp_start()/stop() into
  mcp251xfd_chip_start/stop() (stable-fixes).
- Refresh
  patches.suse/can-mcp251xfd-clarify-the-meaning-of-timestamp.patch.
- commit 6779985
* Tue Oct  1 2024 tiwai@suse.de
- USB: serial: pl2303: add device id for Macrosilicon MS3020
  (stable-fixes).
- powercap/intel_rapl: Add support for AMD family 1Ah
  (stable-fixes).
- ASoC: amd: yc: Add a quirk for MSI Bravo 17 (D7VEK)
  (stable-fixes).
- ASoC: tda7419: fix module autoloading (stable-fixes).
- ASoC: intel: fix module autoloading (stable-fixes).
- ASoC: Intel: soc-acpi-cht: Make Lenovo Yoga Tab 3 X90F DMI
  match less strict (stable-fixes).
- ALSA: hda: add HDMI codec ID for Intel PTL (stable-fixes).
- drm: komeda: Fix an issue related to normalized zpos
  (stable-fixes).
- can: mcp251xfd: mcp251xfd_ring_init(): check TX-coalescing
  configuration (stable-fixes).
- spi: spidev: Add missing spi_device_id for jg10309-01
  (git-fixes).
- spi: bcm63xx: Enable module autoloading (stable-fixes).
- spi: spidev: Add an entry for elgin,jg10309-01 (stable-fixes).
- hwmon: (asus-ec-sensors) remove VRM temp X570-E GAMING
  (stable-fixes).
- wifi: iwlwifi: clear trans->state earlier upon error
  (stable-fixes).
- wifi: mac80211: free skb on error path in
  ieee80211_beacon_get_ap() (stable-fixes).
- wifi: iwlwifi: mvm: don't wait for tx queues if firmware is dead
  (stable-fixes).
- wifi: iwlwifi: mvm: pause TCM when the firmware is stopped
  (stable-fixes).
- wifi: iwlwifi: mvm: fix iwl_mvm_max_scan_ie_fw_cmd_room()
  (stable-fixes).
- wifi: iwlwifi: mvm: fix iwl_mvm_scan_fits() calculation
  (stable-fixes).
- wifi: iwlwifi: lower message level for FW buffer destination
  (stable-fixes).
- platform/x86: x86-android-tablets: Make Lenovo Yoga Tab 3 X90F
  DMI match less strict (stable-fixes).
- pinctrl: at91: make it work with current gpiolib (stable-fixes).
- can: mcp251xfd: properly indent labels (stable-fixes).
- commit a530f31
* Mon Sep 30 2024 krisman@suse.de
- mm/filemap: skip to create PMD-sized page cache if needed
  (bsc#1228454 CVE-2024-41031).
- commit 03907fa
* Mon Sep 30 2024 dwagner@suse.de
- nvme-fabrics: use reserved tag for reg read/write command
  (bsc#1228620 CVE-2024-41082).
- commit 239456c
* Mon Sep 30 2024 oneukum@suse.com
- i2c: Convert to platform remove callback returning void
  (jsc#PED-10702).
- Refresh
  patches.suse/i2c-synquacer-Fix-an-error-handling-path-in-synquace.patch.
- Refresh
  patches.suse/i2c-wmt-Fix-an-error-handling-path-in-wmt_i2c_probe.patch.
- Refresh patches.suse/i2c-wmt-split-out-common-files.patch.
- commit f88ec74
* Mon Sep 30 2024 oneukum@suse.com
- i2c: dev: Check for I2C_FUNC_I2C before calling i2c_transfer
  (jsc#PED-10702).
- commit 9352566
* Mon Sep 30 2024 pmladek@suse.com
- kthread: Fix task state in kthread worker if being frozen
  (bsc#1231146).
- commit fe88a62
* Mon Sep 30 2024 jroedel@suse.de
- x86/sev: Move sev_guest.h into common SEV header (jsc#PED-5865).
- Update
  patches.suse/0017-KVM-SEV-Provide-support-for-SNP_GUEST_REQUEST-NAE-ev.patch
  (jsc#PED-5865).
- Update
  patches.suse/0018-KVM-SEV-Provide-support-for-SNP_EXTENDED_GUEST_REQUE.patch
  (jsc#PED-5865).
- Update
  patches.suse/0019-crypto-ccp-Add-the-SNP_VLEK_LOAD-command.patch
  (jsc#PED-5865).
- commit 66856e5
* Mon Sep 30 2024 tiwai@suse.de
- supported.conf: mark adiantum and xctr crypto modules as supported (bsc#1231035)
- commit 59d03d7
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Remove usage of I2C_CLASS_SPD (jsc#PED-10702).
- commit 52c282e
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Fix missing Kconfig dependency (jsc#PED-10702).
- Update config files.
- commit f954df0
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Call i2c_register_spd for muxed child segments
  (jsc#PED-10702).
- commit 45dec67
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Fix a refactoring that broke a touchpad on Lenovo P1
  (jsc#PED-10702).
- commit b2a9cae
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Fix using mux_pdev before it's set (jsc#PED-10702).
- commit 4b2d99f
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Add helper i801_get_block_len (jsc#PED-10702).
- commit a3ae321
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Add SMBUS_LEN_SENTINEL (jsc#PED-10702).
- commit 554ac99
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Split i801_block_transaction (jsc#PED-10702).
- commit 89fb647
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Add helper i801_check_and_clear_pec_error
  (jsc#PED-10702).
- commit f8c7e2f
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Remove unused argument from tco functions
  (jsc#PED-10702).
- commit 5d5a3e6
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Simplify class-based client device instantiation
  (jsc#PED-10702).
- commit 9d8598a
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: add helper i801_restore_regs (jsc#PED-10702).
- commit 3910abf
* Mon Sep 30 2024 oneukum@suse.com
- i2c: i801: Remove #ifdef guards for PM related functions
  (jsc#PED-10702).
- commit f44e603
* Mon Sep 30 2024 petr.pavlu@suse.com
- Refresh
  patches.suse/bpf-kprobe-remove-unused-declaring-of-bpf_kprobe_override.patch.
- commit 5a0b269
* Mon Sep 30 2024 petr.pavlu@suse.com
- bpf: Fix use-after-free in bpf_uprobe_multi_link_attach()
  (git-fixes).
- commit 1884922
* Mon Sep 30 2024 petr.pavlu@suse.com
- tracing: Avoid possible softlockup in tracing_iter_reset()
  (git-fixes).
- commit d5df75c
* Mon Sep 30 2024 petr.pavlu@suse.com
- tracing: Fix overflow in get_free_elt() (git-fixes
  CVE-2024-43890 bsc#1229764).
- commit ceb524e
* Mon Sep 30 2024 iivanov@suse.de
- arm64: acpi: Harden get_cpu_for_acpi_id() against missing CPU entry (bsc#1231120 CVE-2024-46822)
- commit cc6d7b5
* Mon Sep 30 2024 oneukum@suse.com
- i2c: smbus: Support DDR5 and LPDDR5 SPD EEPROMs (jsc#PED-10702).
- commit 9364afd
* Mon Sep 30 2024 oneukum@suse.com
- i2c: mux: Remove class argument from i2c_mux_add_adapter()
  (jsc#PED-10702).
- commit 9543eba
* Mon Sep 30 2024 tiwai@suse.de
- mailbox: bcm2835: Fix timeout during suspend mode (git-fixes).
- mailbox: rockchip: fix a typo in module autoloading (git-fixes).
- i2c: designware: fix controller is holding SCL low while ENABLE
  bit is disabled (git-fixes).
- drm/amd/display: handle nulled pipe context in DCE110's
  set_drr() (git-fixes).
- drm/amdgpu: Fix get each xcp macro (git-fixes).
- tomoyo: fallback to realpath if symlink's pathname does not
  exist (git-fixes).
- cxl/pci: Fix to record only non-zero ranges (git-fixes).
- ata: libata-scsi: Fix ata_msense_control() CDL page reporting
  (git-fixes).
- firmware_loader: Block path traversal (git-fixes).
- driver core: Fix a potential null-ptr-deref in
  module_add_driver() (git-fixes).
- driver core: Fix error handling in driver API device_rename()
  (git-fixes).
- ep93xx: clock: Fix off by one in ep93xx_div_recalc_rate()
  (git-fixes).
- iio: magnetometer: ak8975: Fix reading for ak099xx sensors
  (git-fixes).
- iio: chemical: bme680: Fix read/write ops to device by adding
  mutexes (git-fixes).
- ABI: testing: fix admv8818 attr description (git-fixes).
- iio: adc: ad7606: fix standby gpio state to match the
  documentation (git-fixes).
- iio: adc: ad7606: fix oversampling gpio array (git-fixes).
- tty: rp2: Fix reset with non forgiving PCIe host bridges
  (git-fixes).
- USB: class: CDC-ACM: fix race between get_serial and set_serial
  (git-fixes).
- usb: dwc2: drd: fix clock gating on USB role switch (git-fixes).
- usb: cdnsp: Fix incorrect usb_request status (git-fixes).
- USB: usbtmc: prevent kernel-usb-infoleak (git-fixes).
- USB: serial: kobil_sct: restore initial terminal settings
  (git-fixes).
- xhci: Set quirky xHC PCI hosts to D3 _after_ stopping and
  freeing them (git-fixes).
- usb: dwc2: Skip clock gating on Broadcom SoCs (git-fixes).
- spi: atmel-quadspi: Avoid overwriting delay register settings
  (git-fixes).
- spi: spi-fsl-lpspi: Undo runtime PM changes at driver exit time
  (git-fixes).
- spi: atmel-quadspi: Undo runtime PM changes at driver exit time
  (git-fixes).
- rtc: at91sam9: fix OF node leak in probe() error path
  (git-fixes).
- i3c: master: svc: Fix use after free vulnerability in
  svc_i3c_master Driver Due to Race Condition (git-fixes).
- remoteproc: k3-r5: Fix error handling when power-up failed
  (git-fixes).
- remoteproc: imx_rproc: Initialize workqueue earlier (git-fixes).
- remoteproc: imx_rproc: Correct ddr alias for i.MX8M (git-fixes).
- KEYS: prevent NULL pointer dereference in find_asymmetric_key()
  (git-fixes).
- media: i2c: ar0521: Use cansleep version of gpiod_set_value()
  (git-fixes).
- media: ov5675: Fix power on/off delay timings (git-fixes).
- media: sun4i_csi: Implement link validate for sun4i_csi subdev
  (git-fixes).
- media: platform: rzg2l-cru: rzg2l-csi2: Add missing
  MODULE_DEVICE_TABLE (git-fixes).
- media: venus: fix use after free bug in venus_remove due to
  race condition (git-fixes).
- media: uapi/linux/cec.h: cec_msg_set_reply_to: zero flags
  (git-fixes).
- clk: ti: dra7-atl: Fix leak of of_nodes (git-fixes).
- watchdog: imx_sc_wdt: Don't disable WDT in suspend (git-fixes).
- pinctrl: single: fix missing error code in pcs_probe()
  (git-fixes).
- xz: cleanup CRC32 edits from 2018 (git-fixes).
- ata: pata_macio: Use WARN instead of BUG (stable-fixes).
- commit c5ab3ca
* Mon Sep 30 2024 oneukum@suse.com
- i2c: mux: reg: Remove class-based device auto-detection support
  (jsc#PED-10702).
- commit 8000ff4
* Mon Sep 30 2024 oneukum@suse.com
- i2c: mux: gpio: remove support for class-based device
  instantiation (jsc#PED-10702).
- commit 6024383
* Mon Sep 30 2024 oneukum@suse.com
- i2c: mux: gpio: don't fiddle with GPIOLIB internals
  (jsc#PED-10702).
- commit 2656e30
* Mon Sep 30 2024 oneukum@suse.com
- i2c: mux: gpio: adhere to coding style (jsc#PED-10702).
- commit ad61f98
* Mon Sep 30 2024 tiwai@suse.de
- Move upstreamed SCSI patches into sorted section
- commit aba5747
* Mon Sep 30 2024 hare@suse.de
- kcm: Serialise kcm_sendmsg() for the same socket (CVE-2024-44946
  bsc#1230015).
- commit 4310760
* Mon Sep 30 2024 hare@suse.de
- nvme-multipath: avoid hang on inaccessible namespaces
  (bsc#1228244).
- kcm: Serialise kcm_sendmsg() for the same socket
  (CVE-2024-44946,bsc#1230015).
- commit a84ca87
* Mon Sep 30 2024 hare@suse.de
- nvme-multipath: system fails to create generic nvme device
  (bsc#1228244).
- commit 4fc57d2
* Mon Sep 30 2024 ailiop@suse.com
- erofs: fix incorrect symlink detection in fast symlink
  (git-fixes).
- commit 2e1ae75
* Mon Sep 30 2024 ailiop@suse.com
- afs: Don't cross .backup mountpoint from backup volume
  (git-fixes).
- commit f35dae1
* Mon Sep 30 2024 ailiop@suse.com
- afs: Revert "afs: Hide silly-rename files from userspace"
  (git-fixes).
- commit 11353bb
* Fri Sep 27 2024 mwilck@suse.com
- scsi: sd: Fix off-by-one error in
  sd_read_block_characteristics() (bsc#1223848).
- commit 621f2fb
* Fri Sep 27 2024 mwilck@suse.com
- scsi: ibmvfc: Add max_sectors module parameter (bsc#1216223).
- commit af0ff0f
* Fri Sep 27 2024 dsterba@suse.com
- drm/amd/display: Check denominator crb_pipes before used (CVE-2024-46772 bsc#1230772)
- commit 322be4a
* Fri Sep 27 2024 dsterba@suse.com
- blacklist.conf: CVE-2024-46727 bsc#1230707: not applicable
  No OTG code and all return values from
  resource_get_otg_master_for_stream() are checked before use.
- commit f44b1e7
* Fri Sep 27 2024 oneukum@suse.com
- treewide: rename pinctrl_gpio_request_new() (jsc#PED-10702).
- commit 7aa99b3
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: remove pinctrl_gpio_set_config() (jsc#PED-10702).
- commit 8c0560c
* Fri Sep 27 2024 oneukum@suse.com
- gpiolib: add gpio_device_get_base() stub for !GPIOLIB
  (jsc#PED-10702).
- commit 037f285
* Fri Sep 27 2024 oneukum@suse.com
- gpiolib: add gpiod_to_gpio_device() stub for !GPIOLIB
  (jsc#PED-10702).
- commit 7bb9cad
* Fri Sep 27 2024 oneukum@suse.com
- gpiolib: Fix scope-based gpio_device refcounting
  (jsc#PED-10702).
- commit 7f441f3
* Fri Sep 27 2024 oneukum@suse.com
- gpiolib: sysfs: Do unexport GPIO when user asks for it
  (jsc#PED-10702).
- Refresh
  patches.suse/gpio-sysfs-extend-the-critical-section-for-unregiste.patch.
- commit d142469
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: remove pinctrl_gpio_direction_output() (jsc#PED-10702).
- commit 77e2df6
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: cirrus: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 4aa1b74
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: remove pinctrl_gpio_direction_input() (jsc#PED-10702).
- commit be63631
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: cy8c95x0: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 9e924b8
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: mediatek: paris: use new pinctrl GPIO helpers
  (jsc#PED-10702).
- commit d7689d1
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: ingenic: use new pinctrl GPIO helpers (jsc#PED-10702).
- pinctrl: mediatek: common: use new pinctrl GPIO helpers
  (jsc#PED-10702).
- pinctrl: mediatek: moore: use new pinctrl GPIO helpers
  (jsc#PED-10702).
- commit c8be469
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: axp209: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit e10a506
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: axp209: Add support for GPIO3 on the AXP209
  (jsc#PED-10702).
- commit 8e0ba86
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: as3722: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 31022c4
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: st: use new pinctrl GPIO helpers (jsc#PED-10702).
- pinctrl: rk805: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 8127e74
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: allwinner: h616: Add r_i2c pinctrl nodes
  (git-fixes).
- commit 642d7e6
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: imx8-ss-dma: Fix adc0 closing brace location
  (git-fixes).
- commit 970cc49
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: rockchip: Correct vendor prefix for Hardkernel
  ODROID-M1 (git-fixes).
- commit 87f0ae6
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: ocelot: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 419ff06
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: vt8500: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 6b62bb0
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: rockchip: Raise Pinebook Pro's panel backlight
  PWM frequency (git-fixes).
- commit 1582b94
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: intel: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 3674192
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: intel: refine ->irq_set_type() hook (jsc#PED-10702).
- commit 0b317a9
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: cherryview: use new pinctrl GPIO helpers
  (jsc#PED-10702).
- commit 9ec7d21
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: cherryview: reduce scope of
  PIN_CONFIG_BIAS_HIGH_IMPEDANCE case (jsc#PED-10702).
- commit 3b105e2
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: lynxpoint: use new pinctrl GPIO helpers
  (jsc#PED-10702).
- commit 2f166c6
* Fri Sep 27 2024 oneukum@suse.com
- gpio: vf610: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 3db46cf
* Fri Sep 27 2024 oneukum@suse.com
- gpio: rockchip: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 8f6bb80
* Fri Sep 27 2024 oneukum@suse.com
- gpio: pxa: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit d6b6f8b
* Fri Sep 27 2024 oneukum@suse.com
- gpio: mvebu: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 362264e
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: rockchip: Correct the Pinebook Pro battery design
  capacity (git-fixes).
- commit 3b2ebbf
* Fri Sep 27 2024 oneukum@suse.com
- gpio: Use device_get_match_data() (jsc#PED-10702).
- commit 005bb99
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: exynos: exynos7885-jackpotlte: Correct RAM amount
  to 4GB (git-fixes).
- commit 1059c29
* Fri Sep 27 2024 oneukum@suse.com
- pinctrl: remove pinctrl_gpio_free() (jsc#PED-10702).
- commit 71dc629
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: signal: Fix some under-bracketed UAPI macros (git-fixes).
- commit 9704ff3
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: rockchip: override BIOS_DISABLE signal via GPIO
  hog on RK3399 Puma (git-fixes).
- commit 6052a8c
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: rockchip: fix eMMC/SPI corruption when audio has
  been used on RK3399 Puma (git-fixes).
- commit 8b3743b
* Fri Sep 27 2024 msuchanek@suse.de
- Update
  patches.suse/powerpc-pseries-make-max-polling-consistent-for-long.patch
  (bsc#1215199 jsc#PED-10954).
- Update
  patches.suse/security-integrity-fix-pointer-to-ESL-data-and-.patch
  (bsc#1012628 jsc#PED-5085 jsc#PED-10954).
- commit ec9be2c
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: dts: rockchip: fix PMIC interrupt pin in pinctrl for
  ROCK Pi E (git-fixes).
- commit 7527015
* Fri Sep 27 2024 andrea.porta@suse.com
- arm64: acpi: Move get_cpu_for_acpi_id() to a header (git-fixes).
- commit 42389f0
* Fri Sep 27 2024 iivanov@suse.de
- ipmi:ssif: Improve detecting during probing (bsc#1228771)
  Move patch into the sorted section.
- commit 77cf6fc
* Fri Sep 27 2024 jslaby@suse.cz
- Update
  patches.suse/ASoC-Intel-Boards-Fix-NULL-pointer-deref-in-BYT-CHT--0cc6548.patch
  (git-fixes CVE-2024-46793 bsc#1230824).
- Update
  patches.suse/ASoC-cs-amp-lib-Fix-NULL-pointer-crash-if-efi.get_va.patch
  (jsc#PED-9993 jsc#PED-10202 CVE-2024-43896 bsc#1229751).
- Update
  patches.suse/ASoc-PCM6240-Return-directly-after-a-failed-devm_kza.patch
  (jsc#PED-9993 jsc#PED-10202 CVE-2024-43822 bsc#1229343).
- Update
  patches.suse/Bluetooth-btnxpuart-Fix-random-crash-seen-while-remo.patch
  (jsc#PED-10412 CVE-2024-46680 bsc#1230557).
- commit 7894abc
* Fri Sep 27 2024 jslaby@suse.cz
- Update patches.suse/ALSA-line6-Fix-racy-access-to-midibuf.patch
  (stable-fixes CVE-2024-44954 bsc#1230176).
- Update
  patches.suse/ASoC-dapm-Fix-UAF-for-snd_soc_pcm_runtime-object.patch
  (git-fixes CVE-2024-46798 bsc#1230830).
- Update
  patches.suse/Bluetooth-btnxpuart-Fix-Null-pointer-dereference-in-.patch
  (stable-fixes CVE-2024-46749 bsc#1230780).
- Update
  patches.suse/Bluetooth-btnxpuart-Shutdown-timer-and-prevent-rearm.patch
  (stable-fixes CVE-2024-44962 bsc#1230213).
- Update
  patches.suse/HID-amd_sfh-free-driver_data-after-destroying-hid-de.patch
  (stable-fixes CVE-2024-46746 bsc#1230751).
- Update
  patches.suse/HID-cougar-fix-slab-out-of-bounds-Read-in-cougar_rep.patch
  (stable-fixes CVE-2024-46747 bsc#1230752).
- Update patches.suse/Input-MT-limit-max-slots.patch (stable-fixes
  CVE-2024-45008 bsc#1230248).
- Update
  patches.suse/Input-uinput-reject-requests-with-unreasonable-numbe.patch
  (stable-fixes CVE-2024-46745 bsc#1230748).
- Update
  patches.suse/KVM-arm64-Make-ICC_-SGI-_EL1-undef-in-the-absence-of.patch
  (git-fixes CVE-2024-46707 bsc#1230582).
- Update
  patches.suse/KVM-s390-fix-validity-interception-issue-when-gisa-is-switched-off.patch
  (git-fixes bsc#1229167 CVE-2024-45005 bsc#1230173).
- Update
  patches.suse/PCI-Add-missing-bridge-lock-to-pci_bus_lock.patch
  (stable-fixes CVE-2024-46750 bsc#1230783).
- Update
  patches.suse/Squashfs-sanity-check-symbolic-link-size.patch
  (git-fixes CVE-2024-46744 bsc#1230747).
- Update
  patches.suse/VMCI-Fix-use-after-free-when-removing-resource-in-vm.patch
  (git-fixes CVE-2024-46738 bsc#1230731).
- Update
  patches.suse/bpf-Fix-a-kernel-verifier-crash-in-stacksafe.patch
  (bsc#1225903 CVE-2024-45020 bsc#1230433).
- Update
  patches.suse/btrfs-fix-race-between-direct-IO-write-and-fsync-whe.patch
  (git-fixes CVE-2024-46734 bsc#1230726).
- Update
  patches.suse/can-bcm-Remove-proc-entry-when-dev-is-unregistered.patch
  (git-fixes CVE-2024-46771 bsc#1230766).
- Update
  patches.suse/can-mcp251x-fix-deadlock-if-an-interrupt-occurs-duri.patch
  (git-fixes CVE-2024-46791 bsc#1230821).
- Update
  patches.suse/char-xillybus-Check-USB-endpoints-when-probing-devic.patch
  (git-fixes CVE-2024-45011 bsc#1230440).
- Update
  patches.suse/char-xillybus-Don-t-destroy-workqueue-from-work-item.patch
  (stable-fixes CVE-2024-45007 bsc#1230175).
- Update
  patches.suse/dmaengine-altera-msgdma-properly-free-descriptor-in-.patch
  (stable-fixes CVE-2024-46716 bsc#1230715).
- Update
  patches.suse/driver-core-Fix-uevent_show-vs-driver-detach-race.patch
  (git-fixes CVE-2024-44952 bsc#1230178).
- Update
  patches.suse/driver-iio-add-missing-checks-on-iio_info-s-callback.patch
  (stable-fixes CVE-2024-46715 bsc#1230700).
- Update
  patches.suse/drm-amd-display-Assign-linear_pitch_alignment-even-f.patch
  (stable-fixes CVE-2024-46732 bsc#1230711).
- Update
  patches.suse/drm-amd-display-Check-UnboundedRequestEnabled-s-valu.patch
  (stable-fixes CVE-2024-46778 bsc#1230776).
- Update
  patches.suse/drm-amd-display-Check-denominator-pbn_div-before-use.patch
  (stable-fixes CVE-2024-46773 bsc#1230791).
- Update
  patches.suse/drm-amd-display-Check-index-for-aux_rd_interval-befo.patch
  (stable-fixes CVE-2024-46728 bsc#1230703).
- Update
  patches.suse/drm-amd-display-Ensure-array-index-tg_inst-won-t-be-.patch
  (stable-fixes CVE-2024-46730 bsc#1230701).
- Update
  patches.suse/drm-amd-display-Ensure-index-calculation-will-not-ov.patch
  (stable-fixes CVE-2024-46726 bsc#1230706).
- Update
  patches.suse/drm-amd-display-Run-DC_LOG_DC-after-checking-link-li.patch
  (stable-fixes CVE-2024-46776 bsc#1230775).
- Update
  patches.suse/drm-amd-display-Skip-wbscl_set_scaler_filter-if-filt.patch
  (stable-fixes CVE-2024-46714 bsc#1230699).
- Update
  patches.suse/drm-amd-display-avoid-using-null-object-of-framebuff.patch
  (git-fixes CVE-2024-46694 bsc#1230511).
- Update
  patches.suse/drm-amd-pm-fix-the-Out-of-bounds-read-warning.patch
  (stable-fixes CVE-2024-46731 bsc#1230709).
- Update
  patches.suse/drm-amdgpu-Fix-out-of-bounds-read-of-df_v1_7_channel.patch
  (stable-fixes CVE-2024-46724 bsc#1230725).
- Update
  patches.suse/drm-amdgpu-Fix-out-of-bounds-write-warning.patch
  (stable-fixes CVE-2024-46725 bsc#1230705).
- Update
  patches.suse/drm-amdgpu-Forward-soft-recovery-errors-to-userspace.patch
  (stable-fixes CVE-2024-44961 bsc#1230207).
- Update patches.suse/drm-amdgpu-Validate-TA-binary-size.patch
  (stable-fixes CVE-2024-44977 bsc#1230217).
- Update
  patches.suse/drm-amdgpu-fix-dereference-after-null-check.patch
  (stable-fixes CVE-2024-46720 bsc#1230724).
- Update
  patches.suse/drm-amdgpu-fix-mc_data-out-of-bounds-read-warning.patch
  (stable-fixes CVE-2024-46722 bsc#1230712).
- Update
  patches.suse/drm-amdgpu-fix-ucode-out-of-bounds-read-warning.patch
  (stable-fixes CVE-2024-46723 bsc#1230702).
- Update
  patches.suse/drm-mgag200-Bind-I2C-lifetime-to-DRM-device.patch
  (git-fixes CVE-2024-44967 bsc#1230224).
- Update
  patches.suse/drm-msm-dpu-cleanup-FB-if-dpu_format_populate_layout.patch
  (git-fixes CVE-2024-44982 bsc#1230204).
- Update
  patches.suse/drm-msm-dpu-move-dpu_encoder-s-connector-assignment-.patch
  (git-fixes CVE-2024-45015 bsc#1230444).
- Update
  patches.suse/drm-vmwgfx-Fix-prime-with-external-buffers.patch
  (git-fixes CVE-2024-46709 bsc#1230539).
- Update
  patches.suse/fs-netfs-fscache_cookie-add-missing-n_accesses-check.patch
  (bsc#1229455 CVE-2024-45000 bsc#1230170).
- Update
  patches.suse/fscache-delete-fscache_cookie_lru_timer-when-fscache-.patch
  (bsc#1230602 CVE-2024-46786 bsc#1230813).
- Update
  patches.suse/fuse-Initialize-beyond-EOF-page-contents-before-setti.patch
  (bsc#1229456 CVE-2024-44947).
- Update
  patches.suse/hwmon-adc128d818-Fix-underflows-seen-when-writing-li.patch
  (stable-fixes CVE-2024-46759 bsc#1230814).
- Update
  patches.suse/hwmon-lm95234-Fix-underflows-seen-when-writing-limit.patch
  (stable-fixes CVE-2024-46758 bsc#1230812).
- Update
  patches.suse/hwmon-nct6775-core-Fix-underflows-seen-when-writing-.patch
  (stable-fixes CVE-2024-46757 bsc#1230809).
- Update
  patches.suse/hwmon-w83627ehf-Fix-underflows-seen-when-writing-lim.patch
  (stable-fixes CVE-2024-46756 bsc#1230806).
- Update
  patches.suse/media-dvb-usb-v2-af9035-Fix-null-ptr-deref-in-af9035.patch
  (git-fixes CVE-2023-52915 bsc#1230270).
- Update
  patches.suse/misc-fastrpc-Fix-double-free-of-buf-in-error-path.patch
  (git-fixes CVE-2024-46741 bsc#1230749).
- Update
  patches.suse/mmc-mmc_test-Fix-NULL-dereference-on-allocation-fail.patch
  (git-fixes CVE-2024-45028 bsc#1230450).
- Update
  patches.suse/msft-hv-3046-uio_hv_generic-Fix-kernel-NULL-pointer-dereference-i.patch
  (git-fixes CVE-2024-46739 bsc#1230732).
- Update
  patches.suse/msft-hv-3048-net-mana-Fix-error-handling-in-mana_create_txq-rxq-s.patch
  (git-fixes CVE-2024-46784 bsc#1230771).
- Update
  patches.suse/net-ethernet-mtk_wed-fix-use-after-free-panic-in-mtk.patch
  (git-fixes CVE-2024-44997 bsc#1230232).
- Update
  patches.suse/net-mana-Fix-RX-buf-alloc_size-alignment-and-atomic-.patch
  (bsc#1229086 CVE-2024-45001 bsc#1230244).
- Update
  patches.suse/net-phy-Fix-missing-of_node_put-for-leds.patch
  (git-fixes CVE-2024-46767 bsc#1230787).
- Update
  patches.suse/nfc-pn533-Add-poll-mod-list-filling-check.patch
  (git-fixes CVE-2024-46676 bsc#1230535).
- Update
  patches.suse/nilfs2-fix-missing-cleanup-on-rollforward-recovery-error.patch
  (git-fixes CVE-2024-46781 bsc#1230768).
- Update
  patches.suse/nilfs2-protect-references-to-superblock-parameters-exposed-in-sysfs.patch
  (git-fixes CVE-2024-46780 bsc#1230808).
- Update
  patches.suse/nouveau-firmware-use-dma-non-coherent-allocator.patch
  (git-fixes CVE-2024-45012 bsc#1230441).
- Update
  patches.suse/nvmet-tcp-fix-kernel-crash-if-commands-allocation-fa.patch
  (git-fixes CVE-2024-46737 bsc#1230730).
- Update
  patches.suse/pci-hotplug-pnv_php-Fix-hotplug-driver-crash-on-Powe.patch
  (stable-fixes CVE-2024-46761 bsc#1230761).
- Update patches.suse/perf-Fix-event-leak-upon-exit.patch
  (git-fixes CVE-2024-43870 bsc#1229494).
- Update
  patches.suse/pinctrl-single-fix-potential-NULL-dereference-in-pcs.patch
  (git-fixes CVE-2024-46685 bsc#1230515).
- Update
  patches.suse/powerpc-qspinlock-Fix-deadlock-in-MCS-queue.patch
  (bac#1230295 ltc#206656 CVE-2024-46797 bsc#1230831).
- Update
  patches.suse/powerpc-rtas-Prevent-Spectre-v1-gadget-construction-.patch
  (bsc#1227487 CVE-2024-46774 bsc#1230767).
- Update
  patches.suse/s390-dasd-fix-error-recovery-leading-to-data-corruption-on-ESE-devices.patch
  (git-fixes bsc#1229452 CVE-2024-45026 bsc#1230454).
- Update
  patches.suse/s390-sclp-Prevent-release-of-buffer-in-I-O.patch
  (git-fixes bsc#1229169 CVE-2024-44969 bsc#1230200).
- Update
  patches.suse/soc-qcom-cmd-db-Map-shared-memory-as-WC-not-WB.patch
  (git-fixes CVE-2024-46689 bsc#1230524).
- Update
  patches.suse/thunderbolt-Mark-XDomain-as-unplugged-when-router-is.patch
  (stable-fixes CVE-2024-46702 bsc#1230589).
- Update
  patches.suse/tty-serial-fsl_lpuart-mark-last-busy-before-uart_add.patch
  (git-fixes CVE-2024-46706 bsc#1230580).
- Update
  patches.suse/usb-dwc3-core-Prevent-USB-core-invalid-event-buffer-.patch
  (stable-fixes CVE-2024-46675 bsc#1230533).
- Update
  patches.suse/usb-dwc3-st-fix-probed-platform-device-ref-count-on-.patch
  (git-fixes CVE-2024-46674 bsc#1230507).
- Update
  patches.suse/usb-gadget-core-Check-for-unset-descriptor.patch
  (git-fixes CVE-2024-44960 bsc#1230191).
- Update
  patches.suse/usb-typec-ucsi-Fix-null-pointer-dereference-in-trace.patch
  (stable-fixes CVE-2024-46719 bsc#1230722).
- Update
  patches.suse/wifi-brcmfmac-cfg80211-Handle-SSID-based-pmksa-delet.patch
  (git-fixes CVE-2024-46672 bsc#1230459).
- Update
  patches.suse/wifi-mwifiex-Do-not-return-unused-priv-in-mwifiex_ge.patch
  (stable-fixes CVE-2024-46755 bsc#1230802).
- Update
  patches.suse/wifi-rtw88-usb-schedule-rx-work-after-everything-is-.patch
  (stable-fixes CVE-2024-46760 bsc#1230753).
- Update
  patches.suse/x86-mm-Fix-pti_clone_pgtable-alignment-assumption.patch
  (git-fixes CVE-2024-44965 bsc#1230221).
- Update
  patches.suse/x86-mtrr-Check-if-fixed-MTRRs-exist-before-saving-them.patch
  (git-fixes CVE-2024-44948 bsc#1230174).
- Update
  patches.suse/xhci-Fix-Panther-point-NULL-pointer-deref-at-full-sp.patch
  (git-fixes CVE-2024-45006 bsc#1230247).
- commit 6da06c4
* Fri Sep 27 2024 glass.su@suse.com
- Update patches.suse/gfs2-Fix-NULL-pointer-dereference-in-gfs2_log_flush.patch (bsc#1230948)
- commit cc71a7c
* Thu Sep 26 2024 vbabka@suse.cz
- userfaultfd: fix checks for huge PMDs (CVE-2024-46787
  bsc#1230815).
- commit a236c90
* Thu Sep 26 2024 lhenriques@suse.de
- cachefiles: Fix non-taking of sb_writers around set/removexattr
  (bsc#1231008).
- commit 1b01b3e
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: remove pinctrl_gpio_request() (jsc#PED-10702).
- commit ff2404a
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: remove pinctrl_gpio_can_use_line() (jsc#PED-10702).
- commit 7918d0b
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: starfive: jh7100: use new pinctrl GPIO helpers
  (jsc#PED-10702).
- commit 0ccc078
* Thu Sep 26 2024 oneukum@suse.com
- gpio: cdev: use pinctrl_gpio_can_use_line_new() (jsc#PED-10702).
- commit 1b88aa5
* Thu Sep 26 2024 oneukum@suse.com
- gpio: cdev: open-code to_gpio_chardev_data() (jsc#PED-10702).
- commit 6b3af87
* Thu Sep 26 2024 oneukum@suse.com
- gpio: aspeed: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 4441498
* Thu Sep 26 2024 oneukum@suse.com
- gpio: em: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 134cfbd
* Thu Sep 26 2024 nmorey@suse.com
- RDMA/rtrs-clt: Reset cid to con_num - 1 to stay in bounds (git-fixes)
- commit a6683f0
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: nuvoton: npcm7xx: use new pinctrl GPIO helpers
  (jsc#PED-10702).
- commit 3daa651
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: renesas: rzg2l: Use devm_clk_get_enabled() helper
  (jsc#PED-10702).
- commit 4301336
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: stm32: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit c9b46df
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: bcm: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 3f31e9c
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: spear: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 05adea8
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: starfive: jh7110: use new pinctrl GPIO helpers
  (jsc#PED-10702).
- commit 4850715
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: starfive: jh7110: Add system pm ops to save and
  restore context (jsc#PED-10702).
- commit 31eec21
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: renesas: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit adfbb33
* Thu Sep 26 2024 oneukum@suse.com
- gpio: tegra: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 75680fc
* Thu Sep 26 2024 jslaby@suse.cz
- PCI: dwc: Expose dw_pcie_ep_exit() to module (git-fixes).
- Refresh
  patches.suse/PCI-dwc-endpoint-Introduce-.pre_init-and-.deinit.patch.
- commit 34c9950
* Thu Sep 26 2024 oneukum@suse.com
- gpio: rcar: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 71715fc
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: provide new GPIO-to-pinctrl glue helpers
  (jsc#PED-10702).
- commit c3fc58c
* Thu Sep 26 2024 oneukum@suse.com
- pinctrl: remove unneeded extern specifiers from consumer.h
  (jsc#PED-10702).
- commit ca7fbca
* Thu Sep 26 2024 jslaby@suse.cz
- PCI: xilinx-nwl: Clean up clock on probe failure/removal
  (git-fixes).
- PCI: xilinx-nwl: Fix off-by-one in INTx IRQ handler (git-fixes).
- PCI: qcom-ep: Enable controller resources like PHY only after
  refclk is available (git-fixes).
- PCI: kirin: Fix buffer overflow in kirin_pcie_parse_port()
  (git-fixes).
- PCI: keystone: Fix if-statement expression in ks_pcie_quirk()
  (git-fixes).
- PCI: imx6: Fix missing call to phy_power_off() in error handling
  (git-fixes).
- PCI: dra7xx: Fix error handling when IRQ request fails in probe
  (git-fixes).
- PCI: dra7xx: Fix threaded IRQ request for "dra7xx-pcie-main"
  IRQ (git-fixes).
- PCI: Wait for Link before restoring Downstream Buses
  (git-fixes).
- commit 1528eee
* Wed Sep 25 2024 msuchanek@suse.de
- powerpc/hvcall: Reorder Nestedv2 hcall opcodes (jsc#PED-11016).
- commit 9c064d8
* Wed Sep 25 2024 dsterba@suse.com
- WIP DO NOT PUSH btrfs: fix a use-after-free when hitting errors inside btrfs_submit_chunk() (CVE-2024-46687 bsc#1230518)
- commit 17b4a47
* Wed Sep 25 2024 msuchanek@suse.de
- KVM: PPC: add missing MODULE_DESCRIPTION() macros
  (jsc#PED-11016).
- KVM: PPC: Book3S HV nestedv2: Keep nested guest HASHPKEYR in
  sync (jsc#PED-11016).
- KVM: PPC: Book3S HV: Add one-reg interface for HASHPKEYR
  register (jsc#PED-11016).
- KVM: PPC: Book3S HV nestedv2: Keep nested guest HASHKEYR in sync
  (jsc#PED-11016).
- KVM: PPC: Book3S HV: Add one-reg interface for HASHKEYR register
  (jsc#PED-11016).
- KVM: PPC: Book3S HV nestedv2: Keep nested guest DEXCR in sync
  (jsc#PED-11016).
- KVM: PPC: Book3S HV: Add one-reg interface for DEXCR register
  (jsc#PED-11016).
- KVM: PPC: Book3S HV: Fix the get_one_reg of SDAR (jsc#PED-11016).
- KVM: PPC: Book3S HV nestedv2: Fix doorbell emulation
  (jsc#PED-11016).
- KVM: PPC: Book3S HV nestedv2: Add DPDES support in helper
  library for Guest state buffer (jsc#PED-11016).
- KVM: PPC: Book3S HV nestedv2: Add support for reading VPA
  counters for pseries guests (jsc#PED-11016).
- KVM: PPC: Book3S HV nestedv2: Fix an error handling path in
  gs_msg_ops_kvmhv_nestedv2_config_fill_info() (jsc#PED-11016).
- KVM: PPC: code cleanup for kvmppc_book3s_irqprio_deliver
  (jsc#PED-11016).
- KVM: PPC: Book3S HV nestedv2: Cancel pending DEC exception
  (jsc#PED-11016).
- powerpc: Fix typos (jsc#PED-11016).
- KVM: PPC: Book3S HV: Fix L2 guest reboot failure due to empty
  'arch_compat' (jsc#PED-11016).
- Refresh patches.suse/powerpc-Add-Power11-architected-and-raw-mode.patch
- KVM: PPC: Book3S HV nestedv2: Do not cancel pending decrementer
  exception (jsc#PED-11016).
- KVM: PPC: Reduce reliance on analyse_instr() in mmio emulation
  (jsc#PED-11016).
- KVM: PPC: Book3S HV nestedv2: Register the VPA with the L0
  (jsc#PED-11016).
- KVM: PPC: Book3S HV nestedv2: Do not call H_COPY_TOFROM_GUEST
  (jsc#PED-11016).
- KVM: PPC: Book3S HV nestedv2: Avoid msr check in
  kvmppc_handle_exit_hv() (jsc#PED-11016).
- KVM: PPC: Book3S HV nestedv2: Do not inject certain interrupts
  (jsc#PED-11016).
- KVM: PPC: Book3S HV nestedv2: Ensure LPCR_MER bit is passed
  to the L0 (jsc#PED-11016).
- KVM: PPC: Book3S HV nestedv2: Get the PID only if needed to
  copy tofrom a guest (jsc#PED-11016).
- KVM: PPC: Book3S HV nestedv2: Do not check msr on hcalls
  (jsc#PED-11016).
- KVM: PPC: Book3S HV nestedv2: Avoid reloading the tb offset
  (jsc#PED-11016).
- KVM: PPC: Book3S HV nestedv2: Invalidate RPT before deleting
  a guest (jsc#PED-11016).
- docs: powerpc: Document nested KVM on POWER (jsc#PED-11016).
- KVM: PPC: Add support for nestedv2 guests (jsc#PED-11016).
- Refresh patches.suse/powerpc-Add-Power11-architected-and-raw-mode.patch
- KVM: PPC: Book3s HV: Hold LPIDs in an unsigned long
  (jsc#PED-11016).
- KVM: PPC: Add helper library for Guest State Buffers
  (jsc#PED-11016).
- KVM: PPC: Book3S HV: Introduce low level MSR accessor
  (jsc#PED-11016).
- Refresh patches.suse/KVM-PPC-Book3S-HV-Handle-pending-exceptions-on-guest.patch
- KVM: PPC: Book3S HV: Use accessors for VCPU registers
  (jsc#PED-11016).
- KVM: PPC: Use accessors for VCORE registers (jsc#PED-11016).
- KVM: PPC: Use accessors for VCPU registers (jsc#PED-11016).
- KVM: PPC: Rename accessor generator macros (jsc#PED-11016).
- KVM: PPC: Introduce FPR/VR accessor functions (jsc#PED-11016).
- KVM: PPC: Always use the GPR accessors (jsc#PED-11016).
- powerpc: Remove extern from function implementations
  (jsc#PED-11016).
- powerpc: Use NULL instead of 0 for null pointers (jsc#PED-11016).
- docs: move powerpc under arch (jsc#PED-11016).
- Documentation/powerpc: Fix ptrace request names (jsc#PED-11016).
- powerpc: Make virt_to_pfn() a static inline (jsc#PED-11016).
- powerpc/inst: add PPC_TLBILX_LPID (jsc#PED-11016).
- Documentation: Fix typos (jsc#PED-11016).
- docs: move s390 under arch (jsc#PED-11016).
- Refresh patches.suse/0012-s390-kexec-refactor-for-kernel-Kconfig.kexec.patch
- Documentation: PCI: Update cross references to .rst files
  (jsc#PED-11016).
- Refresh patches.suse/PCI-Fix-typos-in-docs-and-comments.patch
- powerpc: Mark writes registering ipi to host cpu through kvm
  and polling (jsc#PED-11016).
- powerpc: kvmppc_unmap_free_pmd() pte_offset_kernel()
  (jsc#PED-11016).
- commit 9548a83
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: generic: use new pinctrl GPIO helpers (jsc#PED-10702).
- commit 28e520e
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: provide gpio_device_get_base() (jsc#PED-10702).
- commit ba12b28
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: provide gpiod_to_gpio_device() (jsc#PED-10702).
- commit 4315666
* Wed Sep 25 2024 msuchanek@suse.de
- blacklist.conf: Remove KVM nested api v2 patches
- commit fb61091
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: provide gpio_device_to_device() (jsc#PED-10702).
- commit ce5fe76
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: provide gpio_device_find_by_fwnode() (jsc#PED-10702).
- commit 6fb73ed
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: replace find_chip_by_name() with
  gpio_device_find_by_label() (jsc#PED-10702).
- commit b6fb644
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: reluctantly provide gpio_device_get_chip()
  (jsc#PED-10702).
- commit d57e161
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: provide gpio_device_get_desc() (jsc#PED-10702).
- Refresh
  patches.suse/gpio-prevent-potential-speculation-leaks-in-gpio_dev.patch.
- commit 741b92b
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: make gpiochip_get_desc() public (jsc#PED-10702).
- commit 35e1b77
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: extend the critical sections of lookup tables
  (jsc#PED-10702).
- commit 8d2f2d0
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: unexport gpiod_set_transitory() (jsc#PED-10702).
- commit 72adbe3
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: provide and use gpiod_line_state_notify()
  (jsc#PED-10702).
- commit d536b6a
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: add a second blocking notifier to struct gpio_device
  (jsc#PED-10702).
- commit 6f4079d
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: rename the gpio_device notifier (jsc#PED-10702).
- Refresh
  patches.suse/gpiolib-cdev-fix-use-after-free-in-lineinfo_changed_notify.patch.
- commit 6e12643
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: Replace open coded
  gpiochip_irqchip_add_allocated_domain() (jsc#PED-10702).
- commit 142fd0e
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: Split out gpiochip_irqchip_add_allocated_domain()
  helper (jsc#PED-10702).
- commit 68fd22e
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: Do not assign error pointer to the GPIO IRQ chip domain
  (jsc#PED-10702).
- commit aa812c2
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: Factor out gpiochip_simple_create_domain()
  (jsc#PED-10702).
- commit 400479d
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: Make gpiochip_hierarchy_add_domain() return domain
  (jsc#PED-10702).
- commit 11e0548
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: Do not alter GPIO chip fwnode member (jsc#PED-10702).
- commit 086cbe7
* Wed Sep 25 2024 oneukum@suse.com
- gpiolib: Do not unexport GPIO on freeing (jsc#PED-10702).
- commit 5249893
* Wed Sep 25 2024 ailiop@suse.com
- exfat: fix memory leak in exfat_load_bitmap() (git-fixes).
- commit 9f477b0
* Wed Sep 25 2024 sjaeckel@suse.de
- net: ip_tunnel: prevent perpetual headroom growth
  (CVE-2024-26804 bsc#1222629).
- commit 0ca3b23
* Wed Sep 25 2024 oneukum@suse.com
- Input: ps2-gpio - use IRQF_NO_AUTOEN flag in request_irq()
  (git-fixes).
- commit 45cee3b
* Wed Sep 25 2024 oneukum@suse.com
- blacklist.conf: too risky
- commit f0e13c3
* Wed Sep 25 2024 oneukum@suse.com
- Input: ilitek_ts_i2c - avoid wrong input subsystem sync
  (git-fixes).
- commit e5e587b
* Wed Sep 25 2024 oneukum@suse.com
- Input: tsc2004/5 - fix reset handling on probe (git-fixes).
- commit 1366de4
* Wed Sep 25 2024 oneukum@suse.com
- Input: tsc2004/5 - do not hard code interrupt trigger
  (git-fixes).
- commit 110dbdb
* Wed Sep 25 2024 oneukum@suse.com
- Input: tsc2004/5 - use device core to create driver-specific
  device attributes (git-fixes).
- commit 958966c
* Wed Sep 25 2024 oneukum@suse.com
- Input: adp5588-keys - fix check on return code (git-fixes).
- commit d15133c
* Wed Sep 25 2024 tzimmermann@suse.com
- drm/amd/display: Fix incorrect size calculation for loop (bsc#1230704 CVE-2024-46729)
- commit 55d78a7
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Fix ah error counter in sw stat not increasing (git-fixes)
- commit d7bebcf
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/mlx5: Fix MR cache temp entries cleanup (git-fixes)
- commit b0aa848
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/mlx5: Drop redundant work canceling from clean_keys() (git-fixes)
- commit 6800d7e
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/irdma: fix error message in irdma_modify_qp_roce() (git-fixes)
- commit dcf63e1
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/cxgb4: Added NULL check for lookup_atid (git-fixes)
- commit 23d3195
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/mlx5: Obtain upper net device only when needed (git-fixes)
- commit ca2d8dc
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Fix restricted __le16 degrades to integer issue (git-fixes)
- commit 4481358
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Optimize hem allocation performance (git-fixes)
- commit 7afe440
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Fix 1bit-ECC recovery address in non-4K OS (git-fixes)
- commit 25e36c2
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Fix VF triggering PF reset in abnormal interrupt handler (git-fixes)
- commit a18704a
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Fix spin_unlock_irqrestore() called with IRQs enabled (git-fixes)
- commit 7b15e64
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Fix the overflow risk of hem_list_calc_ba_range() (git-fixes)
- commit 60eb35c
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Fix Use-After-Free of rsv_qp on HIP08 (git-fixes)
- commit 3ab1ca2
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/hns: Don't modify rq next block addr in HIP09 QPC (git-fixes)
- commit 7100eb8
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/mlx5: Limit usage of over-sized mkeys from the MR cache (git-fixes)
- commit 914ed66
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/mlx5: Fix counter update on MR cache mkey creation (git-fixes)
- commit 60e75bb
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/erdma: Return QP state in erdma_query_qp (git-fixes)
- commit 09a59c3
* Wed Sep 25 2024 nmorey@suse.com
- IB/core: Fix ib_cache_setup_one error flow cleanup (git-fixes)
- commit 38bf526
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/rtrs: Reset hb_missed_cnt after receiving other traffic from peer (git-fixes)
- commit c4f28a8
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/iwcm: Fix WARNING:at_kernel/workqueue.c:#check_flush_dependency (git-fixes)
- commit 0456b72
* Wed Sep 25 2024 nmorey@suse.com
- RDMA/core: Remove unused declaration rdma_resolve_ip_route() (git-fixes)
- commit 4cb7201
* Wed Sep 25 2024 jslaby@suse.cz
- blacklist.conf: add one for clang and one PCI git-fixes
- commit b26aea4
* Wed Sep 25 2024 jslaby@suse.cz
- Revert "PCI: Extend ACS configurability (bsc#1228090)." (bsc#1229019)
  This reverts commit 571e4310e81312c847a5caee7e45e66aeea2a169. It breaks
  ACS on certain platforms. Even 6.11 is affected. So drop for now and
  investigate.
- commit 3b92a44
* Tue Sep 24 2024 dsterba@suse.com
- blacklist.conf: CVE-2024-44972 bsc#1230212: not applicable
  Subpage code exists but zoned mode is not enabled being hidden behind
  CONFIG_BTRFS_DEBUG.
- commit ed17920
* Tue Sep 24 2024 dsterba@suse.com
- btrfs: handle errors from btrfs_dec_ref() properly (CVE-2024-46753 bsc#1230796)
- commit 3e3b2cb
* Tue Sep 24 2024 oneukum@suse.com
- net: pse-pd: Use EOPNOTSUPP error code instead of ENOTSUPP
  (git-fixes).
- blacklist.conf: kABI not yet an issue in SP7
- commit c18dd33
* Tue Sep 24 2024 oneukum@suse.com
- blacklist.conf: kABI
- commit 05421bb
* Tue Sep 24 2024 oneukum@suse.com
- media: vicodec: allow en/decoder cmd w/o CAPTURE (git-fixes).
- commit 62ef4d1
* Tue Sep 24 2024 oneukum@suse.com
- media: qcom: camss: Remove use_count guard in stop_streaming
  (git-fixes).
- commit ef85228
* Tue Sep 24 2024 oneukum@suse.com
- Revert "media: tuners: fix error return code of
  hybrid_tuner_request_state()" (git-fixes).
- drivers: media: dvb-frontends/rtl2830: fix an out-of-bounds
  write error (git-fixes).
- drivers: media: dvb-frontends/rtl2832: fix an out-of-bounds
  write error (git-fixes).
- commit 48dc3a9
* Tue Sep 24 2024 sjaeckel@suse.de
- net: bridge: xmit: make sure we have at least eth header len
  bytes (CVE-2024-38538 bsc#1226606).
- commit 2548071
* Tue Sep 24 2024 jlee@suse.com
- PKCS#7: Check codeSigning EKU of certificates in PKCS#7
  (bsc#1226666).
- commit dbae63e
* Mon Sep 23 2024 jgross@suse.com
- xen/swiotlb: fix allocated size (git-fixes).
- commit 199871d
* Mon Sep 23 2024 jgross@suse.com
- xen/swiotlb: add alignment check for dma buffers (bsc#1229928).
- commit 0ffbc04
* Mon Sep 23 2024 jgross@suse.com
- xen: tolerate ACPI NVS memory overlapping with Xen allocated
  memory (bsc#1226003).
- commit 3dc14d8
* Mon Sep 23 2024 jgross@suse.com
- xen: allow mapping ACPI data using a different physical address
  (bsc#1226003).
- commit 0928eec
* Mon Sep 23 2024 dsterba@suse.com
- x86/tdx: Fix data leak in mmio_read() (CVE-2024-46794 bsc#1230825)
- commit 9a2a1c2
* Mon Sep 23 2024 dsterba@suse.com
- tcp_bpf: fix return value of tcp_bpf_sendmsg() (CVE-2024-46783 bsc#1230810)
- commit eb9d143
* Mon Sep 23 2024 dwagner@suse.de
- nvme: fix namespace removal list (git-fixes).
- commit b45d192
* Mon Sep 23 2024 dsterba@suse.com
- ublk_drv: fix NULL pointer dereference in ublk_ctrl_start_recovery() (CVE-2024-46735 bsc#1230727)
- commit 23e039f
* Mon Sep 23 2024 dsterba@suse.com
- Update references for patches.suse/nvmet-tcp-fix-kernel-crash-if-commands-allocation-fa.patch (CVE-2024-46737 bsc#1230730)
- commit 8ce7f58
* Mon Sep 23 2024 jgross@suse.com
- xen: add capability to remap non-RAM pages to different PFNs
  (bsc#1226003).
- commit 47109fd
* Mon Sep 23 2024 dwagner@suse.de
- nvme: fix error-handling for io_uring nvme-passthrough
  (git-fixes).
  Refresh:
  - patches.suse/nvme-use-bio_integrity_map_user.patch
- commit ff79e52
* Mon Sep 23 2024 dsterba@suse.com
- net/mlx5e: SHAMPO, Fix incorrect page release (CVE-2024-46717 bsc#1230719)
- commit d6a30a9
* Mon Sep 23 2024 jgross@suse.com
- xen: move max_pfn in xen_memory_setup() out of function scope
  (bsc#1226003).
- commit 2750357
* Mon Sep 23 2024 jgross@suse.com
- xen: move checks for e820 conflicts further up (bsc#1226003).
- commit 191a602
* Mon Sep 23 2024 jgross@suse.com
- xen: introduce generic helper checking for memory map conflicts
  (bsc#1226003).
- commit eb57cec
* Mon Sep 23 2024 jgross@suse.com
- xen: use correct end address of kernel for conflict checking
  (bsc#1226003).
- commit c40fc6b
* Mon Sep 23 2024 dwagner@suse.de
- scsi: lpfc: Copyright updates for 14.4.0.4 patches (bsc#1229429
  jsc#PED-9899).
- scsi: lpfc: Update lpfc version to 14.4.0.4 (bsc#1229429
  jsc#PED-9899).
- scsi: lpfc: Update PRLO handling in direct attached topology
  (bsc#1229429 jsc#PED-9899).
- scsi: lpfc: Fix unsolicited FLOGI kref imbalance when in direct
  attached topology (bsc#1229429 jsc#PED-9899).
- scsi: lpfc: Fix unintentional double clearing of vmid_flag
  (bsc#1229429 jsc#PED-9899).
- scsi: lpfc: Validate hdwq pointers before dereferencing in
  reset/errata paths (bsc#1229429 jsc#PED-9899).
- scsi: lpfc: Remove redundant vport assignment when building
  an abort request (bsc#1229429 jsc#PED-9899).
- scsi: lpfc: Change diagnostic log flag during receipt of
  unknown ELS cmds (bsc#1229429 jsc#PED-9899).
- scsi: lpfc: Fix overflow build issue (bsc#1229429 jsc#PED-9899).
- commit 18ec475
* Mon Sep 23 2024 tzimmermann@suse.com
- drm/vmwgfx: Prevent unmapping active read buffers (bsc#1230540 CVE-2024-46710)
- commit 84f019d
* Mon Sep 23 2024 dwagner@suse.de
- nvme-tcp: fix link failure for TCP auth (git-fixes).
- nvmet: Identify-Active Namespace ID List command should reject
  invalid nsid (git-fixes).
- nvme-pci: Add sleep quirk for Samsung 990 Evo (git-fixes).
- nvme-pci: allocate tagset on reset if necessary (git-fixes).
- nvmet-tcp: fix kernel crash if commands allocation fails
  (git-fixes).
- nvme/pci: Add APST quirk for Lenovo N60z laptop (git-fixes).
- nvme: use srcu for iterating namespace list (git-fixes).
  Refresh:
  - patches.suse/nvme-tcp-sanitize-tls-key-handling.patch
- nvmet-rdma: fix possible bad dereference when freeing rsps
  (git-fixes).
- nvmet-tcp: do not continue for invalid icreq (git-fixes).
- nvme: clear caller pointer on identify failure (git-fixes).
- nvmet-trace: avoid dereferencing pointer too early (git-fixes).
- commit 7382ad4
* Mon Sep 23 2024 jslaby@suse.cz
- Update
  patches.suse/KVM-arm64-vgic-v2-Check-for-non-NULL-vCPU-in-vgic_v2.patch
  (git-fixes CVE-2024-36953 bsc#1225812).
- Update
  patches.suse/vfio-pci-fix-potential-memory-leak-in-vfio_intx_enab.patch
  (git-fixes CVE-2024-38632 bsc#1226860).
  Add CVE references.
- commit c9c3b6f
* Mon Sep 23 2024 jslaby@suse.cz
- Update
  patches.suse/ALSA-scarlett2-Add-missing-mutex-lock-around-get-met.patch
  (jsc#PED-9993 jsc#PED-10202 CVE-2023-52689 bsc#1224684).
- Update
  patches.suse/ASoC-mediatek-mt8195-Add-platform-entry-for-ETDM1_OU.patch
  (jsc#PED-9993 jsc#PED-10202 CVE-2024-42088 bsc#1228451).
- Update
  patches.suse/Bluetooth-L2CAP-Fix-div-by-zero-in-l2cap_le_flowctl_.patch
  (jsc#PED-10412 CVE-2024-36968 bsc#1226130).
- Update patches.suse/Bluetooth-btusb-Fix-memory-leak.patch
  (jsc#PED-10412 CVE-2024-26887 bsc#1223123).
- Update
  patches.suse/Bluetooth-btusb-mediatek-Fix-double-free-of-skb-in-c.patch
  (jsc#PED-10412 CVE-2024-35856 bsc#1224695).
- Update patches.suse/Bluetooth-msft-Fix-memory-leak.patch
  (jsc#PED-10412 CVE-2024-26888 bsc#1223124).
- Update
  patches.suse/Bluetooth-qca-fix-info-leak-when-fetching-board-id.patch
  (jsc#PED-10412 CVE-2024-36033 bsc#1225721).
- Update
  patches.suse/clk-bcm-dvp-Assign-num-before-accessing-hws.patch
  (git-fixes CVE-2024-39462 bsc#1227094).
- Update
  patches.suse/clk-bcm-rpi-Assign-num-before-accessing-hws.patch
  (git-fixes CVE-2024-39461 bsc#1227093).
  Add CVE references.
- commit f5acd18
* Sun Sep 22 2024 ailiop@suse.com
- nilfs2: fix potential oob read in nilfs_btree_check_delete()
  (git-fixes).
- commit cc0f59d
* Sun Sep 22 2024 ailiop@suse.com
- nilfs2: determine empty node blocks as corrupted (git-fixes).
- commit 3244e52
* Sun Sep 22 2024 ailiop@suse.com
- nilfs2: fix potential null-ptr-deref in nilfs_btree_insert()
  (git-fixes).
- commit 90f4e49
* Fri Sep 20 2024 dsterba@suse.com
- media: mtk-vcodec: potential null pointer deference in SCP (CVE-2024-40973 bsc#1227890)
- commit ce5074d
* Fri Sep 20 2024 fdmanana@suse.com
- btrfs: don't BUG_ON() when 0 reference count at
  btrfs_lookup_extent_info() (bsc#1230786 CVE-2024-46751).
- btrfs: reduce nesting for extent processing at
  btrfs_lookup_extent_info() (bsc#1230794 CVE-2024-46752).
- btrfs: remove superfluous metadata check at
  btrfs_lookup_extent_info() (bsc#1230794 CVE-2024-46752).
- btrfs: replace BUG_ON() with error handling at
  update_ref_for_cow() (bsc#1230794 CVE-2024-46752).
- btrfs: simplify setting the full backref flag at
  update_ref_for_cow() (bsc#1230794 CVE-2024-46752).
- btrfs: remove NULL transaction support for
  btrfs_lookup_extent_info() (bsc#1230794 CVE-2024-46752).
- btrfs: remove level argument from btrfs_set_block_flags
  (bsc#1230794 CVE-2024-46752).
- commit a1c1176
* Fri Sep 20 2024 msuchanek@suse.de
- powerpc/pseries/dlpar: Add device tree nodes for DLPAR IO add
  (jsc#PED-10566 jsc#PED-9919).
- powerpc/pseries/dlpar: Remove device tree node for DLPAR IO
  remove (jsc#PED-10566 jsc#PED-9919).
- powerpc/pseries: Use correct data types from pseries_hp_errorlog
  struct (jsc#PED-10566 jsc#PED-9919).
- commit d53773b
* Fri Sep 20 2024 fdmanana@suse.com
- btrfs: send: allow cloning non-aligned extent if it ends at
  i_size (bsc#1230854).
- commit e9cad4b
* Fri Sep 20 2024 oneukum@suse.com
- blacklist.conf: kABI
- commit 5244a06
* Fri Sep 20 2024 ailiop@suse.com
- ocfs2: cancel dqi_sync_work before freeing oinfo (git-fixes).
- commit 1f37ac4
* Fri Sep 20 2024 ailiop@suse.com
- ocfs2: fix possible null-ptr-deref in ocfs2_set_buffer_uptodate
  (git-fixes).
- commit b7bf7eb
* Fri Sep 20 2024 ailiop@suse.com
- ocfs2: remove unreasonable unlock in ocfs2_read_blocks
  (git-fixes).
- commit e2cb129
* Fri Sep 20 2024 ailiop@suse.com
- ocfs2: fix null-ptr-deref when journal load failed (git-fixes).
- commit b463b02
* Fri Sep 20 2024 ailiop@suse.com
- jfs: fix out-of-bounds in dbNextAG() and diAlloc() (git-fixes).
- commit d948d87
* Fri Sep 20 2024 tiwai@suse.de
- of/irq: Prevent device address out-of-bounds read in interrupt
  map walk (CVE-2024-46743 bsc#1230756).
- commit 300f40a
* Fri Sep 20 2024 tiwai@suse.de
- i2c: qcom-geni: Use IRQF_NO_AUTOEN flag in request_irq()
  (git-fixes).
- i2c: isch: Add missed 'else' (git-fixes).
- i2c: xiic: Wait for TX empty to avoid missed TX NAKs
  (git-fixes).
- i2c: aspeed: Update the stop sw state when the bus recovery
  occurs (git-fixes).
- resource: fix region_intersects() vs add_memory_driver_managed()
  (git-fixes).
- drivers:drm:exynos_drm_gsc:Fix wrong assignment in gsc_bind()
  (git-fixes).
- drm/msm: fix %%s null argument error (git-fixes).
- drm/msm/dsi: correct programming sequence for SM8350 / SM8450
  (git-fixes).
- drm/msm/a5xx: workaround early ring-buffer emptiness check
  (git-fixes).
- drm/msm/a5xx: fix races in preemption evaluation stage
  (git-fixes).
- drm/msm/a5xx: properly clear preemption records on resume
  (git-fixes).
- drm/msm/a5xx: disable preemption in submits by default
  (git-fixes).
- drm/msm: Fix incorrect file name output in adreno_request_fw()
  (git-fixes).
- drm/mediatek: ovl_adaptor: Add missing of_node_put()
  (git-fixes).
- drm: omapdrm: Add missing check for alloc_ordered_workqueue
  (git-fixes).
- drm/radeon/evergreen_cs: fix int overflow errors in cs track
  offsets (git-fixes).
- drm/amd/amdgpu: Properly tune the size of struct (git-fixes).
- drm/radeon: properly handle vbios fake edid sizing (git-fixes).
- drm/amdgpu: properly handle vbios fake edid sizing (git-fixes).
- drm/amd/display: Add null check for set_output_gamma in
  dcn30_set_output_transfer_func (git-fixes).
- drm/amdgpu: fix a possible null pointer dereference (git-fixes).
- drm/radeon: fix null pointer dereference in
  radeon_add_common_modes (git-fixes).
- drm/vc4: hdmi: Handle error case of pm_runtime_resume_and_get
  (git-fixes).
- drm/bridge: lontium-lt8912b: Validate mode in
  drm_bridge_funcs::mode_valid() (git-fixes).
- drm/rockchip: dw_hdmi: Fix reading EDID when using a forced mode
  (git-fixes).
- drm/rockchip: vop: Allow 4096px width scaling (git-fixes).
- drm/rockchip: vop: enable VOP_FEATURE_INTERNAL_RGB on RK3066
  (git-fixes).
- drm/rockchip: vop: clear DMA stop bit on RK3066 (git-fixes).
- drm/stm: ltdc: check memory returned by devm_kzalloc()
  (git-fixes).
- drm/stm: Fix an error handling path in stm_drm_platform_probe()
  (git-fixes).
- ata: libata: Clear DID_TIME_OUT for ATA PT commands with sense
  data (git-fixes).
- HID: wacom: Do not warn about dropped packets for first packet
  (git-fixes).
- HID: wacom: Support sequence numbers smaller than 16-bit
  (git-fixes).
- tpm: Clean up TPM space after command failure (git-fixes).
- ipmi: docs: don't advertise deprecated sysfs entries
  (git-fixes).
- commit b4e4911
* Fri Sep 20 2024 tonyj@suse.de
- blacklist.conf: temp blacklist commit to allow merge to checkin w/out git-fixes error
- commit 3a3266a
* Thu Sep 19 2024 dsterba@suse.com
- smb/client: avoid dereferencing rdata=NULL in smb2_new_read_req() (CVE-2024-46686 bsc#1230517)
- commit a155846
* Thu Sep 19 2024 dsterba@suse.com
- firmware: qcom: scm: Mark get_wq_ctx() as atomic call (CVE-2024-46692 bsc#1230520)
- commit ee65da0
* Thu Sep 19 2024 dsterba@suse.com
- scsi: aacraid: Fix double-free on probe failure (CVE-2024-46673 bsc#1230506)
- commit 49aab2b
* Thu Sep 19 2024 dsterba@suse.com
- gtp: fix a potential NULL pointer dereference (CVE-2024-46677 bsc#1230549)
- commit 9cdd14b
* Thu Sep 19 2024 dsterba@suse.com
- blacklist.conf: CVE-2024-46711 bsc#1230542: code partially present, fix part of refactoring and fix series
  The patch to backport is one in a number of about 30 patches refactoring
  and reworking MPTCP subflow handling. Several other patches are needed
  just to apply it cleanly but also change some of the logic where the
  actual fix would apply.
- commit 1a03613
* Thu Sep 19 2024 dsterba@suse.com
- ethtool: check device is present when getting link settings (CVE-2024-46679 bsc#1230556)
- commit 68643d1
* Thu Sep 19 2024 colyli@suse.de
- md/raid5: avoid BUG_ON() while continue reshape after
  reassembling (bsc#1229790, CVE-2024-43914).
- commit bfb799a
* Thu Sep 19 2024 oneukum@suse.com
- gpiolib: demote the hogging log messages to debug
  (jsc#PED-10702).
- commit 485f7f1
* Thu Sep 19 2024 oneukum@suse.com
- gpiolib: Unify allocation and initialization of GPIO valid mask
  (jsc#PED-10702).
- commit 4cf06e5
* Thu Sep 19 2024 oneukum@suse.com
- gpiolib: Consolidate the allocated mask freeing APIs
  (jsc#PED-10702).
- commit 14e44d5
* Thu Sep 19 2024 oneukum@suse.com
- gpiolib: provide gpio_device_find_by_label() (jsc#PED-10702).
- commit 6d0f598
* Thu Sep 19 2024 oneukum@suse.com
- gpiolib: add support for scope-based management to gpio_device
  (jsc#PED-10702).
- commit dcb8397
* Thu Sep 19 2024 oneukum@suse.com
- gpiolib: remove unnecessary extern specifiers from the driver
  header (jsc#PED-10702).
- Refresh
  patches.suse/gpiolib-make-gpio_device_get-and-gpio_device_put-pub.patch.
- Refresh patches.suse/gpiolib-provide-gpio_device_find.patch.
- commit 18fd820
* Thu Sep 19 2024 oneukum@suse.com
- gpiolib: remove stray newline in gpio/driver.h (jsc#PED-10702).
- commit 17cdd18
* Thu Sep 19 2024 oneukum@suse.com
- gpiolib: Drop unused domain_ops memeber of GPIO IRQ chip
  (jsc#PED-10702).
- commit 60c45ca
* Thu Sep 19 2024 ailiop@suse.com
- xfs: restrict when we try to align cow fork delalloc to cowextsz
  hints (git-fixes).
- commit 96ac1b7
* Thu Sep 19 2024 jdelvare@suse.de
- clk: Provide !COMMON_CLK dummy for devm_clk_rate_exclusive_get()
  (bsc#1227885).
- commit bf3362b
* Thu Sep 19 2024 colyli@suse.de
- Replace git-fixes tag by bsc#1226507,
  patches.suse/md-Don-t-wait-for-MD_RECOVERY_NEEDED-for-HOT_REMOVE_DISK-ioctl-a1fd.patch
  (bsc#1226507).
- commit b04e0cb
* Thu Sep 19 2024 colyli@suse.de
- closures: Change BUG_ON() to WARN_ON() (bsc#1229004,
  CVE-2024-42252).
- commit 84b7984
* Thu Sep 19 2024 jdelvare@suse.de
- clk: Add a devm variant of clk_rate_exclusive_get()
  (bsc#1227885).
- commit b6fb747
* Thu Sep 19 2024 oneukum@suse.com
- r8152: add vendor/device ID pair for D-Link DUB-E250
  (git-fixes).
- Refresh
  patches.suse/r8152-add-vendor-device-ID-pair-for-ASUS-USB-C2500.patch.
- commit 0c077ab
* Thu Sep 19 2024 oneukum@suse.com
- usbnet: ipheth: fix carrier detection in modes 1 and 4
  (git-fixes).
- commit 591cebb
* Thu Sep 19 2024 oneukum@suse.com
- usbnet: ipheth: do not stop RX on failing RX callback
  (git-fixes).
- commit c58c483
* Thu Sep 19 2024 oneukum@suse.com
- usbnet: ipheth: drop RX URBs with no payload (git-fixes).
- commit 73a78e2
* Thu Sep 19 2024 jgross@suse.com
- KVM: arm64: Disallow copying MTE to guest memory while KVM is
  dirty logging (git-fixes).
- commit 3cf4c02
* Thu Sep 19 2024 oneukum@suse.com
- usbnet: ipheth: remove extraneous rx URB length check
  (git-fixes).
- commit 507443a
* Thu Sep 19 2024 oneukum@suse.com
- usbnet: ipheth: add CDC NCM support (git-fixes).
- commit 1bf1d1e
* Thu Sep 19 2024 jgross@suse.com
- KVM: arm64: Release pfn, i.e. put page, if copying MTE tags
  hits ZONE_DEVICE (git-fixes).
- commit 64bccd6
* Thu Sep 19 2024 oneukum@suse.com
- usbnet: ipheth: transmit URBs without trailing padding
  (git-fixes).
- usbnet: ipheth: fix risk of NULL pointer deallocation
  (git-fixes).
- commit d804072
* Thu Sep 19 2024 jgross@suse.com
- KVM: arm64: Invalidate EL1&0 TLB entries for all VMIDs in nvhe
  hyp init (git-fixes).
- commit 30df9d2
* Thu Sep 19 2024 tiwai@suse.de
- drm/amd/display: Solve mst monitors blank out problem after
  resume (git-fixes).
- commit cd94b30
* Thu Sep 19 2024 jgross@suse.com
- virtio-net: synchronize probe with ndo_set_features (git-fixes).
- commit 1a471dd
* Thu Sep 19 2024 tiwai@suse.de
- fbdev: hpfb: Fix an error handling path in hpfb_dio_probe()
  (git-fixes).
- hwmon: (ntc_thermistor) fix module autoloading (git-fixes).
- hwmon: (max16065) Fix overflows seen when writing limits
  (git-fixes).
- mtd: powernv: Add check devm_kasprintf() returned value
  (git-fixes).
- mtd: slram: insert break after errors in parsing the map
  (git-fixes).
- power: supply: hwmon: Fix missing temp1_max_alarm attribute
  (git-fixes).
- power: supply: Drop use_cnt check from
  power_supply_property_is_writeable() (git-fixes).
- power: supply: max17042_battery: Fix SOC threshold calc w/
  no current sense (git-fixes).
- power: supply: axp20x_battery: Remove design from min and max
  voltage (git-fixes).
- pinctrl: meteorlake: Add Arrow Lake-H/U ACPI ID (stable-fixes).
- drm/amdgpu/atomfirmware: Silence UBSAN warning (stable-fixes).
- drm/amd/display: Avoid race between dcn10_set_drr() and
  dc_state_destruct() (git-fixes).
- Input: synaptics - enable SMBus for HP Elitebook 840 G2
  (stable-fixes).
- Input: ads7846 - ratelimit the spi_sync error message
  (stable-fixes).
- drm/msm/adreno: Fix error return if missing firmware-name
  (stable-fixes).
- scripts: kconfig: merge_config: config files: add a trailing
  newline (stable-fixes).
- platform/surface: aggregator_registry: Add support for Surface
  Laptop Go 3 (stable-fixes).
- platform/surface: aggregator_registry: Add Support for Surface
  Pro 10 (stable-fixes).
- HID: multitouch: Add support for GT7868Q (stable-fixes).
- drm/mediatek: Set sensible cursor width/height values to fix
  crash (stable-fixes).
- drm: panel-orientation-quirks: Add quirk for Ayn Loki Max
  (stable-fixes).
- drm: panel-orientation-quirks: Add quirk for Ayn Loki Zero
  (stable-fixes).
- wifi: mt76: mt7921: fix NULL pointer access in
  mt7921_ipv6_addr_change (stable-fixes).
- net: phy: vitesse: repair vsc73xx autonegotiation
  (stable-fixes).
- cxl/core: Fix incorrect vendor debug UUID define (git-fixes).
- drm/amd/display: Fix FEC_READY write on DP LT (stable-fixes).
- drm/amd/display: Defer handling mst up request in resume
  (stable-fixes).
- drm/amd/display: Disable error correction if it's not supported
  (stable-fixes).
- commit 040b0ea
* Wed Sep 18 2024 jdelvare@suse.de
- i2c: lpi2c: Avoid calling clk_get_rate during transfer
  (bsc#1227885 CVE-2024-40965).
- commit abb755c
* Wed Sep 18 2024 oneukum@suse.com
- i2c: viai2c: turn common code into a proper module
  (jsc#PED-10702).
- commit 2525cea
* Wed Sep 18 2024 oneukum@suse.com
- i2c: Drop explicit initialization of struct
  i2c_device_id::driver_data to 0 (jsc#PED-10702).
- commit 5e7368b
* Wed Sep 18 2024 oneukum@suse.com
- i2c: add zhaoxin i2c controller driver (jsc#PED-10702).
- Update config files.
- commit d9e10dd
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: add platform type VIAI2C_PLAT_WMT (jsc#PED-10702).
- commit 843b44e
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: fix a bug when thread blocked (jsc#PED-10702).
- commit b5caac9
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: rename something (jsc#PED-10702).
- commit da8d7e1
* Wed Sep 18 2024 mhocko@suse.com
- x86/mm/ident_map: Use gbpages only where full GB page should
  be mapped (bsc#1220382).
- x86/kexec: Add EFI config table identity mapping for kexec
  kernel (bsc#1220382).
- commit 26eab5b
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: split out common files (jsc#PED-10702).
- commit ab5ccfd
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: create wmt_i2c_init for general init (jsc#PED-10702).
- commit 5b953d9
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: Reduce redundant: REG_CR setting (jsc#PED-10702).
- commit a6c2c70
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: Reduce redundant: function parameter (jsc#PED-10702).
- commit 87e02ca
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: Reduce redundant: clock mode setting (jsc#PED-10702).
- commit d15699a
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: Reduce redundant: wait event complete (jsc#PED-10702).
- commit 5c1072c
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: Reduce redundant: bus busy check (jsc#PED-10702).
- commit b2876cf
* Wed Sep 18 2024 oneukum@suse.com
- i2c: wmt: Use devm_platform_get_and_ioremap_resource()
  (jsc#PED-10702).
- commit 7ba3be9
* Wed Sep 18 2024 oneukum@suse.com
- i2c: sprd: Convert to platform remove callback returning void
  (jsc#PED-10702).
- commit 63b19e9
* Wed Sep 18 2024 oneukum@suse.com
- i2c: smbus: Prepare i2c_register_spd for usage on muxed segments
  (jsc#PED-10702).
- commit 316ba78
* Wed Sep 18 2024 oneukum@suse.com
- i2c: constify the struct device_type usage (jsc#PED-10702).
- commit 50d3674
* Wed Sep 18 2024 oneukum@suse.com
- i2c: Remove redundant comparison in npcm_i2c_reg_slave
  (jsc#PED-10702).
- commit 12000a2
* Wed Sep 18 2024 oneukum@suse.com
- i2c: npcm7xx: move to per-adapter debugfs directory
  (jsc#PED-10702).
- commit 27840f8
* Wed Sep 18 2024 oneukum@suse.com
- i2c: gpio: move to per-adapter debugfs directory
  (jsc#PED-10702).
- commit d2bd050
* Wed Sep 18 2024 oneukum@suse.com
- i2c: gpio: remove error checks with debugfs (jsc#PED-10702).
- commit 5663caa
* Wed Sep 18 2024 oneukum@suse.com
- i2c: create debugfs entry per adapter (jsc#PED-10702).
- commit f86c829
* Wed Sep 18 2024 oneukum@suse.com
- i2c: core: fix lockdep warning for sparsely nested adapter chain
  (jsc#PED-10702).
- commit cca2d59
* Wed Sep 18 2024 oneukum@suse.com
- i2c: Add support for Intel LJCA USB I2C driver (jsc#PED-10702).
- commit 992beec
* Wed Sep 18 2024 oneukum@suse.com
- i2c: Annotate struct i2c_atr with __counted_by (jsc#PED-10702).
- commit 51b2022
* Wed Sep 18 2024 tiwai@suse.de
- Move upstreamed nvme patches into sorted section
- commit 1e42d2f
* Wed Sep 18 2024 tiwai@suse.de
- ASoC: tas2781-i2c: Drop weird GPIO code (git-fixes).
- ASoC: tas2781: Fix a compiling warning reported by robot kernel
  test due to adding tas2563_dvc_table (git-fixes).
- commit 3498c94
* Wed Sep 18 2024 tiwai@suse.de
- spi: ppc4xx: Avoid returning 0 when failed to parse and map IRQ
  (git-fixes).
- commit 1cec71a
* Wed Sep 18 2024 tiwai@suse.de
- ASoC: meson: Remove unused declartion in header file
  (git-fixes).
- ASoC: soc-ac97: Fix the incorrect description (git-fixes).
- ASoC: rt5682: Return devm_of_clk_add_hw_provider to transfer
  the error (git-fixes).
- ASoC: tas2781-i2c: Get the right GPIO line (git-fixes).
- ASoC: cs42l42: Convert comma to semicolon (git-fixes).
- ASoC: rt5682s: Return devm_of_clk_add_hw_provider to transfer
  the error (git-fixes).
- ALSA: hda: cs35l41: fix module autoloading (git-fixes).
- selftests: lib: remove strscpy test (git-fixes).
- scripts: sphinx-pre-install: remove unnecessary double check
  for $cur_version (git-fixes).
- Documentation: ioctl: document 0x07 ioctl code (git-fixes).
- module: Fix KCOV-ignored file name (git-fixes).
- reset: k210: fix OF node leak in probe() error path (git-fixes).
- reset: berlin: fix OF node leak in probe() error path
  (git-fixes).
- bus: integrator-lm: fix OF node leak in probe() (git-fixes).
- soc: fsl: cpm1: tsa: Fix tsa_write8() (git-fixes).
- firmware: tegra: bpmp: Drop unused mbox_client_to_bpmp()
  (git-fixes).
- firmware: arm_scmi: Fix double free in OPTEE transport
  (git-fixes).
- soc: versatile: integrator: fix OF node leak in probe() error
  path (git-fixes).
- memory: mtk-smi: Use devm_clk_get_enabled() (git-fixes).
- memory: tegra186-emc: drop unused to_tegra186_emc() (git-fixes).
- spi: bcm63xx: Fix module autoloading (git-fixes).
- spi: rpc-if: Add missing MODULE_DEVICE_TABLE (git-fixes).
- spi: meson-spicc: convert comma to semicolon (git-fixes).
- spi: ppc4xx: handle irq_of_parse_and_map() errors (git-fixes).
- regulator: core: Fix regulator_is_supported_voltage() kerneldoc
  return value (git-fixes).
- regulator: core: Fix short description for
  _regulator_check_status_enabled() (git-fixes).
- regulator: Return actual error in of_regulator_bulk_get_all()
  (git-fixes).
- regulator: rt5120: Convert comma to semicolon (git-fixes).
- regulator: wm831x-isink: Convert comma to semicolon (git-fixes).
- clocksource/drivers/qcom: Add missing iounmap() on errors in
  msm_dt_timer_init() (git-fixes).
- commit 994b020
* Tue Sep 17 2024 oneukum@suse.com
- i2c: dev: make i2c_dev_class a static const structure
  (jsc#PED-10702).
- commit b52ab37
* Tue Sep 17 2024 oneukum@suse.com
- i2c: tiny-usb: check usb base class before assuming the
  interface on device is for this driver (jsc#PED-10702).
- commit 2db0283
* Tue Sep 17 2024 oneukum@suse.com
- media: i2c: add I2C Address Translator (ATR) support
  (jsc#PED-10702).
- commit 7a422ed
* Tue Sep 17 2024 tiwai@suse.de
- wifi: mac80211_hwsim: drop owner assignment (bsc#1230505).
- wifi: mac80211_hwsim: add support for BSS color (bsc#1230505).
- wifi: mac80211_hwsim: Use wider regulatory for custom for 6GHz
  tests (bsc#1230505).
- wifi: mac80211_hwsim: Declare HE/EHT capabilities support for
  P2P interfaces (bsc#1230505).
- wifi: mac80211_hwsim: move skip_beacons to be per link
  (bsc#1230505).
- wifi: mac80211_hwsim: set link ID information during Rx
  (bsc#1230505).
- wifi: mac80211_hwsim: add support for switch_vif_chanctx
  callback (bsc#1230505).
- wifi: mac80211_hwsim: Add 160MHz bw range to regdom_custom_04
  (bsc#1230505).
- wifi: mac80211_hwsim: add missing kernel-doc (bsc#1230505).
- wifi: mac80211_hwsim: enable all links only in MLO
  (bsc#1230505).
- wifi: mac80211_hwsim: add control to skip beacons (bsc#1230505).
- wifi: mac80211_hwsim: advertise 15 simultaneous links
  (bsc#1230505).
- wifi: mac80211_hwsim: advertise AP-side EMLSR/EMLMR capa
  (bsc#1230505).
- wifi: mac80211_hwsim: Declare support for negotiated TTLM
  (bsc#1230505).
- wifi: mac80211_hwsim: handle BSS_CHANGED_MLD_TTLM (bsc#1230505).
- wifi: mac80211_hwsim: handle TID to link mapping neg request
  (bsc#1230505).
- wifi: mac80211_hwsim: Add custom reg for DFS concurrent
  (bsc#1230505).
- wifi: mac80211_hwsim: support HE 40 MHz in 2.4 GHz band
  (bsc#1230505).
- wifi: mac80211_hwsim: Handle BSS_CHANGED_VALID_LINKS
  (bsc#1230505).
- wifi: mac80211_hwsim: move kernel-doc description (bsc#1230505).
- wifi: mac80211_hwsim: clean up kernel-doc (bsc#1230505).
- Revert "wifi: mac80211_hwsim: check the return value of
  nla_put_u32" (bsc#1230505).
- wifi: mac80211_hwsim: avoid calling nlmsg_free() in IRQ or
  IRQ disabled (bsc#1230505).
- wifi: mac80211_hwsim: Don't access vif valid links directly
  (bsc#1230505).
- wifi: mac80211_hwsim: check the return value of nla_put_u32
  (bsc#1230505).
- wifi: mac80211_hwsim: avoid warning with MLO PS stations
  (bsc#1230505).
- commit 097ca80
* Tue Sep 17 2024 oneukum@suse.com
- Update
  patches.suse/thunderbolt-Fix-uninitialized-variable-in-tb_tunnel_.patch
  (jsc#PED-10361).
  fix malformed references tag
- commit 86b9590
* Tue Sep 17 2024 tiwai@suse.de
- cpufreq: ti-cpufreq: Introduce quirks to handle syscon fails
  appropriately (git-fixes).
- ACPI: CPPC: Fix MASK_VAL() usage (git-fixes).
- ACPI: PMIC: Remove unneeded check in
  tps68470_pmic_opregion_probe() (git-fixes).
- ACPI: sysfs: validate return type of _STR method (git-fixes).
- crypto: ccp - do not request interrupt on cmd completion when
  irqs disabled (git-fixes).
- hwrng: mtk - Use devm_pm_runtime_enable (git-fixes).
- crypto: ccp - Properly unregister /dev/sev on sev
  PLATFORM_STATUS failure (git-fixes).
- hwrng: cctrng - Add missing clk_disable_unprepare in
  cctrng_resume (git-fixes).
- hwrng: bcm2835 - Add missing clk_disable_unprepare in
  bcm2835_rng_init (git-fixes).
- crypto: iaa - Fix potential use after free bug (git-fixes).
- crypto: xor - fix template benchmarking (git-fixes).
- can: m_can: m_can_close(): stop clocks after device has been
  shut down (git-fixes).
- can: m_can: enable NAPI before enabling interrupts (git-fixes).
- can: bcm: Clear bo->bcm_proc_read after remove_proc_entry()
  (git-fixes).
- Bluetooth: btusb: Fix not handling ZPL/short-transfer
  (git-fixes).
- Bluetooth: hci_sync: Ignore errors from
  HCI_OP_REMOTE_NAME_REQ_CANCEL (git-fixes).
- Bluetooth: hci_core: Fix sending MGMT_EV_CONNECT_FAILED
  (git-fixes).
- wifi: mt76: mt7925: fix a potential array-index-out-of-bounds
  issue for clc (git-fixes).
- wifi: mt76: mt7615: check devm_kasprintf() returned value
  (git-fixes).
- wifi: mt76: mt7921: Check devm_kasprintf() returned value
  (git-fixes).
- wifi: mt76: mt7915: check devm_kasprintf() returned value
  (git-fixes).
- wifi: mt76: mt7996: fix uninitialized TLV data (git-fixes).
- wifi: mt76: mt7915: fix rx filter setting for bfee functionality
  (git-fixes).
- wifi: mt76: mt7603: fix mixed declarations and code (git-fixes).
- wifi: mt76: connac: fix checksum offload fields of connac3 RXD
  (git-fixes).
- wifi: mt76: mt7996: fix NULL pointer dereference in
  mt7996_mcu_sta_bfer_he (git-fixes).
- wifi: mt76: mt7996: fix EHT beamforming capability check
  (git-fixes).
- wifi: mt76: mt7996: fix HE and EHT beamforming capabilities
  (git-fixes).
- wifi: mt76: mt7996: fix wmm set of station interface to 3
  (git-fixes).
- wifi: mt76: mt7996: fix traffic delay when switching back to
  working channel (git-fixes).
- wifi: mt76: mt7996: use hweight16 to get correct tx antenna
  (git-fixes).
- wifi: mt76: mt7921: fix wrong UNII-4 freq range check for the
  channel usage (git-fixes).
- wifi: mt76: mt7915: fix oops on non-dbdc mt7986 (git-fixes).
- wifi: rtw88: remove CPT execution branch never used (git-fixes).
- wifi: wilc1000: fix potential RCU dereference issue in
  wilc_parse_join_bss_param (git-fixes).
- wifi: mac80211: use two-phase skb reclamation in
  ieee80211_do_stop() (git-fixes).
- wifi: cfg80211: fix two more possible UBSAN-detected off-by-one
  errors (git-fixes).
- wifi: cfg80211: fix UBSAN noise in cfg80211_wext_siwscan()
  (git-fixes).
- wifi: mac80211: fix the comeback long retry times (git-fixes).
- wifi: cfg80211: fix bug of mapping AF3x to incorrect User
  Priority (git-fixes).
- wifi: iwlwifi: mvm: increase the time between ranging
  measurements (git-fixes).
- wifi: mac80211: don't use rate mask for offchannel TX either
  (git-fixes).
- wifi: ath12k: fix invalid AMPDU factor calculation in
  ath12k_peer_assoc_h_he() (git-fixes).
- wifi: ath12k: match WMI BSS chan info structure with firmware
  definition (git-fixes).
- wifi: ath12k: fix BSS chan info request WMI command (git-fixes).
- wifi: ath9k: Remove error checks when creating debugfs entries
  (git-fixes).
- wifi: rtw88: always wait for both firmware loading attempts
  (git-fixes).
- wifi: rtw88: 8822c: Fix reported RX band width (git-fixes).
- wifi: brcmfmac: introducing fwil query functions (git-fixes).
- can: j1939: use correct function name in comment (git-fixes).
- commit ffce0ad
* Mon Sep 16 2024 jgross@suse.com
- net: tighten bad gso csum offset check in virtio_net_hdr
  (git-fixes).
- commit 6b94c45
* Mon Sep 16 2024 jgross@suse.com
- blacklist.conf: add 840b2d39a2dc ("virtio_ring: fix KMSAN error for premapped mode")
- commit 2b97440
* Mon Sep 16 2024 jgross@suse.com
- KVM: SVM: fix emulation of msr reads/writes of MSR_FS_BASE
  and MSR_GS_BASE (git-fixes).
- commit aeba695
* Mon Sep 16 2024 oneukum@suse.com
- thunderbolt: Fix kernel-doc for tb_tunnel_alloc_dp()
  (jsc#PED-10361).
- commit f42247a
* Mon Sep 16 2024 oneukum@suse.com
- thunderbolt: Fix uninitialized variable in
  tb_tunnel_alloc_usb3() (jsc#-PED10361).
- commit 6326f6a
* Mon Sep 16 2024 oneukum@suse.com
- thunderbolt: No need to loop over all retimers if access fails
  (jsc#PED-10361).
- commit 5f68f33
* Mon Sep 16 2024 oneukum@suse.com
- thunderbolt: Increase sideband access polling delay
  (jsc#PED-10361).
- commit fa4b1b4
* Mon Sep 16 2024 jgross@suse.com
- blacklist.conf: add 611ff1b1ae98 ("xen: privcmd: Fix possible access to a freed kirqfd instance")
- commit d91e53f
* Mon Sep 16 2024 oneukum@suse.com
- thunderbolt: Get rid of TB_CFG_PKG_PREPARE_TO_SLEEP
  (jsc#PED-10361).
- commit 24dfc42
* Mon Sep 16 2024 oneukum@suse.com
- thunderbolt: Use correct error code with ERROR_NOT_SUPPORTED
  (jsc#PED-10361).
- commit b232ba1
* Mon Sep 16 2024 oneukum@suse.com
- thunderbolt: Allow USB3 bandwidth to be lower than maximum
  supported (jsc#PED-10361).
- commit b924604
* Mon Sep 16 2024 lhenriques@suse.de
- fscache: delete fscache_cookie_lru_timer when fscache exits
  to avoid  UAF (bsc#1230602).
- commit d2c95a5
* Mon Sep 16 2024 sjaeckel@suse.de
- Update
  patches.suse/virtio_net-Fix-napi_skb_cache_put-warning.patch
  (git-fixes CVE-2024-43835 bsc#1229289).
- commit b9542fb
* Mon Sep 16 2024 ohering@suse.de
- x86/hyperv: fix kexec crash due to VP assist page corruption
  (git-fixes).
- Drivers: hv: vmbus: Fix the misplaced function description
  (git-fixes).
- commit c60d936
* Mon Sep 16 2024 ddiss@suse.de
- Update references
  patches.suse/selinux-smack-don-t-bypass-permissions-check-in-inod.patch
  (stable-fixes CVE-2024-46695 bsc#1230519).
- commit 2a7bb57
* Mon Sep 16 2024 neilb@suse.de
- NFSv4: Add missing rescheduling points in
  nfs_client_return_marked_delegations (git-fixes).
- commit a563f31
* Mon Sep 16 2024 neilb@suse.de
- nfsd: Don't leave work of closing files to a work queue
  (bsc#1228140).
- Refresh
  patches.suse/nfsd-use-__fput_sync-to-avoid-delayed-closing-of-fil.patch.
- commit 83ce74a
* Sun Sep 15 2024 tiwai@suse.de
- ASoC: meson: axg-card: fix 'use-after-free' (git-fixes).
- ASoC: codecs: avoid possible garbage value in peb2466_reg_read()
  (git-fixes).
- commit 5a67afd
* Sat Sep 14 2024 tiwai@suse.de
- kABI workaround for soc-qcom pmic_glink changes (CVE-2024-46693
  bsc#1230521).
- commit 9a06e25
* Sat Sep 14 2024 tiwai@suse.de
- usb: typec: ucsi: Move unregister out of atomic section
  (CVE-2024-46691 bsc#1230526).
- soc: qcom: pmic_glink: Fix race during initialization
  (CVE-2024-46693 bsc#1230521).
- commit 26dd9b4
* Sat Sep 14 2024 tiwai@suse.de
- spi: nxp-fspi: fix the KASAN report out-of-bounds bug
  (git-fixes).
- drm/syncobj: Fix syncobj leak in drm_syncobj_eventfd_ioctl
  (git-fixes).
- drm/nouveau/fb: restore init() for ramgp102 (git-fixes).
- dma-buf: heaps: Fix off-by-one in CMA heap fault handler
  (git-fixes).
- drm/i915/guc: prevent a possible int overflow in wq offsets
  (git-fixes).
- usbnet: ipheth: race between ipheth_close and error handling
  (stable-fixes).
- commit 8d8bf2f
* Sat Sep 14 2024 colyli@suse.de
- md/raid1: Fix data corruption for degraded array with slow disk
  (bsc#1230455, CVE-2024-45023).
- commit 34cd7b5
* Fri Sep 13 2024 tonyj@suse.de
- perf/x86/intel: Limit the period on Haswell (git-fixes).
- perf/x86: Fix smp_processor_id()-in-preemptible warnings
  (git-fixes).
- perf/x86/intel/cstate: Add pkg C2 residency counter for Sierra
  Forest (git-fixes).
- ARM: 9406/1: Fix callchain_trace() return value (git-fixes).
- bpf, events: Use prog to emit ksymbol event for main program
  (git-fixes).
- perf/x86/intel: Add a distinct name for Granite Rapids
  (git-fixes).
- perf/x86/intel/ds: Fix non 0 retire latency on Raptorlake
  (git-fixes).
- perf/x86/intel/uncore: Fix the bits of the CHA extended umask
  for SPR (git-fixes).
- perf: Fix event leak upon exit (git-fixes).
- perf/x86/intel/cstate: Fix Alderlake/Raptorlake/Meteorlake
  (git-fixes).
- perf: Fix default aux_watermark calculation (git-fixes).
- perf: Prevent passing zero nr_pages to rb_alloc_aux()
  (git-fixes).
- perf: Fix perf_aux_size() for greater-than 32-bit size
  (git-fixes).
- perf/x86/intel/pt: Fix pt_topa_entry_for_page() address
  calculation (git-fixes).
- perf/x86/intel/pt: Fix a topa_entry base address calculation
  (git-fixes).
- perf/x86/intel/pt: Fix topa_entry base length (git-fixes).
- perf/x86: Serialize set_attr_rdpmc() (git-fixes).
- perf/core: Fix missing wakeup when waiting for context reference
  (git-fixes).
- perf/x86/intel: Factor out the initialization code for SPR
  (git fixes).
- perf/x86/intel: Use the common uarch name for the shared
  functions (git fixes).
- commit bb48e43
* Fri Sep 13 2024 tonyj@suse.de
- blacklist.conf: Add perf git-fix that won't be backported
- commit fbbd522
* Fri Sep 13 2024 dsterba@suse.com
- nvme: move stopping keep-alive into nvme_uninit_ctrl() (CVE-2024-45013 bsc#1230442)
- commit ce739c4
* Fri Sep 13 2024 dsterba@suse.com
- i2c: tegra: Do not mark ACPI devices as irq safe (CVE-2024-45029 bsc#1230451)
- commit 2870112
* Fri Sep 13 2024 dsterba@suse.com
- netfilter: flowtable: initialise extack before use (CVE-2024-45018 bsc#1230431)
- commit 8b44b15
* Fri Sep 13 2024 dsterba@suse.com
- net/mlx5e: Take state lock during tx timeout reporter (CVE-2024-45019 bsc#1230432)
- commit 2552371
* Fri Sep 13 2024 dsterba@suse.com
- net/mlx5: Fix IPsec RoCE MPV trace call (CVE-2024-45017 bsc#1230430)
- commit 60aac02
* Fri Sep 13 2024 dsterba@suse.com
- igb: cope with large MAX_SKB_FRAGS (CVE-2024-45030 bsc#1230457)
- commit d2d3c69
* Fri Sep 13 2024 tiwai@suse.de
- Move s390 kabi patch into the kabi section
- commit 4ab5d36
* Fri Sep 13 2024 jgross@suse.com
- KVM: x86: don't fall through case statements without annotations
  (git-fixes).
- commit 8367b93
* Fri Sep 13 2024 mfranc@suse.cz
- s390/uv: Don't call folio_wait_writeback() without a folio
  reference (git-fixes bsc#1229380 CVE-2024-43832).
- s390/mm: Convert gmap_make_secure to use a folio (git-fixes
  bsc#1230562).
- s390/mm: Convert make_page_secure to use a folio (git-fixes
  bsc#1230563).
- s390: allow pte_offset_map_lock() to fail (git-fixes
  bsc#1230564).
- commit 7069eb7
* Fri Sep 13 2024 jgross@suse.com
- KVM: x86: Only advertise KVM_CAP_READONLY_MEM when supported
  by VM (git-fixes).
- commit f4e22b2
* Fri Sep 13 2024 mhocko@suse.com
- mm/vmalloc: fix page mapping if vm_area_alloc_pages() with
  high order fallback to order 0 (CVE-2024-45022 bsc#1230435).
- commit cc8880a
* Fri Sep 13 2024 osalvador@suse.de
- Revert "mm/sparsemem: fix race in accessing memory_section->usage"
  This reverts commit 6aa8957889611fbe7f06353f917cfb3d9620a680 to fix a regression (bsc#1230413)
- commit 720e36b
* Fri Sep 13 2024 osalvador@suse.de
- Revert "mm, kmsan: fix infinite recursion due to RCU critical section"
  This reverts commit 16ad73a9f4c2888f3bc28513f5e9a88d753f8741 to fix a regression (bsc#1230413)
- commit 2fd5290
* Fri Sep 13 2024 osalvador@suse.de
- Revert "mm: prevent derefencing NULL ptr in pfn_section_valid()"
  This reverts commit 35f619d3c421219e07bc89d2d6a37fbff25519fe to fix a refression
  (bsc#1230413)
- commit 7e5afd7
* Fri Sep 13 2024 mhocko@suse.com
- memcg_write_event_control(): fix a user-triggerable oops
  (CVE-2024-45021 bsc#1230434).
- commit 99a85a8
* Fri Sep 13 2024 tiwai@suse.de
- platform/x86: panasonic-laptop: Allocate 1 entry extra in the
  sinf array (git-fixes).
- platform/x86: panasonic-laptop: Fix SINF array out of bounds
  accesses (git-fixes).
- usb: dwc3: core: update LC timer as per USB Spec V3.2
  (stable-fixes).
- lib/generic-radix-tree.c: Fix rare race in
  __genradix_ptr_alloc() (stable-fixes).
- kselftests: dmabuf-heaps: Ensure the driver name is
  null-terminated (stable-fixes).
- regmap: maple: work around gcc-14.1 false-positive warning
  (stable-fixes).
- phy: zynqmp: Take the phy mutex in xlate (stable-fixes).
- pcmcia: Use resource_size function on resource object
  (stable-fixes).
- pci/hotplug/pnv_php: Fix hotplug driver crash on Powernv
  (stable-fixes).
- PCI: keystone: Add workaround for Errata #i2037 (AM65x SR 1.0)
  (stable-fixes).
- PCI: Add missing bridge lock to pci_bus_lock() (stable-fixes).
- usb: gadget: aspeed_udc: validate endpoint index for ast udc
  (stable-fixes).
- usb: uas: set host status byte on data completion error
  (stable-fixes).
- media: qcom: camss: Add check for v4l2_fwnode_endpoint_parse
  (stable-fixes).
- media: vivid: don't set HDMI TX controls if there are no HDMI
  outputs (stable-fixes).
- media: vivid: fix wrong sizeimage value for mplane
  (stable-fixes).
- leds: spi-byte: Call of_node_put() on error path (stable-fixes).
- wifi: rtw88: usb: schedule rx work after everything is set up
  (stable-fixes).
- wifi: rtw89: wow: prevent to send unexpected H2C during download
  Firmware (stable-fixes).
- wifi: mwifiex: Do not return unused priv in
  mwifiex_get_priv_by_id() (stable-fixes).
- wifi: ath12k: fix firmware crash due to invalid peer nss
  (stable-fixes).
- wifi: ath12k: fix uninitialize symbol error on
  ath12k_peer_assoc_h_he() (stable-fixes).
- wifi: brcmsmac: advertise MFP_CAPABLE to enable WPA3
  (stable-fixes).
- wifi: iwlwifi: mvm: use IWL_FW_CHECK for link ID check
  (stable-fixes).
- commit 3b57fa8
* Fri Sep 13 2024 ailiop@suse.com
- Squashfs: sanity check symbolic link size (git-fixes).
- commit fa6af4a
* Fri Sep 13 2024 tiwai@suse.de
- hwmon: (pmbus) Conditionally clear individual status bits for
  pmbus rev >= 1.2 (git-fixes).
- Input: uinput - reject requests with unreasonable number of
  slots (stable-fixes).
- HID: amd_sfh: free driver_data after destroying hid device
  (stable-fixes).
- HID: cougar: fix slab-out-of-bounds Read in cougar_report_fixup
  (stable-fixes).
- i3c: mipi-i3c-hci: Error out instead on BUG_ON() in IBI DMA
  setup (stable-fixes).
- Input: ili210x - use kvmalloc() to allocate buffer for firmware
  update (stable-fixes).
- drm/amdgpu: reject gang submit on reserved VMIDs (stable-fixes).
- drm/amdgpu: Set no_hw_access when VF request full GPU fails
  (stable-fixes).
- drm/amdgpu/display: handle gfx12 in
  amdgpu_dm_plane_format_mod_supported (stable-fixes).
- drm/amdgpu: handle gfx12 in amdgpu_display_verify_sizes
  (stable-fixes).
- drm/amdgpu: check for LINEAR_ALIGNED correctly in
  check_tiling_flags_gfx6 (stable-fixes).
- drm/amd/display: Check denominator pbn_div before used
  (stable-fixes).
- drm/amdgpu: clear RB_OVERFLOW bit when enabling interrupts
  (stable-fixes).
- drm/amdgpu: Fix smatch static checker warning (stable-fixes).
- drm/amdgpu: add missing error handling in function
  amdgpu_gmc_flush_gpu_tlb_pasid (stable-fixes).
- drm/amd/display: Check HDCP returned status (stable-fixes).
- hwmon: (w83627ehf) Fix underflows seen when writing limit
  attributes (stable-fixes).
- hwmon: (nct6775-core) Fix underflows seen when writing limit
  attributes (stable-fixes).
- hwmon: (lm95234) Fix underflows seen when writing limit
  attributes (stable-fixes).
- hwmon: (adc128d818) Fix underflows seen when writing limit
  attributes (stable-fixes).
- commit 2fa929e
* Fri Sep 13 2024 osalvador@suse.de
- Revert "mm/sparsemem: fix race in accessing memory_section->usage"
  This reverts commit 6aa8957889611fbe7f06353f917cfb3d9620a680.
- commit 5376e5a
* Fri Sep 13 2024 osalvador@suse.de
- Revert "mm, kmsan: fix infinite recursion due to RCU critical section"
  This reverts commit 16ad73a9f4c2888f3bc28513f5e9a88d753f8741.
- commit 505329c
* Fri Sep 13 2024 osalvador@suse.de
- Revert "mm: prevent derefencing NULL ptr in pfn_section_valid()"
  This reverts commit 35f619d3c421219e07bc89d2d6a37fbff25519fe.
- commit 937414d
* Fri Sep 13 2024 tiwai@suse.de
- ata: libata: Fix memory leak for error path in ata_host_alloc()
  (git-fixes).
- devres: Initialize an uninitialized struct member
  (stable-fixes).
- ASoc: TAS2781: replace beXX_to_cpup with get_unaligned_beXX
  for potentially broken alignment (stable-fixes).
- ASoC: topology: Properly initialize soc_enum values
  (stable-fixes).
- ALSA: hda: Add input value sanity checks to HDMI channel map
  controls (stable-fixes).
- ALSA: control: Apply sanity check of input values for user
  elements (stable-fixes).
- crypto: qat - fix unintentional re-enabling of error interrupts
  (stable-fixes).
- drm/amd/display: Run DC_LOG_DC after checking link->link_enc
  (stable-fixes).
- drm/amd/display: Check UnboundedRequestEnabled's value
  (stable-fixes).
- drm/amd: Add gfx12 swizzle mode defs (stable-fixes).
- Bluetooth: btnxpuart: Fix Null pointer dereference in
  btnxpuart_flush() (stable-fixes).
- can: mcp251xfd: rx: add workaround for erratum DS80000789E 6
  of mcp2518fd (stable-fixes).
- can: mcp251xfd: rx: prepare to workaround broken RX FIFO head
  index erratum (stable-fixes).
- can: mcp251xfd: mcp251xfd_handle_rxif_ring_uinc(): factor out
  in separate function (stable-fixes).
- can: mcp251xfd: clarify the meaning of timestamp (stable-fixes).
- can: kvaser_pciefd: Skip redundant NULL pointer check in ISR
  (stable-fixes).
- ACPI: processor: Fix memory leaks in error paths of
  processor_add() (stable-fixes).
- ACPI: processor: Return an error if acpi_processor_get_info()
  fails in processor_add() (stable-fixes).
- cpufreq: amd-pstate: fix the highest frequency issue which
  limits performance (git-fixes).
- cpufreq: amd-pstate: Enable amd-pstate preferred core support
  (stable-fixes).
- ACPI: CPPC: Add helper to get the highest performance value
  (stable-fixes).
- Bluetooth: hci_sync: Add helper functions to manipulate cmd_sync
  queue (stable-fixes).
- Bluetooth: hci_event: Use HCI error defines instead of magic
  values (stable-fixes).
- commit 96be389
* Thu Sep 12 2024 jgross@suse.com
- virtio_net: Fix napi_skb_cache_put warning (git-fixes).
- commit 860ef0a
* Thu Sep 12 2024 jgross@suse.com
- virtio_net: fixing XDP for fully checksummed packets handling
  (git-fixes).
- commit 77fb9e7
* Thu Sep 12 2024 mkoutny@suse.com
- randomize_kstack: Improve stack alignment codegen (bsc#1224478).
- commit d06c22b
* Thu Sep 12 2024 mfranc@suse.cz
- s390/dasd: Fix redundant /proc/dasd* entries removal
  (bsc#1227694).
- commit b66530a
* Thu Sep 12 2024 mkoutny@suse.com
- randomize_kstack: Remove non-functional per-arch entropy
  filtering (bsc#1224478).
- commit 1136c03
* Thu Sep 12 2024 tiwai@suse.de
- Move upstreamed input patch into sorted section
- commit e197a51
* Thu Sep 12 2024 jgross@suse.com
- blacklist.conf: add db5247d9bf5c ("vhost_task: Handle SIGKILL by flushing work and exiting")
- commit 7acfcbb
* Thu Sep 12 2024 jgross@suse.com
- KVM: SVM: Don't advertise Bus Lock Detect to guest if SVM
  support is missing (git-fixes).
- commit 42f7b0c
* Thu Sep 12 2024 jgross@suse.com
- KVM: x86: Acquire kvm->srcu when handling KVM_SET_VCPU_EVENTS
  (git-fixes).
- commit 610cfdd
* Thu Sep 12 2024 mkoutny@suse.com
- randomize_kstack: Improve entropy diffusion (bsc#1224478).
- blacklist.conf: Unblacklist above commit
- commit 4fdf8b0
* Thu Sep 12 2024 mkoutny@suse.com
- cgroup: Move rcu_head up near the top of cgroup_root
  (bsc#1222254).
- blacklist.conf: Unblacklist above commit
- commit 3ecdba8
* Thu Sep 12 2024 jgross@suse.com
- KVM: arm64: Make ICC_*SGI*_EL1 undef in the absence of a vGICv3
  (git-fixes).
- commit bae7627
* Thu Sep 12 2024 jroedel@suse.de
- kABI: Workaround kABI change in
  patches.suse/iommu-dma-Trace-bounce-buffer-usage-when-mapping-buf.patch
  (git-fixes).
- Refresh
  patches.suse/iommu-dma-Trace-bounce-buffer-usage-when-mapping-buf.patch.
- commit d37ca1f
* Thu Sep 12 2024 jgross@suse.com
- blacklist.conf: add 778c350eb580 ("Revert KVM: async_pf: avoid recursive flushing of work items")
- commit 3ff1683
* Thu Sep 12 2024 jgross@suse.com
- KVM: arm64: Do not re-initialize the KVM lock (git-fixes).
- commit b05c6c8
* Thu Sep 12 2024 mfranc@suse.cz
- s390/dasd: Remove DMA alignment (LTC#208933 bsc#1230426
  git-fixes).
- commit 5b1f3c2
* Thu Sep 12 2024 jgross@suse.com
- KVM: arm64: vgic-v2: Check for non-NULL vCPU in
  vgic_v2_parse_attr() (git-fixes).
- commit 4ccaaf2
* Thu Sep 12 2024 jgross@suse.com
- KVM: arm64: Don't pass a TLBI level hint when zapping table
  entries (git-fixes).
- commit e3cb3e5
* Thu Sep 12 2024 jgross@suse.com
- blacklist.conf: add f62d4c3eb687 ("KVM: arm64: Don't defer TLB invalidation when zapping table entries")
- commit 80a75dc
* Thu Sep 12 2024 jgross@suse.com
- blacklist.conf: add c60d847be7b8 ("KVM: arm64: Fix double-free following kvm_pgtable_stage2_free_unlinked()")
- commit 518faac
* Thu Sep 12 2024 jgross@suse.com
- KVM: arm64: nvhe: Ignore SVE hint in SMCCC function ID
  (git-fixes).
- commit 9d7939a
* Thu Sep 12 2024 tiwai@suse.de
- blacklist.conf: move SP7-specific entries into the own section
- commit 887ee3c
* Thu Sep 12 2024 jgross@suse.com
- KVM: arm64: Block unsafe FF-A calls from the host (git-fixes).
- commit 6327e50
* Thu Sep 12 2024 tiwai@suse.de
- minmax: reduce min/max macro expansion in atomisp driver
  (git-fixes).
- commit 6d37707
* Wed Sep 11 2024 dsterba@suse.com
- net: dsa: bcm_sf2: Fix a possible memory leak in bcm_sf2_mdio_register() (CVE-2024-44971 bsc#1230211)
- commit f262d95
* Wed Sep 11 2024 dsterba@suse.com
- tcp: prevent concurrent execution of tcp_sk_exit_batch (CVE-2024-44991 bsc#1230195)
- commit 179b01d
* Wed Sep 11 2024 dsterba@suse.com
- bonding: fix xfrm real_dev null pointer dereference (CVE-2024-44989 bsc#1230193)
- commit 5caf0d2
* Wed Sep 11 2024 tonyj@suse.de
- perf arch events: Fix duplicate RISC-V SBI firmware event name
  (git-fixes).
- commit 4570763
* Wed Sep 11 2024 tonyj@suse.de
- perf tool: fix dereferencing NULL al->maps (git-fixes).
- commit 5e4751b
* Wed Sep 11 2024 tonyj@suse.de
- perf intel-pt: Fix exclude_guest setting (git-fixes).
- commit e69b63b
* Wed Sep 11 2024 tonyj@suse.de
- perf intel-pt: Fix aux_watermark calculation for 64-bit size
  (git-fixes).
- commit e3b3bca
* Wed Sep 11 2024 tonyj@suse.de
- perf report: Fix condition in sort__sym_cmp() (git-fixes).
- commit c3e65ee
* Wed Sep 11 2024 tonyj@suse.de
- perf pmus: Fixes always false when compare duplicates aliases
  (git-fixes).
- commit 8eeac69
* Wed Sep 11 2024 tonyj@suse.de
- tools/perf: Fix the string match for "/tmp/perf-$PID.map"
  files in dso__load (git-fixes).
- commit 9a7d0fb
* Wed Sep 11 2024 krisman@suse.de
- bonding: fix null pointer deref in bond_ipsec_offload_ok
  (CVE-2024-44990 bsc#1230194).
- media: aspeed: Fix memory overwrite if timing is 1600x900
  (CVE-2023-52916 bsc#1230269).
- commit 7cce3c7
* Wed Sep 11 2024 tonyj@suse.de
- perf test: Make test_arm_callgraph_fp.sh more robust
  (git-fixes).
- commit 8d430e5
* Wed Sep 11 2024 tonyj@suse.de
- perf stat: Fix the hard-coded metrics calculation on the hybrid
  (git-fixes).
- commit 0fe6062
* Wed Sep 11 2024 tonyj@suse.de
- perf pmu: Assume sysfs events are always the same case
  (git-fixes).
- Refresh
  patches.suse/perf-pmu-Count-sys-and-cpuid-JSON-events-separately.patch.
- commit 0eb9b05
* Wed Sep 11 2024 krisman@suse.de
- rtla/osnoise: Prevent NULL dereference in error handling
  (CVE-2024-45002 bsc#1230169).
- net/mlx5e: SHAMPO, Fix invalid WQ linked list unlink
  (CVE-2024-44970 bsc#1230209).
- commit 33e2b5d
* Wed Sep 11 2024 iivanov@suse.de
- config/arm64: Disable platforms which are unsupported in SP7 (jsc#PED-10480)
  Disable platforms enabled because of openSUSE Leap.
  Disabling SoC also automatically disables all leaf
  drivers which directly depends on it.
    Actions Semi SoCs
    Allwinner SoCs
    Annapurna Labs Alpine platform
    Apple Silicon SoC family
    Marvell Berlin SoC Family
    Bitmain SoC Platforms
    Samsung Exynos SoC family
    Microchip Sparx5 SoC Family
    LG Electronics LG1K SoC Family
    Keem Bay SoC
    MediaTek SoC Family
    Amlogic Platforms
    Nuvoton NPCM Architecture
    Qualcomm Platforms
    Realtek Platforms
    Intel SoCFPGA ARMv8 Families
    Spreadtrum SoC platform
    Toshiba Visconti SoC Family
- commit 365bc0b
* Wed Sep 11 2024 oneukum@suse.com
- lirc: rc_dev_get_from_fd(): fix file leak (git-fixes).
- commit b3b20de
* Wed Sep 11 2024 oneukum@suse.com
- thunderbolt: Fix calculation of consumed USB3 bandwidth on a
  path (git-fixes).
- commit c3642e6
* Wed Sep 11 2024 marco.crivellari@suse.com
- Move fixes into sorted section (bsc#1230119)
- commit c8d5e3a
* Wed Sep 11 2024 tiwai@suse.de
- Refresh patches.suse/Bluetooth-qca-Set-both-WIDEBAND_SPEECH-and-LE_STATES.patch
  Correct the chunk after merge conflicts
- commit 0345510
* Wed Sep 11 2024 tiwai@suse.de
- power: sequencing: fix an invalid pointer dereference in error
  path (jsc#PED-10412).
- commit ba2b760
* Wed Sep 11 2024 tiwai@suse.de
- Refresh
  patches.suse/Bluetooth-Fix-double-free-in-hci_conn_cleanup.patch.
- Refresh
  patches.suse/Bluetooth-hci_conn-Only-do-ACL-connections-sequentia.patch.
  Recover the original context after backporting other fixes
- commit 4e1042e
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: MGMT: Fix not generating command complete for
  MGMT_OP_DISCONNECT (jsc#PED-10412).
- Bluetooth: hci_sync: Introduce
  hci_cmd_sync_run/hci_cmd_sync_run_once (jsc#PED-10412).
- Bluetooth: qca: If memdump doesn't work, re-enable IBS
  (jsc#PED-10412).
- Bluetooth: btnxpuart: Fix random crash seen while removing
  driver (jsc#PED-10412).
- Bluetooth: btintel: Allow configuring drive strength of BRI
  (jsc#PED-10412).
- Bluetooth: HCI: Invert LE State quirk to be opt-out rather
  then opt-in (jsc#PED-10412).
- Bluetooth: hci_qca: fix a NULL-pointer derefence at shutdown
  (jsc#PED-10412).
- Bluetooth: hci_qca: fix QCA6390 support on non-DT platforms
  (jsc#PED-10412).
- commit 913dd38
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_qca: don't call pwrseq_power_off() twice for
  QCA6390 (jsc#PED-10412).
- Bluetooth: hci_event: Fix setting DISCOVERY_FINDING for passive
  scanning (jsc#PED-10412).
- Bluetooth: btmtk: remove #ifdef around declarations
  (jsc#PED-10412).
- Bluetooth: btmtk: Fix btmtk.c undefined reference build error
  harder (jsc#PED-10412).
- Bluetooth: btmtk: Fix btmtk.c undefined reference build error
  (jsc#PED-10412).
- Bluetooth: btmtk: Fix kernel crash when entering
  btmtk_usb_suspend (jsc#PED-10412).
- Bluetooth: btmtk: Mark all stub functions as inline
  (jsc#PED-10412).
- Bluetooth: hci_qca: Fix build error (jsc#PED-10412).
- commit 9db9c08
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_qca: use the power sequencer for wcn7850 and
  wcn6855 (jsc#PED-10412).
- Bluetooth: hci_qca: make pwrseq calls the default if available
  (jsc#PED-10412).
- Bluetooth: hci_qca: unduplicate calls to
  hci_uart_register_device() (jsc#PED-10412).
- Bluetooth: hci_qca: schedule a devm action for disabling the
  clock (jsc#PED-10412).
- Bluetooth: btnxpuart: Fix warnings for suspend and resume
  functions (jsc#PED-10412).
- Bluetooth: btnxpuart: Add system suspend and resume handlers
  (jsc#PED-10412).
- Bluetooth: btnxpuart: Add support for IW615 chipset
  (jsc#PED-10412).
- Bluetooth: btnxpuart: Add support for AW693 A1 chipset
  (jsc#PED-10412).
- Bluetooth: btintel: Add support for Whale Peak2 (jsc#PED-10412).
- Bluetooth: btintel: Add support for BlazarU core
  (jsc#PED-10412).
- commit 6b69188
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btusb: mediatek: add ISO data transmission functions
  (jsc#PED-10412).
- Bluetooth: btmtk: move btusb_recv_acl_mtk to btmtk.c
  (jsc#PED-10412).
- Bluetooth: btmtk: move btusb_mtk_[setup, shutdown] to btmtk.c
  (jsc#PED-10412).
- Bluetooth: btmtk: move btusb_mtk_hci_wmt_sync to btmtk.c
  (jsc#PED-10412).
- Bluetooth: btusb: add callback function in btusb suspend/resume
  (jsc#PED-10412).
- Bluetooth: btmtk: rename btmediatek_data (jsc#PED-10412).
- Bluetooth: btusb: mediatek: return error for failed reg access
  (jsc#PED-10412).
- Bluetooth: btusb: mediatek: remove the unnecessary goto tag
  (jsc#PED-10412).
- Bluetooth: Remove hci_request.{c,h} (jsc#PED-10412).
- Bluetooth: hci_sync: Remove remaining dependencies of
  hci_request (jsc#PED-10412).
- commit 73094c1
* Wed Sep 11 2024 tiwai@suse.de
- Update config and supported files: CONFIG_POWER_SEQUENCING (jsc#PED-10412)
- commit 8cfbade
* Wed Sep 11 2024 oneukum@suse.com
- thunderbolt: Constify the struct device_type usage
  (jsc#PED-10361).
- commit c0f552c
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_sync: Move handling of interleave_scan
  (jsc#PED-10412).
- Bluetooth: hci_core: Don't use hci_prepare_cmd (jsc#PED-10412).
- Bluetooth: hci_core: Remove usage of hci_req_sync
  (jsc#PED-10412).
- Bluetooth: hci_core: cleanup struct hci_dev (jsc#PED-10412).
- Bluetooth: btintel: Fix the sfi name for BlazarU
  (jsc#PED-10412).
- Bluetooth: qca: don't disable power management for QCA6390
  (jsc#PED-10412).
- Bluetooth: hci: fix build when POWER_SEQUENCING=m
  (jsc#PED-10412).
- Bluetooth: btintel: Fix spelling of *intermediate* in comment
  (jsc#PED-10412).
- Bluetooth: qca: use the power sequencer for QCA6390
  (jsc#PED-10412).
- Bluetooth: btintel: Add firmware ID to firmware name
  (jsc#PED-10412).
- power: sequencing: implement the pwrseq core (jsc#PED-10412).
- commit ef3a45d
* Wed Sep 11 2024 oneukum@suse.com
- thunderbolt: Add trace events support for the control channel
  (jsc#PED-10361).
- commit 7c01a94
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_core, hci_sync: cleanup struct discovery_state
  (jsc#PED-10412).
- Bluetooth: btnxpuart: Update firmware names (jsc#PED-10412).
- Bluetooth: hci_bcm4377: Add BCM4388 support (jsc#PED-10412).
- Bluetooth: Add vendor-specific packet classification for ISO
  data (jsc#PED-10412).
- Bluetooth: iso: remove unused struct 'iso_list_data'
  (jsc#PED-10412).
- Bluetooth: btintel_pcie: Remove unnecessary memset(0) calls
  (jsc#PED-10412).
- Bluetooth: Use sizeof(*pointer) instead of sizeof(type)
  (jsc#PED-10412).
- Bluetooth: MGMT: Uninitialized variable in load_conn_param()
  (jsc#PED-10412).
- Bluetooth/nokia: Remove unused struct 'hci_nokia_radio_hdr'
  (jsc#PED-10412).
- tty: rfcomm: prefer array indexing over pointer arithmetic
  (jsc#PED-10412).
- commit da8d18e
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_core: Prefer array indexing over pointer
  arithmetic (jsc#PED-10412).
- Bluetooth: hci_core: Prefer struct_size over open coded
  arithmetic (jsc#PED-10412).
- Bluetooth: btintel_pcie: Fix irq leak (jsc#PED-10412).
- Bluetooth: btintel_pcie: Print Firmware Sequencer information
  (jsc#PED-10412).
- Bluetooth: btusb: mediatek: add MT7922 subsystem reset
  (jsc#PED-10412).
- Bluetooth: btusb: mediatek: reset the controller before
  downloading the fw (jsc#PED-10412).
- Bluetooth: btusb: mediatek: refactor the function
  btusb_mtk_reset (jsc#PED-10412).
- Bluetooth: btmtk: apply the common btmtk_fw_get_filename
  (jsc#PED-10412).
- Bluetooth: btmtk: add the function to get the fw name
  (jsc#PED-10412).
- commit 1069025
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btnxpuart: Handle FW Download Abort scenario
  (jsc#PED-10412).
- Bluetooth: btnxpuart: Enable status prints for firmware download
  (jsc#PED-10412).
- Bluetooth: btnxpuart: Fix Null pointer dereference in
  btnxpuart_flush() (jsc#PED-10412).
- Bluetooth: hci_bcm4377: Increase boot timeout (jsc#PED-10412).
- Bluetooth: MGMT: Make MGMT_OP_LOAD_CONN_PARAM update existing
  connection (jsc#PED-10412).
- Bluetooth: btintel_pcie: Fix REVERSE_INULL issue reported by
  coverity (jsc#PED-10412).
- Bluetooth: Add quirk to ignore reserved PHY bits in LE Extended
  Adv Report (jsc#PED-10412).
- Bluetooth: hci_sync: Fix not using correct handle
  (jsc#PED-10412).
- bluetooth: virtio: drop owner assignment (jsc#PED-10412).
- commit 62febf1
* Wed Sep 11 2024 tiwai@suse.de
- Update config and supported files: CONFIG_BT_INTEL_PCIE (jsc#PED-10412)
- commit d0ed0d6
* Wed Sep 11 2024 oneukum@suse.com
- thunderbolt: Keep the domain powered when USB4 port is in
  redrive mode (jsc#PED-10361).
- Refresh
  patches.suse/new-paddings-for-the-new-features-of-TB.patch.
- commit 9b79c66
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btmtksdio: drop driver owner initialization
  (jsc#PED-10412).
- Bluetooth: btmrvl_sdio: drop driver owner initialization
  (jsc#PED-10412).
- Bluetooth: btintel_pcie: Refactor and code cleanup
  (jsc#PED-10412).
- Bluetooth: btintel_pcie: Fix warning reported by sparse
  (jsc#PED-10412).
- Bluetooth: hci_core: Fix not handling hdev->le_num_of_adv_sets=1
  (jsc#PED-10412).
- Bluetooth: btintel: Fix compiler warning for multi_v7_defconfig
  config (jsc#PED-10412).
- Bluetooth: btintel_pcie: Fix compiler warnings (jsc#PED-10412).
- Bluetooth: btintel_pcie: Add *setup* function to download
  firmware (jsc#PED-10412).
- Bluetooth: btintel_pcie: Add support for PCIe transport
  (jsc#PED-10412).
- Bluetooth: btintel: Export few static functions (jsc#PED-10412).
- commit 240b2e1
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: L2CAP: Fix div-by-zero in l2cap_le_flowctl_init()
  (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-Ignore-too-large-handle-values-in-BIG.patch.
- Refresh
  patches.suse/bluetooth-hci-disallow-setting-handle-bigger-than-HC.patch.
- commit 7babf5a
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: compute LE flow credits based on recvbuf space
  (jsc#PED-10412).
- Refresh patches.suse/Bluetooth-L2CAP-Fix-deadlock.patch.
- Refresh
  patches.suse/bluetooth-l2cap-sync-sock-recv-cb-and-release.patch.
- commit f2065ca
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_conn: Use __counted_by() and avoid -Wfamnae
  warning (jsc#PED-10412).
- Bluetooth: btintel: Add support for Filmore Peak2 (BE201)
  (jsc#PED-10412).
- Bluetooth: btintel: Add support for BlazarI (jsc#PED-10412).
- LE Create Connection command timeout increased to 20 secs
  (jsc#PED-10412).
- Bluetooth: hci_sync: Use cmd->num_cis instead of magic number
  (jsc#PED-10412).
- Bluetooth: hci_conn: Use struct_size() in
  hci_le_big_create_sync() (jsc#PED-10412).
- Bluetooth: qca: clean up defines (jsc#PED-10412).
- Bluetooth: qca: drop bogus module version (jsc#PED-10412).
- commit fab50f1
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: qca: drop bogus edl header checks (jsc#PED-10412).
- Bluetooth: hci_conn: Use __counted_by() to avoid -Wfamnae
  warning (jsc#PED-10412).
- Bluetooth: hci_conn, hci_sync: Use __counted_by() to avoid
  - Wfamnae warnings (jsc#PED-10412).
- Bluetooth: btusb: Sort usb_device_id table by the ID
  (jsc#PED-10412).
- Bluetooth: btusb: Add USB HW IDs for MT7921/MT7922/MT7925
  (jsc#PED-10412).
- Bluetooth: qca: Support downloading board id specific NVM for
  WCN7850 (jsc#PED-10412).
- Bluetooth: Populate hci_set_hw_info for Intel and Realtek
  (jsc#PED-10412).
- Bluetooth: Remove 3 repeated macro definitions (jsc#PED-10412).
- Bluetooth: hci_conn: Remove a redundant check for HFP offload
  (jsc#PED-10412).
- Bluetooth: btusb: Correct timeout macro argument used to
  receive control message (jsc#PED-10412).
- commit 70d6028
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: ISO: Handle PA sync when no BIGInfo reports are
  generated (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-hci_event-Set-QoS-encryption-from-BIGInfo-.patch.
- commit 68729b6
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btusb: Fix the patch for MT7920 the affected to
  MT7921 (jsc#PED-10412).
- Bluetooth: hci_bcm: Limit bcm43455 baudrate to 2000000
  (jsc#PED-10412).
- Bluetooth: L2CAP: Avoid -Wflex-array-member-not-at-end warnings
  (jsc#PED-10412).
- Bluetooth: hci_intel: Fix multiple issues reported by
  checkpatch.pl (jsc#PED-10412).
- Bluetooth: ISO: Make iso_get_sock_listen generic
  (jsc#PED-10412).
- Bluetooth: hci_event: Set DISCOVERY_FINDING on SCAN_ENABLED
  (jsc#PED-10412).
- Bluetooth: Add proper definitions for scan interval and window
  (jsc#PED-10412).
- Bluetooth: hci_intel: Convert to platform remove callback
  returning void (jsc#PED-10412).
- Bluetooth: hci_bcm: Convert to platform remove callback
  returning void (jsc#PED-10412).
- commit c4cc5d0
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btqcomsmd: Convert to platform remove callback
  returning void (jsc#PED-10412).
- Bluetooth: Add support for MediaTek MT7922 device
  (jsc#PED-10412).
- Bluetooth: btintel: Add support to download intermediate loader
  (jsc#PED-10412).
- Bluetooth: btintel: Define macros for image types
  (jsc#PED-10412).
- Bluetooth: qca: fix info leak when fetching board id
  (jsc#PED-10412).
- Bluetooth: qca: generalise device address check (jsc#PED-10412).
- Bluetooth: qca: fix wcn3991 device address check
  (jsc#PED-10412).
- Bluetooth: btusb: mediatek: Fix double free of skb in coredump
  (jsc#PED-10412).
- Bluetooth: qca: fix invalid device address check
  (jsc#PED-10412).
- commit b071de5
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_sync: Use advertised PHYs on
  hci_le_ext_create_conn_sync (jsc#PED-10412).
- Revert "Bluetooth: hci_qca: Set BDA quirk bit if fwnode exists
  in DT" (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-qca-fix-device-address-endianness.patch.
- commit c8b7a54
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_sync: Fix UAF in hci_acl_create_conn_sync
  (jsc#PED-10412).
- Bluetooth: mgmt: remove NULL check in
  add_ext_adv_params_complete() (jsc#PED-10412).
- Bluetooth: mgmt: remove NULL check in
  mgmt_set_connectable_complete() (jsc#PED-10412).
- Bluetooth: btusb: Add support Mediatek MT7920 (jsc#PED-10412).
- Bluetooth: ISO: Clean up returns values in iso_connect_ind()
  (jsc#PED-10412).
- Bluetooth: fix use-after-free in accessing skb after sending it
  (jsc#PED-10412).
- Bluetooth: btusb: Fix memory leak (jsc#PED-10412).
- commit 18e7427
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btintel: Print Firmware Sequencer information
  (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-btintel-Fail-setup-on-error.patch.
- commit fd6652b
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: msft: Fix memory leak (jsc#PED-10412).
- Bluetooth: hci_sync: Fix overwriting request callback
  (jsc#PED-10412).
- Bluetooth: hci_sync: Use address filtering when HCI_PA_SYNC
  is set (jsc#PED-10412).
- Bluetooth: ISO: Reassemble PA data for bcast sink
  (jsc#PED-10412).
- Bluetooth: ISO: Add hcon for listening bis sk (jsc#PED-10412).
- Bluetooth: hci_sync: Fix UAF on create_le_conn_complete
  (jsc#PED-10412).
- Bluetooth: hci_sync: Fix UAF on hci_abort_conn_sync
  (jsc#PED-10412).
- Bluetooth: constify the struct device_type usage
  (jsc#PED-10412).
- Bluetooth: btbcm: Use devm_kstrdup() (jsc#PED-10412).
- commit 22de4dc
* Wed Sep 11 2024 oneukum@suse.com
- thunderbolt: Improve DisplayPort tunnel setup process to be
  more robust (jsc#PED-10361).
- commit 4f4f6b4
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_sync: Attempt to dequeue connection attempt
  (jsc#PED-10412).
- Refresh patches.suse/Bluetooth-HCI-Remove-HCI_AMP-support.patch.
- commit c43a167
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_conn: Only do ACL connections sequentially
  (jsc#PED-10412).
- commit a159377
* Wed Sep 11 2024 oneukum@suse.com
- thunderbolt: Calculate DisplayPort tunnel bandwidth after DPRX
  capabilities read (jsc#PED-10361).
- commit 96d3bbc
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btbcm: Use strreplace() (jsc#PED-10412).
- Bluetooth: hci_sync: Add helper functions to manipulate cmd_sync
  queue (jsc#PED-10412).
- Bluetooth: hci_conn: Fix UAF Write in
  __hci_acl_create_connection_sync (jsc#PED-10412).
- Bluetooth: hci_conn: Always use sk_timeo as conn_timeout
  (jsc#PED-10412).
- Bluetooth: Remove pending ACL connection attempts
  (jsc#PED-10412).
- Bluetooth: btusb: Add new VID/PID 13d3/3602 for MT7925
  (jsc#PED-10412).
- Bluetooth: hci_event: Use HCI error defines instead of magic
  values (jsc#PED-10412).
- Bluetooth: Disconnect connected devices before rfkilling adapter
  (jsc#PED-10412).
- commit 8446296
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btrtl: Add the support for RTL8852BT/RTL8852BE-VT
  (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-btusb-Add-RTL8852BE-device-0489-e125-to-de.patch.
- commit b25587c
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: Add new state HCI_POWERING_DOWN (jsc#PED-10412).
- Bluetooth: btnxpuart: Resolve TX timeout error in power save
  stress test (jsc#PED-10412).
- Bluetooth: qca: Fix triggering coredump implementation
  (jsc#PED-10412).
- commit 84f0df9
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_qca: Set BDA quirk bit if fwnode exists in DT
  (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-qca-fix-device-address-endianness.patch.
- commit 743b80e
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btnxpuart: remove useless assignment (jsc#PED-10412).
- Bluetooth: qca: Support HFP offload for QCA2066 (jsc#PED-10412).
- commit ba64060
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btintel: Print firmware SHA1 (jsc#PED-10412).
- Bluetooth: hci_core: Remove le_restart_scan work
  (jsc#PED-10412).
- Bluetooth: Add documentation to exported functions in lib
  (jsc#PED-10412).
- Bluetooth: btusb: Don't suspend when there are connections
  (jsc#PED-10412).
- Bluetooth: ISO: Reassociate a socket with an active BIS
  (jsc#PED-10412).
- Bluetooth: ISO: Allow binding a PA sync socket (jsc#PED-10412).
- Bluetooth: Do not include crypto/algapi.h (jsc#PED-10412).
- Bluetooth: btmtksdio: enable bluetooth wakeup in system suspend
  (jsc#PED-10412).
- Bluetooth: ISO: Copy BASE if service data matches
  EIR_BAA_SERVICE_UUID (jsc#PED-10412).
- Bluetooth: ISO: Fix bcast listener cleanup (jsc#PED-10412).
- commit d0b79ad
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: qca: add support for QCA2066 (jsc#PED-10412).
- blacklist.conf: drop the backported entry
- Refresh
  patches.suse/Bluetooth-qca-fix-info-leak-when-fetching-fw-build-i.patch.
- commit ec94898
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: msft: __hci_cmd_sync() doesn't return NULL
  (jsc#PED-10412).
- Bluetooth: ISO: Match QoS adv handle with BIG handle
  (jsc#PED-10412).
- Bluetooth: ISO: Allow binding a bcast listener to 0 bises
  (jsc#PED-10412).
- Bluetooth: ISO: Set CIS bit only for devices with CIS support
  (jsc#PED-10412).
- Bluetooth: Add support ITTIM PE50-M75C (jsc#PED-10412).
- commit 4aa9f8a
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: rfcomm: remove casts from tty->driver_data
  (jsc#PED-10412).
- Bluetooth: ISO: Add support for periodic adv reports processing
  (jsc#PED-10412).
- commit 34add37
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_core: Fix missing instances using
  HCI_MAX_AD_LENGTH (jsc#PED-10412).
- Refresh patches.suse/Bluetooth-Fix-eir-name-length.patch.
- commit cbae469
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: qca: add support for WCN7850 (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-hci_qca-don-t-use-IS_ERR_OR_NULL-with-gpio.patch.
- Refresh
  patches.suse/Bluetooth-qca-fix-device-address-endianness.patch.
- Refresh
  patches.suse/Bluetooth-qca-set-power_ctrl_enabled-on-NULL-returne.patch.
- commit a63e12d
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: qca: use switch case for soc type behavior
  (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-hci_qca-don-t-use-IS_ERR_OR_NULL-with-gpio.patch.
- Refresh
  patches.suse/Bluetooth-qca-fix-device-address-endianness.patch.
- commit 895c11d
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btnxpuart: Improve inband Independent Reset handling
  (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-btnxpuart-fix-recv_buf-return-value.patch.
- commit 564a779
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_conn: Fix sending
  BT_HCI_CMD_LE_CREATE_CONN_CANCEL (jsc#PED-10412).
- commit 6f9f45a
* Wed Sep 11 2024 oneukum@suse.com
- thunderbolt: Reserve released DisplayPort bandwidth for a
  group for 10 seconds (jsc#PED-10361).
- commit 130bf14
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btnxpuart: Add support for IW624 chipset
  (jsc#PED-10412).
- Bluetooth: btnxpuart: Remove check for CTS low after FW download
  (jsc#PED-10412).
- Bluetooth: hci_conn: avoid checking uninitialized CIG/CIS ids
  (jsc#PED-10412).
- Bluetooth: Remove unnecessary NULL check before vfree()
  (jsc#PED-10412).
- commit e6aa8ab
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_core: Make hci_is_le_conn_scanning public
  (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-hci_sync-Use-QoS-to-determine-which-PHY-to.patch.
- commit 458c1e2
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_sync: Fix handling of HCI_OP_CREATE_CONN_CANCEL
  (jsc#PED-10412).
- commit 1ed4d51
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: ISO: handle bound CIS cleanup via hci_conn
  (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-ISO-Use-defer-setup-to-separate-PA-sync-an.patch.
- commit 920025f
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btqca: Add WCN3988 support (jsc#PED-10412).
- Bluetooth: btnxpuart: Add support for AW693 chipset
  (jsc#PED-10412).
- bluetooth: Explicitly include correct DT includes
  (jsc#PED-10412).
- Bluetooth: btbcm: add default address for BCM43430A1
  (jsc#PED-10412).
- Bluetooth: btmtk: Fix kernel crash when processing coredump
  (jsc#PED-10412).
- Bluetooth: hci_debugfs: Use kstrtobool() instead of strtobool()
  (jsc#PED-10412).
- Bluetooth: MGMT: Fix always using HCI_MAX_AD_LENGTH
  (jsc#PED-10412).
- Bluetooth: msft: Fix error code in
  msft_cancel_address_filter_sync() (jsc#PED-10412).
- Bluetooth: btusb: mediatek: add MediaTek devcoredump support
  (jsc#PED-10412).
- Bluetooth: btmtk: introduce btmtk reset work (jsc#PED-10412).
- Bluetooth: btusb: mediatek: readx_poll_timeout replaces open
  coding (jsc#PED-10412).
- Bluetooth: btmtk: add printing firmware information
  (jsc#PED-10412).
- Bluetooth: hci_sync: Enable events for BIS capable devices
  (jsc#PED-10412).
- commit 1c732d6
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: msft: Extended monitor tracking by address filter
  (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-HCI-Introduce-HCI_QUIRK_BROKEN_LE_CODED.patch.
- Refresh
  patches.suse/Bluetooth-msft-fix-slab-use-after-free-in-msft_do_cl.patch.
- commit f5005b6
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: btusb: Add support Mediatek MT7925 (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-btmtk-Add-MODULE_FIRMWARE-for-MT7922.patch.
- commit ff226e0
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: ISO: Support multiple BIGs (jsc#PED-10412).
- Refresh patches.suse/Bluetooth-ISO-Fix-BIS-cleanup.patch.
- commit ea5b8bb
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_sock: Forward credentials to monitor
  (jsc#PED-10412).
- Refresh
  patches.suse/Bluetooth-af_bluetooth-Make-BT_PKT_STATUS-generic.patch.
- commit e0517ad
* Wed Sep 11 2024 tiwai@suse.de
- Bluetooth: hci_qca: Add qcom devcoredump support
  (jsc#PED-10412).
- Bluetooth: hci_qca: Add qcom devcoredump sysfs support
  (jsc#PED-10412).
- Bluetooth: Init sk_peer_* on bt_sock_alloc (jsc#PED-10412).
- Bluetooth: Consolidate code around sk_alloc into a helper
  function (jsc#PED-10412).
- Bluetooth: Check for ISO support in controller (jsc#PED-10412).
- commit 1901fd5
* Wed Sep 11 2024 tiwai@suse.de
- Refresh patches.suse/ipmi-ssif-Improve-detecting-during-probing.patch
  Add commit id and move away from out-of-tree section
- commit ceb6869
* Wed Sep 11 2024 tiwai@suse.de
- Move upstreamed kaslr patch into sorted section
- commit 554594b
* Wed Sep 11 2024 pjakobsson@suse.de
- blacklist.conf: 28083ff18d3f accel/ivpu: Fix DevTLB errors on suspend/resume and recovery
- commit 195a7fc
* Wed Sep 11 2024 dsterba@suse.com
- net: dsa: mv88e6xxx: Fix out-of-bound access (CVE-2024-44988 bsc#1230192)
- commit 5ca3065
* Wed Sep 11 2024 dsterba@suse.com
- ipv6: prevent UAF in ip6_send_skb() (CVE-2024-44987 bsc#1230185)
- commit 075c292
* Wed Sep 11 2024 tonyj@suse.de
- perf tools: Add/use PMU reverse lookup from config to name
  (git-fixes).
- commit 62632fc
* Wed Sep 11 2024 tonyj@suse.de
- perf tools: Use pmus to describe type from attribute
  (git-fixes).
- commit 3dc616b
* Wed Sep 11 2024 tonyj@suse.de
- perf: script: add raw|disasm arguments to --insn-trace option
  (git-fixes).
- Refresh
  patches.suse/perf-script-Show-also-errors-for-insn-trace-option.patch.
- commit f716aa4
* Wed Sep 11 2024 tonyj@suse.de
- perf annotate: Use global annotation_options (git-fixes).
- Refresh
  patches.suse/perf-annotate-Fix-annotation_calc_lines-to-pass-correct-address-to-get_srcline.patch.
- commit b70a6bc
* Wed Sep 11 2024 tonyj@suse.de
- perf top: Convert to the global annotation_options (git-fixes).
- commit c12ae1d
* Wed Sep 11 2024 tonyj@suse.de
- perf report: Convert to the global annotation_options
  (git-fixes).
- commit e5bcc3a
* Wed Sep 11 2024 tonyj@suse.de
- perf annotate: Introduce global annotation_options (git-fixes).
- commit b458961
* Wed Sep 11 2024 tonyj@suse.de
- perf maps: Move symbol maps functions to maps.c (git-fixes).
- Refresh
  patches.suse/perf-symbols-Fix-ownership-of-string-in-dso__load_vmlinux.patch.
- commit 93caf35
* Wed Sep 11 2024 tonyj@suse.de
- perf annotate: Split branch stack cycles information out of
  'struct annotation_line' (git-fixes).
- commit 733d4c0
* Wed Sep 11 2024 tonyj@suse.de
- perf machine thread: Remove exited threads by default
  (git-fixes).
- commit 3c4b077
* Wed Sep 11 2024 dsterba@suse.com
- Update references for patches.suse/ipv6-fix-possible-UAF-in-ip6_finish_output2.patch (CVE-2024-44986 bsc#1230230 bsc#1230206)
- commit 814e7ee
* Wed Sep 11 2024 dsterba@suse.com
- bnxt_en: Fix double DMA unmapping for XDP_REDIRECT (CVE-2024-44984 bsc#1230240)
- commit 43e2e07
* Wed Sep 11 2024 dsterba@suse.com
- gtp: pull network headers in gtp_dev_xmit() (CVE-2024-44999 bsc#1230233)
- commit 057aaf8
* Tue Sep 10 2024 tonyj@suse.de
- perf record: Lazy load kernel symbols (git-fixes).
- commit 84efd43
* Tue Sep 10 2024 tonyj@suse.de
- Detect memory allocation failure in
  annotated_source__alloc_histograms (bsc#1227962).
- commit 6424d7a
* Tue Sep 10 2024 tonyj@suse.de
- Add alternate commit id for git-fixes.
  Refresh
  patches.suse/perf-evlist-Fix-evlist__new_default-for-1-core-PMU.patch.
- commit 3b7c481
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: There are only 5 basic router registers in pre-USB4
  routers (git-fixes).
- commit 065ac58
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Introduce tb_tunnel_direction_downstream()
  (jsc#PED-10361).
- commit ba7c759
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Re-order bandwidth group functions (jsc#PED-10361).
- commit d12ba0d
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Fail the failed bandwidth request properly
  (jsc#PED-10361).
- commit caec991
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Log an error if DPTX request is not cleared
  (jsc#PED-10361).
- commit 0e05631
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Handle bandwidth allocation mode disable request
  (jsc#PED-10361).
- commit 5ad8932
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Re-calculate estimated bandwidth when allocation
  mode is enabled (jsc#PED-10361).
- commit 4ff0de4
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Use DP_LOCAL_CAP for maximum bandwidth calculation
  (jsc#PED-10361).
- commit ae9bf79
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Correct typo in host_reset parameter
  (jsc#PED-10361).
- commit ef318a9
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Skip discovery also in USB4 v2 host
  (jsc#PED-10361).
- commit 7ae281c
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Remove usage of the deprecated ida_simple_xx()
  API (jsc#PED-10361).
- commit a696c4b
* Tue Sep 10 2024 oneukum@suse.com
- Documentation: core-api: Drop :export: for int_log.h
  (jsc#PED-8643).
- commit 8ef6285
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Fix rollback in tb_port_lane_bonding_enable()
  for lane 1 (git-fixes).
- commit 108e81e
* Tue Sep 10 2024 tiwai@suse.de
- dmaengine: add channel device name to channel registration
  (jsc#PED-10356).
- dmaengine: add missing MODULE_DESCRIPTION() macros
  (jsc#PED-10356).
- commit 7a3dcb1
* Tue Sep 10 2024 tiwai@suse.de
- dmaengine: idxd: Check for driver name match before sva user
  feature (jsc#PED-10356).
- dmaengine: idxd: constify the struct device_type usage
  (jsc#PED-10356).
- dmaengine: idxd: make dsa_bus_type const (jsc#PED-10356).
- commit 968852c
* Tue Sep 10 2024 tiwai@suse.de
- dmaengine: idxd: Remove shadow Event Log head stored in idxd
  (jsc#PED-10356).
- Refresh
  patches.suse/dmaengine-idxd-Convert-spinlock-to-mutex-to-lock-evl.patch.
- commit a5dcf0b
* Tue Sep 10 2024 tiwai@suse.de
- dmaengine: idxd: Remove usage of the deprecated ida_simple_xx()
  API (jsc#PED-10356).
- dmaengine: idxd: Fix incorrect descriptions for GRPCFG register
  (jsc#PED-10356).
- dmaengine: idxd: rate limit printk in misc interrupt thread
  (jsc#PED-10356).
- dmaengine:idxd: Use local64_try_cmpxchg in
  perfmon_pmu_event_update (jsc#PED-10356).
- commit e000083
* Tue Sep 10 2024 tiwai@suse.de
- dmaengine: idxd: No need to clear memory after a
  dma_alloc_coherent() call (jsc#PED-10356).
- Refresh
  patches.suse/dmaengine-idxd-Convert-spinlock-to-mutex-to-lock-evl.patch.
- commit c702328
* Tue Sep 10 2024 iivanov@suse.de
- ipmi:ssif: Improve detecting during probing (bsc#1228771)
- commit db0a09e
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Fix XDomain rx_lanes_show and tx_lanes_show
  (git-fixes).
- commit b11c099
* Tue Sep 10 2024 tiwai@suse.de
- Drop soundwire patch that caused a regression (bsc#1230350)
  Deleted:
  patches.suse/soundwire-stream-fix-programming-slave-ports-for-non.patch
- commit 5c05eeb
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Reset topology created by the boot firmware
  (jsc#PED-10361).
- commit fd7acbb
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: Reduce retry timeout to speed up boot for some
  devices (jsc#PED-10232).
- commit 1dfc48d
* Tue Sep 10 2024 fdmanana@suse.com
- btrfs: fix race between direct IO write and fsync when using
  same fd (git-fixes).
- commit dc59ebc
* Tue Sep 10 2024 oneukum@suse.com
- thunderbolt: make tb_bus_type const (jsc#PED-10232).
- commit 04ab8d9
* Tue Sep 10 2024 pjakobsson@suse.de
- clk: bcm: rpi: Assign ->num before accessing ->hws (git-fixes).
- commit 860d52d
* Tue Sep 10 2024 pjakobsson@suse.de
- clk: bcm: dvp: Assign ->num before accessing ->hws (git-fixes).
- commit c22e6ac
* Tue Sep 10 2024 pjakobsson@suse.de
- accel/ivpu: Don't enable any tiles by default on VPU40xx (git-fixes).
- commit 67e76ed
* Tue Sep 10 2024 pjakobsson@suse.de
- accel/ivpu: Disable PLL after VPU IP reset during FLR (git-fixes).
- commit f64a3b8
* Tue Sep 10 2024 pjakobsson@suse.de
- mm: fix VMA heap bounds checking (git-fixes).
- commit e4218bb
* Tue Sep 10 2024 pjakobsson@suse.de
- accel/ivpu/37xx: Fix hangs related to MMIO reset (git-fixes).
- commit 94760b1
* Tue Sep 10 2024 vbabka@suse.cz
- mm/swap: fix race when skipping swapcache (CVE-2024-26759
  bsc#1230340).
- commit 990c0c6
* Tue Sep 10 2024 dwagner@suse.de
- blacklist: drop 1147dd050356 ("nvme: fix error-handling for io_uring
  nvme-passthrough")
  The nvme subsystem will be updated to latest upstream version (jsc#120381).
  Thus remove this fix from the blacklist.
- commit d92abec
* Tue Sep 10 2024 davide.benini@suse.com
- blacklist.conf: remove entry for "netrom: no security implications in reading
  the value - WONTFIX - CVE-2024-27419 - bsc#1224759"
  The CVE was marked as WONTFIX in a previous version, as there were no security
  implications with it.
  As it is not a breaker, I am now removing the entry from the blacklist
- commit 03b7aa4
* Tue Sep 10 2024 tiwai@suse.de
- wifi: iwlwifi: remove fw_running op (stable-fixes).
- commit 2a8c267
* Tue Sep 10 2024 tiwai@suse.de
- kABI workaround for cros_ec stuff (git-fixes).
- commit cb01b4e
* Tue Sep 10 2024 tiwai@suse.de
- platform/chrome: cros_ec_lpc: MEC access can use an AML mutex
  (stable-fixes).
- commit d9de020
* Mon Sep  9 2024 ohering@suse.de
- Drivers: hv: vmbus: Fix rescind handling in uio_hv_generic
  (git-fixes).
- uio_hv_generic: Fix kernel NULL pointer dereference in
  hv_uio_rescind (git-fixes).
- net: mana: Fix error handling in mana_create_txq/rxq's NAPI
  cleanup (git-fixes).
- commit 27572d4
* Mon Sep  9 2024 jgross@suse.com
- x86/pat: Fix W^X violation false-positives when running as
  Xen PV guest (bsc#1221527).
- commit 9acf0ca
* Mon Sep  9 2024 jgross@suse.com
- x86/pat: Restructure _lookup_address_cpa() (bsc#1221527).
- commit 56f7c9c
* Mon Sep  9 2024 nik.borisov@suse.com
- x86/resctrl: Fix uninitialized memory read when last CPU of domain  goes offline (git-fixes).
- commit 11e8cdf
* Mon Sep  9 2024 nik.borisov@suse.com
- x86/resctrl: Fix arch_mbm_* array overrun on SNC (git-fixes).
- commit 34a43df
* Mon Sep  9 2024 nik.borisov@suse.com
- x86/resctrl: Don't try to free nonexistent RMIDs (git-fixes).
- commit 26fde78
* Mon Sep  9 2024 nik.borisov@suse.com
- x86/cpu/intel: Drop stray FAM6 check with new Intel CPU model defines (git-fixes).
- Refresh patches.suse/ASoC-Intel-avs-es8336-Switch-to-new-Intel-CPU-model-define.patch.
- commit a41e10c
* Mon Sep  9 2024 msuchanek@suse.de
- powerpc/qspinlock: Fix deadlock in MCS queue (bac#1230295
  ltc#206656).
- commit c4a2ba1
* Mon Sep  9 2024 mwilck@suse.com
- Refresh
  patches.kabi/kabi-dm_blk_ioctl-implement-path-failover-for-SG_IO.patch.
- Refresh
  patches.suse/dm_blk_ioctl-implement-path-failover-for-SG_IO.patch.
- commit 73c5a36
* Mon Sep  9 2024 tiwai@suse.de
- ASoC: Intel: Boards: Fix NULL pointer deref in BYT/CHT boards
  harder (git-fixes).
- commit 8bf5c93
* Mon Sep  9 2024 jgross@suse.com
- x86/mm: Use lookup_address_in_pgd_attr() in show_fault_oops()
  (bsc#1221527).
- commit 84d383c
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu/37xx: Fix missing VPUIP interrupts (drm-backport-placeholder)
- commit fb067bc
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Extend address range for MMU mmap (drm-backport-placeholder)
- commit 5833592
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Don't enter d0i3 during FLR (drm-backport-placeholder)
- commit f877c9b
* Mon Sep  9 2024 pjakobsson@suse.de
- fbdev: mmp: Annotate struct mmp_path with __counted_by (drm-backport-placeholder)
- commit 9259874
* Mon Sep  9 2024 pjakobsson@suse.de
- fbdev: mmp: Annotate struct mmphw_ctrl with __counted_by (drm-backport-placeholder)
- commit 5688792
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu/40xx: Fix missing VPUIP interrupts (drm-backport-placeholder)
- commit 46a2194
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu/40xx: Disable frequency change interrupt (drm-backport-placeholder)
- commit 0c31759
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu/40xx: Ensure clock resource ownership Ack before Power-Up (drm-backport-placeholder)
- commit 825debe
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Add Arrow Lake pci id (drm-backport-placeholder)
- commit 5066621
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu/40xx: Fix buttress interrupt handling (drm-backport-placeholder)
- commit 87d77b6
* Mon Sep  9 2024 jgross@suse.com
- x86/pat: Introduce lookup_address_in_pgd_attr() (bsc#1221527).
- commit 09ca5ca
* Mon Sep  9 2024 pjakobsson@suse.de
- drm/i915/gvt: Drop final dependencies on KVM internal details (drm-backport-placeholder).
- Refresh patches.suse/0566-drm-i915-gvt-remove-unused-to_gvt-and-reduce-include.patch.
- commit 40d8f09
* Mon Sep  9 2024 pjakobsson@suse.de
- clk: Annotate struct clk_hw_onecell_data with __counted_by (drm-backport-placeholder)
- commit 73504c4
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Add initial support for VPU 4 (drm-backport-placeholder)
- commit 66b70a3
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Refactor memory ranges logic (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071)
- commit 357f874
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Switch to generation based FW names (drm-backport-placeholder)
- commit c33f7f9
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Use generation based function and registers names (drm-backport-placeholder)
- commit ea56e2d
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Rename sources to use generation based names (drm-backport-placeholder)
- commit 1fa8cfd
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/qaic: remove redundant pointer pexec (drm-backport-placeholder)
- commit 7c25d6c
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Add fw_name file to debugfs (drm-backport-placeholder)
- commit 890f7b1
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Print firmware name and version (drm-backport-placeholder)
- commit d14887a
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Add debugfs files for testing device reset (drm-backport-placeholder)
- commit 994d046
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Add firmware tracing support (drm-backport-placeholder)
- commit 2afc9cd
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Initial debugfs support (drm-backport-placeholder)
- commit 89efe4b
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Mark 64 kB contiguous areas as contiguous in PTEs (drm-backport-placeholder)
- commit 857f841
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Rename and cleanup MMU600 page tables (drm-backport-placeholder)
- commit 39c8cf5
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Make DMA bit mask HW specific (drm-backport-placeholder)
- commit 134f6b3
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Add MMU support for 4 level page mappings (drm-backport-placeholder)
- commit c21d3f1
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Remove configuration of MMU TBU1 and TBU3 (drm-backport-placeholder)
- commit ace013a
* Mon Sep  9 2024 pjakobsson@suse.de
- accel/ivpu: Use struct_size() (drm-backport-placeholder)
- commit 9163143
* Mon Sep  9 2024 pjakobsson@suse.de
- drm/amdkfd: use vma_is_initial_stack() and vma_is_initial_heap() (drm-backport-placeholder)
- commit 4163224
* Mon Sep  9 2024 pjakobsson@suse.de
- mm: factor out VMA stack and heap checks (drm-backport-placeholder)
- commit eab730c
* Mon Sep  9 2024 nik.borisov@suse.com
- x86/tsc_msr: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit bbbc536
* Mon Sep  9 2024 nik.borisov@suse.com
- tools/power/turbostat: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit cac6e9d
* Mon Sep  9 2024 nik.borisov@suse.com
- Documentation/x86: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit cc064d5
* Mon Sep  9 2024 nik.borisov@suse.com
- peci, hwmon: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 7fef22b
* Mon Sep  9 2024 nik.borisov@suse.com
- media: atomisp: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit de81d9e
* Mon Sep  9 2024 nik.borisov@suse.com
- ACPI: x86: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 3a6f10e
* Mon Sep  9 2024 nik.borisov@suse.com
- platform/x86/intel/ifs: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 134570d
* Mon Sep  9 2024 nik.borisov@suse.com
- PCI/PM: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit cbdf496
* Mon Sep  9 2024 nik.borisov@suse.com
- thermal: intel: intel_soc_dts_thermal: Switch to new Intel CPU model  defines (jsc#PED-10246,jsc#PED-10350).
- commit 32eefc8
* Mon Sep  9 2024 nik.borisov@suse.com
- powercap: intel_rapl: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit b9580b6
* Mon Sep  9 2024 nik.borisov@suse.com
- powercap: intel_rapl_msr: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit ca14f1d
* Mon Sep  9 2024 nik.borisov@suse.com
- thermal: intel: intel_tcc_cooling: Switch to new Intel CPU model  defines (jsc#PED-10246,jsc#PED-10350).
- commit c8ce5de
* Mon Sep  9 2024 nik.borisov@suse.com
- intel_idle: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 7b2aaa6
* Mon Sep  9 2024 nik.borisov@suse.com
- cpufreq: intel_pstate: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit e12554f
* Mon Sep  9 2024 nik.borisov@suse.com
- cpufreq: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 89a6ffd
* Mon Sep  9 2024 nik.borisov@suse.com
- ACPI: LPSS: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 1669d2e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1373-drm-amd-Disable-ASPM-for-VI-w-all-Intel-systems.patch (drm-backport-placeholder)
- commit 9b53da2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1372-drm-i915-pmu-Check-if-pmu-is-closed-before-stopping-.patch (drm-backport-placeholder)
- commit 413c4bc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1371-drm-i915-mcr-Hold-GT-forcewake-during-steering-opera.patch (drm-backport-placeholder)
- commit cc1ab52
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1370-drm-i915-perf-Determine-context-valid-in-OA-reports.patch (drm-backport-placeholder)
- commit 2f2faeb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1369-drm-logicvc-Kconfig-select-REGMAP-and-REGMAP_MMIO.patch (drm-backport-placeholder)
- commit b6470ad
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1368-drm-amdkfd-reserve-a-fence-slot-while-locking-the-BO.patch (drm-backport-placeholder)
- commit b974cec
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1367-drm-amdgpu-Remove-redundant-call-to-priority_is_vali.patch (drm-backport-placeholder)
- commit dcc4165
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1366-drm-dp_mst-Fix-NULL-deref-in-get_mst_branch_device_b.patch (drm-backport-placeholder)
- commit 61f074a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1365-drm-amdgpu-ignore-duplicate-BOs-again.patch (drm-backport-placeholder)
- commit b94fad1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1364-drm-mediatek-Correctly-free-sg_table-in-gem-prime-vm.patch (drm-backport-placeholder)
- commit e11ca26
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1363-drm-i915-Retry-gtt-fault-when-out-of-fence-registers.patch (drm-backport-placeholder)
- commit 55a2bbd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1362-drm-i915-cx0-Only-clear-set-the-Pipe-Reset-bit-of-th.patch (drm-backport-placeholder)
- commit 28c51c6
* Mon Sep  9 2024 nik.borisov@suse.com
- tpm: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 153217e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1361-gpu-drm-Eliminate-DRM_SCHED_PRIORITY_UNSET.patch (drm-backport-placeholder)
- commit 6bf2051
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1360-drm-amdgpu-Unset-context-priority-is-now-invalid.patch (drm-backport-placeholder)
- commit 9301174
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1359-drm-edid-add-8-bpc-quirk-to-the-BenQ-GW2765.patch (drm-backport-placeholder)
- commit e1edd05
* Mon Sep  9 2024 nik.borisov@suse.com
- KVM: VMX: Switch to new Intel CPU model infrastructure (jsc#PED-10246,jsc#PED-10350).
- commit eb9c8a3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1358-drm-ttm-Reorder-sys-manager-cleanup-step.patch (drm-backport-placeholder)
- commit 48b5379
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1357-drm-nouveau-disp-fix-DP-capable-DSM-connectors.patch (drm-backport-placeholder)
- commit bff79b4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1356-drm-nouveau-exec-fix-ioctl-kernel-doc-warning.patch (drm-backport-placeholder)
- commit 9b07d5b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1355-drm-panel-Move-AUX-B116XW03-out-of-panel-edp-back-to.patch (drm-backport-placeholder)
- commit 4f7a6ed
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1354-drm-bridge-ti-sn65dsi86-Associate-DSI-device-lifetim.patch (drm-backport-placeholder)
- commit 7f905cd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1353-drm-amdgpu-Reserve-fences-for-VM-update.patch (drm-backport-placeholder)
- commit ff660a2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1351-fbdev-core-syscopyarea-fix-sloppy-typing.patch (drm-backport-placeholder)
- commit c3cb853
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1350-fbdev-core-cfbcopyarea-fix-sloppy-typing.patch (drm-backport-placeholder)
- commit 5d19887
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1349-fbdev-uvesafb-Call-cn_del_callback-at-the-end-of-uve.patch (drm-backport-placeholder)
- commit 7b0bf51
* Mon Sep  9 2024 nik.borisov@suse.com
- KVM: x86/pmu: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 6947c06
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1348-fbdev-uvesafb-Remove-uvesafb_exec-prototype-from-inc.patch (drm-backport-placeholder)
- commit c553785
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1347-fbdev-sa1100fb-mark-sa1100fb_init-static.patch (drm-backport-placeholder)
- commit aad041f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1346-fbdev-omapfb-fix-some-error-codes.patch (drm-backport-placeholder)
- commit 43ead21
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1345-fbdev-atyfb-only-use-ioremap_uc-on-i386-and-ia64.patch (drm-backport-placeholder)
- commit 3b57ca4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1344-drm-amdgpu-fix-SI-failure-due-to-doorbells-allocatio.patch (drm-backport-placeholder)
- commit 6ff6ffb
* Mon Sep  9 2024 nik.borisov@suse.com
- platform/x86: intel_scu_wdt: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 0f741cc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1343-drm-amdgpu-add-missing-NULL-check.patch (drm-backport-placeholder)
- commit 4edfbec
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1342-drm-amd-display-Don-t-set-dpms_off-for-seamless-boot.patch (drm-backport-placeholder)
- commit 138bd7c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1341-drm-msm-dpu-fail-dpu_plane_atomic_check-based-on-mdp.patch (drm-backport-placeholder)
- commit 966790c
* Mon Sep  9 2024 nik.borisov@suse.com
- platform/x86: intel_speed_select_if: Switch to new Intel CPU model  defines (jsc#PED-10246,jsc#PED-10350).
- commit a04d8a1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1340-drm-msm-dp-Add-newlines-to-debug-printks.patch (drm-backport-placeholder)
- commit 73a6703
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1339-drm-msm-dpu-change-_dpu_plane_calc_bw-to-use-u64-to-.patch (drm-backport-placeholder)
- commit d8b61f6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1338-drm-msm-dsi-fix-irq_of_parse_and_map-error-checking.patch (drm-backport-placeholder)
- commit 7aebf3d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1337-drm-msm-dsi-skip-the-wait-for-video-mode-done-if-not.patch (drm-backport-placeholder)
- commit be54b87
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1336-drm-msm-mdss-fix-highest-bank-bit-for-msm8998.patch (drm-backport-placeholder)
- commit 0a1b54d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1335-drm-msm-dp-do-not-reinitialize-phy-unless-retry-duri.patch (drm-backport-placeholder)
- commit 7164e4d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1334-drm-tiny-correctly-print-struct-resource-on-error.patch (drm-backport-placeholder)
- commit 9d4eaaf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1333-drm-atomic-helper-relax-unregistered-connector-check.patch (drm-backport-placeholder)
- commit 405dfe2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1332-drm-panel-boe-tv101wum-nl6-Completely-pull-GPW-to-VG.patch (drm-backport-placeholder)
- commit 2520377
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0001-drm-vmwgfx-Keep-a-gem-reference-to-user-bos-in-surfa.patch (drm-backport-placeholder)
- commit 7c169da
* Mon Sep  9 2024 nik.borisov@suse.com
- platform/x86: intel-uncore-freq: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 6d966d3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1330-drm-vmwgfx-fix-typo-of-sizeof-argument.patch (drm-backport-placeholder)
- commit b71907e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1329-dma-buf-add-dma_fence_timestamp-helper.patch (drm-backport-placeholder)
- commit 72a9e5f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1328-drm-nouveau-exec-report-max-pushs-through-getparam.patch (drm-backport-placeholder)
- commit 158cf3e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1327-drm-nouveau-chan-use-channel-class-definitions.patch (drm-backport-placeholder)
- commit 8ce7b79
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1326-drm-nouveau-chan-use-struct-nvif_mclass.patch (drm-backport-placeholder)
- commit d7b4fc4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1325-drm-panel-orientation-quirks-Add-quirk-for-One-Mix-2.patch (drm-backport-placeholder)
- commit b2406aa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1324-drm-tests-Fix-kunit_release_action-ctx-argument.patch (drm-backport-placeholder)
- commit 8870625
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1323-drm-amd-display-apply-edge-case-DISPCLK-WDIVIDER-cha.patch (drm-backport-placeholder)
- commit cb73def
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1322-drm-amd-Fix-detection-of-_PR3-on-the-PCIe-root-port.patch (drm-backport-placeholder)
- commit cab59c8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1321-drm-amd-Fix-logic-error-in-sienna_cichlid_update_pci.patch (drm-backport-placeholder)
- commit 7083b49
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1320-drm-amdgpu-Fix-a-memory-leak.patch (drm-backport-placeholder)
- commit 64d7348
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1319-drm-amd-pm-add-unique_id-for-gc-11.0.3.patch (drm-backport-placeholder)
- commit 72c746f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1318-drm-i915-Invalidate-the-TLBs-on-each-GT.patch (drm-backport-placeholder)
- commit af8b7f7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1317-drm-i915-Register-engines-early-to-avoid-type-confus.patch (drm-backport-placeholder)
- commit d409c9c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1316-drm-i915-Don-t-set-PIPE_CONTROL_FLUSH_L3-for-aux-inv.patch (drm-backport-placeholder)
- commit 298c303
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1315-i915-guc-Get-runtime-pm-in-busyness-worker-only-if-a.patch (drm-backport-placeholder)
- commit 68a3a4e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1314-drm-i915-gt-Fix-reservation-address-in-ggtt_reserve_.patch (drm-backport-placeholder)
- commit 6851ff4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1313-drm-amdkfd-Use-gpu_offset-for-user-queue-s-wptr.patch (drm-backport-placeholder)
- commit 97beeee
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-the-ability-to-use-lower-resolut.patch (drm-backport-placeholder)
- commit 5de1824
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1311-drm-amdgpu-fix-a-memory-leak-in-amdgpu_ras_feature_e.patch (drm-backport-placeholder)
- commit 4110332
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1310-Revert-drm-amdgpu-Report-vbios-version-instead-of-PN.patch (drm-backport-placeholder)
- commit 3dca1ff
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1309-drm-amd-display-Fix-MST-recognizes-connected-display.patch (drm-backport-placeholder)
- commit 7f098ab
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/i915-pmu-Move-execlist-stats-initialization-to-execl.patch (drm-backport-placeholder)
- commit bb3d876
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1307-drm-i915-gt-Prevent-error-pointer-dereference.patch (drm-backport-placeholder)
- commit 4f4eb8f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1306-fbdev-sh7760fb-Depend-on-FB-y.patch (drm-backport-placeholder)
- commit 8b1e9ec
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-virtio-clean-out_fence-on-complete_submit.patch (drm-backport-placeholder)
- commit 9293fe5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-meson-fix-memory-leak-on-hpd_notify-callback.patch (drm-backport-placeholder)
- commit 9a50bc2
* Mon Sep  9 2024 nik.borisov@suse.com
- platform/x86: intel_ips: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 3ed03cd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1303-nouveau-u_memcpya-fix-NULL-vs-error-pointer-bug.patch (drm-backport-placeholder)
- commit 83c6407
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1302-nouveau-u_memcpya-use-vmemdup_user.patch (drm-backport-placeholder)
- commit 4fc4169
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1301-drm-nouveau-sched-fix-leaking-memory-of-timedout-job.patch (drm-backport-placeholder)
- commit f8a51fa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1300-drm-nouveau-fence-fix-type-cast-warning-in-nouveau_f.patch (drm-backport-placeholder)
- commit 89da4cf
* Mon Sep  9 2024 nik.borisov@suse.com
- platform/x86: intel_turbo_max_3: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 5a7c76a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1299-drm-fix-up-fbdev-Kconfig-defaults.patch (drm-backport-placeholder)
- commit d18d43b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-tests-Fix-incorrect-argument-in-drm_test_mm_inse.patch (drm-backport-placeholder)
- commit cb51ae8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-tests-helpers-Avoid-a-driver-uaf.patch (drm-backport-placeholder)
- commit 8a6f77e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1296-Revert-drm-vkms-Fix-race-condition-between-the-hrtim.patch (drm-backport-placeholder)
- commit 581dd19
* Mon Sep  9 2024 nik.borisov@suse.com
- platform/x86: p2sb: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 5bf30af
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-make-fence-wait-in-suballocator-uninterrr.patch (drm-backport-placeholder)
- commit 7ec8d6c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Only-check-eDP-HPD-when-AUX-CH-is-shared.patch (drm-backport-placeholder)
- commit 8bbc3d8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1293-drm-amdkfd-Insert-missing-TLB-flush-on-GFX10-and-lat.patch (drm-backport-placeholder)
- commit 0dc8333
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1292-drm-amd-display-Fix-2nd-DPIA-encoder-Assignment.patch (drm-backport-placeholder)
- commit fbd9db4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1291-drm-amd-display-Add-DPIA-Link-Encoder-Assignment-Fix.patch (drm-backport-placeholder)
- commit 8a0ef27
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1290-drm-amd-display-fix-replay_mode-kernel-doc-warning.patch (drm-backport-placeholder)
- commit d72d34c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1289-drm-amdgpu-Handle-null-atom-context-in-VBIOS-info-io.patch (drm-backport-placeholder)
- commit aede40b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1288-drm-amdkfd-Checkpoint-and-restore-queues-on-GFX11.patch (drm-backport-placeholder)
- commit b4116c0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1287-drm-amd-display-Adjust-the-MST-resume-flow.patch (drm-backport-placeholder)
- commit 716e403
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1286-drm-amdgpu-fallback-to-old-RAS-error-message-for-aqu.patch (drm-backport-placeholder)
- commit bfd74a6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1285-drm-amdgpu-nbio4.3-set-proper-rmmio_remap.reg_offset.patch (drm-backport-placeholder)
- commit 625c9f1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1284-drm-amdgpu-soc21-don-t-remap-HDP-registers-for-SR-IO.patch (drm-backport-placeholder)
- commit c4c8940
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1283-drm-amd-display-Don-t-check-registers-if-using-AUX-B.patch (drm-backport-placeholder)
- commit 98777e6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1282-drm-amdgpu-fix-retry-loop-test.patch (drm-backport-placeholder)
- commit 842edb1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1281-drm-amd-display-Add-dirty-rect-support-for-Replay.patch (drm-backport-placeholder)
- commit f32b64f
* Mon Sep  9 2024 nik.borisov@suse.com
- x86/platform/atom: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 90cf751
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1280-Revert-drm-amd-Disable-S-G-for-APUs-when-64GB-or-mor.patch (drm-backport-placeholder)
- commit 1e62f43
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-the-white-screen-issue-when-64GB.patch (drm-backport-placeholder)
- commit a07ec01
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1278-drm-amdkfd-Update-CU-masking-for-GFX-9.4.3.patch (drm-backport-placeholder)
- commit e3f3bf0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1277-drm-amdkfd-Update-cache-info-reporting-for-GFX-v9.4..patch (drm-backport-placeholder)
- commit 390994d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1276-drm-amdgpu-Store-CU-info-from-all-XCCs-for-GFX-v9.4..patch (drm-backport-placeholder)
- commit 13866f1
* Mon Sep  9 2024 nik.borisov@suse.com
- platform/x86: intel_telemetry: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit d3d4006
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1275-drm-amdkfd-Fix-unaligned-64-bit-doorbell-warning.patch (drm-backport-placeholder)
- commit a4fb78e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1274-drm-amdkfd-Fix-reg-offset-for-setting-CWSR-grace-per.patch (drm-backport-placeholder)
- commit 7f62bd1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-gm12u320-Fix-the-timeout-usage-for-usb_bulk_msg.patch (drm-backport-placeholder)
- commit c177b9b
* Mon Sep  9 2024 nik.borisov@suse.com
- platform/x86/intel/pmc: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 50e924b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Make-fence-wait-in-suballocator-uninterrupti.patch (drm-backport-placeholder)
- commit 442b0e2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1271-drm-drm_connector-Provide-short-description-of-param.patch (drm-backport-placeholder)
- commit c13de16
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1270-drm-drm_exec-Work-around-a-WW-mutex-lockdep-oddity.patch (drm-backport-placeholder)
- commit dfae0da
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1269-drm-ci-docs-fix-build-warning-add-missing-escape.patch (drm-backport-placeholder)
- commit a62683e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1268-drm-Add-initial-ci-subdirectory.patch (drm-backport-placeholder)
- commit 6ae2380
* Mon Sep  9 2024 nik.borisov@suse.com
- crypto: x86/poly1305 - Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 0977105
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1267-drm-amdgpu-Restrict-bootloader-wait-to-SMUv13.0.6.patch (drm-backport-placeholder)
- commit 19100ee
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-prevent-potential-division-by-zero-e.patch (drm-backport-placeholder)
- commit f6440ae
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-enable-cursor-degamma-for-DCN3-DRM-l.patch (drm-backport-placeholder)
- commit 9362b42
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1264-drm-amd-display-limit-the-v_startup-workaround-to-AS.patch (drm-backport-placeholder)
- commit 04c91c2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amd-display-Remove-v_startup-workaround-f.patch (drm-backport-placeholder)
- commit 4cdceb1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1262-drm-amdgpu-fix-amdgpu_cs_p1_user_fence.patch (drm-backport-placeholder)
- commit 91ea284
* Mon Sep  9 2024 nik.borisov@suse.com
- crypto: x86/twofish - Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit aefad1a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1261-Revert-Revert-drm-amd-display-Implement-zpos-propert.patch (drm-backport-placeholder)
- commit 2d2701c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1260-drm-amdkfd-Add-missing-gfx11-MQD-manager-callbacks.patch (drm-backport-placeholder)
- commit a0065aa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1259-drm-amdgpu-Free-ras-cmd-input-buffer-properly.patch (drm-backport-placeholder)
- commit cca3134
* Mon Sep  9 2024 nik.borisov@suse.com
- ASoC: Intel: avs: es8336: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit e8181fb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1258-drm-amdgpu-Hide-xcp-partition-sysfs-under-SRIOV.patch (drm-backport-placeholder)
- commit 5a75596
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1257-drm-amdgpu-use-read-modify-write-mode-for-gfx-v9_4_3.patch (drm-backport-placeholder)
- commit 2135367
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1256-drm-amdkfd-use-mask-to-get-v9-interrupt-sq-data-bits.patch (drm-backport-placeholder)
- commit 73117b1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1255-drm-amdgpu-Allocate-coredump-memory-in-a-nonblocking.patch (drm-backport-placeholder)
- commit ce187e3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1254-drm-amdgpu-Support-query-ecc-cap-for-aqua_vanjaram.patch (drm-backport-placeholder)
- commit 870b1d3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1253-drm-amdgpu-Add-umc_info-v4_0-structure.patch (drm-backport-placeholder)
- commit d928f04
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-always-switch-off-ODM-before-committ.patch (drm-backport-placeholder)
- commit a0f94ea
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Remove-wait-while-locked.patch (drm-backport-placeholder)
- commit 1b13939
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1250-drm-amd-display-update-blank-state-on-ODM-changes.patch (drm-backport-placeholder)
- commit 0ecafeb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-smu-write-msg-id-fail-retry-proc.patch (drm-backport-placeholder)
- commit ad1cdc1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1248-drm-amdgpu-Add-SMU-v13.0.6-default-reset-methods.patch (drm-backport-placeholder)
- commit ee9cecf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1247-Partially-revert-drm-amd-display-update-add-plane-to.patch (drm-backport-placeholder)
- commit ded2897
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-register-edp_backlight_control-for-D.patch (drm-backport-placeholder)
- commit e1cef22
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1245-drm-amdgpu-Add-bootloader-wait-for-PSP-v13.patch (drm-backport-placeholder)
- commit b348a02
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1244-drm-amdgpu-register-a-dirty-framebuffer-callback-for.patch (drm-backport-placeholder)
- commit adb201f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1243-drm-amdgpu-Updated-TCP-UTCL1-programming.patch (drm-backport-placeholder)
- commit d59d0c2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1242-drm-amd-pm-fix-debugfs-pm_info-output.patch (drm-backport-placeholder)
- commit 039be93
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1241-drm-amdgpu-Fix-the-return-for-gpu-mode1_reset.patch (drm-backport-placeholder)
- commit 2eaf1a4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1240-drm-amd-display-fix-static-screen-detection-setting.patch (drm-backport-placeholder)
- commit 1f10bad
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-mode-scaling-RMX_.patch (drm-backport-placeholder)
- commit 25be854
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1238-drm-amd-pm-Fix-critical-temp-unit-of-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit 28bde79
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1237-drm-amdgpu-Remove-SRAM-clock-gater-override-by-drive.patch (drm-backport-placeholder)
- commit ff52f33
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1236-drm-amdgpu-Add-bootloader-status-check.patch (drm-backport-placeholder)
- commit e18cec0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1235-drm-amdkfd-use-correct-method-to-get-clock-under-SRI.patch (drm-backport-placeholder)
- commit 59b1fb5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1234-drm-amdgpu-Unset-baco-dummy-mode-on-nbio-v7.9.patch (drm-backport-placeholder)
- commit c7aef6a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1233-drm-amd-display-set-minimum-of-VBlank_nom.patch (drm-backport-placeholder)
- commit e5af6b6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1232-drm-amd-display-Correct-unit-conversion-for-vstartup.patch (drm-backport-placeholder)
- commit 0e89681
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1231-drm-amd-display-Roll-back-unit-correction.patch (drm-backport-placeholder)
- commit 0c7b575
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1230-drm-amdgpu-Enable-ras-for-mp0-v13_0_6-sriov.patch (drm-backport-placeholder)
- commit 967163d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1229-drm-amdkfd-retry-after-EBUSY-is-returned-from-hmm_ra.patch (drm-backport-placeholder)
- commit 83c62bc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1228-drm-amdgpu-jpeg-skip-change-of-power-gating-state-fo.patch (drm-backport-placeholder)
- commit d5ce212
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1227-drm-amd-pm-Add-critical-temp-for-GC-v9.4.3.patch (drm-backport-placeholder)
- commit 4bc24ac
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1226-drm-amd-pm-Update-SMUv13.0.6-PMFW-headers.patch (drm-backport-placeholder)
- commit b08c2cf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1225-drm-amdgpu-update-gc_info-v2_1-from-discovery.patch (drm-backport-placeholder)
- commit 29300aa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1224-drm-amdgpu-update-mall-info-v2-from-discovery.patch (drm-backport-placeholder)
- commit 2e6016f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1223-drm-amdgpu-Only-support-RAS-EEPROM-on-dGPU-platform.patch (drm-backport-placeholder)
- commit b9bf33d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1222-Documentation-gpu-Update-amdgpu-documentation.patch (drm-backport-placeholder)
- commit 70056d2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1221-drm-amdgpu-pm-Add-notification-for-no-DC-support.patch (drm-backport-placeholder)
- commit 4e13ab1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1220-drm-amd-display-Enable-Replay-for-static-screen-use-.patch (drm-backport-placeholder)
- commit 56d22cb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-mark-requests-for-GuC-virtual-engines-to-av.patch (drm-backport-placeholder)
- commit 9c892c5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1218-drm-nouveau-fence-fix-undefined-fence-state-after-em.patch (drm-backport-placeholder)
- commit 1628e73
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/accel-ivpu-refactor-deprecated-strncpy.patch (drm-backport-placeholder)
- commit c506064
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gvt-Protect-gfn-hash-table-with-vgpu_lock.patch (drm-backport-placeholder)
- commit 56f1767
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gvt-Drop-unused-helper-intel_vgpu_reset_gtt.patch (drm-backport-placeholder)
- commit 598b396
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gvt-Don-t-rely-on-KVM-s-gfn_to_pfn-to-query.patch (drm-backport-placeholder)
- commit 5cd2916
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gvt-Error-out-on-an-attempt-to-shadowing-an.patch (drm-backport-placeholder)
- commit 25c3702
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gvt-Explicitly-check-that-vGPU-is-attached-.patch (drm-backport-placeholder)
- commit bf052e6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gvt-Put-the-page-reference-obtained-by-KVM-.patch (drm-backport-placeholder)
- commit 3914b4b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gvt-Verify-hugepages-are-contiguous-in-phys.patch (drm-backport-placeholder)
- commit e3c6f1b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gvt-remove-interface-intel_gvt_is_valid_gfn.patch (drm-backport-placeholder)
- commit 1724f5b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gvt-Verify-pfn-is-valid-before-dereferencin.patch (drm-backport-placeholder)
- commit 11b3b91
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1205-backlight-led_bl-Remove-redundant-of_match_ptr.patch (drm-backport-placeholder)
- commit d2c6349
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1204-backlight-lp855x-Drop-ret-variable-in-brightness-cha.patch (drm-backport-placeholder)
- commit 096ede3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/backlight-gpio_backlight-Drop-output-GPIO-direction-.patch (drm-backport-placeholder)
- commit 3c65d96
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1202-backlight-lp855x-Catch-errors-when-changing-brightne.patch (drm-backport-placeholder)
- commit 68f2b64
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/backlight-lp855x-Initialize-PWM-state-on-first-brigh.patch (drm-backport-placeholder)
- commit 617d59e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1200-backlight-qcom-wled-Explicitly-include-correct-DT-in.patch (drm-backport-placeholder)
- commit 39133ad
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1199-fbdev-g364fb-fix-build-failure-with-mips.patch (drm-backport-placeholder)
- commit e2d2d9c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-Update-fbdev-source-file-paths.patch (drm-backport-placeholder)
- commit 3a9b567
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1197-fbdev-ssd1307fb-Use-bool-for-ssd1307fb_deviceinfo-fl.patch (drm-backport-placeholder)
- commit 053597d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1196-fbdev-neofb-Shorten-Neomagic-product-name-in-info-st.patch (drm-backport-placeholder)
- commit c7c703e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1195-fbdev-mx3fb-Remove-the-driver.patch (drm-backport-placeholder)
- commit 9677355
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1194-fbdev-core-Use-list_for_each_entry-helper.patch (drm-backport-placeholder)
- commit 9b786d0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1193-mei-make-mei_class-a-static-const-structure.patch (drm-backport-placeholder)
- commit 25e94c1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1192-mei-gsc-add-module-description.patch (drm-backport-placeholder)
- commit 1d4b194
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1191-mei-pxp-Keep-a-const-qualifier-when-calling-mei_clde.patch (drm-backport-placeholder)
- commit 308f277
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1190-mei-obtain-firmware-version-only-on-gsc.patch (drm-backport-placeholder)
- commit 6424faa
* Mon Sep  9 2024 tiwai@suse.de
- drm/amd/display: Replace dm_execute_dmub_cmd with
  dc_wake_and_execute_dmub_cmd (git-fixes).
- commit 6d87705
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1189-mei-bus-enable-asynchronous-suspend.patch (drm-backport-placeholder)
- commit d276bb7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1188-mei-log-firmware-status-on-hw_start-failure.patch (drm-backport-placeholder)
- commit 933ee42
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1187-tty-sysrq-switch-sysrq-handlers-from-int-to-u8.patch (drm-backport-placeholder)
- commit 6fa4c82
* Mon Sep  9 2024 tiwai@suse.de
- wifi: cfg80211: make hash table duplicates more survivable
  (stable-fixes).
- Refresh patches.kabi/wireless-kabi-workaround.patch.
- commit 62f6e12
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1186-PCI-VGA-Fix-typos.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit f4e4bed
* Mon Sep  9 2024 tiwai@suse.de
- VMCI: Fix use-after-free when removing resource in
  vmci_resource_remove() (git-fixes).
- misc: fastrpc: Fix double free of 'buf' in error path
  (git-fixes).
- iio: fix scale application in
  iio_convert_raw_to_processed_unlocked (git-fixes).
- iio: adc: ad7124: fix config comparison (git-fixes).
- iio: adc: ad7124: fix chip ID mismatch (git-fixes).
- iio: buffer-dmaengine: fix releasing dma channel on error
  (git-fixes).
- iio: adc: ad7606: remove frstdata check for serial mode
  (git-fixes).
- staging: iio: frequency: ad9834: Validate frequency parameter
  value (git-fixes).
- usb: dwc3: Avoid waking up gadget during startxfer (git-fixes).
- net: usb: qmi_wwan: add MeiG Smart SRM825L (stable-fixes).
- drm/gpuvm: fix missing dependency to DRM_EXEC (git-fixes).
- drm: panel-orientation-quirks: Add quirk for OrangePi Neo
  (stable-fixes).
- drm/fb-helper: Don't schedule_work() to flush frame buffer
  during panic() (stable-fixes).
- PCI: al: Check IORESOURCE_BUS existence during probe
  (stable-fixes).
- usb: typec: ucsi: Fix null pointer dereference in trace
  (stable-fixes).
- usbip: Don't submit special requests twice (stable-fixes).
- media: uvcvideo: Enforce alignment of frame and interval
  (stable-fixes).
- wifi: ath12k: initialize 'ret' in
  ath12k_dp_rxdma_ring_sel_config_wcn7850() (stable-fixes).
- wifi: ath11k: initialize 'ret' in
  ath11k_qmi_load_file_target_mem() (stable-fixes).
- wifi: ath12k: initialize 'ret' in
  ath12k_qmi_load_file_target_mem() (stable-fixes).
- wifi: rtw89: ser: avoid multiple deinit on same CAM
  (stable-fixes).
- wifi: mac80211: check ieee80211_bss_info_change_notify()
  against MLD (stable-fixes).
- wifi: cfg80211: restrict operation during radar detection
  (stable-fixes).
- pwm: xilinx: Fix u32 overflow issue in 32-bit width PWM mode
  (stable-fixes).
- hwmon: (k10temp) Check return value of amd_smn_read()
  (stable-fixes).
- regmap: spi: Fix potential off-by-one when calculating reserved
  size (stable-fixes).
- commit 73bbd93
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1181-PCI-VGA-Replace-full-MIT-license-text-with-SPDX-iden.patch (drm-backport-placeholder)
- commit c1ec740
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-Use-RMW-accessors-for-changing-LNKCTL.patch (drm-backport-placeholder)
- commit 447cf45
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Use-RMW-accessors-for-changing-LNKCTL.patch (drm-backport-placeholder)
- commit a9642cf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1178-drm-i915-Fix-TLB-Invalidation-seqno-store.patch (drm-backport-placeholder)
- commit 6c5aa73
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1177-drm-gpuva_mgr-remove-unused-prev-pointer-in-__drm_gp.patch (drm-backport-placeholder)
- commit edd069b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1176-drm-tests-drm_kunit_helpers-Place-correct-function-n.patch (drm-backport-placeholder)
- commit 8aeea98
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1175-drm-nouveau-uapi-don-t-pass-NO_PREFETCH-flag-implici.patch (drm-backport-placeholder)
- commit e1b65f7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1174-drm-nouveau-uvmm-fix-unset-region-pointer-on-remap.patch (drm-backport-placeholder)
- commit 83ea442
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1173-drm-nouveau-sched-avoid-job-races-between-entities.patch (drm-backport-placeholder)
- commit 902f181
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1172-drm-ttm-tests-Fix-type-conversion-in-ttm_pool_test.patch (drm-backport-placeholder)
- commit a91bb57
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1171-drm-msm-a6xx-Bail-out-early-if-setting-GPU-OOB-fails.patch (drm-backport-placeholder)
- commit e94232e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1170-drm-msm-a6xx-Move-LLC-accessors-to-the-common-header.patch (drm-backport-placeholder)
- commit c950ec1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1169-drm-msm-a6xx-Introduce-a6xx_llc_read.patch (drm-backport-placeholder)
- commit 646728a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1168-drm-msm-adreno-Add-missing-MODULE_FIRMWARE-macros.patch (drm-backport-placeholder)
- commit 4f8857f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1167-drm-msm-gpu-Push-gpu-lock-down-past-runpm.patch (drm-backport-placeholder)
- commit daf6f71
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-a690-Switch-to-a660_gmu.bin.patch (drm-backport-placeholder)
- commit 99cd428
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1165-drm-msm-Remove-vma-use-tracking.patch (drm-backport-placeholder)
- commit 543b279
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1164-drm-msm-Take-lru-lock-once-per-submit_pin_objects.patch (drm-backport-placeholder)
- commit 33500e0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1163-drm-msm-Use-drm_gem_object-in-submit-bos-table.patch (drm-backport-placeholder)
- commit 4ab71c2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1162-drm-msm-Take-lru-lock-once-per-job_run.patch (drm-backport-placeholder)
- commit fb7b5b7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1161-drm-msm-adreno-adreno_gpu-Switch-to-memdup_user_nul-.patch (drm-backport-placeholder)
- commit 9b48b44
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1160-drm-msm-Disallow-relocs-on-a6xx.patch (drm-backport-placeholder)
- commit 3fa1415
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-a6xx-Fix-GMU-lockdep-splat.patch (drm-backport-placeholder)
- commit 231416e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-a2xx-Call-adreno_gpu_init-earlier.patch (drm-backport-placeholder)
- commit 28ed5fc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1157-drm-msm-a6xx-Fix-up-GMU-region-reservations.patch (drm-backport-placeholder)
- commit 32ef75b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1156-drm-msm-a6xx-Improve-GMU-force-shutdown-sequence.patch (drm-backport-placeholder)
- commit 91e2dcc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1155-drm-msm-a6xx-Ensure-clean-GMU-state-in-a6xx_gmu_fw_s.patch (drm-backport-placeholder)
- commit fec6328
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1154-drm-msm-a6xx-Skip-empty-protection-ranges-entries.patch (drm-backport-placeholder)
- commit 12b4306
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1153-drm-msm-a6xx-Use-descriptive-bitfield-names-for-CP_P.patch (drm-backport-placeholder)
- commit 05e27e2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1152-drm-msm-a6xx-Add-some-missing-header-definitions.patch (drm-backport-placeholder)
- commit 9afd2e3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1151-drm-msm-a6xx-Fix-misleading-comment.patch (drm-backport-placeholder)
- commit a46b46c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1150-drm-msm-adreno-Switch-to-chip-id-for-identifying-GPU.patch (drm-backport-placeholder)
- commit 7dc3b1e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1149-drm-msm-adreno-Move-adreno-info-to-config.patch (drm-backport-placeholder)
- commit d424a51
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1148-drm-msm-adreno-Add-helper-for-formating-chip-id.patch (drm-backport-placeholder)
- commit af38c47
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1147-drm-msm-adreno-Add-adreno-family.patch (drm-backport-placeholder)
- commit 48bede5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1146-drm-msm-adreno-Bring-the-a630-family-together.patch (drm-backport-placeholder)
- commit 82bbd16
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1145-drm-msm-adreno-Move-speedbin-mapping-to-device-table.patch (drm-backport-placeholder)
- commit 8206cbc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1144-drm-msm-adreno-Allow-SoC-specific-gpu-device-table-e.patch (drm-backport-placeholder)
- commit 8680298
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1143-drm-msm-adreno-Use-quirk-to-identify-cached-coherent.patch (drm-backport-placeholder)
- commit 5b3a291
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1142-drm-msm-adreno-Use-quirk-identify-hw_apriv.patch (drm-backport-placeholder)
- commit 8c73a72
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1141-drm-msm-adreno-Remove-redundant-revn-param.patch (drm-backport-placeholder)
- commit 30083e1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1140-drm-msm-adreno-Remove-redundant-gmem-size-param.patch (drm-backport-placeholder)
- commit f85b5aa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1139-drm-msm-adreno-Remove-GPU-name.patch (drm-backport-placeholder)
- commit 61ee3f4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-fix-the-irq-index-in-dpu_encoder_phys_wb.patch (drm-backport-placeholder)
- commit a4c00e1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1137-drm-msm-dpu-initialise-clk_rate-to-0-in-_dpu_core_pe.patch (drm-backport-placeholder)
- commit bbfeaff
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1136-drm-msm-dpu-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 7533493
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-mdp5-Don-t-leak-some-plane-state.patch (drm-backport-placeholder)
- commit 963a004
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1134-drm-msm-dpu-Drop-encoder-vsync_event.patch (drm-backport-placeholder)
- commit 943c0f7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1133-drm-msm-dpu-fix-DSC-1.2-enc-subblock-length.patch (drm-backport-placeholder)
- commit 7dff825
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1132-drm-msm-dpu-fix-DSC-1.2-block-lengths.patch (drm-backport-placeholder)
- commit af644f7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-increase-memtype-count-to-16-for-sm8550.patch (drm-backport-placeholder)
- commit 5477c00
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1130-drm-msm-dpu-drop-dpu_core_perf_destroy.patch (drm-backport-placeholder)
- commit 84a66f4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1129-drm-msm-dpu-move-max-clock-decision-to-dpu_kms.patch (drm-backport-placeholder)
- commit fb91e7f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1128-drm-msm-dpu-remove-extra-clk_round_rate-call.patch (drm-backport-placeholder)
- commit 9540baa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1127-drm-msm-dpu-remove-unused-fields-from-struct-dpu_cor.patch (drm-backport-placeholder)
- commit f7b75e9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1126-drm-msm-dpu-use-dpu_perf_cfg-in-DPU-core_perf-code.patch (drm-backport-placeholder)
- commit 0452580
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1125-drm-msm-dpu-drop-the-dpu_core_perf_crtc_update-s-sto.patch (drm-backport-placeholder)
- commit 098e2f8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1124-drm-msm-dpu-rework-indentation-in-dpu_core_perf.patch (drm-backport-placeholder)
- commit 003549b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1123-drm-msm-dpu-drop-separate-dpu_core_perf_tune-overrid.patch (drm-backport-placeholder)
- commit 45bc2cd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1122-drm-msm-dpu-bail-from-_dpu_core_perf_crtc_update_bus.patch (drm-backport-placeholder)
- commit ee5ea86
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1121-drm-msm-dpu-drop-BWC-features-from-DPU_MDP_foo-names.patch (drm-backport-placeholder)
- commit 99bee9d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1120-drm-msm-dpu-drop-UBWC-configuration.patch (drm-backport-placeholder)
- commit 856caed
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1119-drm-msm-dpu-use-MDSS-data-for-programming-SSPP.patch (drm-backport-placeholder)
- commit af73ce9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1118-drm-msm-mdss-populate-missing-data.patch (drm-backport-placeholder)
- commit 33ec412
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1117-drm-msm-mdss-export-UBWC-data.patch (drm-backport-placeholder)
- commit 0de045e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1116-drm-msm-mdss-rename-ubwc_version-to-ubwc_enc_version.patch (drm-backport-placeholder)
- commit 444a0b4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1115-drm-msm-dpu-drop-compatibility-INTR-defines.patch (drm-backport-placeholder)
- commit 3f59aed
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1114-drm-msm-dpu-drop-now-unused-mdss_irqs-field-from-hw-.patch (drm-backport-placeholder)
- commit 8148879
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1113-drm-msm-dpu-autodetect-supported-interrupts.patch (drm-backport-placeholder)
- commit b076895
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1112-drm-msm-dpu-split-interrupt-address-arrays.patch (drm-backport-placeholder)
- commit 3d2958c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1111-drm-msm-dpu-inline-__intr_offset.patch (drm-backport-placeholder)
- commit 4d7289f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1110-drm-msm-Remove-redundant-DRM_DEV_ERROR.patch (drm-backport-placeholder)
- commit 2db944c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1109-drm-msm-dsi-Reuse-QCM2290-14nm-DSI-PHY-configuration.patch (drm-backport-placeholder)
- commit 83edcff
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1108-drm-msm-mdss-Add-SM6125-support.patch (drm-backport-placeholder)
- commit 90d92f4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1107-drm-msm-dpu-Add-SM6125-support.patch (drm-backport-placeholder)
- commit b9901a8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1106-drm-msm-dpu-drop-DPU_INTF_DATA_COMPRESS-from-dpu-cat.patch (drm-backport-placeholder)
- commit 1aa489c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1105-drm-msm-dpu-rename-enable_compression-to-program_int.patch (drm-backport-placeholder)
- commit f2bbc7a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1104-drm-msm-dpu-rename-all-hw_intf-structs-to-have-dpu_h.patch (drm-backport-placeholder)
- commit 94f35bb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1103-drm-msm-dpu-use-dpu-core-s-major-version-to-enable-d.patch (drm-backport-placeholder)
- commit 7e62023
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1102-drm-msm-dpu-re-introduce-dpu-core-revision-to-the-ca.patch (drm-backport-placeholder)
- commit ab3ae22
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1101-drm-msm-dsi-Enable-BURST_MODE-for-command-mode-for-D.patch (drm-backport-placeholder)
- commit d2c7b86
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1100-drm-msm-dpu-Update-dev-core-dump-to-dump-registers-o.patch (drm-backport-placeholder)
- commit 87209eb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1099-drm-msm-dpu-Refactor-printing-of-main-blocks-in-devi.patch (drm-backport-placeholder)
- commit ca8c395
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1098-drm-msm-dpu-Remove-redundant-prefix-suffix-in-name-o.patch (drm-backport-placeholder)
- commit f8951f9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1097-drm-msm-dpu-Define-names-for-unnamed-sblks.patch (drm-backport-placeholder)
- commit 660f9d3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1096-drm-msm-dpu-Drop-unused-num-argument-from-relevant-m.patch (drm-backport-placeholder)
- commit 2fa100c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-Update-dev-core-dump-to-not-print-backwards.patch (drm-backport-placeholder)
- commit 8d11890
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1094-drm-msm-dpu-drop-empty-features-mask-INTF_SDM845_MAS.patch (drm-backport-placeholder)
- commit d4fb057
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1093-drm-msm-dpu-drop-empty-features-mask-MERGE_3D_SM8150.patch (drm-backport-placeholder)
- commit 6aabae1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1092-drm-msm-dpu-inline-INTF_BLK-and-INTF_BLK_DSI_TE-macr.patch (drm-backport-placeholder)
- commit 7a0402a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1091-drm-msm-dpu-inline-WB_BLK-macros.patch (drm-backport-placeholder)
- commit f1990c3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1090-drm-msm-dpu-inline-various-PP_BLK_-macros.patch (drm-backport-placeholder)
- commit 5651d5b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1089-drm-msm-dpu-inline-MERGE_3D_BLK-macros.patch (drm-backport-placeholder)
- commit 6b2248d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1088-drm-msm-dpu-inline-DSC_BLK-and-DSC_BLK_1_2-macros.patch (drm-backport-placeholder)
- commit 7655e48
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1087-drm-msm-dpu-inline-LM_BLK-macros.patch (drm-backport-placeholder)
- commit c778ae5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1086-drm-msm-dpu-inline-DSPP_BLK-macros.patch (drm-backport-placeholder)
- commit 66e34de
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1085-drm-msm-dpu-inline-SSPP_BLK-macros.patch (drm-backport-placeholder)
- commit 23b9752
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1084-drm-msm-dpu-correct-indentation-for-CTL-definitions.patch (drm-backport-placeholder)
- commit 12924de
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1083-drm-msm-dpu-drop-zero-features-from-dpu_ctl_cfg-data.patch (drm-backport-placeholder)
- commit 0844ec3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1082-drm-msm-dpu-drop-zero-features-from-dpu_mdp_cfg-data.patch (drm-backport-placeholder)
- commit 7787286
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1081-drm-msm-dpu-expand-.clk_ctrls-definitions.patch (drm-backport-placeholder)
- commit 10bb6a8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1080-drm-msm-dpu-drop-enum-dpu_mdp-and-MDP_TOP-value.patch (drm-backport-placeholder)
- commit 6c42ada
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1079-drm-msm-dpu-drop-dpu_mdss_cfg-mdp_count-field.patch (drm-backport-placeholder)
- commit 35de06a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1078-drm-msm-dpu-simplify-peer-LM-handling.patch (drm-backport-placeholder)
- commit a99fcbb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1077-drm-msm-dpu-always-use-MSM_DP-DSI_CONTROLLER_n.patch (drm-backport-placeholder)
- commit a2d3309
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1076-drm-msm-enumerate-DSI-interfaces.patch (drm-backport-placeholder)
- commit b4a0b10
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1075-drm-msm-dsi-Hook-up-refgen-regulator.patch (drm-backport-placeholder)
- commit f73f361
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1074-drm-msm-dpu-remove-struct-drm_dsc_config-from-struct.patch (drm-backport-placeholder)
- commit cf4debe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1073-drm-msm-dpu-retrieve-DSI-DSC-struct-through-priv-dsi.patch (drm-backport-placeholder)
- commit 024eef1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1072-drm-msm-stop-storing-the-array-of-CRTCs-in-struct-ms.patch (drm-backport-placeholder)
- commit 70d706a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1071-drm-msm-dpu1-Rename-sm8150_dspp_blk-to-sdm845_dspp_b.patch (drm-backport-placeholder)
- commit 15bf96f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1070-drm-amdgpu-Add-memory-vendor-information.patch (drm-backport-placeholder)
- commit 9d48c46
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1069-drm-amdgpu-Remove-gfxoff-check-in-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit 8c937df
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1068-drm-amd-pm-Update-pci-link-speed-for-smu-v13.0.6.patch (drm-backport-placeholder)
- commit 9bc4d7d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1067-drm-amd-pm-allow-the-user-to-force-BACO-on-smu-v13.0.patch (drm-backport-placeholder)
- commit 708403a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1066-drm-amdgpu-vcn-Skip-vcn-power-gating-change-for-srio.patch (drm-backport-placeholder)
- commit f5db22a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1065-drm-amd-display-Handle-Replay-related-hpd-irq.patch (drm-backport-placeholder)
- commit df6ce97
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1064-drm-amdgpu-jpeg-sriov-support-for-jpeg_v4_0_3.patch (drm-backport-placeholder)
- commit 7fd56cb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1063-drm-amd-display-Update-adaptive-sync-infopackets-for.patch (drm-backport-placeholder)
- commit 26b8049
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1062-drm-amd-display-Promote-DAL-to-3.2.247.patch (drm-backport-placeholder)
- commit 1e9fdc8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1061-drm-amd-display-FW-Promotion-Release-0.0.179.0.patch (drm-backport-placeholder)
- commit 44fe689
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1060-drm-amdgpu-Replace-ternary-operator-with-min-in-amdg.patch (drm-backport-placeholder)
- commit 6a301bb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1059-drm-amd-display-Replace-ternary-operator-with-min-in.patch (drm-backport-placeholder)
- commit 6937640
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1058-drm-amd-Hide-unsupported-power-attributes.patch (drm-backport-placeholder)
- commit b9e3ff5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1057-drm-amd-Rename-AMDGPU_PP_SENSOR_GPU_POWER.patch (drm-backport-placeholder)
- commit 6ba9eb2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1056-drm-amd-Show-both-power-attributes-for-vega20.patch (drm-backport-placeholder)
- commit 20332c5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1055-drm-amd-Fix-the-return-for-average-power-on-aldebara.patch (drm-backport-placeholder)
- commit a0972b8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1054-drm-amd-Drop-unnecessary-helper-for-aldebaran.patch (drm-backport-placeholder)
- commit b3428fd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1053-drm-amd-Fix-SMU-13.0.4-13.0.11-GPU-metrics-average-p.patch (drm-backport-placeholder)
- commit ed03a66
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1052-drm-radeon-Use-pci_dev_id-to-simplify-the-code.patch (drm-backport-placeholder)
- commit 0df0536
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1051-drm-amdgpu-Remove-duplicated-includes.patch (drm-backport-placeholder)
- commit 83c0fca
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1050-drm-amd-pm-Clean-up-errors-in-amdgpu_smu.h.patch (drm-backport-placeholder)
- commit 5b711fd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1049-drm-amd-display-enable-low-power-mode-for-VGA-memory.patch (drm-backport-placeholder)
- commit 1ae7235
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1048-drm-amd-pm-Clean-up-errors-in-smu_v11_0_pptable.h.patch (drm-backport-placeholder)
- commit 3f4af9f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1047-drm-amdgpu-expand-runpm-parameter.patch (drm-backport-placeholder)
- commit 5431262
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1046-drm-amd-Introduce-AMDGPU_PP_SENSOR_GPU_INPUT_POWER.patch (drm-backport-placeholder)
- commit 34fddfb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1045-drm-amd-Remove-freesync-video-mode-amdgpu-parameter.patch (drm-backport-placeholder)
- commit 6bf6ed6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1044-drm-amd-Add-a-new-hwmon-attribute-for-instantaneous-.patch (drm-backport-placeholder)
- commit 39cdb9a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1043-drm-amdgpu-vcn-sriov-support-for-vcn_v4_0_3.patch (drm-backport-placeholder)
- commit 1b7132c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1042-drm-amdgpu-Replace-ternary-operator-with-min-in-amdg.patch (drm-backport-placeholder)
- commit 9e7e091
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1041-drm-amd-display-Add-some-missing-register-definition.patch (drm-backport-placeholder)
- commit 6372820
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1040-drm-amd-display-avoid-crash-and-add-z8_marks-related.patch (drm-backport-placeholder)
- commit 2b01ffb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1039-drm-amd-display-implement-pipe-type-definition-and-a.patch (drm-backport-placeholder)
- commit b2ae4a1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1038-drm-amd-display-Enable-8k60hz-mode-on-single-display.patch (drm-backport-placeholder)
- commit 73d9888
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1037-drm-amd-display-fix-incorrect-stream_res-allocation-.patch (drm-backport-placeholder)
- commit 1a2148d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1036-drm-amd-display-Gamut-remap-only-changes-missed.patch (drm-backport-placeholder)
- commit 8044833
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1035-drm-amd-display-PMFW-to-wait-for-DMCUB-ack-for-FPO-c.patch (drm-backport-placeholder)
- commit d560528
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1034-drm-amd-display-Enable-subvp-high-refresh-up-to-175h.patch (drm-backport-placeholder)
- commit 41fe710
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1033-drm-amdgpu-vcn-change-end-doorbell-index-for-vcn_v4_.patch (drm-backport-placeholder)
- commit 54c3435
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1032-drm-amdkfd-workaround-address-watch-clearing-bug-for.patch (drm-backport-placeholder)
- commit 5b2bd11
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1031-drm-amd-display-disable-clock-gating-logic-reversed-.patch (drm-backport-placeholder)
- commit 4160b86
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1030-drm-amd-display-Support-Compliance-Test-Pattern-Gene.patch (drm-backport-placeholder)
- commit 13565a8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1029-drm-amdgpu-jpeg-mmsch_v4_0_3-requires-doorbell-on-32.patch (drm-backport-placeholder)
- commit c3ee981
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1028-drm-radeon-Remove-unnecessary-NULL-values.patch (drm-backport-placeholder)
- commit 19a4b74
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1027-drm-amd-display-Remove-unnecessary-NULL-values.patch (drm-backport-placeholder)
- commit cf4ee39
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1026-drm-amdgpu-vcn-mmsch_v4_0_3-requires-doorbell-on-32-.patch (drm-backport-placeholder)
- commit 3f8132b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1025-drm-amdkfd-Remove-unnecessary-NULL-values.patch (drm-backport-placeholder)
- commit d81a2cc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1024-drm-amd-display-dmub_replay-don-t-use-kernel-doc-mar.patch (drm-backport-placeholder)
- commit f40e79f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1023-drm-amd-Add-amdgpu_hwmon_get_sensor_generic.patch (drm-backport-placeholder)
- commit a1e36a0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1022-drm-amdgpu-vcn-Add-MMSCH-v4_0_3-support-for-sriov.patch (drm-backport-placeholder)
- commit 30479ba
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1021-drm-amdgpu-Add-I2C-EEPROM-support-on-smu-v13_0_6.patch (drm-backport-placeholder)
- commit 876a7ba
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1020-drm-amd-pm-bump-SMU-v13.0.5-driver_if-header-version.patch (drm-backport-placeholder)
- commit f540534
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1019-drm-amd-pm-correct-the-logics-for-retreiving-SMU13-O.patch (drm-backport-placeholder)
- commit a1d6343
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1018-drm-amd-pm-correct-the-way-for-checking-custom-OD-se.patch (drm-backport-placeholder)
- commit a9b9658
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1017-drm-amd-Use-pci_dev_id-to-simplify-the-code.patch (drm-backport-placeholder)
- commit fa782d1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1016-drm-amdkfd-fix-double-assign-skip-process-context-cl.patch (drm-backport-placeholder)
- commit 3e13ebe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1015-drm-amd-display-Update-replay-for-clk_mgr-optimizati.patch (drm-backport-placeholder)
- commit b9920c1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1014-drm-amdgpu-Fix-identifier-names-to-function-definiti.patch (drm-backport-placeholder)
- commit 2208d1e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1013-drm-amdgpu-mode1-reset-needs-to-recover-mp1-for-mp0-.patch (drm-backport-placeholder)
- commit 8209478
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1012-drm-amd-pm-avoid-driver-getting-empty-metrics-table-.patch (drm-backport-placeholder)
- commit 4d24b42
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1011-drm-amdkfd-Use-memdup_user-rather-than-duplicating-i.patch (drm-backport-placeholder)
- commit e5f2e22
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1010-drm-amdgpu-Remove-unnecessary-ras-cap-check.patch (drm-backport-placeholder)
- commit 70af3d2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1009-drm-amdkfd-fix-build-failure-without-CONFIG_DYNAMIC_.patch (drm-backport-placeholder)
- commit af7fa8f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1008-drm-radeon-Fix-multiple-line-dereference-in-atom_iio.patch (drm-backport-placeholder)
- commit b79ce2f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1007-drm-amd-pm-Add-vclk-and-dclk-sysnode-for-GC-9.4.3.patch (drm-backport-placeholder)
- commit ffa506c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1006-drm-amdkfd-Add-missing-tba_hi-programming-on-aldebar.patch (drm-backport-placeholder)
- commit 8971d9b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1005-drm-amdgpu-Fix-missing-comment-for-mb-in-amdgpu_devi.patch (drm-backport-placeholder)
- commit ecc9e26
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1004-drm-amd-display-Add-Replay-supported-enabled-checks.patch (drm-backport-placeholder)
- commit aa3b056
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1003-drm-ttm-tests-Require-MMU-when-testing.patch (drm-backport-placeholder)
- commit f0e7cef
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1002-drm-panel-simple-Fix-Innolux-G156HCE-L01-LVDS-clock.patch (drm-backport-placeholder)
- commit ca1b506
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1001-drm-etnaviv-fix-error-code-in-event_alloc.patch (drm-backport-placeholder)
- commit ef0c599
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/1000-drm-etnaviv-expedited-MMU-fault-handling.patch (drm-backport-placeholder)
- commit aca1c61
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0999-drm-etnaviv-drop-GPU-initialized-property.patch (drm-backport-placeholder)
- commit e41b436
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0998-drm-etnaviv-better-track-GPU-state.patch (drm-backport-placeholder)
- commit 13a4d10
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0997-drm-etnaviv-avoid-runtime-PM-usage-in-etnaviv_gpu_bi.patch (drm-backport-placeholder)
- commit d9e067d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0996-drm-etnaviv-make-clock-handling-symetric-between-run.patch (drm-backport-placeholder)
- commit c02f12e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0995-drm-etnaviv-move-runtime-PM-handling-to-events.patch (drm-backport-placeholder)
- commit 4be1786
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0994-drm-etnaviv-free-events-the-usual-way-in-recover-wor.patch (drm-backport-placeholder)
- commit add0c86
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0993-drm-etnaviv-move-down-etnaviv_gpu_recover_hang-in-fi.patch (drm-backport-placeholder)
- commit 1a75b21
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0992-drm-etnaviv-add-HWDB-entry-for-GC520-r5341-c204.patch (drm-backport-placeholder)
- commit 8aa86bc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0991-drm-etnaviv-add-HWDB-entry-for-VIP8000-Nano-r8002.patch (drm-backport-placeholder)
- commit 051e093
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-etnaviv-fix-dumping-of-active-MMU-context.patch (drm-backport-placeholder)
- commit ce39579
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0989-drm-etnaviv-slow-down-FE-idle-polling.patch (drm-backport-placeholder)
- commit 494aaf7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0988-drm-etnaviv-Replace-of_platform.h-with-explicit-incl.patch (drm-backport-placeholder)
- commit 626d238
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0987-drm-amdgpu-don-t-allow-userspace-to-create-a-doorbel.patch (drm-backport-placeholder)
- commit ad3253d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0986-drm-amdkfd-rename-device_queue_manager_init_v10_navi.patch (drm-backport-placeholder)
- commit 955ab22
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0985-drm-amdkfd-drop-IOMMUv2-support.patch (drm-backport-placeholder)
- commit 2ca405d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0984-drm-amdgpu-Use-local64_try_cmpxchg-in-amdgpu_perf_re.patch (drm-backport-placeholder)
- commit b8447fe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0983-drm-amdgpu-Add-pci-usage-to-nbio-v7.9.patch (drm-backport-placeholder)
- commit 1c6025e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0982-drm-amdgpu-Add-pcie-usage-callback-to-nbio.patch (drm-backport-placeholder)
- commit 3f89501
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0981-drm-amdgpu-Extend-poison-mode-check-to-SDMA-VCN-JPEG.patch (drm-backport-placeholder)
- commit cfa8775
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0980-drm-buddy-Fix-drm-buddy-info-output-format.patch (drm-backport-placeholder)
- commit c24933a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0979-drm-amdgpu-irq-Move-irq-resume-to-the-beginning.patch (drm-backport-placeholder)
- commit 91dc641
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0978-drm-amdgpu-add-RAS-fatal-error-handler-for-NBIO-v7.9.patch (drm-backport-placeholder)
- commit 0d57d45
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0977-drm-amdgpu-Fix-identation-issues-in-kgd_gfx_v9_progr.patch (drm-backport-placeholder)
- commit 3542c55
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0976-drm-amd-display-Get-replay-info-from-VSDB.patch (drm-backport-placeholder)
- commit 60285cf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0975-drm-amdgpu-Add-FRU-sysfs-nodes-only-if-needed.patch (drm-backport-placeholder)
- commit 03fd80d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0974-drm-amd-pm-Clean-up-errors-in-smu73_discrete.h.patch (drm-backport-placeholder)
- commit a070da6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0973-drm-amdgpu-Clean-up-errors-in-vcn_v3_0.c.patch (drm-backport-placeholder)
- commit 472e031
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0972-drm-amdgpu-Clean-up-errors-in-tonga_ih.c.patch (drm-backport-placeholder)
- commit 5a0bfdf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0971-drm-amdgpu-Clean-up-errors-in-gfx_v7_0.c.patch (drm-backport-placeholder)
- commit 41866e6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0970-drm-amdgpu-Clean-up-errors-in-vcn_v4_0.c.patch (drm-backport-placeholder)
- commit 5400f96
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0969-drm-amdgpu-Clean-up-errors-in-uvd_v3_1.c.patch (drm-backport-placeholder)
- commit 7f87eb0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0968-drm-amdgpu-Clean-up-errors-in-mxgpu_vi.c.patch (drm-backport-placeholder)
- commit 83545e3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0967-drm-amdgpu-Clean-up-errors-in-nv.c.patch (drm-backport-placeholder)
- commit 6890789
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0966-drm-amdgpu-Clean-up-errors-in-amdgpu_virt.c.patch (drm-backport-placeholder)
- commit 9ca2070
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0965-drm-amdgpu-Clean-up-errors-in-amdgpu_ring.h.patch (drm-backport-placeholder)
- commit aef4dd6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0964-drm-amdgpu-Clean-up-errors-in-amdgpu_trace.h.patch (drm-backport-placeholder)
- commit 5db2631
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0963-drm-amdgpu-Clean-up-errors-in-mes_v11_0.c.patch (drm-backport-placeholder)
- commit 07dac1d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0962-drm-amdgpu-Clean-up-errors-in-amdgpu_atombios.h.patch (drm-backport-placeholder)
- commit 2061b3c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0961-drm-amdgpu-Clean-up-errors-in-soc21.c.patch (drm-backport-placeholder)
- commit d247801
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0960-drm-amdgpu-Clean-up-errors-in-dce_v8_0.c.patch (drm-backport-placeholder)
- commit 67b2a93
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0959-drm-amdgpu-jpeg-Clean-up-errors-in-vcn_v1_0.c.patch (drm-backport-placeholder)
- commit 0635b12
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0958-drm-amdgpu-Clean-up-errors-in-mxgpu_nv.c.patch (drm-backport-placeholder)
- commit a793ce1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0957-drm-amdgpu-Clean-up-errors-in-dce_v10_0.c.patch (drm-backport-placeholder)
- commit 2911290
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0956-drm-jpeg-Clean-up-errors-in-jpeg_v2_0.c.patch (drm-backport-placeholder)
- commit dff9791
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0955-drm-amdgpu-Clean-up-errors-in-uvd_v7_0.c.patch (drm-backport-placeholder)
- commit 2ad7755
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0954-drm-amdgpu-atomfirmware-Clean-up-errors-in-amdgpu_at.patch (drm-backport-placeholder)
- commit cfea29b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0953-drm-amdgpu-Clean-up-errors-in-mmhub_v9_4.c.patch (drm-backport-placeholder)
- commit a492d85
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0952-drm-amdgpu-Clean-up-errors-in-vega20_ih.c.patch (drm-backport-placeholder)
- commit 20f0a89
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0951-drm-amdgpu-Clean-up-errors-in-ih_v6_0.c.patch (drm-backport-placeholder)
- commit 8d848ee
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0950-drm-amdgpu-Clean-up-errors-in-amdgpu_psp.h.patch (drm-backport-placeholder)
- commit 31540df
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0949-drm-amdgpu-Clean-up-errors-in-vce_v3_0.c.patch (drm-backport-placeholder)
- commit d0ed6ef
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0948-drm-amdgpu-Clean-up-errors-in-cik_ih.c.patch (drm-backport-placeholder)
- commit 6141cb1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0947-drm-amd-display-Clean-up-errors-in-dce_clk_mgr.c.patch (drm-backport-placeholder)
- commit 6b7a9af
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0946-drm-amd-display-Clean-up-errors-in-display_mode_vba_.patch (drm-backport-placeholder)
- commit bfc7101
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0945-drm-amd-display-Clean-up-errors-in-dcn10_dpp_dscl.c.patch (drm-backport-placeholder)
- commit 587df9a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0944-drm-amd-display-Clean-up-errors-in-dc_stream.c.patch (drm-backport-placeholder)
- commit 32d62ac
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0943-drm-amd-display-Clean-up-errors-in-bios_parser2.c.patch (drm-backport-placeholder)
- commit 2ff55a0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0942-drm-amd-display-Clean-up-errors-in-dcn316_smu.c.patch (drm-backport-placeholder)
- commit f82fd0f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0941-drm-amd-display-Clean-up-errors-in-dcn316_clk_mgr.c.patch (drm-backport-placeholder)
- commit 30e0110
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0940-drm-amd-display-Clean-up-errors-in-dcn315_smu.c.patch (drm-backport-placeholder)
- commit 949aba5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0939-drm-amd-display-Clean-up-errors-in-dce112_hw_sequenc.patch (drm-backport-placeholder)
- commit 148711d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0938-drm-amd-display-Clean-up-errors-in-dce110_hw_sequenc.patch (drm-backport-placeholder)
- commit e64508c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0937-drm-amd-display-Clean-up-errors-in-dce110_timing_gen.patch (drm-backport-placeholder)
- commit 8e61f85
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0936-drm-amd-dc-Clean-up-errors-in-hpd_regs.h.patch (drm-backport-placeholder)
- commit a3f8bef
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0935-drm-amd-display-Clean-up-errors-in-ddc_regs.h.patch (drm-backport-placeholder)
- commit ed9fcfc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0934-drm-amd-display-Clean-up-errors-in-color_gamma.c.patch (drm-backport-placeholder)
- commit 3425643
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0933-drm-amd-pm-Clean-up-errors-in-amdgpu_pm.c.patch (drm-backport-placeholder)
- commit 382e671
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0932-drm-amd-pm-Clean-up-errors-in-sislands_smc.h.patch (drm-backport-placeholder)
- commit 3347dcd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0931-drm-amd-pm-Clean-up-errors-in-r600_dpm.h.patch (drm-backport-placeholder)
- commit 5453fc7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0930-drivers-amd-pm-Clean-up-errors-in-smu8_smumgr.h.patch (drm-backport-placeholder)
- commit e7d307a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0929-drm-amd-pm-Clean-up-errors-in-smu75.h.patch (drm-backport-placeholder)
- commit 56e07ec
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0928-drm-amd-pm-Clean-up-errors-in-smu73.h.patch (drm-backport-placeholder)
- commit 9248508
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0927-drm-amd-pm-Clean-up-errors-in-hwmgr.h.patch (drm-backport-placeholder)
- commit feec25a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0926-drm-amd-pm-Clean-up-errors-in-hardwaremanager.h.patch (drm-backport-placeholder)
- commit fe81f34
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0925-drm-amd-pm-Clean-up-errors-in-pp_thermal.h.patch (drm-backport-placeholder)
- commit 7ddea22
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0924-drm-amd-pm-Clean-up-errors-in-smu7.h.patch (drm-backport-placeholder)
- commit 2d34929
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0923-drm-amd-pm-Clean-up-errors-in-smu7_fusion.h.patch (drm-backport-placeholder)
- commit 6551c00
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0922-drm-amd-pm-Clean-up-errors-in-smu71.h.patch (drm-backport-placeholder)
- commit 9060e02
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0921-drm-amd-pm-Remove-many-unnecessary-NULL-values.patch (drm-backport-placeholder)
- commit f2cf5a5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0920-drm-amd-pm-Clean-up-errors-in-smu9_driver_if.h.patch (drm-backport-placeholder)
- commit 00465e3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0919-drm-amd-pm-Clean-up-errors-in-polaris_baco.c.patch (drm-backport-placeholder)
- commit 128b82f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0918-drm-amd-pm-Clean-up-errors-in-vega20_pptable.h.patch (drm-backport-placeholder)
- commit 5c23baf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0917-drm-amd-pm-Clean-up-errors-in-vega12_hwmgr.h.patch (drm-backport-placeholder)
- commit 90e5319
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0916-drm-amd-pm-powerplay-hwmgr-hwmgr-Clean-up-errors-in-.patch (drm-backport-placeholder)
- commit c0ffa57
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0915-drm-amd-pm-Clean-up-errors-in-tonga_baco.c.patch (drm-backport-placeholder)
- commit 0abb9b0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0914-gpu-amd-Clean-up-errors-in-ppatomfwctrl.h.patch (drm-backport-placeholder)
- commit 5e44a22
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0913-drm-amdgpu-powerplay-Clean-up-errors-in-vega20_hwmgr.patch (drm-backport-placeholder)
- commit a65fc4b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0912-drm-amdgpu-Clean-up-errors-in-vega20_baco.c.patch (drm-backport-placeholder)
- commit 5dd7af9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0911-drm-amd-pm-Clean-up-errors-in-vega20_hwmgr.h.patch (drm-backport-placeholder)
- commit 3f371ab
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0910-drm-amdgpu-powerplay-Clean-up-errors-in-smu_helper.h.patch (drm-backport-placeholder)
- commit dd5564a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0909-drm-amd-Clean-up-errors-in-vega10_processpptables.c.patch (drm-backport-placeholder)
- commit 1e9d38c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0908-drm-amd-Clean-up-errors-in-pptable_v1_0.h.patch (drm-backport-placeholder)
- commit 1b8b832
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0907-drm-amd-Clean-up-errors-in-smu7_hwmgr.c.patch (drm-backport-placeholder)
- commit 1c47b87
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0906-drm-amd-pm-Clean-up-errors-in-vega10_pptable.h.patch (drm-backport-placeholder)
- commit adabeda
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0905-drm-amdgpu-Clean-up-errors-in-ppatomctrl.h.patch (drm-backport-placeholder)
- commit aa8763d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0904-drm-amdgpu-Clean-up-errors-in-ci_baco.c.patch (drm-backport-placeholder)
- commit ba6ada4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0903-drm-amdgpu-Clean-up-errors-in-smu_helper.c.patch (drm-backport-placeholder)
- commit 50e073c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0902-drm-amdgpu-Clean-up-errors-in-common_baco.c.patch (drm-backport-placeholder)
- commit 045b873
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0901-drm-amdgpu-Clean-up-errors-in-smu7_powertune.c.patch (drm-backport-placeholder)
- commit 7ae3c0a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0900-drm-amd-pm-Clean-up-errors-in-vega12_baco.c.patch (drm-backport-placeholder)
- commit 319a41e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0899-drm-amd-pm-Clean-up-errors-in-vega12_pptable.h.patch (drm-backport-placeholder)
- commit 4ab3bc2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0898-drm-amd-pm-Clean-up-errors-in-vega10_powertune.c.patch (drm-backport-placeholder)
- commit 5a7dd18
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0897-drm-amd-pm-Clean-up-errors-in-fiji_baco.c.patch (drm-backport-placeholder)
- commit c4e0e6c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0896-drm-amd-pm-Clean-up-errors-in-smu10_hwmgr.c.patch (drm-backport-placeholder)
- commit d506d6b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0895-drm-amd-pm-powerplay-hwmgr-ppevvmath-Clean-up-errors.patch (drm-backport-placeholder)
- commit 8fa41af
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0894-drm-amd-pm-Clean-up-errors-in-vega12_hwmgr.c.patch (drm-backport-placeholder)
- commit 15b88e5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0893-drm-amd-pm-Clean-up-errors-in-vega10_baco.c.patch (drm-backport-placeholder)
- commit 598f081
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0892-drm-amd-pm-Clean-up-errors-in-amd_powerplay.c.patch (drm-backport-placeholder)
- commit 2bd854a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0891-drm-amd-pm-Clean-up-errors-in-amdgpu_smu.c.patch (drm-backport-placeholder)
- commit a5132ed
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0890-drm-amd-Clean-up-errors-in-smu_v13_0_5_ppt.c.patch (drm-backport-placeholder)
- commit 7013790
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0889-drm-amd-pm-Clean-up-errors-in-smu_v13_0_5_ppt.c.patch (drm-backport-placeholder)
- commit 706c5c4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0888-drm-amd-pm-Clean-up-errors-in-smu_v13_0_6_ppt.c.patch (drm-backport-placeholder)
- commit 69b34c5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0887-drm-amd-pm-Clean-up-errors-in-aldebaran_ppt.c.patch (drm-backport-placeholder)
- commit 4c95899
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0886-drm-amd-pm-Clean-up-errors-in-smu_v13_0.c.patch (drm-backport-placeholder)
- commit 15516d0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0885-drm-amd-pm-Clean-up-errors-in-smu_v13_0_7_ppt.c.patch (drm-backport-placeholder)
- commit 8360a95
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0884-drm-amd-pm-Clean-up-errors-in-smu_v11_0.h.patch (drm-backport-placeholder)
- commit 22f6667
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0883-drm-amdgpu-Remove-a-lot-of-unnecessary-ternary-opera.patch (drm-backport-placeholder)
- commit f82de86
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0882-drm-amd-display-Return-value-of-function.patch (drm-backport-placeholder)
- commit 0bb1176
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0881-drm-amdgpu-Report-vbios-version-instead-of-PN.patch (drm-backport-placeholder)
- commit 50b7994
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0880-drm-amd-display-Promote-DAL-to-3.2.246.patch (drm-backport-placeholder)
- commit ee7ca9f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0879-drm-amd-display-Change-HDCP-update-sequence-for-DM.patch (drm-backport-placeholder)
- commit 129c176
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0878-drm-amd-display-rename-acquire_idle_pipe_for_layer-t.patch (drm-backport-placeholder)
- commit 67a0699
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0877-drm-amd-display-move-idle-pipe-allocation-logic-into.patch (drm-backport-placeholder)
- commit fb6952a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0876-drm-amd-display-Use-max-memclk-variable-when-setting.patch (drm-backport-placeholder)
- commit d8928bb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0875-drm-amd-display-Add-vendor-Id-for-reference.patch (drm-backport-placeholder)
- commit fe87fb1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0874-drm-amd-display-Blocking-invalid-420-modes-on-HDMI-T.patch (drm-backport-placeholder)
- commit fcf7385
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0873-drm-amd-display-Blocking-invalid-420-modes-on-HDMI-T.patch (drm-backport-placeholder)
- commit 8c0557c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0872-drm-amd-display-Revert-drm-amd-display-Read-down-spr.patch (drm-backport-placeholder)
- commit 8e1674b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0871-drm-amd-display-do-not-treat-clip_rect-size-change-a.patch (drm-backport-placeholder)
- commit 4e348fb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0870-drm-amd-display-adjust-visual-confirm-dpp-height-off.patch (drm-backport-placeholder)
- commit f098e9d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0869-drm-amd-display-update-add-plane-to-context-logic-wi.patch (drm-backport-placeholder)
- commit 4f708c6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0868-drm-amd-display-always-acquire-MPO-pipe-for-every-bl.patch (drm-backport-placeholder)
- commit adbbd1a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0867-drm-amd-display-support-plane-clip-with-zero-recout-.patch (drm-backport-placeholder)
- commit 8c6cf0f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0866-drm-amd-display-Use-DTBCLK-as-refclk-instead-of-DPRE.patch (drm-backport-placeholder)
- commit a1c622e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0865-drm-amd-display-Set-Stream-Update-Flags-in-commit_st.patch (drm-backport-placeholder)
- commit e55a94f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0864-drm-amd-display-Make-mpc32-functions-available-to-fu.patch (drm-backport-placeholder)
- commit 7cb5457
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0863-drm-amd-display-Fix-a-bug-when-searching-for-insert_.patch (drm-backport-placeholder)
- commit dc3d4bb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0862-drm-amd-display-Enable-DPIA-trace-with-DC-debug-mask.patch (drm-backport-placeholder)
- commit 08e7cd7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0861-drm-amd-display-Add-interface-to-enable-DPIA-trace.patch (drm-backport-placeholder)
- commit 98a24aa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0860-drm-amd-display-fix-a-regression-in-blank-pixel-data.patch (drm-backport-placeholder)
- commit 59c21da
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0859-drm-amdgpu-cleanup-MES-process-level-doorbells.patch (drm-backport-placeholder)
- commit afbd336
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0858-drm-amdgpu-use-doorbell-mgr-for-MES-kernel-doorbells.patch (drm-backport-placeholder)
- commit 86d56f7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0857-drm-amdgpu-remove-unused-functions-and-variables.patch (drm-backport-placeholder)
- commit 7f641a9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-ensure-async-flips-are-only-accepted.patch (drm-backport-placeholder)
- commit 1eee13f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0855-drm-amdgpu-use-doorbell-mgr-for-kfd-process-doorbell.patch (drm-backport-placeholder)
- commit 7559853
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0854-drm-amdgpu-use-doorbell-mgr-for-kfd-kernel-doorbells.patch (drm-backport-placeholder)
- commit e30abb2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0853-drm-amd-display-Read-replay-data-from-sink.patch (drm-backport-placeholder)
- commit c201369
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0852-drm-amd-display-Add-Freesync-Panel-DM-code.patch (drm-backport-placeholder)
- commit c1128c1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0851-drm-amd-pm-update-smu_v13_0_6-message-vf-flag.patch (drm-backport-placeholder)
- commit 5f8c4d7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0850-drm-amdgpu-Report-Missing-MES-Firmware-Versions-with.patch (drm-backport-placeholder)
- commit 6a13c7d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0849-drm-amdgpu-get-absolute-offset-from-doorbell-index.patch (drm-backport-placeholder)
- commit 61d08b3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0848-drm-amdgpu-create-kernel-doorbell-pages.patch (drm-backport-placeholder)
- commit f4e5ebe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0847-drm-amdgpu-Use-nbio-callback-for-nv-and-soc21.patch (drm-backport-placeholder)
- commit 7693aa9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-fix-variable-dereferenced-issue-in-amdgpu.patch (drm-backport-placeholder)
- commit 4bd8ace
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0845-drm-amdgpu-Add-pci-replay-count-to-nbio-v7.9.patch (drm-backport-placeholder)
- commit 56d5885
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0844-drm-amdgpu-initialize-ttm-for-doorbells.patch (drm-backport-placeholder)
- commit 3b4acbe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0843-drm-amdgpu-accommodate-DOMAIN-PL_DOORBELL.patch (drm-backport-placeholder)
- commit e1d8f26
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0842-drm-amdkfd-Sign-extend-TMA-address-in-trap-handler.patch (drm-backport-placeholder)
- commit 7e1102f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0841-drm-amdkfd-Relocate-TBA-TMA-to-opposite-side-of-VM-h.patch (drm-backport-placeholder)
- commit f3fe0a2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0840-drm-amdkfd-Sync-trap-handler-binaries-with-source.patch (drm-backport-placeholder)
- commit 13c2949
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0839-drm-amdgpu-add-UAPI-for-allocating-doorbell-memory.patch (drm-backport-placeholder)
- commit 1777e2d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0838-drm-amdgpu-don-t-modify-num_doorbells-for-mes.patch (drm-backport-placeholder)
- commit 5dcb365
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0837-drm-amdgpu-Add-pcie-replay-count-callback-to-nbio.patch (drm-backport-placeholder)
- commit 147148b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0836-drm-amd-display-Promote-DC-to-2.3.245.patch (drm-backport-placeholder)
- commit 4d77524
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0835-Revert-drm-amd-display-Implement-zpos-property.patch (drm-backport-placeholder)
- commit 76ce5de
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0834-drm-amd-display-Implement-interface-for-notify-curso.patch (drm-backport-placeholder)
- commit 86f00c2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0833-drm-amdgpu-Prefer-pr_err-_warn-_notice-over-printk-i.patch (drm-backport-placeholder)
- commit 03bfe9f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0832-drm-amd-display-Temporary-Disable-MST-DP-Colorspace-.patch (drm-backport-placeholder)
- commit 2c3dc47
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0831-Revert-drm-amdgpu-Prefer-dev_-variant-over-printk-in.patch (drm-backport-placeholder)
- commit b8a8afc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0830-drm-amd-display-Clean-up-flip-pending-timeout-handli.patch (drm-backport-placeholder)
- commit 566c702
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0829-drm-amdgpu-init-TA-microcode-for-SRIOV-VF-when-MP0-I.patch (drm-backport-placeholder)
- commit 30ceed4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0828-drm-amdgpu-remove-SRIOV-VF-FB-location-programming.patch (drm-backport-placeholder)
- commit a336ee6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0827-drm-amd-display-Add-Functions-to-enable-Freesync-Pan.patch (drm-backport-placeholder)
- commit 3197401
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0826-drm-amdgpu-enable-SDMA-MGCG-for-SDMA-5.2.x.patch (drm-backport-placeholder)
- commit 789b90c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0825-drm-amdgpu-Issue-ras-enable_feature-for-gfx-ip-only.patch (drm-backport-placeholder)
- commit 91b5d61
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0824-drm-amdgpu-Remove-gfx-v11_0_3-ras_late_init-call.patch (drm-backport-placeholder)
- commit ed053ef
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0823-drm-amdgpu-Clean-up-style-problems-in-mmhub_v2_3.c.patch (drm-backport-placeholder)
- commit 074dd22
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0822-drm-amdgpu-Move-vram-gtt-flash-defines-to-amdgpu_-tt.patch (drm-backport-placeholder)
- commit 19f8e87
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0821-Revert-drm-radeon-Prefer-dev_-variant-over-printk.patch (drm-backport-placeholder)
- commit 41f39e0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0820-drm-amdgpu-Apply-poison-mode-check-to-GFX-IP-only.patch (drm-backport-placeholder)
- commit 1ba32ac
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0819-drm-amdgpu-Only-create-err_count-sysfs-when-hw_op-is.patch (drm-backport-placeholder)
- commit 2421b19
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0818-drm-amd-display-Add-structs-for-Freesync-Panel-Repla.patch (drm-backport-placeholder)
- commit 58a0875
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0817-drm-amdgpu-Sort-the-includes-in-amdgpu-amdgpu_drv.c.patch (drm-backport-placeholder)
- commit 8a90f79
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0816-drm-amdgpu-Cleanup-amdgpu-amdgpu_cgs.c.patch (drm-backport-placeholder)
- commit da2d11c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0815-drm-amdgpu-Fix-style-issues-in-amdgpu_psp.c.patch (drm-backport-placeholder)
- commit f00f2dd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0814-drm-amdgpu-Fix-style-issues-in-amdgpu_debugfs.c.patch (drm-backport-placeholder)
- commit 428dfc4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0813-drm-amd-pm-fix-pp_dpm_sclk-node-not-displaying-corre.patch (drm-backport-placeholder)
- commit 1cddc91
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0812-drm-amdkfd-avoid-unmap-dma-address-when-svm_ranges-a.patch (drm-backport-placeholder)
- commit 19b5453
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0811-drm-amd-display-Fix-typo-in-enable-and-disable-symcl.patch (drm-backport-placeholder)
- commit b806d68
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0810-drm-amd-display-Add-symclk-enable-disable-during-str.patch (drm-backport-placeholder)
- commit 5353ff0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0809-drm-amdgpu-discovery-add-ih-6.1.0-support.patch (drm-backport-placeholder)
- commit 734b621
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0808-drm-amdgpu-add-ih-6.1-support.patch (drm-backport-placeholder)
- commit decf520
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0807-drm-amdgpu-add-ih-6.1-registers.patch (drm-backport-placeholder)
- commit 433491a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0806-drm-amdgpu-discovery-add-smuio-14.0.0-support.patch (drm-backport-placeholder)
- commit 34c7e62
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0805-drm-amdgpu-discovery-add-hdp-6.1.0-support.patch (drm-backport-placeholder)
- commit 8eb8324
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0804-drm-amdgpu-discovery-enable-sdma6-for-SDMA-6.1.0.patch (drm-backport-placeholder)
- commit 3db1776
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0803-drm-amdgpu-sdma6-initialize-sdma-6.1.0.patch (drm-backport-placeholder)
- commit ca2305e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0802-drm-rcar-du-Enable-ABGR-and-XBGR-formats.patch (drm-backport-placeholder)
- commit c8b5bee
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0801-drm-rcar-du-Add-more-formats-to-DRM_MODE_BLEND_PIXEL.patch (drm-backport-placeholder)
- commit 2dc98f6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0800-drm-renesas-Convert-to-devm_platform_ioremap_resourc.patch (drm-backport-placeholder)
- commit d4ed383
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0799-drm-rcar-du-Use-dev_err_probe-to-record-cause-of-KMS.patch (drm-backport-placeholder)
- commit 2bc29e7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0798-drm-rcar-du-Replace-DRM_INFO-with-drm_info.patch (drm-backport-placeholder)
- commit 607c806
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0797-drm-mediatek-mtk_disp_ccorr-Remove-half-completed-in.patch (drm-backport-placeholder)
- commit 048579e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0796-drm-mediatek-mtk_disp_aal-Remove-half-completed-inco.patch (drm-backport-placeholder)
- commit 6055c51
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-void-pointer-to-enum-cast-warning.patch (drm-backport-placeholder)
- commit 5df31cf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-potential-memory-leak-if-vmap-fail.patch (drm-backport-placeholder)
- commit 6ebb4d4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-dereference-before-null-check.patch (drm-backport-placeholder)
- commit cd2d7e7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Add-cnt-checking-for-coverity-issue.patch (drm-backport-placeholder)
- commit 897fa6a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Remove-freeing-not-dynamic-allocated-me.patch (drm-backport-placeholder)
- commit b1ff4de
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0790-drm-mediatek-Convert-to-platform-remove-callback-ret.patch (drm-backport-placeholder)
- commit a1ce9ab
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0789-drm-mediatek-Do-not-check-for-0-return-after-calling.patch (drm-backport-placeholder)
- commit e619593
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0788-drm-mediatek-dp-Don-t-register-HPD-interrupt-handler.patch (drm-backport-placeholder)
- commit 481c70f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0787-drm-mediatek-dp-Add-.wait_hpd_asserted-for-AUX-bus.patch (drm-backport-placeholder)
- commit e5de611
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0786-drm-mediatek-dp-Add-support-for-embedded-DisplayPort.patch (drm-backport-placeholder)
- commit e5e7ee9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0785-drm-mediatek-dp-Move-PHY-registration-to-new-functio.patch (drm-backport-placeholder)
- commit c448503
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0784-drm-mediatek-dp-Avoid-mutex-locks-if-audio-is-not-su.patch (drm-backport-placeholder)
- commit 77231e2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0783-drm-mediatek-dp-Enable-event-interrupt-only-when-bri.patch (drm-backport-placeholder)
- commit 7509cbd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0782-drm-mediatek-dp-Move-AUX_P0-setting-to-mtk_dp_initia.patch (drm-backport-placeholder)
- commit c5980ed
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0781-drm-mediatek-dp-Use-devm-variant-of-drm_bridge_add.patch (drm-backport-placeholder)
- commit a70f5f3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0780-drm-mediatek-dp-Change-logging-to-dev-for-mtk_dp_aux.patch (drm-backport-placeholder)
- commit 398660a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0779-drm-mediatek-dp-Move-AUX-and-panel-poweron-off-seque.patch (drm-backport-placeholder)
- commit 54b028c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-dp-Add-missing-error-checks-in-mtk_dp_p.patch (drm-backport-placeholder)
- commit 10d8172
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0777-drm-mediatek-mtk_dpi-Compress-struct-of_device_id-en.patch (drm-backport-placeholder)
- commit 4b79106
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0776-drm-mediatek-mtk_dpi-Use-devm_platform_ioremap_resou.patch (drm-backport-placeholder)
- commit 876c66e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0775-drm-mediatek-mtk_dpi-Switch-to-.remove_new-void-call.patch (drm-backport-placeholder)
- commit 99fea98
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0774-drm-mediatek-mtk_dpi-Switch-to-devm_drm_of_get_bridg.patch (drm-backport-placeholder)
- commit 42d6611
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0773-drm-mediatek-mtk_dpi-Simplify-with-dev_err_probe.patch (drm-backport-placeholder)
- commit c6b4b47
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0772-drm-mediatek-mtk_dpi-Simplify-with-devm_drm_bridge_a.patch (drm-backport-placeholder)
- commit 38eef0d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-mediatek-Fix-uninitialized-symbol.patch (drm-backport-placeholder)
- commit 614ea4b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0770-drm-i915-guc-Fix-potential-null-pointer-deref-in-GuC.patch (drm-backport-placeholder)
- commit 54614ae
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0769-drm-i915-gt-Apply-workaround-22016122933-correctly.patch (drm-backport-placeholder)
- commit f7417cd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0768-drm-i915-Make-i915_coherent_map_type-GT-centric.patch (drm-backport-placeholder)
- commit cd98413
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0767-drm-i915-gt-Simplify-shmem_create_from_object-map_ty.patch (drm-backport-placeholder)
- commit 5fa3008
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0766-drm-i915-irq-move-all-PCH-irq-postinstall-calls-to-d.patch (drm-backport-placeholder)
- commit 4d31968
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0765-drm-i915-irq-add-ilk_de_irq_postinstall.patch (drm-backport-placeholder)
- commit 51a13d0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0764-drm-i915-irq-add-dg1_de_irq_postinstall.patch (drm-backport-placeholder)
- commit 4670e27
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0763-drm-i915-irq-add-dedicated-intel_display_irq_init.patch (drm-backport-placeholder)
- commit 7a13ce0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0762-drm-i915-debug-log-when-GMD-ID-indicates-there-s-no-.patch (drm-backport-placeholder)
- commit 0b28afa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0761-drm-i915-display-pre-initialize-some-values-in-probe.patch (drm-backport-placeholder)
- commit 215df9f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0760-drm-i915-adls-s-ADLS_RPLS-RAPTORLAKE_S-in-platform-a.patch (drm-backport-placeholder)
- commit 5e9b82d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0759-drm-i915-adln-s-ADLP-ALDERLAKE_P-in-ADLN-defines.patch (drm-backport-placeholder)
- commit 1bff397
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0758-drm-i915-rplu-s-ADLP_RPLU-RAPTORLAKE_U-in-RPLU-defin.patch (drm-backport-placeholder)
- commit ed1dd9f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0757-drm-i915-rplp-s-ADLP_RPLP-RAPTORLAKE_P-for-RPLP-defi.patch (drm-backport-placeholder)
- commit b5d59fa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0756-drm-i915-adlp-s-ADLP-ALDERLAKE_P-for-display-and-gra.patch (drm-backport-placeholder)
- commit 8b94cf1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0755-drm-i915-tgl-s-TGL-TIGERLAKE-for-platform-subplatfor.patch (drm-backport-placeholder)
- commit 3d70f27
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0754-drm-i915-jsl-s-JSL-JASPERLAKE-for-platform-subplatfo.patch (drm-backport-placeholder)
- commit 70db4bf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0753-drm-i915-rkl-s-RKL-ROCKETLAKE-for-platform-subplatfo.patch (drm-backport-placeholder)
- commit f6454a8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0752-drm-i915-cml-s-CML-COMETLAKE-for-platform-subplatfor.patch (drm-backport-placeholder)
- commit 3b1ada9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0751-drm-i915-cfl-s-CFL-COFFEELAKE-for-platform-subplatfo.patch (drm-backport-placeholder)
- commit 8a0355b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0750-drm-i915-kbl-s-KBL-KABYLAKE-for-platform-subplatform.patch (drm-backport-placeholder)
- commit 3209b59
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0749-drm-i915-skl-s-SKL-SKYLAKE-for-platform-subplatform-.patch (drm-backport-placeholder)
- commit 8f46a64
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0748-drm-i915-bdw-s-BDW-BROADWELL-for-platform-subplatfor.patch (drm-backport-placeholder)
- commit 836a5c1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0747-drm-i915-hsw-s-HSW-HASWELL-for-platform-subplatform-.patch (drm-backport-placeholder)
- commit 7c1c739
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0746-drm-i915-fbc-Moved-fence-related-code-away-from-inte.patch (drm-backport-placeholder)
- commit c183ac8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0745-drm-i915-fbc-Make-FBC-check-stolen-at-use-time.patch (drm-backport-placeholder)
- commit f997bae
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0744-drm-i915-Move-stolen-memory-handling-into-i915_gem_s.patch (drm-backport-placeholder)
- commit 089918c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0743-drm-i915-sdvo-ignore-returned-broken-edid-on-intel_s.patch (drm-backport-placeholder)
- commit e980227
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0742-drm-ttm-Remove-two-unused-function-declarations.patch (drm-backport-placeholder)
- commit 2c58f03
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0741-drm-test-drm_exec-fix-memory-leak-on-object-prepare.patch (drm-backport-placeholder)
- commit d10f34f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0740-drm-atmel-hlcdc-Support-inverting-the-pixel-clock-po.patch (drm-backport-placeholder)
- commit a920b79
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0739-drm-panfrost-Sync-IRQ-by-job-s-timeout-handler.patch (drm-backport-placeholder)
- commit 8cdeaa1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0738-drm-exec-add-test-case-for-using-a-drm_exec-multiple.patch (drm-backport-placeholder)
- commit df1dd23
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0737-drm-exec-use-unique-instead-of-local-label.patch (drm-backport-placeholder)
- commit 3e07384
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0736-drm-ttm-tests-Add-tests-for-ttm_pool.patch (drm-backport-placeholder)
- commit 811e290
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0735-drm-ttm-tests-Add-tests-for-ttm_device.patch (drm-backport-placeholder)
- commit 717b305
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0734-drm-ttm-Introduce-KUnit-test.patch (drm-backport-placeholder)
- commit 5aede33
* Mon Sep  9 2024 pjakobsson@suse.de
- Delete patches.suse/0733-accel-ivpu-Refactor-memory-ranges-logic.patch.
- commit 27ec5bd
* Mon Sep  9 2024 tiwai@suse.de
- clocksource/drivers/imx-tpm: Fix next event not taking effect
  sometime (git-fixes).
- clocksource/drivers/imx-tpm: Fix return -ETIME when delta
  exceeds INT_MAX (git-fixes).
- dma-debug: avoid deadlock between dma debug vs printk and
  netconsole (stable-fixes).
- drm/amdgpu: fix contiguous handling for IB parsing v2
  (git-fixes).
- dmaengine: altera-msgdma: properly free descriptor in
  msgdma_free_descriptor (stable-fixes).
- dmaengine: altera-msgdma: use irq variant of spin_lock/unlock
  while invoking callbacks (stable-fixes).
- driver: iio: add missing checks on iio_info's callback access
  (stable-fixes).
- drm/amd/display: Skip wbscl_set_scaler_filter if filter is null
  (stable-fixes).
- drm/amd/display: Check BIOS images before it is used
  (stable-fixes).
- drm/amd/display: Avoid overflow from uint32_t to uint8_t
  (stable-fixes).
- drm/amd/display: use preferred link settings for dp signal only
  (stable-fixes).
- drm/amd/display: Remove register from DCN35 DMCUB diagnostic
  collection (stable-fixes).
- drm/amd/display: Correct the defined value for
  AMDGPU_DMUB_NOTIFICATION_MAX (stable-fixes).
- drm/amd/display: added NULL check at start of dc_validate_stream
  (stable-fixes).
- drm/amd/display: Wake DMCUB before sending a command for replay
  feature (stable-fixes).
- drm/amd/display: Don't use fsleep for PSR exit waits on dmub
  replay (stable-fixes).
- drm/amdgpu: fix overflowed constant warning in
  mmhub_set_clockgating() (stable-fixes).
- drm/amdgpu: add lock in kfd_process_dequeue_from_device
  (stable-fixes).
- drm/amdgpu: add lock in amdgpu_gart_invalidate_tlb
  (stable-fixes).
- drm/amdgpu: add skip_hw_access checks for sriov (stable-fixes).
- drm/bridge: tc358767: Check if fully initialized before
  signalling HPD event via IRQ (stable-fixes).
- drm/meson: plane: Add error handling (stable-fixes).
- drm/drm-bridge: Drop conditionals around of_node pointers
  (stable-fixes).
- drm/amd/display: Add null checks for 'stream' and 'plane'
  before dereferencing (stable-fixes).
- drm/amdgu: fix Unintentional integer overflow for mall size
  (stable-fixes).
- drm/amdgpu: update type of buf size to u32 for eeprom functions
  (stable-fixes).
- drm/amd/display: Fix pipe addition logic in
  calc_blocks_to_ungate DCN35 (stable-fixes).
- drm/kfd: Correct pinned buffer handling at kfd restore and
  validate process (stable-fixes).
- drm/amd/pm: check negtive return for table entries
  (stable-fixes).
- drm/amdgpu: the warning dereferencing obj for nbio_v7_4
  (stable-fixes).
- drm/amd/pm: check specific index for smu13 (stable-fixes).
- drm/amd/pm: check specific index for aldebaran (stable-fixes).
- drm/amdgpu: fix the waring dereferencing hive (stable-fixes).
- drm/amdgpu: fix dereference after null check (stable-fixes).
- drm/amdgpu: Fix the warning division or modulo by zero
  (stable-fixes).
- drm/amdgpu/pm: Check input value for CUSTOM profile mode
  setting on legacy SOCs (stable-fixes).
- drm/amdkfd: Reconcile the definition and use of oem_id in
  struct kfd_topology_device (stable-fixes).
- drm/amdgpu: fix mc_data out-of-bounds read warning
  (stable-fixes).
- drm/amdgpu: fix ucode out-of-bounds read warning (stable-fixes).
- drm/amdgpu: Fix uninitialized variable warning in
  amdgpu_info_ioctl (stable-fixes).
- drm/amdgpu: Fix out-of-bounds read of df_v1_7_channel_number
  (stable-fixes).
- drm/amdkfd: Check debug trap enable before write dbg_ev_file
  (stable-fixes).
- drm/amdgpu: Fix out-of-bounds write warning (stable-fixes).
- drm/amdgpu: Fix the uninitialized variable warning
  (stable-fixes).
- drm/amdgpu/pm: Fix uninitialized variable agc_btc_response
  (stable-fixes).
- drm/amdgpu/pm: Fix uninitialized variable warning for smu10
  (stable-fixes).
- drm/amd/pm: fix uninitialized variable warnings for vangogh_ppt
  (stable-fixes).
- drm/amd/amdgpu: Check tbo resource pointer (stable-fixes).
- drm/amd/display: Fix index may exceed array range within
  fpu_update_bw_bounding_box (stable-fixes).
- drm/amd/display: Skip inactive planes within
  ModeSupportAndSystemConfiguration (stable-fixes).
- drm/amd/display: Ensure index calculation will not overflow
  (stable-fixes).
- drm/amd/display: Fix Coverity INTEGER_OVERFLOW within
  decide_fallback_link_setting_max_bw_policy (stable-fixes).
- drm/amd/display: Spinlock before reading event (stable-fixes).
- drm/amd/display: Fix Coverity INTEGER_OVERFLOW within
  dal_gpio_service_create (stable-fixes).
- drm/amd/display: Fix Coverity INTERGER_OVERFLOW within
  construct_integrated_info (stable-fixes).
- drm/amd/display: Check msg_id before processing transcation
  (stable-fixes).
- drm/amd/display: Check num_valid_sets before accessing
  reader_wm_sets[] (stable-fixes).
- drm/amd/display: Add array index check for hdcp ddc access
  (stable-fixes).
- drm/amd/display: Check index for aux_rd_interval before using
  (stable-fixes).
- drm/amd/display: Stop amdgpu_dm initialize when stream nums
  greater than 6 (stable-fixes).
- drm/amd/display: Check gpio_id before used as array index
  (stable-fixes).
- drm/amd/display: Ensure array index tg_inst won't be -1
  (stable-fixes).
- drm/amdgpu: avoid reading vf2pf info size from FB
  (stable-fixes).
- drm/amd/pm: fix uninitialized variable warnings for vega10_hwmgr
  (stable-fixes).
- drm/amdgpu: fix uninitialized scalar variable warning
  (stable-fixes).
- drm/amd/pm: fix the Out-of-bounds read warning (stable-fixes).
- drm/amd/pm: Fix negative array index read (stable-fixes).
- drm/amd/pm: fix warning using uninitialized value of
  max_vid_step (stable-fixes).
- drm/amd/pm: fix uninitialized variable warning for smu8_hwmgr
  (stable-fixes).
- drm/amd/pm: fix uninitialized variable warning (stable-fixes).
- drm/amdgpu/pm: Check the return value of smum_send_msg_to_smc
  (stable-fixes).
- drm/amdgpu: fix overflowed array index read warning
  (stable-fixes).
- drm/amdgpu: Handle sg size limit for contiguous allocation
  (stable-fixes).
- drm/amd/display: Assign linear_pitch_alignment even for VM
  (stable-fixes).
- drm/amd/display: Handle the case which quad_part is equal 0
  (stable-fixes).
- drm/amdgpu: Fix uninitialized variable warning in
  amdgpu_afmt_acr (stable-fixes).
- cpufreq: scmi: Avoid overflow of target_freq in fast switch
  (stable-fixes).
- commit e23c4dc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0732-accel-ivpu-Extend-get_param-ioctl-to-identify-capabi.patch (drm-backport-placeholder)
- commit daf8ae2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0731-drm-nouveau-sched-Don-t-pass-user-flags-to-drm_synco.patch (drm-backport-placeholder)
- commit a0f8d0f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0730-drm-nouveau-uvmm-remove-dedicated-VM-pointer-from-VM.patch (drm-backport-placeholder)
- commit c792730
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0729-drm-nouveau-uvmm-remove-incorrect-calls-to-mas_unloc.patch (drm-backport-placeholder)
- commit 46cb200
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0728-drm-nouveau-remove-incorrect-__user-annotations.patch (drm-backport-placeholder)
- commit dc4898f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0727-drm-nouveau-nvkm-vmm-silence-warning-from-cast.patch (drm-backport-placeholder)
- commit 05f4773
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0726-nouveau-dmem-fix-copy-paste-error-in-nouveau_dmem_mi.patch (drm-backport-placeholder)
- commit 2671a3a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0725-drm-mcde-remove-redundant-of_match_ptr.patch (drm-backport-placeholder)
- commit 8a23500
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0724-drm-tve200-remove-redundant-of_match_ptr.patch (drm-backport-placeholder)
- commit 1f16a14
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0723-drm-nouveau-debugfs-implement-DRM-GPU-VA-debugfs.patch (drm-backport-placeholder)
- commit ec924f0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0722-drm-nouveau-implement-new-VM_BIND-uAPI.patch (drm-backport-placeholder)
- commit da8a88f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0721-drm-nouveau-nvkm-vmm-implement-raw-ops-to-manage-uvm.patch (drm-backport-placeholder)
- commit d50e2b2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0720-drm-nouveau-chan-provide-nouveau_channel_kill.patch (drm-backport-placeholder)
- commit c8d4946
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0719-drm-nouveau-fence-fail-to-emit-when-fence-context-is.patch (drm-backport-placeholder)
- commit 4ba7338
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0718-drm-nouveau-fence-separate-fence-alloc-and-emit.patch (drm-backport-placeholder)
- commit b262d4d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0717-drm-nouveau-move-usercopy-helpers-to-nouveau_drv.h.patch (drm-backport-placeholder)
- commit 0464665
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0716-drm-nouveau-bo-initialize-GEM-GPU-VA-interface.patch (drm-backport-placeholder)
- commit 9d29c03
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0715-drm-nouveau-get-vmm-via-nouveau_cli_vmm.patch (drm-backport-placeholder)
- commit d9fffbd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0714-drm-nouveau-new-VM_BIND-uAPI-interfaces.patch (drm-backport-placeholder)
- commit 01b4c6d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0713-drm-nouveau-fixup-the-uapi-header-file.patch (drm-backport-placeholder)
- commit 3f372fc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0712-drm-gem-fix-lockdep-check-for-dma-resv-lock.patch (drm-backport-placeholder)
- commit 9729e0a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0711-drm-Drop-select-FRAMEBUFFER_CONSOLE-for-DRM_FBDEV_EM.patch (drm-backport-placeholder)
- commit a81d489
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0710-fbdev-xilinxfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit dffe03c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0709-fbdev-vesafb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 92915da
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0708-fbdev-valkyriefb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 03f5de7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0707-fbdev-uvesafb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit ad21fe8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0706-fbdev-sunxvr2500-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 97ea29f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0705-fbdev-sunxvr1000-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit bdc8efb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0704-fbdev-sstfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 9688afe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0703-fbdev-simplefb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 2315352
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0702-fbdev-sh7760fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 58e9f13
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0701-fbdev-s3cfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit a8b50e7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0700-fbdev-q40fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit efa7bf6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0699-fbdev-pxafb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 3d7dd89
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0698-fbdev-pxa168fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 88dbe53
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0697-fbdev-pmagb-b-fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 2d94053
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0696-fbdev-pmag-ba-fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 7102c00
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0695-fbdev-pmag-aa-fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit dace2b1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0694-fbdev-platinumfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit fd9036b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0693-fbdev-omapfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 5fbfe7a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0692-fbdev-offb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit ca46039
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0691-fbdev-ocfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit ae6acd2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0690-fbdev-mx3fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 9e57505
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0689-fbdev-mmpfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 6f5c282
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0688-fbdev-mb862xxfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 80c05e4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0687-fbdev-maxinefb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit e31d47e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0686-fbdev-macfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 10f1fe4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0685-fbdev-kyro-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 6399c3f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0684-fbdev-imxfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 3b377bd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0683-fbdev-i740fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit a0293a1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0682-fbdev-gxt4500-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 1b7fb4f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0681-fbdev-grvga-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 7f51035
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0680-fbdev-goldfishfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit a796df0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0679-fbdev-geode-lxfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 80b9fdd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0678-fbdev-geode-gxfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit fa29215
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0677-fbdev-geode-gx1fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 2e84317
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0676-fbdev-g364fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit a3ac5b0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0675-fbdev-fsl-diu-fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit a772b79
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0674-fbdev-fm2fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 8ed75b6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0673-fbdev-efifb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 68e9bf0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0672-fbdev-da8xx-fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 94073c7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0671-fbdev-chipsfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 0b3d940
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0670-fbdev-carminefb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 7d3a7f5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0669-fbdev-aty128fb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit f5ceff2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0668-fbdev-atmel_lcdfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 6968c53
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0667-fbdev-asiliantfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 59b1ea0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0666-fbdev-acornfb-Use-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 6d5acf9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0665-drm-panel-sitronix-st7789v-add-jasonic-jt240mhqs-hwt.patch (drm-backport-placeholder)
- commit e94fcd7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0664-drm-panel-sitronix-st7789v-add-support-for-partial-m.patch (drm-backport-placeholder)
- commit a011863
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0663-drm-panel-sitronix-st7789v-add-panel-orientation-sup.patch (drm-backport-placeholder)
- commit 0b1c77b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0662-drm-panel-sitronix-st7789v-fix-indentation-in-drm_pa.patch (drm-backport-placeholder)
- commit 9b99f56
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0661-drm-bridge-dw_hdmi-Fix-ELD-is-not-updated-issue.patch (drm-backport-placeholder)
- commit 6eeec03
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0660-drm-loongson-Add-a-check-for-lsdc_bo_create-errors.patch (drm-backport-placeholder)
- commit 3852d27
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0659-drm-doc-fix-underline-for-section-DRM-Sync-Objects.patch (drm-backport-placeholder)
- commit 8d9fd30
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0658-drm-exynos-remove-redundant-of_match_ptr.patch (drm-backport-placeholder)
- commit b04ac3f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0657-drm-exynos-fix-a-possible-null-pointer-dereference-d.patch (drm-backport-placeholder)
- commit cce8fcf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0656-drm-i915-Remove-unnecessary-include.patch (drm-backport-placeholder)
- commit eb3afc1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0655-drm-i915-Invalidate-the-TLBs-on-each-GT.patch (drm-backport-placeholder)
- commit 0916f98
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0654-i915-drm-gt-Move-the-gt-defines-in-the-gt-directory.patch (drm-backport-placeholder)
- commit fcb4594
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0653-drm-i915-gt-Move-TLB-invalidation-to-its-own-file.patch (drm-backport-placeholder)
- commit 0587223
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0652-drm-i915-selftest-gsc-Ensure-GSC-Proxy-init-complete.patch (drm-backport-placeholder)
- commit aa91310
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0651-drm-i915-Use-the-i915_vma_flush_writes-helper.patch (drm-backport-placeholder)
- commit f54d806
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0650-drm-i915-Replace-i915-gt0-with-to_gt-i915.patch (drm-backport-placeholder)
- commit 83556c2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0649-drm-i915-use-direct-alias-for-i915-in-requests.patch (drm-backport-placeholder)
- commit 2e4df67
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0648-drm-i915-huc-check-HuC-and-GuC-version-compatibility.patch (drm-backport-placeholder)
- commit bf10259
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0647-drm-i915-Expose-RPS-thresholds-in-sysfs.patch (drm-backport-placeholder)
- commit 5eda5a3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0646-drm-i915-Add-helpers-for-managing-rps-thresholds.patch (drm-backport-placeholder)
- commit db7a3d4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0645-drm-i915-Record-default-rps-threshold-values.patch (drm-backport-placeholder)
- commit 3b34127
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0644-drm-i915-Move-setting-of-rps-thresholds-to-init.patch (drm-backport-placeholder)
- commit 26e1ab2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0643-drm-i915-gt-Do-not-use-stolen-on-MTL.patch (drm-backport-placeholder)
- commit 94917d6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0642-drm-i915-mtl-Update-cache-coherency-setting-for-cont.patch (drm-backport-placeholder)
- commit 9a8e498
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0641-drm-i915-guc-Dump-perf_limit_reasons-for-debug.patch (drm-backport-placeholder)
- commit 49b1320
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0640-drm-i915-Remove-some-dead-code.patch (drm-backport-placeholder)
- commit 22db1a7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0639-drm-i915-gt-Also-check-set-bits-in-clr_set.patch (drm-backport-placeholder)
- commit ef8a159
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0638-drm-i915-gt-Remove-bogus-comment-on-IVB_FBC_RT_BASE_.patch (drm-backport-placeholder)
- commit 2f9f840
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0637-drm-i915-gt-Enable-read-back-on-XEHP_FF_MODE2.patch (drm-backport-placeholder)
- commit 3ae3c5c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0636-drm-i915-gt-Drop-read-from-GEN8_L3CNTLREG-in-ICL-wor.patch (drm-backport-placeholder)
- commit 8b7ffed
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0635-drm-i915-gt-Fix-context-workarounds-with-non-masked-.patch (drm-backport-placeholder)
- commit 49463ca
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0634-drm-i915-gt-Clear-all-bits-from-GEN12_FF_MODE2.patch (drm-backport-placeholder)
- commit af1b467
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0633-drm-i915-gt-Move-wal_get_fw_for_rmw.patch (drm-backport-placeholder)
- commit 2ad1981
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0632-drm-i915-Replace-kmap-with-kmap_local_page.patch (drm-backport-placeholder)
- commit 70f80e9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0631-drm-i915-Extend-Wa_14015795083-platforms.patch (drm-backport-placeholder)
- commit f4ece12
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0630-drm-i915-mtl-Update-workaround-14018778641.patch (drm-backport-placeholder)
- commit 3f2d024
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0629-drm-i915-gsc-Fix-intel_gsc_uc_fw_proxy_init_done-wit.patch (drm-backport-placeholder)
- commit bd62e12
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0628-drm-i915-mtl-gsc-Add-a-gsc_info-debugfs.patch (drm-backport-placeholder)
- commit 3be97bd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0627-drm-i915-mtl-gsc-query-the-GSC-FW-for-its-compatibil.patch (drm-backport-placeholder)
- commit 83121f9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0626-drm-i915-mtl-gsc-extract-release-and-security-versio.patch (drm-backport-placeholder)
- commit 11bc5e8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0625-drm-i915-gsc-fixes-and-updates-for-GSC-memory-alloca.patch (drm-backport-placeholder)
- commit d3ecb28
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0624-drm-i915-Fix-a-VMA-UAF-for-multi-gt-platform.patch (drm-backport-placeholder)
- commit 752cdfe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0623-drm-i915-uncore-fix-race-around-i915-params.mmio_deb.patch (drm-backport-placeholder)
- commit 8a65d14
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0622-drm-i915-uncore-split-unclaimed_reg_debug-to-header-.patch (drm-backport-placeholder)
- commit 08423f6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0621-drm-i915-Add-function-to-clear-scanout-flag-for-vmas.patch (drm-backport-placeholder)
- commit 9b9b7a0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0620-drm-i915-display-Remove-i915_gem_object_types.h-from.patch (drm-backport-placeholder)
- commit 7b8fdb0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0619-drm-i915-Add-getter-setter-for-i915_gem_object-front.patch (drm-backport-placeholder)
- commit f4c721a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0618-drm-i915-Add-macros-to-get-i915-device-from-i915_gem.patch (drm-backport-placeholder)
- commit 96b8663
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0617-drm-i915-color-Downscale-degamma-lut-values-read-fro.patch (drm-backport-placeholder)
- commit 4c2b32a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0616-drm-i915-color-Upscale-degamma-values-for-MTL.patch (drm-backport-placeholder)
- commit 793d862
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0615-drm-i915-hotplug-Reduce-SHPD_FILTER-to-250us.patch (drm-backport-placeholder)
- commit 7554d94
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0614-drm-i915-Simplify-expression-to_i915-dev-drm.patch (drm-backport-placeholder)
- commit 8eb25fc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0613-drm-i915-Start-using-plane-scale-factor-for-relative.patch (drm-backport-placeholder)
- commit 762f4bd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0612-drm-i915-display-Do-not-use-stolen-on-MTL.patch (drm-backport-placeholder)
- commit 08a6765
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0611-drm-i915-vdsc-Remove-FIXME-in-intel_dsc_compute_conf.patch (drm-backport-placeholder)
- commit 63ff4ce
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0610-drm-i915-dsc-Add-rc_range_parameter-calculation-for-.patch (drm-backport-placeholder)
- commit 5538b7c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0609-drm-i915-drm-Fix-comment-for-YCbCr20-qp-table-declar.patch (drm-backport-placeholder)
- commit 4a78c48
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0608-drm-i915-dsc-Move-rc-param-calculation-for-native_42.patch (drm-backport-placeholder)
- commit 1f8f79f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0607-i915-display-hotplug-use-drm_kms_helper_connector_ho.patch (drm-backport-placeholder)
- commit 6c0584d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0606-drm-i915-Don-t-rely-that-2-VDSC-engines-are-always-e.patch (drm-backport-placeholder)
- commit 167483e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0605-drm-i915-Add-helper-function-for-getting-number-of-V.patch (drm-backport-placeholder)
- commit 6864c1d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0604-drm-i915-Try-to-initialize-DDI-ICL-DSI-ports-for-eve.patch (drm-backport-placeholder)
- commit d999de3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0603-drm-i915-bios-Extract-intel_bios_encoder_port.patch (drm-backport-placeholder)
- commit cae162f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0602-drm-i915-Remove-AUX-CH-sanitation.patch (drm-backport-placeholder)
- commit 4ce0f87
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0601-drm-i915-Remove-DDC-pin-sanitation.patch (drm-backport-placeholder)
- commit 19bf625
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0600-drm-i915-Only-populate-aux_ch-if-really-needed.patch (drm-backport-placeholder)
- commit 6f8ace8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0599-drm-i915-Initialize-dig_port-aux_ch-to-NONE-to-be-su.patch (drm-backport-placeholder)
- commit 4342efa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0598-drm-i915-Fail-if-DSC-compression-requirement-is-less.patch (drm-backport-placeholder)
- commit fe6cd8d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0597-drm-i915-dram-replace-__raw_uncore_read32-with-intel.patch (drm-backport-placeholder)
- commit 4e28f0a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0596-drm-i915-uncore-add-intel_uncore_regs-helper.patch (drm-backport-placeholder)
- commit 2e326c2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0595-drm-i915-make-device-info-a-const-pointer-to-rodata.patch (drm-backport-placeholder)
- commit 8a437fe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0594-drm-i915-move-display-device-and-runtime-info-to-str.patch (drm-backport-placeholder)
- commit d5be46f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0593-drm-i915-fix-display-info-usage.patch (drm-backport-placeholder)
- commit 609bf3a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0592-drm-i915-separate-display-info-printing-from-the-res.patch (drm-backport-placeholder)
- commit bf2cda5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0591-drm-i915-move-platform_engine_mask-and-memory_region.patch (drm-backport-placeholder)
- commit 4fbb3f4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0590-drm-i915-Remove-prototype-for-intel_cx0_phy_ddi_vswi.patch (drm-backport-placeholder)
- commit 492d09f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0589-drm-doc-fix-duplicate-declaration-warning.patch (drm-backport-placeholder)
- commit 6974d72
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0588-drm-i915-Prevent-needless-toggling-of-DC-states-duri.patch (drm-backport-placeholder)
- commit 8a5bd9f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0587-drm-i915-Add-way-to-specify-the-power-off-delay-of-a.patch (drm-backport-placeholder)
- commit 74602b4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0586-drm-i915-Remove-redundant-forward-declarations-from-.patch (drm-backport-placeholder)
- commit 242129e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0585-drm-i915-hdcp-Add-a-debug-statement-at-hdcp2-capabil.patch (drm-backport-placeholder)
- commit c3671c7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0584-drm-i915-mtl-Skip-using-vbt-hdmi_level_shifter-selec.patch (drm-backport-placeholder)
- commit f297119
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0583-drm-i915-mtl-Add-new-vswing-table-for-C20-phy-to-sup.patch (drm-backport-placeholder)
- commit 1d1d9aa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0582-drm-i915-mtl-update-DP-2.0-vswing-table-for-C20-phy.patch (drm-backport-placeholder)
- commit 5675da8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0581-drm-i915-Convert-HSW-BDW-to-use-port_mask-for-DDI-pr.patch (drm-backport-placeholder)
- commit fa51810
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0580-drm-i915-Init-DDI-outputs-based-on-port_mask-on-skl.patch (drm-backport-placeholder)
- commit 0582a36
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0579-drm-i915-Beef-up-SDVO-HDMI-port-checks.patch (drm-backport-placeholder)
- commit 8a87ee0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0578-drm-i915-Assert-that-the-port-being-initialized-is-v.patch (drm-backport-placeholder)
- commit f40bec2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0577-drm-i915-Assert-that-device-info-bitmasks-have-enoug.patch (drm-backport-placeholder)
- commit f101762
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0576-drm-i915-Introduce-device-info-port_mask.patch (drm-backport-placeholder)
- commit f839d7d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0575-drm-i915-Remove-bogus-DDI-F-from-hsw-bdw-output-init.patch (drm-backport-placeholder)
- commit 005b1f9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0574-drm-i915-psr-Re-enable-PSR1-on-hsw-bdw.patch (drm-backport-placeholder)
- commit 4426b32
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0573-drm-i915-psr-Allow-PSR-with-sprite-enabled-on-hsw-bd.patch (drm-backport-placeholder)
- commit a2f2b36
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0572-drm-i915-psr-Don-t-skip-both-TP1-and-TP2-3-on-hsw-bd.patch (drm-backport-placeholder)
- commit 534299f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0571-drm-i915-psr-Do-no-mask-display-register-writes-on-h.patch (drm-backport-placeholder)
- commit 13afbfe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0570-drm-i915-psr-Implement-WaPsrDPRSUnmaskVBlankInSRD-hs.patch (drm-backport-placeholder)
- commit 82c9162
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0569-drm-i915-psr-Implement-WaPsrDPAMaskVBlankInSRD-hsw.patch (drm-backport-placeholder)
- commit 1046d62
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0568-drm-i915-psr-Restore-PSR-interrupt-handler-for-HSW.patch (drm-backport-placeholder)
- commit bb5336a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0567-drm-i915-psr-HSW-BDW-have-no-PSR2.patch (drm-backport-placeholder)
- commit aa8b617
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0566-drm-i915-psr-Bring-back-HSW-BDW-PSR-AUX-CH-registers.patch (drm-backport-placeholder)
- commit c5616b0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0565-drm-i915-psr-Reintroduce-HSW-PSR1-registers.patch (drm-backport-placeholder)
- commit 937da89
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0564-drm-i915-psr-Wrap-PSR1-register-with-functions.patch (drm-backport-placeholder)
- commit 005d69d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0563-drm-i915-Re-init-clock-gating-on-coming-out-of-PC8.patch (drm-backport-placeholder)
- commit 1afbb59
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0562-drm-i915-mtl-Cleanup-usage-of-phy-lane-reset.patch (drm-backport-placeholder)
- commit 0206e6c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0561-drm-i915-hdcp-Modify-hdcp_gsc_message-msg-sending-me.patch (drm-backport-placeholder)
- commit a1ae694
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0560-drm-i915-dsi-Remove-weird-has_pch_encoder-asserts.patch (drm-backport-placeholder)
- commit 04864c9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0559-drm-i915-dsi-Grab-the-crtc-from-the-customary-place.patch (drm-backport-placeholder)
- commit c301526
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0558-drm-i915-dsi-Move-panel-reset-power-off-to-be-the-la.patch (drm-backport-placeholder)
- commit 01200b4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0557-drm-i915-dsi-Respect-power_off_delay-on-icl.patch (drm-backport-placeholder)
- commit cbed895
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0556-drm-i915-dsi-Do-DSC-scaler-disable-earlier-on-icl.patch (drm-backport-placeholder)
- commit c838aba
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0555-drm-i915-dsi-Move-most-things-from-.disable-into-.po.patch (drm-backport-placeholder)
- commit 63bb3d6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0554-drm-i915-dsi-Implement-encoder-shutdown-for-icl.patch (drm-backport-placeholder)
- commit 843ee46
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0553-drm-i915-dsi-Respect-power-cycle-delay-on-icl.patch (drm-backport-placeholder)
- commit 491ad03
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0552-drm-i915-dsi-Gate-DSI-clocks-earlier.patch (drm-backport-placeholder)
- commit 09a0405
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0551-drm-i915-dsi-Split-icl-D-PHY-vs.-DSI-timing-steps.patch (drm-backport-placeholder)
- commit d02b104
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0550-drm-i915-dsi-Print-the-VBT-MIPI-sequence-delay-durat.patch (drm-backport-placeholder)
- commit 3d42b70
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0549-drm-i915-dsi-Do-display-on-sequence-later-on-icl.patch (drm-backport-placeholder)
- commit bfe91de
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0548-drm-i915-dsi-Do-panel-power-on-reset-deassert-earlie.patch (drm-backport-placeholder)
- commit e73e691
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0547-drm-i915-gmch-avoid-unused-variable-warning.patch (drm-backport-placeholder)
- commit 2cfd123
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0546-fbdev-ps3fb-Build-without-kernel-device.patch (drm-backport-placeholder)
- commit f34b3a0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0545-drm-doc-document-that-PRIME-import-export-is-always-.patch (drm-backport-placeholder)
- commit 417cb7e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0544-drm-doc-document-drm_event-and-its-types.patch (drm-backport-placeholder)
- commit fcdf3b4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0543-drm-doc-add-warning-about-connector_type_id-stabilit.patch (drm-backport-placeholder)
- commit a61bef0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0542-drm-doc-use-proper-cross-references-for-sections.patch (drm-backport-placeholder)
- commit 87387b8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0541-fbcon-Make-fbcon_registered_fb-and-fbcon_num_registe.patch (drm-backport-placeholder)
- commit 6f1a5ea
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0540-drm-drm_plane.h-fix-grammar-of-the-comment.patch (drm-backport-placeholder)
- commit d221d2c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0539-drm-bridge-dw_hdmi-Add-cec-suspend-resume-functions.patch (drm-backport-placeholder)
- commit 00464b5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0538-drm-panel-simple-Add-Innolux-G156HCE-L01-panel-entry.patch (drm-backport-placeholder)
- commit b35d420
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0537-drm-panel-Fix-todo-indentation-for-panel-prepared-en.patch (drm-backport-placeholder)
- commit 455471a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0536-drm-panel-Fix-kernel-doc-typo-for-follower_lock.patch (drm-backport-placeholder)
- commit 3b5a136
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0535-drm-tiny-panel-mipi-dbi-Allow-sharing-the-D-C-GPIO.patch (drm-backport-placeholder)
- commit c3575b0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0534-drm-mipi-dbi-Lock-SPI-bus-before-setting-D-C-GPIO.patch (drm-backport-placeholder)
- commit b75b594
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0533-drm-bridge-Add-debugfs-print-for-bridge-chains.patch (drm-backport-placeholder)
- commit 0504632
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0532-drm-panel-Add-a-way-for-other-devices-to-follow-pane.patch (drm-backport-placeholder)
- commit 33db8e2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0531-drm-panel-Check-for-already-prepared-enabled-in-drm_.patch (drm-backport-placeholder)
- commit be0da84
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0530-drm-panel-edp-Add-enable-timings-for-N140HCA-EAC-pan.patch (drm-backport-placeholder)
- commit 77c6401
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0529-drm-panel-sitronix-st7789v-Check-display-ID.patch (drm-backport-placeholder)
- commit da3d3ca
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0528-drm-panel-sitronix-st7789v-Add-EDT-ET028013DMA-panel.patch (drm-backport-placeholder)
- commit 186a5d3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0527-drm-panel-sitronix-st7789v-Clarify-a-definition.patch (drm-backport-placeholder)
- commit 849c7d8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0526-drm-panel-sitronix-st7789v-Use-9-bits-per-spi-word-b.patch (drm-backport-placeholder)
- commit 8ff2713
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0525-drm-panel-sitronix-st7789v-add-Inanbo-T28CP45TN89-su.patch (drm-backport-placeholder)
- commit b3e00c3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0524-drm-panel-sitronix-st7789v-avoid-hardcoding-polarity.patch (drm-backport-placeholder)
- commit 162f58e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0523-drm-panel-sitronix-st7789v-avoid-hardcoding-invert-m.patch (drm-backport-placeholder)
- commit 5f85128
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0522-drm-panel-sitronix-st7789v-add-media-bus-format.patch (drm-backport-placeholder)
- commit b812289
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0521-drm-panel-sitronix-st7789v-avoid-hardcoding-panel-si.patch (drm-backport-placeholder)
- commit 2408e6d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0520-drm-panel-sitronix-st7789v-avoid-hardcoding-mode-inf.patch (drm-backport-placeholder)
- commit 101cbc2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0519-drm-panel-sitronix-st7789v-improve-error-handling.patch (drm-backport-placeholder)
- commit 1180a45
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0518-drm-panel-sitronix-st7789v-simplify-st7789v_spi_writ.patch (drm-backport-placeholder)
- commit d705ff7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0517-drm-panel-sitronix-st7789v-make-reset-GPIO-optional.patch (drm-backport-placeholder)
- commit 33bc203
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0516-drm-panel-sitronix-st7789v-remove-unused-constants.patch (drm-backport-placeholder)
- commit 22ccb28
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0515-drm-panel-sitronix-st7789v-add-SPI-ID-table.patch (drm-backport-placeholder)
- commit b8937af
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0514-drm-tests-Alloc-drm_device-on-drm_exec-tests.patch (drm-backport-placeholder)
- commit 83b0073
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0513-drm-virtio-Support-sync-objects.patch (drm-backport-placeholder)
- commit 20a492a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0512-fbdev-Align-deferred-I-O-with-naming-of-helpers.patch (drm-backport-placeholder)
- commit 0620394
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0511-fbdev-Use-_DMAMEM_-infix-for-DMA-memory-helpers.patch (drm-backport-placeholder)
- commit 4ddc96a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0510-fbdev-Use-_SYSMEM_-infix-for-system-memory-helpers.patch (drm-backport-placeholder)
- commit 557ebf0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0509-fbdev-Use-_IOMEM_-infix-for-I-O-memory-helpers.patch (drm-backport-placeholder)
- commit b484c71
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-simple-Add-missing-connector-type-and-pixe.patch (drm-backport-placeholder)
- commit 382d311
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0507-drm-panel-Support-for-startek-kd070fhfid015-MIPI-DSI.patch (drm-backport-placeholder)
- commit 92f5098
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0506-drm-panel-ilitek-ili9881c-Add-TDO-TL050HDV35-LCD-pan.patch (drm-backport-placeholder)
- commit 9f6c9ac
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0505-drm-panel-simple-specify-bpc-for-powertip_ph800480t0.patch (drm-backport-placeholder)
- commit 94c92cb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0504-drm-panel-r66451-select-CONFIG_DRM_DISPLAY_DP_HELPER.patch (drm-backport-placeholder)
- commit 7fbbac9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0503-drm-vc4-tests-pv-muxing-Document-test-scenario.patch (drm-backport-placeholder)
- commit 766785e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0502-drm-vc4-tests-Switch-to-atomic-state-allocation-help.patch (drm-backport-placeholder)
- commit fe316d5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0501-drm-vc4-tests-pv-muxing-Switch-to-managed-locking-in.patch (drm-backport-placeholder)
- commit 864746d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0500-drm-vc4-tests-mock-Use-a-kunit-action-to-unregister-.patch (drm-backport-placeholder)
- commit a0282b9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0499-drm-vc4-tests-pv-muxing-Remove-call-to-drm_kunit_hel.patch (drm-backport-placeholder)
- commit 6d078f2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0498-drm-tests-helpers-Create-a-helper-to-allocate-an-ato.patch (drm-backport-placeholder)
- commit dd71b68
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0497-drm-tests-helpers-Create-a-helper-to-allocate-a-lock.patch (drm-backport-placeholder)
- commit 4ed48d1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0496-drm-tests-probe-helper-Remove-call-to-drm_kunit_help.patch (drm-backport-placeholder)
- commit 8d5fd53
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0495-drm-tests-modes-Remove-call-to-drm_kunit_helper_free.patch (drm-backport-placeholder)
- commit 00eff51
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0494-drm-tests-client-modeset-Remove-call-to-drm_kunit_he.patch (drm-backport-placeholder)
- commit 915c2ed
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0493-drm-tests-helpers-Switch-to-kunit-actions.patch (drm-backport-placeholder)
- commit 6ba40f7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-fix-Wunused-const-variable-warning.patch (drm-backport-placeholder)
- commit 32eb1dc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0491-drm-ssd130x-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit bbbd32d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0490-drm-Fix-references-to-drm_plane_helper_check_state.patch (drm-backport-placeholder)
- commit 38d62ed
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-Remove-references-to-removed-transitional-helper.patch (drm-backport-placeholder)
- commit c9f35ca
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0488-drm-todo-Convert-list-of-fbconv-links-to-footnotes.patch (drm-backport-placeholder)
- commit ff9960a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0487-drm-todo-Add-atomic-modesetting-references.patch (drm-backport-placeholder)
- commit e038f43
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-repaper-Reduce-temporary-buffer-size-in-repaper_.patch (drm-backport-placeholder)
- commit 227b0a7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-armada-Fix-off-by-one-error-in-armada_overlay_ge.patch (drm-backport-placeholder)
- commit 00453d9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0484-drm-Spelling-s-randevouz-rendez-vous.patch (drm-backport-placeholder)
- commit 844eda3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0483-drm-Spelling-s-sempahore-semaphore.patch (drm-backport-placeholder)
- commit 3880a6d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0482-drm-udl-Convert-to-drm_crtc_helper_atomic_check.patch (drm-backport-placeholder)
- commit 3dfd211
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0481-drm-bridge_connector-Handle-drm_connector_init_with_.patch (drm-backport-placeholder)
- commit e05ace7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0480-gpu-ipu-v3-prg-Convert-to-devm_platform_ioremap_reso.patch (drm-backport-placeholder)
- commit 722caeb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0479-gpu-ipu-v3-pre-Convert-to-devm_platform_ioremap_reso.patch (drm-backport-placeholder)
- commit 2f3f91f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0478-drm-imx-ipuv3-ipuv3-plane-reuse-local-variable-heigh.patch (drm-backport-placeholder)
- commit fef788b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-ast-report-connection-status-on-Display-Port.patch (drm-backport-placeholder)
- commit 1151d67
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-ast-Add-BMC-virtual-connector.patch (drm-backport-placeholder)
- commit 63bbebc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0475-drm-imx-dcss-Use-dev_err_probe.patch (drm-backport-placeholder)
- commit 400886f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0474-drm-panel-simple-Simplify-matching-using-of_device_g.patch (drm-backport-placeholder)
- commit c0c633e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0473-video-logo-LOGO-should-depend-on-FB_CORE-i.s.o.-FB.patch (drm-backport-placeholder)
- commit bc69180
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0472-Revert-fbcon-Use-kzalloc-in-fbcon_prepare_logo.patch (drm-backport-placeholder)
- commit 3d0d988
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-gem-fb-helper-Consistenly-use-drm_dbg_kms.patch (drm-backport-placeholder)
- commit a4ee009
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-atomic-helper-Update-reference-to-drm_crtc_force.patch (drm-backport-placeholder)
- commit 4d560ef
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0469-drm-vkms-Fix-race-condition-between-the-hrtimer-and-.patch (drm-backport-placeholder)
- commit 05485be
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0468-drm-vkms-Add-support-to-1D-gamma-LUT.patch (drm-backport-placeholder)
- commit f4d9a1b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0467-drm-tegra-sor-Convert-to-devm_platform_ioremap_resou.patch (drm-backport-placeholder)
- commit 58c3f8a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0466-drm-tegra-hdmi-Convert-to-devm_platform_ioremap_reso.patch (drm-backport-placeholder)
- commit 29678e0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-tegra-dpaux-Fix-incorrect-return-value-of-platfo.patch (drm-backport-placeholder)
- commit 038b0cf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0464-drm-tegra-output-hdmi-Support-bridge-connector.patch (drm-backport-placeholder)
- commit c1aa0d2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0463-drm-tegra-Enable-runtime-PM-during-probe.patch (drm-backport-placeholder)
- commit f1ab8b1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0462-drm-tegra-dpaux-Use-devm_platform_ioremap_resource.patch (drm-backport-placeholder)
- commit 84aa5ab
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0461-gpu-host1x-Return-error-when-context-device-not-atta.patch (drm-backport-placeholder)
- commit ffff45a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0460-drm-tegra-Add-error-check-for-NVDEC-firmware-memory-.patch (drm-backport-placeholder)
- commit 2ffffb6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0459-drm-i915-Avoid-Wconstant-logical-operand-in-nsecs_to.patch (drm-backport-placeholder)
- commit 89c3abe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0458-drm-v3d-Avoid-Wconstant-logical-operand-in-nsecs_to_.patch (drm-backport-placeholder)
- commit a9fa424
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0457-drm-ssd130x-Use-shadow-buffer-helpers-when-managing-.patch (drm-backport-placeholder)
- commit 14ac6cb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0456-drm-xlnx-zynqmp_dpsub-Use-devm_platform_ioremap_reso.patch (drm-backport-placeholder)
- commit 39edc31
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0455-drm-xlnx-zynqmp_dpsub-Use-dev_err_probe-instead-of-d.patch (drm-backport-placeholder)
- commit 1c226e6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-xlnx-zynqmp_dpsub-Add-missing-check-for-dma_set_.patch (drm-backport-placeholder)
- commit df91f0c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0453-drm-xlnx-zynqmp_dp-Fix-function-name-zynqmp_dp_link_.patch (drm-backport-placeholder)
- commit 22c6628
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0452-drm-amdgpu-correct-vmhub-index-in-GMC-v10-11.patch (drm-backport-placeholder)
- commit e8609da
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0451-drm-amdgpu-Fix-non-standard-format-specifiers-in-amd.patch (drm-backport-placeholder)
- commit 2465eb4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0450-drm-amdgpu-set-completion-status-as-preempted-for-th.patch (drm-backport-placeholder)
- commit 5e1a2e2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0449-drm-radeon-Fix-ENOSYS-with-better-fitting-error-code.patch (drm-backport-placeholder)
- commit cc2f1d6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0448-drm-radeon-Remove-unnecessary-NULL-test-before-kfree.patch (drm-backport-placeholder)
- commit c2997ec
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0447-drm-amdgpu-Use-parentheses-for-sizeof-numa_info-in-a.patch (drm-backport-placeholder)
- commit d115e5b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0446-drm-amdgpu-Fix-unnecessary-else-after-return-in-amdg.patch (drm-backport-placeholder)
- commit 8b5c9b6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0445-drm-amdgpu-discovery-enable-PSP-14.0.0-support.patch (drm-backport-placeholder)
- commit 06bfa13
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0444-drm-amdgpu-add-PSP-14.0.0-support.patch (drm-backport-placeholder)
- commit 425adaf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0443-drm-radeon-Fix-format-error.patch (drm-backport-placeholder)
- commit b58752f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0442-drm-amdkfd-fix-and-enable-ttmp-setup-for-gfx11.patch (drm-backport-placeholder)
- commit 1553f25
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0441-drm-amdgpu-Move-externs-to-amdgpu.h-file-from-amdgpu.patch (drm-backport-placeholder)
- commit aec1b99
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0440-drm-amdgpu-Prefer-dev_-variant-over-printk-in-amdgpu.patch (drm-backport-placeholder)
- commit fac7f6b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0439-drm-amdgpu-Fix-no-new-typedefs-for-enum-_AMDGPU_DOOR.patch (drm-backport-placeholder)
- commit 8dc1aa3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0438-drm-amdgpu-Fix-ENOSYS-means-invalid-syscall-nr-in-am.patch (drm-backport-placeholder)
- commit d994483
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0437-drm-amdgpu-remove-repeat-code-for-mes_add_queue_pkt.patch (drm-backport-placeholder)
- commit 3d0cd0a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0436-drm-amdgpu-Checkpoint-and-Restore-VRAM-BOs-without-V.patch (drm-backport-placeholder)
- commit a560420
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0435-drm-amdgpu-enable-trap-of-each-kfd-vmid-for-gfx-v9.4.patch (drm-backport-placeholder)
- commit 9e45e24
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0434-drm-amd-pm-open-brace-following-struct-go-on-the-sam.patch (drm-backport-placeholder)
- commit efa0d5e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0433-drm-amd-pm-open-brace-following-function-definitions.patch (drm-backport-placeholder)
- commit ab2e746
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0432-drm-amd-pm-that-open-brace-should-be-on-the-previous.patch (drm-backport-placeholder)
- commit 50d4b01
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0431-drm-amd-pm-Clean-up-errors-in-arcturus_ppt.c.patch (drm-backport-placeholder)
- commit 7bdcdc9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0430-drm-amd-pm-Clean-up-errors-in-arcturus_ppt.c.patch (drm-backport-placeholder)
- commit 75232c1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0429-drm-amd-pm-Clean-up-errors-in-navi10_ppt.c.patch (drm-backport-placeholder)
- commit 7efcd68
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0428-drm-amd-pm-add-missing-spaces-before.patch (drm-backport-placeholder)
- commit 64281c7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0427-drm-radeon-Move-assignment-outside-if-condition.patch (drm-backport-placeholder)
- commit c2abc5b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0426-drm-radeon-that-open-brace-should-be-on-the-previous.patch (drm-backport-placeholder)
- commit 57093a7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0425-drm-radeon-that-open-brace-should-be-on-the-previous.patch (drm-backport-placeholder)
- commit 984b348
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0424-drm-radeon-add-missing-spaces-after-and-else-should-.patch (drm-backport-placeholder)
- commit 2378d67
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0423-drm-radeon-add-missing-spaces-before.patch (drm-backport-placeholder)
- commit 8167539
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0422-drm-radeon-si_dpm-open-brace-following-struct-go-on-.patch (drm-backport-placeholder)
- commit 847a852
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0421-drm-amd-pm-Vangogh-Add-new-gpu_metrics_v2_4-to-acqui.patch (drm-backport-placeholder)
- commit 9a76949
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0420-drm-amdgpu-load-sdma-ucode-in-the-guest-machine.patch (drm-backport-placeholder)
- commit 02cbe55
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0419-drm-amdgpu-Use-seq_puts-instead-of-seq_printf.patch (drm-backport-placeholder)
- commit b8773ee
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Update-min-to-min_t-in-amdgpu_info_ioctl.patch (drm-backport-placeholder)
- commit 9cfd958
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0417-drm-amdgpu-Remove-else-after-return-in-is_fru_eeprom.patch (drm-backport-placeholder)
- commit 43ce21e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0416-drm-amd-display-Remove-else-after-return-in-dm_vblan.patch (drm-backport-placeholder)
- commit d4bba6a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0415-drm-amdgpu-Add-ENOMEM-error-handling-when-there-is-n.patch (drm-backport-placeholder)
- commit 5b5a0c3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0414-drm-amdgpu-Check-APU-flag-to-disable-RAS.patch (drm-backport-placeholder)
- commit 1b782ac
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0413-drm-amdgpu-fix-the-indexing-issue-during-rlcg-access.patch (drm-backport-placeholder)
- commit d96b3a0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0412-drm-amdgpu-add-VISIBLE-info-in-amdgpu_bo_print_info.patch (drm-backport-placeholder)
- commit 7ac52b2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0411-drm-amdkfd-avoid-svm-dump-when-dynamic-debug-disable.patch (drm-backport-placeholder)
- commit c83bf2a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0410-drm-radeon-ERROR-foo-bar-should-be-foo-bar.patch (drm-backport-placeholder)
- commit cf517c9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0409-drm-amdgpu-open-brace-following-struct-go-on-the-sam.patch (drm-backport-placeholder)
- commit e1c75bf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0408-drm-amd-pm-open-brace-following-struct-go-on-the-sam.patch (drm-backport-placeholder)
- commit 2c50706
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0407-drm-amd-open-brace-following-struct-go-on-the-same-l.patch (drm-backport-placeholder)
- commit 76cdf29
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0406-drm-amd-display-3.2.244.patch (drm-backport-placeholder)
- commit 3db419b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0405-drm-amd-display-Fix-underflow-issue-on-175hz-timing.patch (drm-backport-placeholder)
- commit abfedb0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0404-drm-amd-display-Add-interface-to-modify-DMUB-panel-p.patch (drm-backport-placeholder)
- commit 1d32e6e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0403-drm-amd-display-Rearrange-dmub_cmd-defs-order.patch (drm-backport-placeholder)
- commit b28e047
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0402-drm-amd-display-Remove-check-for-default-eDP-panel_m.patch (drm-backport-placeholder)
- commit 79c905e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0401-drm-amdgpu-Fix-style-issues-in-amdgpu_gem.c.patch (drm-backport-placeholder)
- commit 6e2631c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0400-drm-amd-display-Add-new-sequence-for-4-lane-HBR3-on-.patch (drm-backport-placeholder)
- commit 7e5f45e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0399-drm-amd-display-Update-DPG-test-pattern-programming.patch (drm-backport-placeholder)
- commit 73a2c72
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0398-drm-amd-display-Correct-unit-conversion-for-vstartup.patch (drm-backport-placeholder)
- commit ca839d2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0397-drm-amd-display-Refactor-recout-calculation-with-a-m.patch (drm-backport-placeholder)
- commit d09461b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0396-drm-amd-display-Read-down-spread-percentage-from-lut.patch (drm-backport-placeholder)
- commit e503f63
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0395-drm-amd-display-Prevent-invalid-pipe-connections.patch (drm-backport-placeholder)
- commit 0130229
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0394-drm-amdgpu-Update-ring-scheduler-info-as-needed.patch (drm-backport-placeholder)
- commit 309a621
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0393-drm-amdgpu-Enabling-FW-workaround-through-shared-mem.patch (drm-backport-placeholder)
- commit 98bee64
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0392-drm-amd-display-Add-VESA-SCR-case-for-default-aux-ba.patch (drm-backport-placeholder)
- commit e4940a3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0391-drm-radeon-Prefer-dev_-variant-over-printk.patch (drm-backport-placeholder)
- commit 2b0a935
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0390-drm-radeon-Fix-style-issues-in-radeon-_encoders.c-_g.patch (drm-backport-placeholder)
- commit c22aa14
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0389-drm-amd-amdgpu-Fix-warnings-in-amdgpu-amdgpu_display.patch (drm-backport-placeholder)
- commit 088d659
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0388-drm-radeon-Avoid-externs-do-not-initialize-globals-t.patch (drm-backport-placeholder)
- commit 7fb7ff6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0387-drm-amd-display-Correct-grammar-mistakes.patch (drm-backport-placeholder)
- commit 1d3bccd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0386-drm-amdgpu-Return-ENOMEM-when-there-is-no-memory-in-.patch (drm-backport-placeholder)
- commit 1eb3cd3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0385-drm-amdgpu-Fix-do-not-add-new-typedefs-in-amdgpu_fw_.patch (drm-backport-placeholder)
- commit fef19b4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0384-drm-amdgpu-Prefer-if-IS_ENABLED-over-if-defined-in-a.patch (drm-backport-placeholder)
- commit 1be0219
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0383-drm-amdkfd-enable-cooperative-groups-for-gfx11.patch (drm-backport-placeholder)
- commit 5d25dcc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0382-drm-amdgpu-set-sw-state-to-gfxoff-after-SR-IOV-reset.patch (drm-backport-placeholder)
- commit 29f9ffb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0381-drm-amdgpu-Fix-one-kernel-doc-comment.patch (drm-backport-placeholder)
- commit 4b0d079
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0380-drm-amdgpu-Program-xcp_ctl-registers-as-needed.patch (drm-backport-placeholder)
- commit 55eeae8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0379-drm-amd-display-Allow-building-DC-with-clang-on-RISC.patch (drm-backport-placeholder)
- commit 8b3577c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0378-drm-amd-display-remove-an-unused-file.patch (drm-backport-placeholder)
- commit 4740697
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0377-drm-radeon-Prefer-pr_err-_info-over-printk.patch (drm-backport-placeholder)
- commit 677e858
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0376-drm-amdgpu-allow-secure-submission-on-VCN4-ring.patch (drm-backport-placeholder)
- commit 8a6e5ba
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0375-drm-amd-Avoid-reading-the-VBIOS-part-number-twice.patch (drm-backport-placeholder)
- commit 2c9204e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0374-drm-amdgpu-Add-RLCG-interface-driver-implementation-.patch (drm-backport-placeholder)
- commit 11d018a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0373-drm-amd-display-Promote-DAL-to-3.2.243.patch (drm-backport-placeholder)
- commit a4ddadd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0372-drm-amd-display-Add-missing-triggers-for-full-update.patch (drm-backport-placeholder)
- commit f6eadb8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0371-drm-amd-display-ABM-pause-toggle.patch (drm-backport-placeholder)
- commit da18e2c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0370-drm-amd-display-Fix-ASIC-check-in-aux-timeout-workar.patch (drm-backport-placeholder)
- commit cd5cb0d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0369-drm-amd-display-Add-link-encoding-to-timing-BW-calcu.patch (drm-backport-placeholder)
- commit 9df3eac
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0368-drm-amd-display-Add-stream-overhead-in-BW-calculatio.patch (drm-backport-placeholder)
- commit a64e227
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0367-drm-amd-display-Initialize-necessary-uninitialized-v.patch (drm-backport-placeholder)
- commit 7bd1f68
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0366-drm-amd-display-Add-helpers-to-get-DMUB-FW-boot-opti.patch (drm-backport-placeholder)
- commit 4efd421
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0365-drm-amd-display-Promote-DAL-to-3.2.242.patch (drm-backport-placeholder)
- commit 25d4d8c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0364-drm-amd-display-Update-128b-132b-downspread-factor-t.patch (drm-backport-placeholder)
- commit 5122f47
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0363-drm-amd-display-Fix-race-condition-when-turning-off-.patch (drm-backport-placeholder)
- commit b1d0aa6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0362-drm-amd-display-add-additional-refresh-rate-conditio.patch (drm-backport-placeholder)
- commit 0d3d6c2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0361-drm-amd-display-refine-to-decide-the-verified-link-s.patch (drm-backport-placeholder)
- commit 3c6be77
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0360-drm-amd-display-Fix-DP2-link-training-failure-with-R.patch (drm-backport-placeholder)
- commit 209ec71
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0359-drm-amd-display-Cache-backlight_millinits-in-link-st.patch (drm-backport-placeholder)
- commit bc5e135
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0358-drm-amd-display-Reenable-all-root-clock-gating-optio.patch (drm-backport-placeholder)
- commit 54343df
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0357-drm-amd-display-Update-SW-cursor-fallback-for-subvp-.patch (drm-backport-placeholder)
- commit d27db72
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0356-drm-amd-display-Skip-querying-caps-when-DMCUB-emulat.patch (drm-backport-placeholder)
- commit e2d0300
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0355-drm-amd-display-Update-scaler-recout-data-for-visual.patch (drm-backport-placeholder)
- commit 93a0a5f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0354-drm-amd-display-Skip-enabling-DMCUB-when-using-emula.patch (drm-backport-placeholder)
- commit b7e4b01
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0353-drm-amd-display-Reduce-stack-size.patch (drm-backport-placeholder)
- commit eadd0d9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0352-drm-amd-display-Hardcode-vco_freq-for-dcn316.patch (drm-backport-placeholder)
- commit e44b846
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0351-drm-amd-display-Add-missing-static.patch (drm-backport-placeholder)
- commit aed3557
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0350-drm-amd-display-Remove-unused-function.patch (drm-backport-placeholder)
- commit 992c5ef
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0349-drm-amd-display-Improve-the-include-of-header-file.patch (drm-backport-placeholder)
- commit 65b1cf3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0348-drm-amd-display-Re-add-aux-intercept-disable-delay-g.patch (drm-backport-placeholder)
- commit 390f455
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0347-drm-amd-display-Use-is_dig_enable-function-instead-o.patch (drm-backport-placeholder)
- commit 8425a41
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0346-drm-amd-display-Setup-stream-encoder-before-link-ena.patch (drm-backport-placeholder)
- commit fd227f4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0345-drm-amdgpu-create-a-new-file-for-doorbell-manager.patch (drm-backport-placeholder)
- commit 65d3e05
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0344-drm-amdgpu-Add-dcdebugmask-option-to-enable-DPIA-tra.patch (drm-backport-placeholder)
- commit e2dce57
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0343-drm-amdgpu-Disable-RAS-by-default-on-APU-flatform.patch (drm-backport-placeholder)
- commit 776e010
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0342-drm-amdgpu-Enable-aqua-vanjaram-RAS.patch (drm-backport-placeholder)
- commit 88eb8e7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0341-drm-amdgpu-Avoid-possiblity-of-kernel-crash-in-gmc_v.patch (drm-backport-placeholder)
- commit bc6d4f4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0340-drm-amd-display-Eliminate-warnings-in-amdgpu_dm_help.patch (drm-backport-placeholder)
- commit 291105a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0339-drm-amd-display-Clean-up-style-problems-in-amdgpu_dm.patch (drm-backport-placeholder)
- commit 488bb0a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0338-drm-amd-display-Implement-zpos-property.patch (drm-backport-placeholder)
- commit cf9b2f9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0337-drm-amd-display-Enable-3-plane-for-DCN-3.01.patch (drm-backport-placeholder)
- commit e391675
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0336-drm-amd-display-Expose-more-formats-for-overlay-plan.patch (drm-backport-placeholder)
- commit 54c98c3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0335-Revert-drm-amdgpu-update-kernel-vcn-ring-test.patch (drm-backport-placeholder)
- commit 7c533f9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0334-Revert-drm-amdgpu-update-kernel-vcn-ring-test.patch (drm-backport-placeholder)
- commit 11ba5d9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0333-drm-amdgpu-Fix-error-warnings-in-gmc_v8_0.c.patch (drm-backport-placeholder)
- commit 16cdbc2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-dc.h-eliminate-kernel-doc-warnings.patch (drm-backport-placeholder)
- commit c0f864d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0331-drm-amdgpu-Rename-to-amdgpu_vm_tlb_seq_struct.patch (drm-backport-placeholder)
- commit 07a1fd2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0330-drm-amdkfd-Fix-stack-size-in-amdgpu_amdkfd_unmap_hiq.patch (drm-backport-placeholder)
- commit 103c15d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0329-drm-amdkfd-report-dispatch-id-always-saved-in-ttmps-.patch (drm-backport-placeholder)
- commit 62f989a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0328-drm-amdgpu-update-kernel-vcn-ring-test.patch (drm-backport-placeholder)
- commit 80b12ed
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0327-drm-amdgpu-update-kernel-vcn-ring-test.patch (drm-backport-placeholder)
- commit fa9157a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0326-drm-amdgpu-add-watchdog-timer-enablement-for-gfx_v9_.patch (drm-backport-placeholder)
- commit fbc3e60
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0325-drm-amdkfd-Update-CWSR-grace-period-for-GFX9.4.3.patch (drm-backport-placeholder)
- commit 54128db
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0324-drm-radeon-ERROR-foo-should-be-foo.patch (drm-backport-placeholder)
- commit 7f2061b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0323-drm-radeon-ERROR-that-open-brace-should-be-on-the-pr.patch (drm-backport-placeholder)
- commit 0f06e85
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0322-drm-radeon-ERROR-foo-should-be-foo.patch (drm-backport-placeholder)
- commit d2facc6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0321-drm-radeon-ERROR-foo-should-be-foo.patch (drm-backport-placeholder)
- commit 7fc36d8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0320-drm-radeon-ERROR-foo-bar-should-be-foo-bar.patch (drm-backport-placeholder)
- commit 07f09fe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0319-drm-amdgpu-use-psp_execute_load_ip_fw-instead.patch (drm-backport-placeholder)
- commit b2cda63
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0318-drm-amdgpu-rename-psp_execute_non_psp_fw_load-and-ma.patch (drm-backport-placeholder)
- commit 34049bd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0317-drm-amdkfd-add-multi-process-debugging-support-for-G.patch (drm-backport-placeholder)
- commit 8f7e0f6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0316-drm-amdkfd-enable-watch-points-globally-for-gfx943.patch (drm-backport-placeholder)
- commit bdee0e6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0315-drm-amdkfd-restore-debugger-additional-info-for-gfx-.patch (drm-backport-placeholder)
- commit f1468c1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0314-drm-amdkfd-add-kfd2kgd-debugger-callbacks-for-GC-v9..patch (drm-backport-placeholder)
- commit 3a20936
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-avoid-integer-overflow-warning-in-amdgpu_.patch (drm-backport-placeholder)
- commit dd2cab9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0312-drm-amdgpu-Increase-soft-IH-ring-size.patch (drm-backport-placeholder)
- commit 0be8f2a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0311-drm-amdgpu-gfx10-move-update_spm_vmid-out-of-rlc_ini.patch (drm-backport-placeholder)
- commit 2662fa2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0310-drm-amdgpu-gfx9-move-update_spm_vmid-out-of-rlc_init.patch (drm-backport-placeholder)
- commit 6d6b952
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0309-drm-amdgpu-Fix-errors-warnings-in-gfx_v10_0.c.patch (drm-backport-placeholder)
- commit dbbd0ee
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0308-drm-amdgpu-Fix-warnings-in-gfxhub_-v3_0-v3_0_3.c.patch (drm-backport-placeholder)
- commit f2f0971
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0307-drm-amdgpu-Fix-warnings-in-gmc_v8_0.c.patch (drm-backport-placeholder)
- commit 83f588f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0306-drm-amd-pm-disbale-dcefclk-device-sysnode-on-GFX-v9..patch (drm-backport-placeholder)
- commit 405fe92
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0305-drm-amdgpu-vkms-drop-redundant-set-of-fb_modifiers_n.patch (drm-backport-placeholder)
- commit 651ad3a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0304-drm-amdgpu-Remove-else-after-return-statement-in-gfx.patch (drm-backport-placeholder)
- commit b19bd20
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0303-drm-amdgpu-Fix-warnings-in-gmc_v11_0.c.patch (drm-backport-placeholder)
- commit d562361
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0302-drm-amdgpu-Remove-else-after-return-statement-in-gmc.patch (drm-backport-placeholder)
- commit 604b940
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0301-drm-amdgpu-Fix-warnings-in-gfxhub_v2_1.c.patch (drm-backport-placeholder)
- commit 1e4f470
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0300-drm-amdgpu-Fix-errors-warnings-in-gmc_-v6_0-v7_0.c.patch (drm-backport-placeholder)
- commit e497b0b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0299-drm-amdgpu-Fix-warnings-in-gmc_v10_0.c.patch (drm-backport-placeholder)
- commit c0c5ec9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0298-drm-amdgpu-Prefer-dev_warn-over-printk.patch (drm-backport-placeholder)
- commit 3ebedaa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0297-drm-amdgpu-Fix-warnings-in-gfxhub_v2_0.c.patch (drm-backport-placeholder)
- commit 8654196
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0296-drm-amdgpu-Remove-redundant-GFX-v9.4.3-sequence.patch (drm-backport-placeholder)
- commit 7c53802
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0295-drm-amdgpu-Fix-warnings-in-gfxhub_-v1_0-v1_2.c.patch (drm-backport-placeholder)
- commit 89a6e20
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0294-drm-amd-display-Block-optimize-on-consecutive-FAMS-e.patch (drm-backport-placeholder)
- commit d4c1338
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Do-not-set-drr-on-pipe-commit.patch (drm-backport-placeholder)
- commit b48dbcd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0292-drm-amdgpu-Fix-error-warnings-in-gmc_v9_0.c.patch (drm-backport-placeholder)
- commit f4af06b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0291-drm-amdgpu-Change-golden-settings-for-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit 5bb44f4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0290-drm-amdkfd-Skip-handle-mapping-SVM-range-with-no-GPU.patch (drm-backport-placeholder)
- commit 2bf9f0b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0289-drm-amd-amdgpu-Add-cu_occupancy-sysfs-file-to-GFX9.4.patch (drm-backport-placeholder)
- commit 8a866e6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0288-drm-amdgpu-have-bos-for-PDs-PTS-cpu-accessible-when-.patch (drm-backport-placeholder)
- commit 7b65c08
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0287-drm-amdkfd-Use-KIQ-to-unmap-HIQ.patch (drm-backport-placeholder)
- commit bf99e96
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0286-drm-amd-display-Clean-up-warnings-in-amdgpu_dm-_mst_.patch (drm-backport-placeholder)
- commit 3b8dba7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0285-drm-amd-display-Remove-unnecessary-casts-in-amdgpu_d.patch (drm-backport-placeholder)
- commit e70756c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0284-drm-amd-display-Clean-up-warnings-in-amdgpu_dm_pp_sm.patch (drm-backport-placeholder)
- commit e46fe51
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0283-drm-amdgpu-skip-address-adjustment-for-GFX-RAS-injec.patch (drm-backport-placeholder)
- commit 39e8c7d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0282-drm-amdgpu-Update-invalid-PTE-flag-setting.patch (drm-backport-placeholder)
- commit 5571416
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0281-drm-amdgpu-return-an-error-if-query_video_caps-is-no.patch (drm-backport-placeholder)
- commit c0d9660
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0280-drm-amdkfd-Access-gpuvm_export_dmabuf-API-to-get-Dma.patch (drm-backport-placeholder)
- commit de3fe4f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0279-drm-amd-adjust-whitespace-for-amdgpu_psp.h.patch (drm-backport-placeholder)
- commit 24792cf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0278-drm-amd-Detect-IFWI-or-PD-upgrade-support-in-psp_ear.patch (drm-backport-placeholder)
- commit ec1b31e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0277-drm-amd-Add-documentation-for-how-to-flash-a-dGPU.patch (drm-backport-placeholder)
- commit 042d3c1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0276-drm-amd-Convert-USB-C-PD-F-W-attributes-into-groups.patch (drm-backport-placeholder)
- commit 78209fc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0275-drm-amd-Make-flashing-messages-quieter.patch (drm-backport-placeholder)
- commit 58f7c9c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0274-drm-amd-Use-attribute-groups-for-PSP-flashing-attrib.patch (drm-backport-placeholder)
- commit 25cdd95
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0273-drm-amd-display-fix-comment-typo.patch (drm-backport-placeholder)
- commit 6767240
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0272-drm-amd-display-Use-seq_puts-in-amdgpu_current_color.patch (drm-backport-placeholder)
- commit dbf3d96
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0271-drm-amd-display-Remove-redundant-braces-in-amdgpu_dm.patch (drm-backport-placeholder)
- commit c068a21
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0270-drm-amd-display-Clean-up-style-problems-in-amdgpu_dm.patch (drm-backport-placeholder)
- commit bf783d4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0269-drm-amd-display-Remove-else-after-return-in-dm_crtc_.patch (drm-backport-placeholder)
- commit 34dade0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0268-drm-amd-display-Remove-else-after-return-statement-i.patch (drm-backport-placeholder)
- commit 488d2c8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0267-drm-amdgpu-Rename-aqua_vanjaram_reg_init.c.patch (drm-backport-placeholder)
- commit ab7d830
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0266-dma-buf-Fix-the-typo-in-DMA-BUF-statistics-doc.patch (drm-backport-placeholder)
- commit cf271eb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0265-drm-ssd130x-Allocate-buffer-in-the-plane-s-.atomic_c.patch (drm-backport-placeholder)
- commit f40d8af
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0264-drm-ssd130x-Inline-the-ssd130x_buf_-alloc-free-funct.patch (drm-backport-placeholder)
- commit 56440b2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0263-drm-ast-Do-not-enable-PCI-resources-multiple-times.patch (drm-backport-placeholder)
- commit 800d0e2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0262-drm-panel-ld9040-add-backlight-Kconfig-dependency.patch (drm-backport-placeholder)
- commit e9975e6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0261-fbdev-Harmonize-some-comments-in-linux-fb.h.patch (drm-backport-placeholder)
- commit d3b0b07
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0260-fbdev-Remove-FB_DEFAULT_SYS_OPS.patch (drm-backport-placeholder)
- commit e32734f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0259-drm-omapdrm-Set-fbdev-FBINFO_VIRTFB-flag.patch (drm-backport-placeholder)
- commit 374c629
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0258-drm-omapdrm-Use-GEM-mmap-for-fbdev-emulation.patch (drm-backport-placeholder)
- commit 9a7648b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0257-drm-omapdrm-Set-VM-flags-in-GEM-object-mmap-function.patch (drm-backport-placeholder)
- commit b01aabc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0256-drm-exynos-Set-fbdev-FBINFO_VIRTFB-flag.patch (drm-backport-placeholder)
- commit 944a159
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0255-drm-exynos-Use-fbdev-DMA-helpers.patch (drm-backport-placeholder)
- commit 485611d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0254-drm-tegra-Store-pointer-to-vmap-ed-framebuffer-in-sc.patch (drm-backport-placeholder)
- commit c852046
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0253-drm-tegra-Set-fbdev-FBINFO_VIRTFB-flag.patch (drm-backport-placeholder)
- commit 25ace41
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0252-drm-tegra-Use-fbdev-DMA-helpers.patch (drm-backport-placeholder)
- commit f9397de
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0251-drm-fbdev-dma-Use-fbdev-DMA-helpers.patch (drm-backport-placeholder)
- commit b228559
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0250-fbdev-Add-fb_ops-init-macros-for-framebuffers-in-DMA.patch (drm-backport-placeholder)
- commit c130a94
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0249-drm-panel-db7430-remove-unused-variables.patch (drm-backport-placeholder)
- commit 9b5f4bf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0248-fbdev-Document-that-framebuffer_alloc-returns-zero-e.patch (drm-backport-placeholder)
- commit 88cadb6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0247-fbdev-Remove-FBINFO_DEFAULT-and-FBINFO_FLAG_DEFAULT.patch (drm-backport-placeholder)
- commit f4d77fb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0245-fbdev-pxafb-Remove-flag-FBINFO_FLAG_DEFAULT.patch (drm-backport-placeholder)
- commit bac786e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0244-fbdev-atafb-Remove-flag-FBINFO_FLAG_DEFAULT.patch (drm-backport-placeholder)
- commit fd1d8af
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0243-fbdev-Remove-FBINFO_FLAG_DEFAULT-from-framebuffer_al.patch (drm-backport-placeholder)
- commit 4101cf4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0242-fbdev-Remove-FBINFO_FLAG_DEFAULT-from-kzalloc-ed-str.patch (drm-backport-placeholder)
- commit c325574
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0241-fbdev-fsl-diu-fb-Remove-flag-FBINFO_DEFAULT.patch (drm-backport-placeholder)
- commit f83f335
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0236-fbdev-Remove-FBINFO_DEFAULT-from-framebuffer_alloc-e.patch (drm-backport-placeholder)
- commit 1f0b2ce
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0235-fbdev-Remove-FBINFO_DEFAULT-from-devm_kzalloc-ed-str.patch (drm-backport-placeholder)
- commit 7d60251
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0234-fbdev-Remove-FBINFO_DEFAULT-from-kzalloc-ed-structs.patch (drm-backport-placeholder)
- commit 6786678
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0233-fbdev-Remove-FBINFO_DEFAULT-from-static-structs.patch (drm-backport-placeholder)
- commit 6dce7d2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0232-drm-Remove-flag-FBINFO_DEFAULT-from-fbdev-emulation.patch (drm-backport-placeholder)
- commit d71cc68
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0231-drm-managed-Clean-up-GFP_-flag-usage-in-drmm_kmalloc.patch (drm-backport-placeholder)
- commit 8ba6e47
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0230-drm-bridge-Remove-redundant-i2c_client-in-anx7625-it.patch (drm-backport-placeholder)
- commit 3b4e76d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0229-drm-bridge-it6505-Fix-Kconfig-indentation.patch (drm-backport-placeholder)
- commit 9da84c2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-anx7625-Drop-device-lock-before-drm_helpe.patch (drm-backport-placeholder)
- commit a9e1624
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0227-drm-Make-FB_CORE-to-be-selected-if-DRM-fbdev-emulati.patch (drm-backport-placeholder)
- commit dad3ebd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0226-fbdev-Split-frame-buffer-support-in-FB-and-FB_CORE-s.patch (drm-backport-placeholder)
- commit a46cb71
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0225-fbdev-Move-core-fbdev-symbols-to-a-separate-Kconfig-.patch (drm-backport-placeholder)
- commit 7aa5ad0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0224-video-Add-auxiliary-display-drivers-to-Graphics-supp.patch (drm-backport-placeholder)
- commit bb9969d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0223-drm-ssd130x-Fix-pitch-calculation-in-ssd130x_fb_blit.patch (drm-backport-placeholder)
- commit 9ac2239
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0222-drm-bridge-tc358767-give-VSDELAY-some-positive-value.patch (drm-backport-placeholder)
- commit 682c0bd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0221-drm-bridge-tc358767-increase-PLL-lock-time-delay.patch (drm-backport-placeholder)
- commit 3359a17
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0220-drm-arm-komeda-Remove-component-framework-and-add-a-.patch (drm-backport-placeholder)
- commit e25e2eb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-adv7511-Fix-low-refresh-rate-register-for-ADV753.patch (drm-backport-placeholder)
- commit b13d74e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0218-drm-Explicitly-include-correct-DT-includes.patch (drm-backport-placeholder)
- commit 07a314b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0217-gpu-host1x-Explicitly-include-correct-DT-includes.patch (drm-backport-placeholder)
- commit cd1bb4c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0216-drm-debugfs-Silence-warning-from-cast.patch (drm-backport-placeholder)
- commit ff70e62
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0215-drm-manager-Fix-printk-format-for-size_t.patch (drm-backport-placeholder)
- commit 88cf1ef
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0214-drm-panel-simple-Drop-prepared_time.patch (drm-backport-placeholder)
- commit bb165f1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0213-drm-syncobj-add-IOCTL-to-register-an-eventfd.patch (drm-backport-placeholder)
- commit 3608874
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0212-drm-debugfs-provide-infrastructure-to-dump-a-DRM-GPU.patch (drm-backport-placeholder)
- commit d85c731
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0211-drm-manager-to-keep-track-of-GPUs-VA-mappings.patch (drm-backport-placeholder)
- commit fb72881
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-anx7625-Use-common-macros-for-HDCP-capabi.patch (drm-backport-placeholder)
- commit 6f1a4e3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-anx7625-Use-common-macros-for-DP-power-se.patch (drm-backport-placeholder)
- commit d54526d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0208-drm-file-use-explicit-values-for-enum-drm_minor_type.patch (drm-backport-placeholder)
- commit 5c6482e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0207-drm-drv-use-enum-drm_minor_type-when-appropriate.patch (drm-backport-placeholder)
- commit 193f88c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0206-drm-panel-ld9040-Register-a-backlight-device.patch (drm-backport-placeholder)
- commit 2b3ee57
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0205-drm-panel-ld9040-Use-better-magic-values.patch (drm-backport-placeholder)
- commit e1d721b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0204-drm-ssd130x-Change-pixel-format-used-to-compute-the-.patch (drm-backport-placeholder)
- commit 611ab1c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0203-drm-loongson-Remove-a-useless-check-in-cursor_plane_.patch (drm-backport-placeholder)
- commit c3b39aa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0202-drm-amdgpu-use-the-new-drm_exec-object-for-CS-v3.patch (drm-backport-placeholder)
- commit 2399158
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0201-drm-amdgpu-use-drm_exec-for-MES-testing.patch (drm-backport-placeholder)
- commit af38bf7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0200-drm-amdgpu-use-drm_exec-for-GEM-and-CSA-handling-v2.patch (drm-backport-placeholder)
- commit b1c8a09
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0199-drm-amdkfd-switch-over-to-using-drm_exec-v3.patch (drm-backport-placeholder)
- commit 6a02ccf
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0198-drm-add-drm_exec-selftests-v4.patch (drm-backport-placeholder)
- commit 790b323
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0197-drm-execution-context-for-GEM-buffers-v7.patch (drm-backport-placeholder)
- commit 05f64cb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0196-fbdev-hyperv_fb-Include-linux-screen_info.h.patch (drm-backport-placeholder)
- commit 4694c96
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0195-drm-arm-Make-ARM-devices-menu-depend-on-DRM.patch (drm-backport-placeholder)
- commit 25e0c10
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0194-drm-ttm-Use-init_on_free-to-delay-release-TTM-BOs.patch (drm-backport-placeholder)
- commit ad686ea
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0193-drm-bridge-cdns-mhdp8546-Fix-the-interrupt-enable-di.patch (drm-backport-placeholder)
- commit 09a9ff9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0192-drm-tidss-Update-encoder-bridge-chain-connect-model.patch (drm-backport-placeholder)
- commit 26329cb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0191-drm-bridge-sii902x-Set-input_bus_flags-in-atomic_che.patch (drm-backport-placeholder)
- commit 53f5b39
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0190-drm-bridge-sii902x-Support-format-negotiation-hooks.patch (drm-backport-placeholder)
- commit 074b8ea
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0189-drm-bridge-mhdp8546-Set-input_bus_flags-from-atomic_.patch (drm-backport-placeholder)
- commit b86f6df
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0188-drm-bridge-mhdp8546-Add-minimal-format-negotiation.patch (drm-backport-placeholder)
- commit 490b1be
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0187-drm-bridge-tfp410-Set-input_bus_flags-in-atomic_chec.patch (drm-backport-placeholder)
- commit 4764118
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0186-drm-bridge-tfp410-Support-format-negotiation-hooks.patch (drm-backport-placeholder)
- commit f4140e7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0185-drm-bridge-tc358767-Use-devm_clk_get_enabled-helper.patch (drm-backport-placeholder)
- commit 14afcef
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0184-drm-nouveau-disp-use-drm_kms_helper_connector_hotplu.patch (drm-backport-placeholder)
- commit 2b5d7c1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0183-nouveau-dispnv50-add-cursor-pitch-check.patch (drm-backport-placeholder)
- commit aae0c5d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0182-drm-virtio-Conditionally-allocate-virtio_gpu_fence.patch (drm-backport-placeholder)
- commit 9fe7fc2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-hyperv-Fix-a-compilation-issue-because-of-not-in.patch (drm-backport-placeholder)
- commit c2b7f4d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0180-fbdev-xen-fbfront-Generate-deferred-I-O-ops.patch (drm-backport-placeholder)
- commit 2cdfac2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0179-fbdev-xen-fbfront-Select-FB_SYS_HELPERS_DEFERRED.patch (drm-backport-placeholder)
- commit 3f5403a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0178-fbdev-ssd1307fb-Generate-deferred-I-O-ops.patch (drm-backport-placeholder)
- commit 866ef1b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0177-fbdev-ssd1307fb-Select-FB_SYS_HELPERS_DEFERRED.patch (drm-backport-placeholder)
- commit 8e5e7ee
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0176-fbdev-metronomefb-Generate-deferred-I-O-ops.patch (drm-backport-placeholder)
- commit ae466e6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0175-fbdev-metronomefb-Select-FB_SYS_HELPERS_DEFERRED.patch (drm-backport-placeholder)
- commit e0d4636
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0174-fbdev-hecubafb-Generate-deferred-I-O-ops.patch (drm-backport-placeholder)
- commit 8a2d947
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0173-fbdev-hecubafb-Select-FB_SYS_HELPERS_DEFERRED.patch (drm-backport-placeholder)
- commit 01727cd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0172-fbdev-broadsheetfb-Generate-deferred-I-O-ops.patch (drm-backport-placeholder)
- commit c1a48f2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0171-fbdev-broadsheetfb-Select-FB_SYS_HELPERS_DEFERRED.patch (drm-backport-placeholder)
- commit 5cc08d7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0170-sysfb-Do-not-include-linux-screen_info.h-from-sysfb-.patch (drm-backport-placeholder)
- commit 0a4b61a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0169-fbdev-sm712fb-Do-not-include-linux-screen_info.h.patch (drm-backport-placeholder)
- commit 51bf224
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0168-drm-nouveau-disp-drop-unused-argument-in-nv50_dp_mod.patch (drm-backport-placeholder)
- commit ad705b5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0167-drm-nouveau-kms-don-t-call-drm_dp_cec_set_edid-on-TM.patch (drm-backport-placeholder)
- commit 2d0a9a1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0166-drm-nouveau-nvif-fix-potential-double-free.patch (drm-backport-placeholder)
- commit 02dd332
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0165-drm-nouveau-fifo-ga100-add-per-runlist-nonstall-intr.patch (drm-backport-placeholder)
- commit 95bd30f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0164-drm-nouveau-fifo-ga100-remove-individual-runlists-ra.patch (drm-backport-placeholder)
- commit ba29845
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0163-drm-nouveau-fifo-return-ERR_PTR-from-nvkm_runl_new.patch (drm-backport-placeholder)
- commit 34139e4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0162-drm-nouveau-fifo-remove-left-over-references-to-nvkm.patch (drm-backport-placeholder)
- commit f983830
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0161-drm-nouveau-fb-ga102-construct-vidmem-heap-via-new-g.patch (drm-backport-placeholder)
- commit 74839f4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0160-drm-nouveau-fb-gp102-ga100-switch-to-simpler-vram-si.patch (drm-backport-placeholder)
- commit 2b2dbef
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0159-drm-nouveau-nvkm-punt-spurious-irq-messages-to-debug.patch (drm-backport-placeholder)
- commit 02f59b0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0158-drm-nouveau-nvkm-fini-object-children-in-reverse-ord.patch (drm-backport-placeholder)
- commit a4602aa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0157-drm-Add-kms-driver-for-loongson-display-controller.patch (drm-backport-placeholder)
- commit 430964f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0156-drm-drm_gem.c-Remove-surplus-else-after-return.patch (drm-backport-placeholder)
- commit 665af8d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0155-drm-gud-use-vmalloc_array-and-vcalloc.patch (drm-backport-placeholder)
- commit 0201e3a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0154-drm-bridge-samsung-dsim-Drain-command-transfer-FIFO-.patch (drm-backport-placeholder)
- commit b36ca0c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0153-drm-edid-Add-quirk-for-OSVR-HDK-2.0.patch (drm-backport-placeholder)
- commit 41272eb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0152-drm-tests-Fix-swapped-drm_framebuffer-tests-paramete.patch (drm-backport-placeholder)
- commit ceed865
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0151-drm-edid-make-read-only-const-array-static.patch (drm-backport-placeholder)
- commit ddbe9f9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0150-drm-ast-Merge-config-and-chip-detection.patch (drm-backport-placeholder)
- commit fa08467
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0149-drm-ast-Move-widescreen-and-tx-chip-detection-into-s.patch (drm-backport-placeholder)
- commit aecca96
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0148-drm-ast-Detect-AST-2510-model.patch (drm-backport-placeholder)
- commit d8b7398
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0147-drm-ast-Detect-AST-1400-model.patch (drm-backport-placeholder)
- commit 8090b89
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0146-drm-ast-Detect-AST-1300-model.patch (drm-backport-placeholder)
- commit e94d064
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0145-drm-ast-Distinguish-among-chip-generations.patch (drm-backport-placeholder)
- commit 037d052
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0144-drm-ast-Set-up-release-action-right-after-enabling-M.patch (drm-backport-placeholder)
- commit b3103fa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0143-drm-ast-Enable-and-unlock-device-access-early-during.patch (drm-backport-placeholder)
- commit 16a6a34
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0142-drm-ast-Set-PCI-config-before-accessing-I-O-register.patch (drm-backport-placeholder)
- commit b5d1160
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0141-drm-ast-Remove-device-POSTing-and-config-from-chip-d.patch (drm-backport-placeholder)
- commit 2874bf1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0140-drm-ast-Remove-dead-else-branch-in-POST-code.patch (drm-backport-placeholder)
- commit a9a15b5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0139-drm-ast-Implement-register-helpers-in-ast_drv.h.patch (drm-backport-placeholder)
- commit 3131ae9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0138-drm-ast-Remove-vga2_clone-field.patch (drm-backport-placeholder)
- commit 5e3ec78
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-ast-Fix-DRAM-init-on-AST2200.patch (drm-backport-placeholder)
- commit a653eaa
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0136-drm-ttm-Don-t-shadow-the-operation-context.patch (drm-backport-placeholder)
- commit 6ac9ad5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0135-fbdev-Make-support-for-userspace-interfaces-configur.patch (drm-backport-placeholder)
- commit 50451a8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0134-fbdev-core-Rework-fb-init-code.patch (drm-backport-placeholder)
- commit 66aaa6a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0133-fbdev-core-Move-file-I-O-code-into-separate-file.patch (drm-backport-placeholder)
- commit 7e42ef7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0132-fbdev-core-Move-procfs-code-to-separate-file.patch (drm-backport-placeholder)
- commit d53d14b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0131-fbdev-core-Add-fb_device_-create-destroy.patch (drm-backport-placeholder)
- commit 126877d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0130-fbdev-core-Move-framebuffer-and-backlight-helpers-in.patch (drm-backport-placeholder)
- commit 0e8f067
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0129-fbdev-core-Pass-Linux-device-to-pm_vt_switch_-functi.patch (drm-backport-placeholder)
- commit 58001ec
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0128-fbdev-tdfxfb-Set-i2c-adapter-parent-to-hardware-devi.patch (drm-backport-placeholder)
- commit 96b7eac
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0127-fbdev-smscufx-Detect-registered-fb_info-from-refcoun.patch (drm-backport-placeholder)
- commit 29e5565
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0126-fbdev-sm501fb-Output-message-with-fb_err.patch (drm-backport-placeholder)
- commit 6202dc2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0125-fbdev-sh7760fb-Use-hardware-device-with-dev_-output-.patch (drm-backport-placeholder)
- commit 60781b6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0124-fbdev-sh7760fb-Alloc-DMA-memory-from-hardware-device.patch (drm-backport-placeholder)
- commit 2e01f62
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0123-fbdev-sh7760fb-Output-messages-with-fb_dbg.patch (drm-backport-placeholder)
- commit 81900d0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0122-fbdev-sh7760fb-Use-fb_dbg-in-sh7760fb_get_color_info.patch (drm-backport-placeholder)
- commit 12f55bd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0121-fbdev-rivafb-Use-hardware-device-as-backlight-parent.patch (drm-backport-placeholder)
- commit e9c3810
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0120-fbdev-rivafb-Reorder-backlight-and-framebuffer-init-.patch (drm-backport-placeholder)
- commit 485609f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0119-fbdev-radeonfb-Use-hardware-device-as-backlight-pare.patch (drm-backport-placeholder)
- commit 4442550
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0118-fbdev-radeonfb-Reorder-backlight-and-framebuffer-cle.patch (drm-backport-placeholder)
- commit fb5162d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0117-fbdev-pxa168fb-Do-not-assign-to-struct-fb_info.dev.patch (drm-backport-placeholder)
- commit 245c0b2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0116-fbdev-nvidiafb-Use-hardware-device-as-backlight-pare.patch (drm-backport-placeholder)
- commit 5d9aa59
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0115-fbdev-nvidiafb-Reorder-backlight-and-framebuffer-ini.patch (drm-backport-placeholder)
- commit 04a803c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0114-fbdev-metronomefb-Use-hardware-device-for-dev_err.patch (drm-backport-placeholder)
- commit 134cbfc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0113-fbdev-mb862xxfb-Output-messages-with-fb_dbg.patch (drm-backport-placeholder)
- commit c2a2e7c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0112-fbdev-fsl-diu-fb-Output-messages-with-fb_-helpers.patch (drm-backport-placeholder)
- commit 65a3483
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-ep93xx-fb-Do-not-assign-to-struct-fb_info.dev.patch (drm-backport-placeholder)
- commit e698fac
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0110-fbdev-ep93xx-fb-Output-messages-with-fb_info-and-fb_.patch (drm-backport-placeholder)
- commit 19cd3a7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0109-fbdev-ep93xx-fb-Alloc-DMA-memory-from-hardware-devic.patch (drm-backport-placeholder)
- commit e7a1f82
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0108-fbdev-broadsheetfb-Call-device_remove_file-with-hard.patch (drm-backport-placeholder)
- commit 6ccdde4
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0107-fbdev-aty128fb-Use-hardware-device-as-backlight-pare.patch (drm-backport-placeholder)
- commit 49146e2
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0106-fbdev-aty128fb-Reorder-backlight-and-framebuffer-ini.patch (drm-backport-placeholder)
- commit 2722da1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0105-fbdev-atyfb-Use-hardware-device-as-backlight-parent.patch (drm-backport-placeholder)
- commit 9f644a0
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0104-fbdev-atyfb-Reorder-backlight-and-framebuffer-init-c.patch (drm-backport-placeholder)
- commit 6c51cbe
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0103-backlight-lv5207lp-Rename-struct-lv5207lp_platform_d.patch (drm-backport-placeholder)
- commit eb6c63d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/backlight-lv5207lp-Compare-against-struct-fb_info.de.patch (drm-backport-placeholder)
- commit 51a58cb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0101-backlight-gpio_backlight-Rename-field-fbdev-to-dev.patch (drm-backport-placeholder)
- commit 7ac4e61
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/backlight-gpio_backlight-Compare-against-struct-fb_i.patch (drm-backport-placeholder)
- commit 14a6119
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0099-backlight-bd6107-Rename-struct-bd6107_platform_data..patch (drm-backport-placeholder)
- commit 157a894
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/backlight-bd6107-Compare-against-struct-fb_info.devi.patch (drm-backport-placeholder)
- commit 83b9b82
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0097-drm-bridge-dw-hdmi-remove-dead-code-and-fix-indentat.patch (drm-backport-placeholder)
- commit 35490b1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0096-drm-bridge-dw-hdmi-truly-enforce-420-only-formats-wh.patch (drm-backport-placeholder)
- commit fc1662d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0095-drm-bridge-dw-hdmi-change-YUV420-selection-logic-at-.patch (drm-backport-placeholder)
- commit 0c58a43
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0001-drm-prime-Unexport-helpers-for-fd-handle-conversion.patch (drm-backport-placeholder)
- commit 21c0d42
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0093-drm-Clear-fd-handle-callbacks-in-struct-drm_driver.patch (drm-backport-placeholder)
- commit dbf4fa1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-mxsfb-Disable-overlay-plane-in-mxsfb_plane_overl.patch (drm-backport-placeholder)
- commit 83813f3
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0090-drm-vkms-Isolate-writeback-pixel-conversion-function.patch (drm-backport-placeholder)
- commit df3a098
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0089-drm-vkms-Enable-ARGB8888-support-for-writeback.patch (drm-backport-placeholder)
- commit dd575cd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0088-drm-vkms-Reduce-critical-section.patch (drm-backport-placeholder)
- commit 8dcb421
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0087-drm-bridge-ps8640-Drop-the-ability-of-ps8640-to-fetc.patch (drm-backport-placeholder)
- commit 369f2df
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0086-drm-kms-log-when-querying-an-object-not-included-in-.patch (drm-backport-placeholder)
- commit e88c510
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0085-drm-atomic-log-errors-in-drm_mode_atomic_ioctl.patch (drm-backport-placeholder)
- commit 251161a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0084-drm-atomic-log-when-page-flip-is-requested-without-C.patch (drm-backport-placeholder)
- commit c806cf6
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0083-drm-atomic-log-on-attempt-to-set-legacy-DPMS-propert.patch (drm-backport-placeholder)
- commit 5a4957d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0082-drm-atomic-log-when-CRTC_ID-prop-value-is-invalid.patch (drm-backport-placeholder)
- commit 74e8421
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0081-drm-atomic-log-when-getting-setting-unknown-properti.patch (drm-backport-placeholder)
- commit 99bcd6b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0080-drm-atomic-drop-extra-bracket-from-log-messages.patch (drm-backport-placeholder)
- commit b78e91b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0079-drm-atomic-log-drm_atomic_replace_property_blob_from.patch (drm-backport-placeholder)
- commit cb78dbb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0078-drm-bridge_connector-use-drm_kms_helper_connector_ho.patch (drm-backport-placeholder)
- commit 6688f51
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0077-drm-sysfs-rename-drm_sysfs_connector_status_event.patch (drm-backport-placeholder)
- commit 19a3a2b
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0076-drm-fix-code-style-for-embedded-structs-in-hdr_metad.patch (drm-backport-placeholder)
- commit cf957c8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0075-drm-mgag200-set-variable-mgag200_modeset-storage-cla.patch (drm-backport-placeholder)
- commit f741fa5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-dw-mipi-dsi-Fix-enable-disable-of-DSI-con.patch (drm-backport-placeholder)
- commit 7d2dcfd
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0073-drm-i2c-Switch-i2c-drivers-back-to-use-.probe.patch (drm-backport-placeholder)
- commit 5e07347
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0072-drm-bridge-tc358762-Handle-HS-VS-polarity.patch (drm-backport-placeholder)
- commit 94f5171
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0071-drm-bridge-tc358762-Guess-the-meaning-of-LCDCTRL-bit.patch (drm-backport-placeholder)
- commit dfb1bcc
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0070-drm-bridge-tc358762-Instruct-DSI-host-to-generate-HS.patch (drm-backport-placeholder)
- commit f9954d8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0069-drm-bridge-tc358762-Switch-to-atomic-ops.patch (drm-backport-placeholder)
- commit 9e95b14
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0068-drm-bridge-tc358762-Split-register-programming-from-.patch (drm-backport-placeholder)
- commit dce540d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0067-drm-bridge-tc358764-Use-BIT-macro-for-actual-bits.patch (drm-backport-placeholder)
- commit 71b2d71
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0066-drm-shmem-helper-Switch-to-reservation-lock.patch (drm-backport-placeholder)
- commit 9b34672
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0065-dma-buf-Change-locking-policy-for-mmap.patch (drm-backport-placeholder)
- commit 3f899e1
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0064-drm-Don-t-assert-held-reservation-lock-for-dma-buf-m.patch (drm-backport-placeholder)
- commit b593d29
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0063-udmabuf-Don-t-assert-held-reservation-lock-for-dma-b.patch (drm-backport-placeholder)
- commit 2e466be
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0062-dma-buf-heaps-Don-t-assert-held-reservation-lock-for.patch (drm-backport-placeholder)
- commit 0b10995
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0061-drm-bridge-lt9611uxc-Add-MODULE_FIRMWARE-macro.patch (drm-backport-placeholder)
- commit f149c01
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0060-drm-vkms-Fix-all-kernel-doc-warnings-of-the-vkms_com.patch (drm-backport-placeholder)
- commit 9426ae5
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0059-drm-vkms-Add-kernel-doc-to-the-function-vkms_compose.patch (drm-backport-placeholder)
- commit 218b617
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0058-drm-amdgpu-Remove-struct-drm_driver.gem_prime_mmap.patch (drm-backport-placeholder)
- commit ac71c00
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0057-drm-Remove-struct-drm_driver.gem_prime_mmap.patch (drm-backport-placeholder)
- commit 2d89ba7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0056-drm-msm-Initialize-mmap-offset-after-constructing-th.patch (drm-backport-placeholder)
- commit 374fe98
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0055-drm-tidss-Add-support-for-AM625-DSS.patch (drm-backport-placeholder)
- commit d56e869
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0054-drm-ingenic-Kconfig-select-REGMAP-and-REGMAP_MMIO.patch (drm-backport-placeholder)
- commit c0f9a9c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0052-drm-ssd130x-Remove-hardcoded-bits-per-pixel-in-ssd13.patch (drm-backport-placeholder)
- commit 1fa6f66
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0051-drm-ssd130x-Don-t-allocate-buffers-on-each-plane-upd.patch (drm-backport-placeholder)
- commit 918ad16
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0050-drm-ssd130x-Set-the-page-height-value-in-the-device-.patch (drm-backport-placeholder)
- commit 7982e29
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0049-drm-ssd130x-Make-default-width-and-height-to-be-cont.patch (drm-backport-placeholder)
- commit c3f4779
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0048-drm-omap-Convert-to-platform-remove-callback-returni.patch (drm-backport-placeholder)
- commit c04c8d8
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0047-drm-tilcdc-Convert-to-platform-remove-callback-retur.patch (drm-backport-placeholder)
- commit 924ed35
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0046-drm-rcar-du-Convert-to-platform-remove-callback-retu.patch (drm-backport-placeholder)
- commit f5b4256
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0045-drm-xlnx-zynqmp_dpsub-Convert-to-platform-remove-cal.patch (drm-backport-placeholder)
- commit 2b8db51
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0044-drm-vc4-Convert-to-platform-remove-callback-returnin.patch (drm-backport-placeholder)
- commit 7ce99c7
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0043-drm-v3d-Convert-to-platform-remove-callback-returnin.patch (drm-backport-placeholder)
- commit 09e0a12
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0042-drm-tve200-Convert-to-platform-remove-callback-retur.patch (drm-backport-placeholder)
- commit 5ce5d90
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0041-drm-tiny-Convert-to-platform-remove-callback-returni.patch (drm-backport-placeholder)
- commit b319fc9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0040-drm-tidss-Convert-to-platform-remove-callback-return.patch (drm-backport-placeholder)
- commit ad91ba9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0039-drm-sun4i-Convert-to-platform-remove-callback-return.patch (drm-backport-placeholder)
- commit 4b7baeb
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0038-drm-stm-Convert-to-platform-remove-callback-returnin.patch (drm-backport-placeholder)
- commit 85e6458
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0037-drm-sti-Convert-to-platform-remove-callback-returnin.patch (drm-backport-placeholder)
- commit 9592720
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0036-drm-rockchip-Convert-to-platform-remove-callback-ret.patch (drm-backport-placeholder)
- commit 22c0677
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0035-drm-panfrost-Convert-to-platform-remove-callback-ret.patch (drm-backport-placeholder)
- commit b4d307d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0034-drm-panel-Convert-to-platform-remove-callback-return.patch (drm-backport-placeholder)
- commit 0ecb60f
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0033-drm-mxsfb-Convert-to-platform-remove-callback-return.patch (drm-backport-placeholder)
- commit 0ea3476
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0032-drm-meson-Convert-to-platform-remove-callback-return.patch (drm-backport-placeholder)
- commit 242d4df
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0031-drm-mcde-Convert-to-platform-remove-callback-returni.patch (drm-backport-placeholder)
- commit 7b4222e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0030-drm-logicvc-Convert-to-platform-remove-callback-retu.patch (drm-backport-placeholder)
- commit 71b4d6e
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0029-drm-lima-Convert-to-platform-remove-callback-returni.patch (drm-backport-placeholder)
- commit 0e84b75
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0028-drm-hisilicon-Convert-to-platform-remove-callback-re.patch (drm-backport-placeholder)
- commit d747a28
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0027-drm-fsl-dcu-Convert-to-platform-remove-callback-retu.patch (drm-backport-placeholder)
- commit 717c012
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0026-drm-atmel-hlcdc-Convert-to-platform-remove-callback-.patch (drm-backport-placeholder)
- commit 7380653
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0025-drm-aspeed-Convert-to-platform-remove-callback-retur.patch (drm-backport-placeholder)
- commit 8329430
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0024-drm-arm-malidp-Convert-to-platform-remove-callback-r.patch (drm-backport-placeholder)
- commit b38280d
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0023-drm-arm-hdlcd-Convert-to-platform-remove-callback-re.patch (drm-backport-placeholder)
- commit c7821e9
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0022-drm-komeda-Convert-to-platform-remove-callback-retur.patch (drm-backport-placeholder)
- commit 06f2842
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0021-drm-panel-Add-driver-for-Visionox-r66451-panel.patch (drm-backport-placeholder)
- commit 133e39a
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0020-drm-panel-s6d7aa0-remove-the-unneeded-variable-in-s6.patch (drm-backport-placeholder)
- commit 0f2034c
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0019-drm-panel-edp-Add-AUO-B116XAB01.4-edp-panel-entry.patch (drm-backport-placeholder)
- commit d996a75
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0018-drm-i915-Move-abs_diff-to-math.h.patch (drm-backport-placeholder)
- commit 72e2a63
* Mon Sep  9 2024 pjakobsson@suse.de
- Update patches.suse/0017-minmax-add-in_range-macro.patch (drm-backport-placeholder)
- commit 8ed3506
* Mon Sep  9 2024 tiwai@suse.de
- sysfs: Fix crash on empty group attributes array (git-fixes).
- Refresh
  patches.suse/sysfs-Introduce-a-mechanism-to-hide-static-attribute.patch.
- commit 8c7ed55
* Mon Sep  9 2024 nmorey@suse.com
- RDMA/efa: Properly handle unexpected AQ completions (git-fixes)
- commit 8c8b9e5
* Sun Sep  8 2024 tiwai@suse.de
- clk: qcom: gcc-sc8280xp: don't use parking clk_ops for QUPs
  (git-fixes).
- clk: qcom: gcc-sm8550: Don't park the USB RCG at registration
  time (git-fixes).
- clk: qcom: gcc-sm8550: Don't use parking clk_ops for QUPs
  (git-fixes).
- clk: qcom: ipq9574: Update the alpha PLL type for GPLLs
  (git-fixes).
- clk: qcom: clk-alpha-pll: Fix zonda set_rate failure when PLL
  is disabled (git-fixes).
- clk: qcom: clk-alpha-pll: Fix the trion pll postdiv set rate
  API (git-fixes).
- clk: qcom: clk-alpha-pll: Fix the pll post div mask (git-fixes).
- commit 060a67a
* Sat Sep  7 2024 tiwai@suse.de
- ALSA: hda/realtek - Fix inactive headset mic jack for ASUS
  Vivobook 15 X1504VAP (stable-fixes).
- ALSA: hda/realtek: Support mute LED on HP Laptop 14-dq2xxx
  (stable-fixes).
- ALSA: hda/realtek: Enable Mute Led for HP Victus 15-fb1xxx
  (stable-fixes).
- ALSA: hda/realtek: extend quirks for Clevo V5[46]0
  (stable-fixes).
- ALSA: hda/realtek: add patch for internal mic in Lenovo V145
  (stable-fixes).
- ALSA: hda/conexant: Add pincfg quirk to enable top speakers
  on Sirius devices (stable-fixes).
- commit 5538dd8
* Sat Sep  7 2024 tiwai@suse.de
- ASoC: sunxi: sun4i-i2s: fix LRCLK polarity in i2s mode
  (git-fixes).
- ASoc: SOF: topology: Clear SOF link platform name upon unload
  (git-fixes).
- ASoC: tegra: Fix CBB error during probe() (git-fixes).
- ASoC: dapm: Fix UAF for snd_soc_pcm_runtime object (git-fixes).
- mmc: cqhci: Fix checking of CQHCI_HALT state (git-fixes).
- mmc: dw_mmc: Fix IDMAC operation with pages bigger than 4K
  (git-fixes).
- mmc: sdhci-of-aspeed: fix module autoloading (git-fixes).
- mmc: core: apply SD quirks earlier during probe (git-fixes).
- gpio: modepin: Enable module autoloading (git-fixes).
- gpio: rockchip: fix OF node leak in probe() (git-fixes).
- Revert "drm/amdgpu: align pp_power_profile_mode with kernel
  docs" (stable-fixes).
- nouveau: fix the fwsec sb verification register (git-fixes).
- drm/i915/fence: Mark debug_fence_free() with __maybe_unused
  (git-fixes).
- drm/i915/fence: Mark debug_fence_init_onstack() with
  __maybe_unused (git-fixes).
- drm/i915: Do not attempt to load the GSC multiple times
  (git-fixes).
- commit 7a89765
* Sat Sep  7 2024 tiwai@suse.de
- ASoC: codecs: lpass-va-macro: set the default codec version
  for sm8250 (jsc#PED-9993 jsc#PED-10202).
- commit 36fdd5c
* Sat Sep  7 2024 tiwai@suse.de
- PCI: Add INTEL_HDA_PTL to pci_ids.h (jsc#PED-9993
  jsc#PED-10202).
- commit e45011e
* Fri Sep  6 2024 tiwai@suse.de
- Revert "ALSA: emu10k1 - delay the PCM interrupts (add
  pcm_irq_delay parameter)" (jsc#PED-9993 jsc#PED-10202).
- commit 10de224
* Fri Sep  6 2024 tiwai@suse.de
- Refresh patches.suse/ASoC-SOF-Intel-mtl-Correct-rom_status_reg.patch (jsc#PED-9993 jsc#PED-10202)
  Fix the missing hunk at SLE15-SP6 backport
- commit 503352d
* Fri Sep  6 2024 tiwai@suse.de
- Refresh patches.suse/ASoC-Intel-avs-Switch-to-ACPI-NHLT.patch
  Fix the minor merge errors
- commit 192aba7
* Fri Sep  6 2024 tiwai@suse.de
- Refresh patches.suse/ASoC-lower-no-backend-DAIs-enabled-for-.-Port-log-se.patch
  Fix the missing hunk at the previous backport
- commit ab7b67f
* Fri Sep  6 2024 dsterba@suse.com
- blacklist.conf: CVE-2024-43886 bsc#1229748: not applicable, functionality not present
  The fix adds a NULL check but it is already there in this codebase. The
  upstream fix is for patch 5db346c256bbac ("drm/amd/display: update pipe
  topology log to support subvp") that adds a secondary display and
  refactors code so the NULL check gets lost in
  resource_log_pipe_topology_update().
- commit b9c5bf2
* Fri Sep  6 2024 tiwai@suse.de
- ALSA: hda: hda_component: Fix mutex crash if nothing ever binds
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-va-macro: warn on unknown version
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-macro: fix version strings returned for
  1.x codecs (jsc#PED-9993 jsc#PED-10202).
- treewide: remove unnecessary <linux/version.h> inclusion
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: cs35l41: Remove redundant call to
  hda_cs_dsp_control_remove() (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: cs35l56: Remove redundant call to
  hda_cs_dsp_control_remove() (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: button detect issue (jsc#PED-9993
  jsc#PED-10202).
- commit eda9d9f
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: cs35l56: Stop creating ALSA controls for firmware
  coefficients (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm_adsp: Add control_add callback and export
  wm_adsp_control_add() (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-macro: fix missing codec version
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Cache shutter IRQ control pointers (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l45: Use new snd_soc_component_get_kcontrol_locked()
  helper (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-component: Add new snd_soc_component_get_kcontrol()
  helpers (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Remove redundant semi-colon at end of function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl_micfil: Differentiate register access permission
  for platforms (jsc#PED-9993 jsc#PED-10202).
- commit 1f4c50a
* Fri Sep  6 2024 tiwai@suse.de
- ALSA: hda: cs35l41: Stop creating ALSA Controls for firmware
  coefficients (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: cs35l56: Stop creating ALSA controls for firmware
  coefficients (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl-asoc-card: Dynamically allocate memory for
  snd_soc_dai_link_components (jsc#PED-9993 jsc#PED-10202).
- ASoC: tegra: select CONFIG_SND_SIMPLE_CARD_UTILS (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: tas2781: mark const variables as __maybe_unused
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: debugfs: simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- commit d1e3ff6
* Fri Sep  6 2024 tiwai@suse.de
- soundwire: cadence: simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel_ace2x: simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel_ace2x: simplify return path in hw_params
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel: simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel: simplify return path in hw_params
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: amd_init: simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- soundwire: amd: simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- soundwire: amd: simplify return path in hw_params (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel_auxdevice: start the bus at default frequency
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel_auxdevice: add cs42l43 codec to
  wake_capable_list (jsc#PED-9993 jsc#PED-10202).
- commit 69d256e
* Fri Sep  6 2024 tiwai@suse.de
- soundwire: intel_ace2.x: add AC timing extensions for
  PantherLake (jsc#PED-9993 jsc#PED-10202).
- commit db94782
* Fri Sep  6 2024 tiwai@suse.de
- soundwire: bus: add stream refcount (jsc#PED-9993
  jsc#PED-10202).
- Refresh patches.suse/soundwire-suse-kabi-padding.patch.
- commit 5f0f7f6
* Fri Sep  6 2024 tiwai@suse.de
- drivers:soundwire: qcom: cleanup port maask calculations
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: bus: simplify by using local slave->prop
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: generic_bandwidth_allocation: change port_bo
  parameter to pointer (jsc#PED-9993 jsc#PED-10202).
- soundwire: Intel: clarify Copyright information (jsc#PED-9993
  jsc#PED-10202).
- soundwire: debugfs: add interface to read/write commands
  (jsc#PED-9993 jsc#PED-10202).
- commit c0f9cd8
* Fri Sep  6 2024 tiwai@suse.de
- firmware: cs_dsp: Rename fw_ver to wmfw_ver (jsc#PED-9993
  jsc#PED-10202).
- firmware: cs_dsp: Clarify wmfw format version log message
  (jsc#PED-9993 jsc#PED-10202).
- firmware: cs_dsp: Make wmfw and bin filename arguments const
  char * (jsc#PED-9993 jsc#PED-10202).
- firmware: cs_dsp: Don't allocate temporary buffer for info text
  (jsc#PED-9993 jsc#PED-10202).
- firmware: cs_dsp: Log that a bin file was loaded (jsc#PED-9993
  jsc#PED-10202).
- commit 7215555
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: tas2781: Add new Kontrol to set tas2563 digital Volume
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: topology: Simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: aw88395: Simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: Convert comma to semicolon (jsc#PED-9993
  jsc#PED-10202).
- ASoc: TAS2781: rename the tas2781_reset as tasdevice_reset
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl-asoc-card: merge spdif support from imx-spdif.c
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl-asoc-card: add compatibility to use 2 codecs in
  dai-links (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl-asoc-card: add second dai link component for codecs
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl-asoc-card: add support for dai links with multiple
  codecs (jsc#PED-9993 jsc#PED-10202).
- ASoC: dapm: Simplify snd_soc_dai_link_event_pre_pmu() with
  cleanup.h (jsc#PED-9993 jsc#PED-10202).
- ASoC: dapm: Simplify dapm_cnew_widget() with cleanup.h
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ops: Simplify with cleanup.h (jsc#PED-9993 jsc#PED-10202).
- ASoC: simple-card: Use cleanup.h instead of devm_kfree()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card2: Use cleanup.h instead of devm_kfree()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card: Use cleanup.h instead of devm_kfree()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: simple-card-utils: Simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wcd934x: Simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- commit cf399f9
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: codecs: wcd9335: Simplify with cleanup.h (jsc#PED-9993
  jsc#PED-10202).
- ASoc: TAS2781: replace beXX_to_cpup with get_unaligned_beXX
  for potentially broken alignment (jsc#PED-9993 jsc#PED-10202).
- ASoc: pcm6240: Remove unnecessary name-prefix for all the
  controls (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: fsl_qmc_audio: Add support for non-interleaved mode
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: fsl_qmc_audio: Introduce
  qmc_dai_constraints_interleaved() (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: fsl_qmc_audio: Introduce
  qmc_audio_pcm_{read,write}_submit() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: fsl_qmc_audio: Identify the QMC channel involved
  in completion routines (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: fsl_qmc_audio: Split channel buffer and PCM pointer
  handling (jsc#PED-9993 jsc#PED-10202).
- commit 79caa13
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: fsl: fsl_qmc_audio: Fix issues detected by checkpatch
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-wsa-macro: Simplify with cleanup.h
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-rx-macro: Use unsigned for number of widgets
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: dapm: Use unsigned for number of widgets in
  snd_soc_dapm_new_controls() (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-rx-macro: Keep static regmap_config as const
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-rx-macro: Simplify with cleanup.h
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-rx-macro: Simplify PDS cleanup with devm
  (jsc#PED-9993 jsc#PED-10202).
- ASoc: tas2781: Set "Speaker Force Firmware Load" as the
  common kcontrol for both tas27871 and tas2563 (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ak4458: remove "reset-gpios" property handler
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-port: add link-trigger-order (jsc#PED-9993
  jsc#PED-10202).
- ASoC: dt-bindings: audio-graph-port: Drop type from "clocks"
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: dt-bindings: audio-graph-port: Document new DAI link
  flags playback-only/capture-only (jsc#PED-9993 jsc#PED-10202).
- ASoC: dt-bindings: Simplify referencing dai-params.yaml
  (jsc#PED-9993 jsc#PED-10202).
- commit fc8307f
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: SOF: ipc4-topology: Use single token list for the copiers
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: tas5086: Convert to GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wsa884x: Constify struct regmap_config (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wsa883x: Constify struct regmap_config (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wsa881x: Constify struct regmap_config (jsc#PED-9993
  jsc#PED-10202).
- ASoC: jz4770: Constify struct regmap_config (jsc#PED-9993
  jsc#PED-10202).
- ASoC: jz4760: Constify struct regmap_config (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs53l30: Constify struct regmap_config (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l36: Constify struct regmap_config (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l35: Constify struct regmap_config (jsc#PED-9993
  jsc#PED-10202).
- commit 8eeb04d
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: cs35l34: Constify struct regmap_config (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl_xcvr: Improve suspend/resume flow in
  fsl_xcvr_trigger() (jsc#PED-9993 jsc#PED-10202).
- ASoC: tas2781: Use of_property_read_reg() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: PCM6240: Use of_property_read_reg() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: topology: Unify code for creating standalone and widget
  enum control (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Unify code for creating standalone and widget
  mixer control (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Unify code for creating standalone and widget
  bytes control (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Reshuffle function placement (jsc#PED-9993
  jsc#PED-10202).
- ASoC: topology: Rename function creating widget kcontrol
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Align dynamic object initialization for controls
  (jsc#PED-9993 jsc#PED-10202).
- commit 7080cfb
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: topology: Correctly set shift_r in soc_tplg_denum_create()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Cleanup soc_tplg_dapm_widget_denum_create
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Cleanup soc_tplg_dapm_widget_dmixer_create
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Cleanup soc_tplg_dapm_widget_dbytes_create
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Properly initialize soc_enum values
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Do not do unnecessary dobj management
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Simplify code (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: nau8824: Add master clock handling (jsc#PED-9993
  jsc#PED-10202).
- ASoC: simple-audio-mux: enable to select MUX names (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l56: Remove redundant clearing of clk_stop_mode1
  (jsc#PED-9993 jsc#PED-10202).
- commit 77a11fd
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: cs35l56: Remove support for A1 silicon (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: lpass-wsa-macro: Fix using NULL pointer in probe()
  dev_err (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-rx-macro: Fix using NULL pointer in probe()
  dev_err (jsc#PED-9993 jsc#PED-10202).
- ASoc: tas2781: Add name_prefix as the prefix name of
  DSP firmwares and calibrated data files (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl_rpmsg: Add support for i.MX95 platform (jsc#PED-9993
  jsc#PED-10202).
- commit 7132fda
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: meson: tdm: add sample rate support up to 768kHz
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-utils: allow sample rate up to 768kHz for the dummy
  dai (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-wsa-macro: add missing select of common code
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: imx-audmix: Split capture device for audmix (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl_audmix: Split playback and capture stream to different
  DAI (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl_sai: Add separate DAI for transmitter and receiver
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card2: add link-trigger-order support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card: add link-trigger-order support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: simple-audio-card: add link-trigger-order support
  (jsc#PED-9993 jsc#PED-10202).
- commit 5712a5b
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: simple-card-utils: add link-trigger-order support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt712-sdca: add the function for version B (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt712-sdca: change the definition name of SDCA channel
  number (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-macro: Use enum for handling codec version
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-macro: Gracefully handle unknown version
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-wsa-macro: Correct support for newer v2.5
  version (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-wsa-macro: Prepare to accommodate new
  codec versions (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-wsa-macro: Drop unused define (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt711-sdca: add GE selected mode control (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: lpass-rx-macro: add missing handling of v2.1 codec
  (jsc#PED-9993 jsc#PED-10202).
- commit ecfebfa
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: Intel: sof_sdw: select PINCTRL_CS42L43 and SPI_CS42L43
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: add quirk for Dell SKU 0B8C (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: maxim-common: add max_98373_get_tx_mask function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: fix jack detection on ADL-N variant RVP
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: regcache_sync error issue (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: ES8326: Minimize the pop noise (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: ES8326: Slove headphone detection issue
  (jsc#PED-9993 jsc#PED-10202).
- ASoc: tas2781: Add name_prefix as the prefix name of firmwares
  and kcontrol to support corresponding TAS2563/TAS2781s
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt6358: Add "Dmic Mode Switch" kcontrol for
  switch DMIC mode (jsc#PED-9993 jsc#PED-10202).
- commit 45b8a03
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: nau8822: add MCLK support (jsc#PED-9993 jsc#PED-10202).
- ASoC: nau8822: set NAU8822_REFIMP_80K only once (jsc#PED-9993
  jsc#PED-10202).
- ASoC: nau8822: move nau8822_set_dai_sysclk() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: sc8280xp: add Display port Jack (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: common: add Display port Jack function (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: q6dsp: parse Display port tokens (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Constify return of snd_soc_dai_get_pcm_stream()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Constify DAI passed to get_channel_map (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Constify passed data to core function (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Constify of_phandle_args in snd_soc_dai_link_component
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Constify of_phandle_args in snd_soc_dai_driver
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Add support for ti,pcm5242 to the pcm512x driver
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd938x: Drop unused num_ports field (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wcd938x: Drop unused RX/TX direction enum
  (jsc#PED-9993 jsc#PED-10202).
- commit 5d925de
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: codecs: wcd938x: Constify wcd938x_sdw_ch_info
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd938x: Constify static data (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wcd934x: Handle nicer probe deferral and simplify
  with dev_err_probe() (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd934x: Drop unused mic bias voltage fields
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd934x: Constify static data (jsc#PED-9993
  jsc#PED-10202).
- commit 6914ec9
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: codecs: wcd934x: Drop unused interp path enum
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd9335: Drop unused dmic rate handling
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd9335: Drop unneeded error message (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wcd9335: Handle nicer probe deferral and simplify
  with dev_err_probe() (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd9335: Constify static data (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wcd9335: Drop unused state container fields
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd-mbhc: Constify passed MBHC reg fields
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: tlv320adc3xxx: Add support for using MICBIAS pins as GPO
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: add pcm constraints for buffer size and period
  size (jsc#PED-9993 jsc#PED-10202).
- commit 733c499
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: amd: acp: move i2s clock generation sequence (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: acp: modify conditional check for programming i2s
  mclk (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: remove unused variables from acp_resource
  structure (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: remove acp_i2s_probe function (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Constify DAI ops auto_selectable_formats (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-dai.h: Constify DAI ops auto_selectable_formats
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card2: add support for aux devices
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: mediatek: Constify struct mtk_adsp_ipc_ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: imx-pcm-fiq: add missing MODULE_DESCRIPTION() macro
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codec: lpass-rx-macro: add support for 2.5 codec version
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codec: lpass-rx-macro: prepare driver to accomdate new
  codec versions (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-macro: add helpers to get codec version
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: add missing MODULE_DESCRIPTION() macros (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: midas_wm1811: Fix error code in probe()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Attempt to read from cirrus,speaker-id device
  property first (jsc#PED-9993 jsc#PED-10202).
- ASoC: samsung: Replace of_gpio.h by proper one (jsc#PED-9993
  jsc#PED-10202).
- ASoC: generic: Replace of_gpio.h by proper one (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rockchip: Remove unused of_gpio.h (jsc#PED-9993
  jsc#PED-10202).
- commit 780a00e
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: fsl: Remove unused of_gpio.h (jsc#PED-9993 jsc#PED-10202).
- commit 0c14591
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: simple-audio-card: merge simple_parse_mclk_fs() into
  simple_link_init() (jsc#PED-9993 jsc#PED-10202).
- ASoC: simple-audio-card: enable playback/capture_only property
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card: merge graph_parse_mclk_fs() into
  graph_link_init() (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card: enable playback/capture_only property
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card: remove ports node name check
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card: add ep_to_port() / port_to_ports()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card2: merge graph_parse_mclk_fs() into
  graph_link_init() (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card2: expand dai_link property part
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card2: remove ports node name check
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card2: add ep_to_port() / port_to_ports()
  (jsc#PED-9993 jsc#PED-10202).
- commit 4939fa4
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: simple-card-utils: remove both playback/capture_only check
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl_xcvr: Add support for i.MX95 platform (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: cx2072x: remove unused struct 'cx2072x_eq_ctrl'
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wm0010: remove unused struct 'wm0010_spi_msg'
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-rx-macro: remove unused struct
  'rx_macro_reg_mask_val' (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: pci-tgl: Align ADL-N sof_dev_desc struct
  name to convention (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd938x: Drop no-op ADC2_BCS Disable Switch
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: samsung: midas_wm1811: Use dev_err_probe where appropriate
  (jsc#PED-9993 jsc#PED-10202).
- commit 2e76136
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: samsung: midas_wm1811: Add GPIO-based headset jack
  detection (jsc#PED-9993 jsc#PED-10202).
- ASoC: samsung: midas_wm1811: Add headset mic bias supply support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: samsung: midas_wm1811: Use SND_SOC_DAPM_REGULATOR_SUPPLY
  for bias regulators (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl_mqs: Add i.MX95 platform support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: qdsp6: Set channel mapping instead of fixed defaults
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: q6apm-lpass-dais: Implement proper channel mapping
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Constify channel mapping array arguments in
  set_channel_map() (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: disable max98373 speaker pins in
  late_probe (jsc#PED-9993 jsc#PED-10202).
- commit edb5423
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: Intel: sof_da7219: remove local max98373 ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: maxim-common: rewrite max_98373_hw_params function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: support tdm slot number query
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc3-topology: support tdm slot number query
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: sof-audio: add sof_dai_get_tdm_slots function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: sof-audio: rename dai clock setting query function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Add quirks for some new Dell laptops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi: Add match entries for some cs42l43
  laptops (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Add missing controls for cs42l43/cs35l56
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: remove get_codec_dai_by_name (jsc#PED-9993
  jsc#PED-10202).
- commit f241188
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: Intel: sof_sdw_rt_sdca_jack_common: use dai parameter
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt_dmic: use from dai parameter
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt700: use dai parameter (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt5682: use dai parameter (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt711: use dai parameter (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw_cs42l42: use dai parameter (jsc#PED-9993
  jsc#PED-10202).
- ASoC: tegra: I2S client convert formats handling (jsc#PED-9993
  jsc#PED-10202).
- ASoC: simple-card-utils: Split simple_fixup_sample_fmt func
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda: print PCI class info only once
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: Constify struct snd_soc_ops (jsc#PED-9993
  jsc#PED-10202).
- commit 398b8a2
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: fsl: fsl_xcvr: Switch to RUNTIME_PM_OPS() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: fsl_easrc: Switch to RUNTIME_PM_OPS() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: fsl_aud2htx: Switch to RUNTIME_PM_OPS() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: topology: Constify struct snd_soc_tplg_ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: Skylake: Constify struct snd_soc_tplg_ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qdsp6: audioreach: Constify struct snd_soc_tplg_ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Constify struct snd_soc_tplg_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: topology: Constify an argument of
  snd_soc_tplg_component_load() (jsc#PED-9993 jsc#PED-10202).
- commit 87e970b
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: codecs: wcd938x: Unify define used for MIC2 bias register
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd938x: Drop unused duplicated MIC2 bias register
  defines (jsc#PED-9993 jsc#PED-10202).
- ALSA: usb: Use BIT() for bit values (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: Add tempo base unit for MIDI2 Set Tempo messages
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: Fix id copying in snd_pcm_set_sync_per_card()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: Fix missing export of snd_pcm_set_sync_per-card()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: cs35l41: Fix missing Speaker ID GPIO description
  in _DSD (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: optimize and clarify stream synchronization ID API
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: reinvent the stream synchronization ID API
  (jsc#PED-9993 jsc#PED-10202).
- commit 7f545a5
* Fri Sep  6 2024 tiwai@suse.de
- ALSA: pcm_dmaengine: Unify two close functions (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: cs35l56: Perform firmware download in the background
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Drop NULL check for snd_ctl_remove() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: control: Allow NULL passed to snd_ctl_remove()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Add input value sanity checks to HDMI channel map
  controls (jsc#PED-9993 jsc#PED-10202).
- ALSA: chmap: Mark Channel Map controls as volatile (jsc#PED-9993
  jsc#PED-10202).
- ALSA: control: Apply sanity check of input values for user
  elements (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Return -EINVAL for invalid volume/switch inputs
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: vmaster: Return error for invalid input values
  (jsc#PED-9993 jsc#PED-10202).
- commit 9bba7a4
* Fri Sep  6 2024 tiwai@suse.de
- ALSA: hda: hda_component: Protect shared data with a mutex
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: hda_component: Move codec field into the parent
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: hda_component: Change codecs to use component parent
  structure (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: hda_component: Introduce component parent structure
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: intel-dsp-config: Add PTL support (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: hda-intel: add PantherLake support (jsc#PED-9993
  jsc#PED-10202).
- commit dcd4c04
* Fri Sep  6 2024 dsterba@suse.com
- ipv6: fix possible UAF in ip6_finish_output2() (bsc#1230206)
- commit 64f6ea9
* Fri Sep  6 2024 dsterba@suse.com
- ipv6: prevent possible UAF in ip6_xmit() (CVE-2024-44985 bsc#1230206)
- commit 209198a
* Fri Sep  6 2024 ddiss@suse.de
- vfs: Don't evict inode under the inode lru traversing context
  (CVE-2024-45003 bsc#1230245).
- commit 630b67a
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: cs35l56: Revert support for dual-ownership of ASP
  registers (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-cs35l56-Handle-OTP-read-latency-over-SoundWire.patch.
- commit 051d80f
* Fri Sep  6 2024 tiwai@suse.de
- ASoC: cs35l56: Limit Speaker Volume to +12dB maximum
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Use header defines for Speaker Volume control
  definition (jsc#PED-9993 jsc#PED-10202).
- commit 94695cd
* Fri Sep  6 2024 msuchanek@suse.de
- powerpc/pseries/iommu: Split Dynamic DMA Window to be used in
  Hybrid mode (jsc#ED-9897).
- commit 7356456
* Fri Sep  6 2024 tiwai@suse.de
- ALSA: scarlett2: Increase mixer range to +12dB (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Add S/PDIF source selection controls
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: usb-audio: Add name for HP Engage Go dock (jsc#PED-9993
  jsc#PED-10202).
- ALSA: usb: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Zero initialize ret in
  scarlett2_ag_target_ctl_get() (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add Bluetooth volume control for Vocaster Two
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add autogain target controls (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Add support for Focusrite Vocaster One and Two
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add DSP controls (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add input mute controls (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Define autogain status texts per-config-set
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Define the maximum preamp input gain
  per-config-set (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add additional input configuration parameters
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add support for config items with size = 32
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add pbuf field to struct scarlett2_config
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Rename gen4_write_addr to param_buf_addr
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add support for reading from flash
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Implement handling of the ACK notification
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Move initialisation code lower in the source
  (jsc#PED-9993 jsc#PED-10202).
- commit aec6fe7
* Fri Sep  6 2024 tiwai@suse.de
- Restore dropped fields for bluetooth MGMT/SMP structs
  (git-fixes).
- commit 5313ecb
* Fri Sep  6 2024 tiwai@suse.de
- usbnet: modern method to get random MAC (git-fixes).
- net: phy: Fix missing of_node_put() for leds (git-fixes).
- Bluetooth: MGMT: Ignore keys being loaded with invalid type
  (git-fixes).
- Revert "Bluetooth: MGMT/SMP: Fix address type when using SMP
  over BREDR/LE" (git-fixes).
- can: mcp251x: fix deadlock if an interrupt occurs during
  mcp251x_open (git-fixes).
- can: mcp251xfd: fix ring configuration when switching from
  CAN-CC to CAN-FD mode (git-fixes).
- can: m_can: Release irq on error in m_can_open (git-fixes).
- can: bcm: Remove proc entry when dev is unregistered
  (git-fixes).
- spi: rockchip: Resolve unbalanced runtime PM / system PM
  handling (git-fixes).
- regulator: core: Stub devm_regulator_bulk_get_const() if
  !CONFIG_REGULATOR (git-fixes).
- platform/x86: dell-smbios: Fix error path in dell_smbios_init()
  (git-fixes).
- commit b6769e6
* Fri Sep  6 2024 jslaby@suse.cz
- serial: sc16is7xx: fix invalid FIFO access with special register
  set (CVE-2024-44950 bsc#1230180).
- serial: sc16is7xx: fix TX fifo corruption (CVE-2024-44951
  bsc#1230181).
- serial: sc16is7xx: refactor FIFO access functions to increase
  commonality (CVE-2024-44951 bsc#1230181).
- commit 4ab54b2
* Fri Sep  6 2024 neilb@suse.de
- NFS: never reuse a NFSv4.0 lock-owner (bsc#1227726).
- commit ed692a4
* Thu Sep  5 2024 tiwai@suse.de
- supported.conf: add snd-sof-intel-hda-generic (jsc#PED-9993 jsc#PED-10202)
- commit dc40ce1
* Thu Sep  5 2024 tiwai@suse.de
- Update config files (jsc#PED-9993 jsc#PED-10202)
- commit c138b3b
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: cs-amp-lib: Ignore empty UEFI calibration entries
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: Fix for incorrect acp error register offsets
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: move iram-dram fence register programming
  sequence (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: cs35l56: Don't use the device index as a calibration
  index (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs-amp-lib: Fix NULL pointer crash if efi.get_variable
  is NULL (jsc#PED-9993 jsc#PED-10202).
- ASoC: sti: add missing probe entry for player and reader
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Only handle dai_config with HW_PARAMS
  for ChainDMA (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: Fix RT5650 SSP lookup (jsc#PED-9993 jsc#PED-10202).
- ASOC: SOF: Intel: hda-loader: only wait for HDaudio IOC for
  IPC4 devices (jsc#PED-9993 jsc#PED-10202).
- ASoc: PCM6240: Return directly after a failed devm_kzalloc()
  in pcmdevice_i2c_probe() (jsc#PED-9993 jsc#PED-10202).
- soundwire: stream: add missing const to Documentation
  (jsc#PED-9993 jsc#PED-10202).
- mfd: cs42l43: Fix wrong GPIO_FN_SEL and SPI_CLK_CONFIG1 defaults
  (jsc#PED-9993 jsc#PED-10202).
- mfd: cs42l43: Fix wrong register defaults (jsc#PED-9993
  jsc#PED-10202).
- mfd: cs42l43: Correct SoundWire port list (jsc#PED-9993
  jsc#PED-10202).
- sh: boards: Fix Sound Simple-Card struct name (jsc#PED-9993
  jsc#PED-10202).
- mfd: cs42l43: Fix MFD_CS42L43 dependency on REGMAP_IRQ
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: aoa: Fix typos in PCM fix patch (jsc#PED-9993
  jsc#PED-10202).
- commit a4891ef
* Thu Sep  5 2024 tiwai@suse.de
- Refresh patches.suse/ASoC-SOF-ipc4-topology-Add-support-for-NHLT-with-16-.patch
  Add alt-commit
- commit 44b5ce3
* Thu Sep  5 2024 tiwai@suse.de
- soundwire: fix usages of device_get_named_child_node()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: fix typo in comment (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel_ace2.x: add support for DOAISE property
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel_ace2.x: add support for DODSE property
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel_ace2x: use DOAIS and DODS settings from
  firmware (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel_ace2x: cleanup DOAIS/DODS settings
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel_ace2x: simplify check_wake() (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel_ace2x: fix wakeup handling (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel_init: resume all devices on exit (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel: export intel_resume_child_device (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel_auxdevice: use pm_runtime_resume() instead
  of pm_request_resume() (jsc#PED-9993 jsc#PED-10202).
- soundwire: qcom: allow multi-link on newer devices (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel_ace2x: use legacy formula for intel_alh_id
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: reconcile dp0_prop and dpn_prop (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel_ace2x: set the clock source (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel_ace2.x: power-up first before setting SYNCPRD
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel_ace2x: move and extend clock selection
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel: add support for MeteorLake additional clocks
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel: add more values for SYNCPRD (jsc#PED-9993
  jsc#PED-10202).
- soundwire: bus: extend base clock checks to 96 MHz (jsc#PED-9993
  jsc#PED-10202).
- soundwire: cadence: show the bus frequency and frame shape
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: clarify maximum allowed address (jsc#PED-9993
  jsc#PED-10202).
- soundwire: remove unused sdw_bus_conf structure (jsc#PED-9993
  jsc#PED-10202).
- soundwire: cadence: remove PDI offset completely (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel: add intel_free_stream() back (jsc#PED-9993
  jsc#PED-10202).
- soundwire: qcom: Convert to platform remove callback returning
  void (jsc#PED-9993 jsc#PED-10202).
- soundwire: bus: don't clear SDCA_CASCADE bit (jsc#PED-9993
  jsc#PED-10202).
- soundwire: amd: use inline function for register update
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: sysfs: remove unneeded ATTRIBUTE_GROUPS() comments
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: sysfs: remove sdw_slave_sysfs_init() (jsc#PED-9993
  jsc#PED-10202).
- soundwire: sysfs: have the driver core handle the creation of
  the device groups (jsc#PED-9993 jsc#PED-10202).
- soundwire: sysfs: cleanup the logic for creating the dp0 sysfs
  attributes (jsc#PED-9993 jsc#PED-10202).
- soundwire: sysfs: move sdw_slave_dev_attr_group into the
  existing list of groups (jsc#PED-9993 jsc#PED-10202).
- ASoC: Use inline function for type safety in
  snd_soc_substream_to_rtd() (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Remove obsolete ABI v4 structs (jsc#PED-9993
  jsc#PED-10202).
- ALSA/ASoC: include: clarify Copyright information (jsc#PED-9993
  jsc#PED-10202).
- sysfs: Introduce a mechanism to hide static attribute_groups
  (jsc#PED-9993 jsc#PED-10202).
- commit 92cec54
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: rt5645: fix issue of random interrupt from push-button
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5645: mic-in detection threshold modification
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5645: improve the depop sequences of CBJ detection
  (jsc#PED-9993 jsc#PED-10202).
- commit ac7f28d
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: mediatek: mt8195: Add platform entry for ETDM1_OUT_BE
  dai link (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: move chip->flag variable assignment
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi: mtl: fix speaker no sound on Dell SKU
  0C64 (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Disconnect ASP1 TX sources when ASP1 DAI is
  hooked up (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Fix route override (jsc#PED-9993
  jsc#PED-10202).
- ASoC: atmel: atmel-classd: Re-add dai_link->platform to fix
  card init (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8183-da7219-max98357: Fix kcontrol name
  collision (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai: remove skip_tlv label (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai: skip tlv for dspless mode
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Solve headphone detection issue
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Increase default type detect time and button
  delay (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: add missing MODULE_DESCRIPTION() macro (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: add missing MODULE_DESCRIPTION() macro (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mxs: add missing MODULE_DESCRIPTION() macro (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: Use imply for suggesting
  CONFIG_SERIAL_MULTI_INSTANTIATE (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: cs35l56: Select SERIAL_MULTI_INSTANTIATE
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Adjust the params based on DAI formats
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Improve readability of
  sof_ipc4_prepare_dai_copier() (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology/pcm: Rename
  sof_ipc4_copier_is_single_format() (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Print out the channel count in
  sof_ipc4_dbg_audio_format (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Add support for NHLT with 16-bit
  only DMIC blob (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: add missing MODULE_DESCRIPTION() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: reorder MODULE_ definitions (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: AMD: group all module related information
  (jsc#PED-9993 jsc#PED-10202).
- commit edab822
* Thu Sep  5 2024 tiwai@suse.de
- leds: trigger: Store brightness set by led_trigger_event()
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/leds-triggers-Flush-pending-brightness-before-activa.patch.
- commit cda5ffe
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: SOF: stream-ipc: remove unnecessary MODULE_LICENSE
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof-sdw: fix missing SPI_MASTER dependency
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Only restrict 44.1kHz for the ASP (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: ES8326: solve hp and button detect issue
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt_sdca_jack_common: Use name_prefix for
  `-sdca` detection (jsc#PED-9993 jsc#PED-10202).
- ALSA: core: Enable proc module when CONFIG_MODULES=y
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: control-led: Integrate mute led trigger (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: hda: disable SoundWire interrupt later
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: Fix build error with built-in config
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt_amp: use dai parameter (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: add dai parameter to rtd_init callback
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: use .controls/.widgets to add
  controls/widgets (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: add controls and dapm widgets in
  codec_info (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: use generic name for controls/widgets
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_cs_amp: rename Speakers to Speaker
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: maxim-common: change max98373 data to static
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: add max98373 dapm routes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use max_98373_dai_link function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: use max_98373_dai_link function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: use max_98373_dai_link function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: maxim-common: add max_98373_dai_link function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-lnl-match: add cs42l43 only support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-mtl-match: add cs42l43 only support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: realtek-common: remove 2-spk rt1015p config
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: board id cleanup for mtl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof-rt5682: remove DMI quirk for hatch
  (jsc#PED-9993 jsc#PED-10202).
- commit fc6340a
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: SOF: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- commit 9c86001
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: sof_sdw_rt_sdca_jack_common: remove -sdca for
  new codecs (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt715-sdca-sdw: Fix wrong complete waiting in
  rt715_dev_resume() (jsc#PED-9993 jsc#PED-10202).
- ASoC: xilinx: Add missing module descriptions (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ux500: Add missing module description (jsc#PED-9993
  jsc#PED-10202).
- ASoC: topology-test: Add missing module description
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: dmaengine: Add missing module description (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: Add missing module descriptions (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sigmadsp: Add missing module description (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ab8500: Add missing module description (jsc#PED-9993
  jsc#PED-10202).
- ASoC: audio-graph-card2: remove unneeded of_node_get()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: xtensa: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: xilinx: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ux500: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: uniphier: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: tegra: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: stm: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sti: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sprd: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: spear: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sh: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rockchip: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: pxa: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mxs: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: meson: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: kirkwood: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: jz4740: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: generic: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cirrus: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: bcm: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: au1x: Use *-y instead of *-objs Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: atmel: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: apple: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: adi: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: Use *-y instead of *-objs in Makefile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: core: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: atmel: tse850-pcm5142: Remove unused of_gpio.h
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: uniphier: Constify static snd_pcm_hardware (jsc#PED-9993
  jsc#PED-10202).
- ASoC: meson: Constify static snd_pcm_hardware (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: Constify static snd_pcm_hardware (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: Constify static snd_pcm_hardware (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wm8996: use 'time_left' variable with
  wait_for_completion_timeout() (jsc#PED-9993 jsc#PED-10202).
- commit fd9364f
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: codecs: wm8994: use 'time_left' variable with
  wait_for_completion_timeout() (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wm8993: use 'time_left' variable with
  wait_for_completion_timeout() (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wm8962: use 'time_left' variable with
  wait_for_completion_timeout() (jsc#PED-9993 jsc#PED-10202).
- ASoC: sunxi: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: samsung: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: meson: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: kirkwood: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: img: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: tegra: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: Use snd_soc_substream_to_rtd() for accessing
  private_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-topology-test: clarify Copyright information
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: clarify Copyright information (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: catpt: clarify Copyright information (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: Intel: clarify Copyright information (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: common: clarify Copyright information (jsc#PED-9993
  jsc#PED-10202).
- commit 3f82779
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: boards: clarify Copyright information (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: clarify Copyright information (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: q6apm-dai: drop unused 'q6apm_dai_rtd' fields
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: move hda.c to different module (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: remove circular dependency on
  hda_sdw_process_wakeen() (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: move tracepoint creation (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: move common code from hda.c (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: start splitting top-level from common parts
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: regroup all SoundWire/Intel functions in hda.c
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-stream: export stream_get_position()
  helper (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Correct DAI copier config and NHLT
  blob request (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Allow selective update in
  sof_ipc4_update_hw_params (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: discard SoundWire configuration if HDaudio
  codec is reported (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: Drop explicit initialization of struct
  i2c_device_id::driver_data to 0 (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof-rt5682: support bclk as PLL source on rt5682s
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof-rt5682: get bclk frequency from topology
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof-rt5682: setup pll_id only when needed
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof-rt5682: add driver_data to sof_rt5682 board
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: add icl_rt5682_def for icl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof-rt5682: remove SOF_RT5682_MCLK_BYTCHT_EN
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof-rt5682: add mclk_en to sof_rt5682_private
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: glk_rt5682_max98357a: delete driver (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_rt5682: support MAX98357A on glk boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: add glk_rt5682_def for glk boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: bxt_da7219_max98357a: remove glk support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: support MAX98357A on glk boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: add glk_da7219_def for glk boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: bxt_da7219_max98357a: remove cml support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: support MAX98357A on cml boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: support MAX98357A (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_rt5682: add missing MAX98357A config
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: bxt_da7219_max98357a: remove MAX98390 support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: support MAX98390 on cml boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: add cml_da7219_def for cml boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: support MAX98390 (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_maxim_common: support MAX98390 on cml boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: nau8825/rt5682: move speaker widget to common
  modules (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Clean up hw constraints initialization
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Store pointer to link_stream in dma_data
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Remove redundancy around DAI prepare
  (jsc#PED-9993 jsc#PED-10202).
- commit b8d3231
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: pcm: Reverse iterate DAIs when shutting them down
  (jsc#PED-9993 jsc#PED-10202).
- commit a99d8b2
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: avs: Remove redundancy around DAI startup
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Store pointer to adev in DAI dma_data
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Remove redundancy around DAI shutdown
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Relocate HDA BE DAI specific operations
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: mediatek: mt8195: Constify snd_sof_dsp_ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: mediatek: mt8186: Constify snd_sof_dsp_ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: intel: byt: Constify snd_sof_dsp_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: intel: bdw: Constify snd_sof_dsp_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: imx8ulp: Constify snd_sof_dsp_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: core: add SOC_DOUBLE_RANGE_TLV() helper macro
  (jsc#PED-9993 jsc#PED-10202).
- commit 00c506f
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: SOF: imx8m: Constify snd_sof_dsp_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: imx8: Constify snd_sof_dsp_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: amd: acp: Constify snd_sof_dsp_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: intel: hda: Constify snd_sof_dsp_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: intel: pci-tng: Constify snd_sof_dsp_ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Constify stored pointer to snd_sof_dsp_ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: pcm: Constify local snd_sof_dsp_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: ipc3: Constify local snd_sof_dsp_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: debug: Constify local snd_sof_dsp_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Advertise passthrough capable PCMs
  (using ChainDMA) (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda: list SoundWire peripherals on mismatch
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda: simplify and reduce indentation for
  hda_sdw_machine_select() (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: topology: remove incorrect widget id in error message
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: debug: Handle cases when fw_lib_prefix is not set,
  NULL (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Add support for cs42l43-cs35l56 sidecar
  amps (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Add callbacks to register sidecar devices
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Delay update of the codec_conf array
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: add a space before cfg-amp in components
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof-sdw: don't set card long_name (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: Allocate snd_soc_card dynamically
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-lnl-match: adds RT714 and RT1318
  support (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi: mtl: add support for Acer Swift Go 14
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi: mtl: add Dell SKU 0C64 and 0CC6
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: skl_hda_dsp_generic: Use devm_kasprintf for the
  components string (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: skl_hda_dsp_generic: Allocate snd_soc_card
  dynamically (jsc#PED-9993 jsc#PED-10202).
- ASoC: sunxi: DMIC: Add controls for adjusting the mic gains
  (jsc#PED-9993 jsc#PED-10202).
- ASoc: PCM6240: Fix spelling mistake: "deley" -> "delay"
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l41: Delete unnecessary condition in
  cs35l41_pcm_hw_params() (jsc#PED-9993 jsc#PED-10202).
- ASoc: PCM6240: Create header file for PCM6240 Family driver code
  (jsc#PED-9993 jsc#PED-10202).
- ASoc: PCM6240: Create PCM6240 Family driver code (jsc#PED-9993
  jsc#PED-10202).
- commit 1dfdc67
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: avs: Switch to ACPI NHLT (jsc#PED-9993
  jsc#PED-10202).
- commit c21f9a2
* Thu Sep  5 2024 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_MT8186_MT6366=m
- supported.conf: update for the unified modules
- commit f79ea43
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: dapm: debugfs: show the widget type (jsc#PED-9993
  jsc#PED-10202).
- ASoC: dapm: debugfs: add component to route lines (jsc#PED-9993
  jsc#PED-10202).
- ASoC: nau8821: Remove redundant ADC controls (jsc#PED-9993
  jsc#PED-10202).
- ASoC: nau8821: Add delay control for ADC (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: Remove unused IRQ-related code (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: New IRQ handling implementation (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sunxi: sun4i-i2s: Fix pcm_formats type specification
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8186: Unify mt8186-mt6366 machine drivers
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: Use common mtk_afe_pcm_platform with common
  probe cb (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: Add common mtk_afe_component_probe callback
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8186-rt1019: Migrate to the common
  mtk_soundcard_startup (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8192: Migrate to the common
  mtk_soundcard_startup (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8195: Migrate to the common
  mtk_soundcard_startup (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: Add common snd_soc_ops .startup() callback
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8186: Migrate to mtk_soundcard_common_probe
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8192: Migrate to mtk_soundcard_common_probe
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8195: Migrate to mtk_soundcard_common_probe
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8188: Migrate to mtk_soundcard_common_probe
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: common: Constify struct mtk_sof_priv
  (jsc#PED-9993 jsc#PED-10202).
- commit 512c34a
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: mediatek: Add common machine soundcard driver probe
  mechanism (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl-asoc-card: add wm8904 codec support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sunxi: sun4i-i2s: Support 32-bit audio formats
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp-da7219-max98357a: Constify regulator_ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: samsung: i2s: Drop unneeded MODULE_ALIAS (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wcd934x: Drop unneeded MODULE_ALIAS (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: Support microphone from Acer Aspire A315-24P
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use RT5682S_PLL1 if needed
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: cml_rt1011_rt5682: delete driver (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_rt5682: support ALC1011 on cml boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_realtek_common: support 4xALC1011 amplifier
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: add mtl_da7219_def for mtl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: mach cleanup for rpl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: mach cleanup for adl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: remove FOUR_SPEAKER quirks (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: soc-acpi: add support for HP Omen14 SoundWire
  configuration (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: add missing sof_sdw_rt_amp_init for
  Realtek multi-function codecs (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: tas2780: remove redundant assignments to variable
  ret (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: davinci-i2s: Add T1 framing support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ti: davinci-i2s: Add S24_LE to supported formats
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: davinci-i2s: Link free-run mode to
  SND_SOC_DAIFMT_[GATED/CONT] (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: davinci-i2s: Enable unexpected frame pulses detection
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: davinci-i2s: Add handling of BP_FC format
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: davinci-i2s: Add TDM support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ti: davinci-i2s: Delete unnecessary assignment
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: davinci-i2s: Use external clock to drive sample rate
  generator (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: davinci-i2s: Replace dev_err with dev_err_probe
  (jsc#PED-9993 jsc#PED-10202).
- commit 69db77f
* Thu Sep  5 2024 tiwai@suse.de
- Update config files.
- commit 8b68be2
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: ti: davinci-i2s: Remove the unused clk_input_pin attribute
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: lnl: Add fw_regs area to debugfs map
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: mtl: Add fw_regs area to debugfs map
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: tgl: Add fw_regs area to debugfs map for IPC4
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: pcm: perform power-down delay checks a bit faster
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: fix for soundwire build dependencies for legacy stack
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: Fix uninitialized variable in probe
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: sc8280xp: Add support for QCM6490 and QCS6490
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-ctrl: only clear WAKESTS for HDaudio
  codecs (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-codec: preserve WAKEEN values
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: lnl: add helper to detect SoundWire wakes
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-ctrl: add missing WAKE_STS clear
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Rule invalid buffer and period sizes out
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Add assert_static to guarantee ABI sizes
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Init debugfs before booting firmware
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Wake from D0ix when starting streaming
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Remove dead code (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Replace risky functions with safer variants
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Fix config_length for config-less copiers
  (jsc#PED-9993 jsc#PED-10202).
- commit 1498adb
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: avs: Fix debug-slot offset calculation
  (jsc#PED-9993 jsc#PED-10202).
- commit a9bda87
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: avs: Silence false-positive memcpy() warnings
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Restore stream decoupling on prepare
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-stream: clarify comment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: don't ignore IOC interrupts for non-audio
  transfers (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-loader: change signature of code loader
  helpers (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-loader: add flag to tag ICCMAX stream
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Cleanup after ABI v4 support removal
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Remove ABI v4 support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: Skylake: Remove soc-topology ABI v4 support
  (jsc#PED-9993 jsc#PED-10202).
- commit fc82fed
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: SOF: Clean up sof_ipc_flood_dfs_write() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Disable pointless writes to debugfs file
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: imx: remove imx8_*_clocks API (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: imx: drop usage of the imx8_*_clocks API
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: nau8822: Remove unused member from struct (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm_adsp: Remove notification of driver write (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: hda_cs_dsp_ctl: Use
  cs_dsp_coeff_lock_and_[read|write]_ctrl() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm_adsp: Use cs_dsp_coeff_lock_and_[read|write]_ctrl()
  (jsc#PED-9993 jsc#PED-10202).
- firmware: cs_dsp: Add locked wrappers for coeff read and write
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: mtl: Correct the mtl_dsp_dump output
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-dsp/mtl: Add support for ACE ROM state
  codes (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda: Create debugfs file to force a clean
  DSP boot (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: rt5682: Constify card_headset_pins
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: rt5663: Constify card_headset_pins
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: rt298: Constify card_headset_pins
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: rt286: Constify card_headset_pins
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: rt274: Constify card_headset_pins
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: nau8825: Constify card_headset_pins
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: es8336: Constify card_headset_pins
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: hdaudio: Constify probing_link (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: Use devm_kstrdup_const (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: hdaudio: Use devm_kstrdup_const (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rsnd: no exception for SCU (jsc#PED-9993 jsc#PED-10202).
- ASoC: rsnd: R-Car Gen1/Gen2 exception (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rsnd: rename rsnd_is_e3() to rsnd_is_gen3_e3()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rsnd: don't get resource from ID (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rsnd: cleanup regmap table (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: remove shadowed variable (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: ipc4-priv: align prototype and function declaration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: acp-loader: abort firmware download on write
  error (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-loader: save FW version info to debugfs
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Save the ALH DAI index during
  hw_params (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: pcm: reset all PCM sources in case of xruns
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: pcm: add pending_stop state variable (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: pcm: simplify sof_pcm_hw_free() with helper
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: sof-audio: revisit sof_pcm_stream_free() error
  handling and logs (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda: Clear Soundwire node ID during BE DAI
  hw_free (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda: move helper to static inline
  (jsc#PED-9993 jsc#PED-10202).
- commit 3dcbc33
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: SOF: IPC4: extend dai_data with node_id (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: hda: extend signature of
  sdw_hda_dai_hw_params() (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: set the DMA TLV device as dai_index
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai: add helpers to set dai config
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai: set dma_stream_channel_map device
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai: set lowest N bits in ch_mask
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: make dma_config_tlv be an array (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai: fix channel map configuration for
  aggregated dailink (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-card: Use snd_ctl_find_id_mixer() instead of
  open-coding (jsc#PED-9993 jsc#PED-10202).
- ALSA: control: Introduce snd_ctl_find_id_mixer_locked()
  (jsc#PED-9993 jsc#PED-10202).
- commit 874d7c1
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: nau8325: Revise soc_enum structure definition
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: nau8325: new driver (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: add mtl_cs42l42_def for mtl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: add rpl_cs42l42_def for rpl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: mach cleanup for adl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: board id cleanup for adl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: mach cleanup for mtl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: mach cleanup for rpl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: mach cleanup for adl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: mach cleanup for tgl boards
  (jsc#PED-9993 jsc#PED-10202).
- commit 4e8ed2e
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: sof_nau8825: mach cleanup for rpl boards
  (jsc#PED-9993 jsc#PED-10202).
- commit fe8e542
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: sof_nau8825: add mtl_nau8825_def for mtl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: mach cleanup for adl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: support tplg suffix detection (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: ssp-common: get codec tplg suffix function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: ssp-common: delete module (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: ssp-common: module name change (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: ssp-common: naming convention change (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: ssp-common: relocate header file (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: ssp-common: relocate source file (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sdw-mockup: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt722-sdca-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt715-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt715-sdca-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt712-sdca-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt712-sdca-dmic: drop driver owner assignment
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt711-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt711-sdca-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt700-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5682-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt1318-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt1316-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt1308-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt1017-sdca-sdw: drop driver owner assignment
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: max98373-sdw: drop driver owner assignment (jsc#PED-9993
  jsc#PED-10202).
- ASoC: tlv320aic3x-spi: drop driver owner assignment
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: tlv320aic32x4-spi: drop driver owner assignment
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: sun8i-codec: Fix build with CONFIG_SND_JACK_INPUT_DEV
  disabled (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Add support for cs42l43 optional speaker
  output (jsc#PED-9993 jsc#PED-10202).
- commit ebe58be
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: sof_sdw: Add quirk for optional codec speakers
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Remove redundant initialisations
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Don't pass acpi_link_adr to init functions
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: change cs35l56 name_prefix (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: change rt715-sdca dai name (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt715-sdca: rename dai name with rt715-sdca prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt722_sdca: use rt_dmic_rtd_init
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt722_sdca: set rtd_init in
  codec_info_list[] (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: remove unused rt dmic rtd_init
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: use generic rtd_init function for Realtek
  SDW DMICs (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Factor out SoundWire DAI creation
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Move generation of DAI links to new
  parsing (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Move append_dai_type to new parsing
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Move ignore_pch_dmic to new parsing
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Move counting and codec_conf to new
  parsing (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof-sdw: Add new code for parsing the snd_soc_acpi
  structs (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: soc-acpi: Add missing cs42l43 endpoints
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Remove no longer supported quirk
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-arl-match: Add rt711 sdca codec
  support (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Factor out codec name generation
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Factor out BlueTooth DAI creation
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Factor out HDMI DAI creation (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: Factor out DMIC DAI creation (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: Factor out SSP DAI creation (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: Use for_each_set_bit (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: Only pass dai_link pointer around
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Move flags to private struct (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: Move get_codec_dai_by_name() into sof_sdw
  itself (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Set channel map directly from endpoints
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Only pass codec_conf pointer around
  (jsc#PED-9993 jsc#PED-10202).
- commit ec776c3
* Thu Sep  5 2024 tiwai@suse.de
- atm: idt77252: prevent use after free in dequeue_rx()
  (CVE-2024-44998 bsc#1230171).
- commit fd57936
* Thu Sep  5 2024 sjaeckel@suse.de
- tcp: add sanity checks to rx zerocopy (CVE-2024-26640
  bsc#1221650).
- commit 21286c2
* Thu Sep  5 2024 nik.borisov@suse.com
- EDAC/skx: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 1a1bbd0
* Thu Sep  5 2024 nik.borisov@suse.com
- EDAC/sb_edac: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 45532f1
* Thu Sep  5 2024 nik.borisov@suse.com
- EDAC, pnd2: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 0594193
* Thu Sep  5 2024 nik.borisov@suse.com
- EDAC/i10nm: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit a6f1745
* Thu Sep  5 2024 nik.borisov@suse.com
- perf/x86/rapl: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 2f9fc15
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/boot: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit cec675a
* Thu Sep  5 2024 nik.borisov@suse.com
- perf/x86/intel: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit fdcacce
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/virt/tdx: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 60ad2f1
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/PCI: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit a330e17
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/cpu/intel: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 03ec745
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/platform/intel-mid: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 038d379
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/cpu: Fix x86_match_cpu() to match just X86_VENDOR_INTEL (jsc#PED-10246,jsc#PED-10350).
- commit 4dbaa29
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/mm: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 2517203
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/tsc: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 6402adf
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/resctrl: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- Refresh
  patches.suse/x86-resctrl-Prepare-for-new-Sub-NUMA-Cluster-SNC-monitor-f.patch.
- commit ae4e002
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/microcode/intel: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 8a97502
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/mce: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit cdf96db
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/cpu: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 3377036
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/cpu/intel_epb: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 07e24f8
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/aperfmperf: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit c68ac51
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/apic: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit e1ea1ad
* Thu Sep  5 2024 nik.borisov@suse.com
- perf/x86/msr: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit d282aab
* Thu Sep  5 2024 nik.borisov@suse.com
- perf/x86/intel/uncore: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 28da6e3
* Thu Sep  5 2024 nik.borisov@suse.com
- perf/x86/intel/pt: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit a2edaca
* Thu Sep  5 2024 nik.borisov@suse.com
- perf/x86/lbr: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 92fe0bc
* Thu Sep  5 2024 nik.borisov@suse.com
- perf/x86/intel/cstate: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit c31a98b
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/bugs: Switch to new Intel CPU model defines (jsc#PED-10246,jsc#PED-10350).
- commit 54b534f
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/cpu/vfm: Update arch/x86/include/asm/intel-family.h (jsc#PED-10246,jsc#PED-10350).
- commit ed3ff00
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/cpu/vfm: Add new macros to work with (vendor/family/model) values (jsc#PED-10246,jsc#PED-10350).
- commit 67d1d8f
* Thu Sep  5 2024 nik.borisov@suse.com
- x86/cpu/vfm: Add/initialize x86_vfm field to struct cpuinfo_x86 (jsc#PED-10246,jsc#PED-10350).
- commit 038477f
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: intel: sof_sdw: Make find_codec_info_dai() return a
  pointer (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Make find_codec_info_acpi() return a
  pointer (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Make find_codec_info_part() return a
  pointer (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-jack: Get rid of legacy GPIO support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sun8i-codec: Implement jack and accessory detection
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: sun50i-codec-analog: Enable jack detection on startup
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: sun8i-codec: Enable bus clock at STANDBY and higher bias
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: sun50i-codec-analog: Move suspend/resume to set_bias_level
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Delete unused REG_SUPPLY (jsc#PED-9993
  jsc#PED-10202).
- commit afaf0e7
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: codecs: ES8326: Reducing power consumption (jsc#PED-9993
  jsc#PED-10202).
- commit a1f576d
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: dmaengine_pcm: Allow passing component name via config
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: i2s_test: Remove redundant dapm routes
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: ssm4567: Board cleanup (jsc#PED-9993
  jsc#PED-10202).
- ASoC: topology: Do not ignore route checks when parsing graphs
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: imx-rpmsg: Update to correct DT node (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: fsl_rpmsg: Register CPU DAI with name of rpmsg
  channel (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: Let imx-audio-rpmsg register platform device for card
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: imx-audio-rpmsg: Register device with rpmsg channel
  name (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: imx-pcm-rpmsg: Register component with rpmsg channel
  name (jsc#PED-9993 jsc#PED-10202).
- commit 654707f
* Thu Sep  5 2024 tiwai@suse.de
- Update config files: CONFIG_ACPI_NHLT=y (jsc#PED-9993 jsc#PED-10202)
- commit 5ba1b88
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: sof_rt5682: board id cleanup for cml boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: remove sof_nau8825 board id
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: remove unnecessary idisp HDMI quirk
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: remove unnecessary idisp HDMI quirk
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: board id cleanup for rpl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: board id cleanup for adl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: board id cleanup for jsl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: add SOF_DA7219_MCLK_EN quirk
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: add codec exit function (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_da7219: use common module for DAI link
  generation (jsc#PED-9993 jsc#PED-10202).
- commit 7dae8eb
* Thu Sep  5 2024 tiwai@suse.de
- ASoC: Intel: sof_ssp_amp: use common module for sof_card_private
  initialization (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use common module for sof_card_private
  initialization (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: use common module for sof_card_private
  initialization (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: use common module for sof_card_private
  initialization (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: support sof_card_private
  initialization (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: rename BT offload quirk (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_rt5682: support ALC5650 on RPL boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: add rpl_mx98360_da7219 board config
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: change dai link helpers to static
  function (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: use common module for DAI link
  generation (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: support DAI link ID customization
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: Commonize ADDA rate transform functions and
  enums (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8192-afe-pcm: Simplify with dev_err_probe()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8192-afe-pcm: Convert to
  devm_pm_runtime_enable() (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-dai: Note valid values of sysclock direction
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: hdac_hda: improve error logs (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: imx-es8328: Remove leftover gpio initialisation
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: imx-es8328: Switch to using gpiod API (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: fsl_ssi: Add dev_err_probe if PCM DMA init fails
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: simplify soundwire dependencies for legacy stack
  (jsc#PED-9993 jsc#PED-10202).
- commit c99ecb5
* Thu Sep  5 2024 tiwai@suse.de
- ACPI: NHLT: Streamline struct naming (jsc#PED-9993
  jsc#PED-10202).
- commit 8eb615f
* Thu Sep  5 2024 tiwai@suse.de
- ALSA: core: Remove superfluous CONFIG_PM (jsc#PED-9993
  jsc#PED-10202).
- ASoC: audio-graph-card2: call of_node_get() before
  of_get_next_child() (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: Correct spaces in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: boards: Properly name input device
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: fix for acp platform device creation failure
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: intel-dsp-config: Switch to ACPI NHLT (jsc#PED-9993
  jsc#PED-10202).
- ALSA: pcm_dmaengine: Add missing module description
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: hda_component: Initialize shared data during bind
  callback (jsc#PED-9993 jsc#PED-10202).
- ACPI: NHLT: Drop redundant types (jsc#PED-9993 jsc#PED-10202).
- ACPI: NHLT: Introduce API for the table (jsc#PED-9993
  jsc#PED-10202).
- ACPI: NHLT: Reintroduce types the table consists of
  (jsc#PED-9993 jsc#PED-10202).
- commit 3757eaa
* Thu Sep  5 2024 tiwai@suse.de
- ALSA: pci: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- commit 6e1a80a
* Thu Sep  5 2024 tiwai@suse.de
- ALSA: hda: conexant: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ALSA-hda-conexant-Fix-headset-auto-detect-fail-in-th.patch.
- commit 867b79f
* Thu Sep  5 2024 tiwai@suse.de
- ALSA: hda: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ALSA: core: Use *-y instead of *-objs in Makefile (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: via: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: sigmantel: Reduce CONFIG_PM dependencies
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: realtek: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: hdmi: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: cs4809: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: cirrus: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- commit b9c22eb
* Thu Sep  5 2024 tiwai@suse.de
- ALSA: hda: ca0132: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: analog: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: generic: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: codec: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: intel: Reduce CONFIG_PM dependencies (jsc#PED-9993
  jsc#PED-10202).
- ASoC: meson: axg-tdm: add continuous clock support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l56: fix usages of device_get_named_child_node()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Avoid static analysis warning of uninitialised
  variable (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Core: Handle error returned by
  sof_select_ipc_and_paths (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-pcm: Do not reset the ChainDMA if it has not
  been allocated (jsc#PED-9993 jsc#PED-10202).
- commit 97a76e9
* Thu Sep  5 2024 tiwai@suse.de
- ALSA: control: Use list_for_each_entry_safe() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: dummy: Allow UMP conversion (jsc#PED-9993
  jsc#PED-10202).
- ALSA: pcm: add support for 705.6kHz and 768kHz sample rates
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-pcm: Introduce generic sof_ipc4_pcm_stream_priv
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-pcm: Use consistent name for
  sof_ipc4_timestamp_info pointer (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-pcm: Use consistent name for snd_sof_pcm_stream
  pointer (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: debug: show firmware/topology prefix/names
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Fix debug window description (jsc#PED-9993
  jsc#PED-10202).
- commit 0e10462
* Thu Sep  5 2024 tiwai@suse.de
- ALSA: hda: Intel: Select AZX_DCAPS_PIO_COMMANDS for Lunar Lake
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ALSA-hda-Add-Intel-BMG-PCI-ID-and-HDMI-codec-vid.patch.
- commit c335ee1
* Thu Sep  5 2024 tiwai@suse.de
- ALSA: hda: cs35l41: Use shared cs-amp-lib to apply calibration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-bus: Use PIO mode for Lunar Lake
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: pci: hda: hda_controller: Add support for
  use_pio_for_commands mode (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: hdac_controller: Implement support for
  use_pio_for_commands mode (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Introduce flags to force commands via PIO instead
  of CORB (jsc#PED-9993 jsc#PED-10202).
- commit b3990a8
* Thu Sep  5 2024 oneukum@suse.com
- USB: serial: option: add MeiG Smart SRM825L (git-fixes).
- commit 047a639
* Thu Sep  5 2024 ailiop@suse.com
- nilfs2: fix state management in error path of log writing
  function (git-fixes).
- commit 9b55988
* Thu Sep  5 2024 oneukum@suse.com
- cdc-acm: Add DISABLE_ECHO quirk for GE HealthCare UI Controller
  (git-fixes).
- commit a322b71
* Thu Sep  5 2024 oneukum@suse.com
- usb: dwc3: core: Prevent USB core invalid event buffer address
  access (git-fixes).
- commit de7b6b3
* Thu Sep  5 2024 ailiop@suse.com
- nilfs2: fix missing cleanup on rollforward recovery error
  (git-fixes).
- commit b4149d3
* Thu Sep  5 2024 ailiop@suse.com
- nilfs2: protect references to superblock parameters exposed
  in sysfs (git-fixes).
- commit e7215f6
* Thu Sep  5 2024 iivanov@suse.de
- arm64: tlb: Allow range operation for MAX_TLBI_RANGE_PAGES (bsc#1229585)
- commit a52467b
* Thu Sep  5 2024 iivanov@suse.de
- arm64: tlb: Improve __TLBI_VADDR_RANGE() (bsc#1229585)
- commit 26752eb
* Thu Sep  5 2024 iivanov@suse.de
- arm64: tlb: Fix TLBI RANGE operand (bsc#1229585)
- commit 24bd468
* Thu Sep  5 2024 iivanov@suse.de
- blacklist.conf: ("KVM: arm64: Use TLBI_TTL_UNKNOWN in __kvm_tlb_flush_vmid_range()") (bsc#1229585)
- commit 29fbf2b
* Thu Sep  5 2024 iivanov@suse.de
- arm64/mm: Update tlb invalidation routines for FEAT_LPA2 (bsc#1229585)
- commit b8ec0d4
* Thu Sep  5 2024 iivanov@suse.de
- arm64/mm: Modify range-based tlbi to decrement scale (bsc#1229585)
- commit e08c708
* Thu Sep  5 2024 tiwai@suse.de
- Refresh patches.suse/ASoC-qcom-sc8280xp-Limit-speaker-digital-volumes.patch
- commit 2841ede
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: add more debugfs stub helpers (drm-backport-placeholder)
- commit e599ffd
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: refactor error info reset (drm-backport-placeholder)
- commit 9e3c36a
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: add event queue extra validation (drm-backport-placeholder)
- commit a16d367
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: unsecure TSB_CFG_MTRR regs (drm-backport-placeholder)
- commit 0bfa42e
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: move ioctl error print to debug level (drm-backport-placeholder)
- commit dd1fe80
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: fix bug of not fetching addr_dec info (drm-backport-placeholder)
- commit 31d61be
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: remove sim code (drm-backport-placeholder)
- commit 21f0745
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: mask part of hmmu page fault captured address (drm-backport-placeholder)
- commit d69018e
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: update state when loading boot fit (drm-backport-placeholder)
- commit 863b714
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: print qman data on error only for lower qman (drm-backport-placeholder)
- commit 55021cc
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: use lower QM in QM errors handling (drm-backport-placeholder)
- commit 99db81d
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: use binning info when handling razwi (drm-backport-placeholder)
- commit 7280d33
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: remove support for mmu disable (drm-backport-placeholder)
- commit d4f957f
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: upon DMA errors, use FW-extracted error cause (drm-backport-placeholder)
- commit b9ac16e
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: print max timeout value on CS stuck (drm-backport-placeholder)
- commit 741aa37
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: align to latest firmware specs (drm-backport-placeholder)
- commit 406dc54
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: set unused bit as reserved (drm-backport-placeholder)
- commit 90304be
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: rename security functions related arguments (drm-backport-placeholder)
- commit e930ca4
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: Fix some kernel-doc comments (drm-backport-placeholder)
- commit b22aa41
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: always fetch pci addr_dec error info (drm-backport-placeholder)
- commit e035d51
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: fix a static warning - 'dubious: x & !y' (drm-backport-placeholder)
- commit 4dbbfff
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: poll for device status update following WFE cmd (drm-backport-placeholder)
- commit 4dca9dc
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: expose debugfs files later (drm-backport-placeholder)
- commit 94925df
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: add missing tpc interrupt info (drm-backport-placeholder)
- commit 69d2f49
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: refactor abort of completions and waits (drm-backport-placeholder)
- commit 6e30b02
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: minimize encapsulation signal mutex lock time (drm-backport-placeholder)
- commit 8c7a31f
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: call to HW/FW err returns 0 when no events exist (drm-backport-placeholder)
- commit 44d31b0
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: unsecure TPC bias registers (drm-backport-placeholder)
- commit 7e2be8c
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: do soft-reset using cpucp packet (drm-backport-placeholder)
- commit 296b973
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: check fw version using sw version (drm-backport-placeholder)
- commit f81ab67
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: extract and save the FW's SW major/minor/sub-minor (drm-backport-placeholder)
- commit 55f0e9e
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: rename fw_{major/minor}_version to (drm-backport-placeholder)
- commit fc725bb
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: add helper to extract the FW major/minor (drm-backport-placeholder)
- commit 5a7bac6
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: fix bug in free scratchpad memory (drm-backport-placeholder)
- commit ee8dfc4
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: remove commented code that won't be used (drm-backport-placeholder)
- commit 0992b7d
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: allow user to modify EDMA RL register (drm-backport-placeholder)
- commit 3bd1fc9
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: ignore false positive razwi (drm-backport-placeholder)
- commit 7fa1a0f
* Thu Sep  5 2024 pjakobsson@suse.de
- accel/habanalabs: remove variable gaudi_irq_name (drm-backport-placeholder)
- commit b273bfe
* Thu Sep  5 2024 pjakobsson@suse.de
- drm/gma500: Clear fbdev framebuffer with fb_memset_io() (drm-backport-placeholder)
- commit aa5cd8d
* Thu Sep  5 2024 pjakobsson@suse.de
- x86/fbdev: Include asm/fb.h as needed (drm-backport-placeholder).
- Refresh patches.suse/0012-arch-x86-Include-asm-fb.h-in-fbdev-source-file.patch.
- commit 444a024
* Thu Sep  5 2024 tiwai@suse.de
- USB: serial: option: add MeiG Smart SRM825L (stable-fixes).
- cdc-acm: Add DISABLE_ECHO quirk for GE HealthCare UI Controller
  (stable-fixes).
- usb: dwc3: core: Prevent USB core invalid event buffer address
  access (stable-fixes).
- selinux,smack: don't bypass permissions check in inode_setsecctx
  hook (stable-fixes).
- drm/amdgpu/swsmu: always force a state reprogram on init
  (stable-fixes).
- drm/amdgpu: align pp_power_profile_mode with kernel docs
  (stable-fixes).
- commit 1d64229
* Thu Sep  5 2024 tiwai@suse.de
- supported.conf: mark soundwire-amd as supported (jsc#PED-9993 jsc#PED-10202)
- commit c51ed92
* Thu Sep  5 2024 tiwai@suse.de
- Refresh patches.suse/ASoC-mediatek-Assign-dummy-when-codec-not-specified-.patch
  Fix the build
- commit 5e84cf7
* Wed Sep  4 2024 krisman@suse.de
- Resort io_uring kABI patches
  These ended up in the wrong section.  Push them to the right place, next
  to the other io_uring kabi patches.
- commit f218522
* Wed Sep  4 2024 krisman@suse.de
- kABI: Split kABI out of 'io_uring: Re-add dummy_ubuf for kABI purposes'
  When introducing this patch, I merged the kABI patch with the actual
  backport, which is not recommended.  Split it up, such that the backport
  is similar to the upstream patch and handle the kABI issue exactly the
  same way, but through a separate kABI patch.
- commit 5b3aa8f
* Wed Sep  4 2024 krisman@suse.de
- kABI: Split kABI out of 'io_uring/kbuf: get rid of bl->is_ready'
  When introducing this patch, I merged the kABI patch with the actual
  backport, which is not recommended.  Split it up, such that the backport
  is similar to the upstream patch and handle the kABI issue exactly the
  same way, but through a separate kABI patch.
- commit d39d376
* Wed Sep  4 2024 jack@suse.cz
- ext4: sanity check for NULL pointer after ext4_force_shutdown
  (bsc#1229753 CVE-2024-43898).
- commit d9361cb
* Wed Sep  4 2024 jack@suse.cz
- udf: Fix bogus checksum computation in udf_rename() (bsc#1229389
  CVE-2024-43845).
- commit 985c73e
* Wed Sep  4 2024 jack@suse.cz
- ext4: fix infinite loop when replaying fast_commit (bsc#1229394
  CVE-2024-43828).
- commit c9c168b
* Wed Sep  4 2024 jack@suse.cz
- block: fix deadlock between sd_remove & sd_release (bsc#1229371
  CVE-2024-42294).
- commit a556834
* Wed Sep  4 2024 jack@suse.cz
- udf: Avoid using corrupted block bitmap buffer (bsc#1229362
  CVE-2024-42306).
- commit 26b3a5d
* Wed Sep  4 2024 jack@suse.cz
- ext4: check dot and dotdot of dx_root before making dir indexed
  (bsc#1229363 CVE-2024-42305).
- commit d42c7e5
* Wed Sep  4 2024 jack@suse.cz
- mm/filemap: make MAX_PAGECACHE_ORDER acceptable to xarray
  (bsc#1229001 CVE-2024-42243).
- commit 962c57e
* Wed Sep  4 2024 jack@suse.cz
- protect the fetch of ->fd[fd] in do_dup2() from mispredictions
  (bsc#1229334 CVE-2024-42265).
- commit 1088a58
* Wed Sep  4 2024 jack@suse.cz
- ext4: make sure the first directory block is not a hole
  (bsc#1229364 CVE-2024-42304).
- commit 0ee54f7
* Wed Sep  4 2024 davide.benini@suse.com
- netfilter: ctnetlink: use helper function to calculate expect ID
  (CVE-2024-44944 bsc#1229899).
- commit da9b5c6
* Wed Sep  4 2024 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_CS_AMP_LIB=m (jsc#PED-9993 jsc#PED-10202)
- commit e129bc9
* Wed Sep  4 2024 tiwai@suse.de
- Revert "ALSA: usb-audio: Skip setting clock selector for single
  connections" (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ALSA-usb-audio-Ignore-clock-selector-errors-for-sing.patch.
- commit 88f95f4
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: usb-audio: Support read-only clock selector control
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ALSA-usb-audio-Ignore-clock-selector-errors-for-sing.patch.
- commit d95b38c
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: usb-audio: Skip setting clock selector for single
  connections (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ALSA-usb-audio-Ignore-clock-selector-errors-for-sing.patch.
- commit 28075b6
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: scarlett2: Fix Scarlett 4th Gen input gain range again
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Fix Scarlett 4th Gen input gain range
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Fix Scarlett 4th Gen autogain status values
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Fix Scarlett 4th Gen 4i4 low-voltage detection
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Fix yet more -Wformat-truncation warnings
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add PCM Input Switch for Solo Gen 4
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add support for Solo, 2i2, and 4i4 Gen 4
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add R/O headphone volume control (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Add minimum firmware version check
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Rename DSP mux channels (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Add support for DSP mux channels (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Add support for custom Gen 4 Direct Monitor
  mixes (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Handle Gen 4 Direct Monitor mix updates
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Store mix_ctls for Gen 4 Direct Monitor
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add power status control (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Disable autogain during phantom power state
  change (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Disable input controls while autogain is
  running (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Minor refactor MSD mode check (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Add support for software-controllable input
  gain (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add support for Air Presence + Drive option
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Allow for controls with a "mute mode"
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add support for Gen 4 style parameters
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add support for air/phantom control on input 2
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Remove repeated elem->head.mixer references
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Split direct_monitor out from monitor_other
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Split input_other into level/pad/air/phantom
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Rename db_scale_scarlett2_gain to volume
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add #define for SCARLETT2_MIX_MAX (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Add scarlett2_mixer_value_to_db() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Allow for interfaces without per-channel volume
  (jsc#PED-9993 jsc#PED-10202).
- commit 84eef3b
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: scarlett2: Remove line_out_hw_vol device info entry
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Split dim_mute_update from vol_updated
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Remove struct scarlett2_usb_volume_status
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Refactor common port_count lookups
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Change num_mux_* from int to u8 (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Parameterise notifications (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Formatting fixes (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Refactor scarlett2_config_save() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Refactor scarlett2_usb_set_config()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add check for config_item presence
  (jsc#PED-9993 jsc#PED-10202).
- commit d635a33
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: scarlett2: Remove scarlett2_config_sets array
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add config set struct (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Check presence of mixer using mux_assignment
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Check for phantom persistence config item
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Infer standalone switch from config items
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Infer has_msd_mode from config items
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Simplify enums by removing explicit values
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add support for uploading new firmware
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add ioctl commands to erase flash segments
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add skeleton hwdep/ioctl interface
  (jsc#PED-9993 jsc#PED-10202).
- commit 374a7bf
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: scarlett2: Allow passing any output to line_out_remap()
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ALSA-scarlett2-Add-missing-error-checks-to-_ctl_get.patch.
- commit 4c745d6
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: scarlett2: Retrieve useful flash segment numbers
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add #defines for firmware upgrade (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Add missing mutex lock around get meter levels
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Update maintainer info (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Convert meter levels from little-endian
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Add missing check with firmware version control
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Remap Level Meter values (jsc#PED-9993
  jsc#PED-10202).
- ALSA: scarlett2: Add support for reading firmware version
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: scarlett2: Rename Gen 3 config sets (jsc#PED-9993
  jsc#PED-10202).
- commit d1c0361
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: scarlett2: Rename scarlett_gen2 to scarlett2 (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ALSA-scarlett2-Add-clamp-in-scarlett2_mixer_ctl_put.patch.
- Refresh
  patches.suse/ALSA-scarlett2-Add-missing-error-check-to-scarlett2_-5f6ff69.patch.
- Refresh
  patches.suse/ALSA-scarlett2-Add-missing-error-check-to-scarlett2_.patch.
- Refresh
  patches.suse/ALSA-scarlett2-Add-missing-error-checks-to-_ctl_get.patch.
- commit 4a34466
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: caiaq: Replace with __packed attribute (jsc#PED-9993
  jsc#PED-10202).
- ALSA: usx2y: Annotate struct snd_usx2y_urb_seq with __counted_by
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: usb-audio: scarlett_gen2: Fix another -Wformat-truncation
  warning (jsc#PED-9993 jsc#PED-10202).
- ALSA: caiaq: Fix -Wformat-truncation warning (jsc#PED-9993
  jsc#PED-10202).
- ALSA: usb-audio: scarlett_gen2: Fix -Wformat-truncation warning
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: usb-audio: mixer: Remove temporary string use in
  parse_clock_source_unit (jsc#PED-9993 jsc#PED-10202).
- ALSA: usb-audio: Remove unused function declaration
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: bcd2000: refactor deprecated strncpy (jsc#PED-9993
  jsc#PED-10202).
- commit 04e86fa
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: hda: Add pplcllpl/u members to hdac_ext_stream
  (jsc#PED-9993 jsc#PED-10202).
- commit 5ff47d9
* Wed Sep  4 2024 tiwai@suse.de
- ptrace: Convert ptrace_attach() to use lock guards (jsc#PED-9993
  jsc#PED-10202).
- cleanup: Add conditional guard support (jsc#PED-9993
  jsc#PED-10202).
- commit 86c77b1
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: SOF: Core: Add remove_late() to sof_init_environment
  failure path (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: fix for false dsp interrupts (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: lnl: Disable DMIC/SSP offload on remove
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Removing the control of ADC_SCALE
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Solve a headphone detection issue after
  suspend and resume (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: modify clock table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: ES8326: Solve error interruption issue
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: boards: Add modules description (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt-sdw*: add __func__ to all error logs (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: acp: fix for acp pdm configuration check
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda: Compensate LLP in case it is not reset
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-pcm: Correct the delay calculation (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: sof-pcm: Add pointer callback to sof_ipc_pcm_ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-pcm: Invalidate the stream_start_offset in
  PAUSED state (jsc#PED-9993 jsc#PED-10202).
- commit 708daa0
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: SOF: ipc4-pcm: Combine the SOF_IPC4_PIPE_PAUSED cases
  in pcm_trigger (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-pcm: Move struct sof_ipc4_timestamp_info
  definition locally (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Remove the get_stream_position callback (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: hda-common-ops: Do not set the
  get_stream_position callback (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-pcm: Use the snd_sof_pcm_get_dai_frame_counter()
  for pcm_delay (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: Set the dai/host get frame/byte counter
  callbacks (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Introduce a new callback pair to be used for PCM
  delay reporting (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: mtl/lnl: Use the generic get_stream_position
  callback (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda: Implement get_stream_position (Linear
  Link Position) (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-pcm: Use dsp_max_burst_size_in_ms to
  place constraint (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Save the DMA maximum burst size for
  PCMs (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Add dsp_max_burst_size_in_ms member to
  snd_sof_pcm_stream (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Correct extraction of data pointer in
  suspend/resume (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: mtrace: rework mtrace timestamp setting (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs-amp-lib: Check for no firmware controls when writing
  calibration (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda/tas2781: remove useless dev_dbg from playback_hook
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda/tas2781: add debug statements to kcontrols
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: cs35l56: Raise device name message log level
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: support NHLT device type (jsc#PED-9993
  jsc#PED-10202).
- commit 807355b
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: hda: intel-nhlt: add intel_nhlt_ssp_device_type() function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-compress: Fix and add DPCM locking (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: amd: Skip IRAM/DRAM size modification for Steam
  Deck OLED (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: Move signed_fw_image to struct acp_quirk_entry
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: yc: Revert "add new YC platform variant (0x63)
  support" (jsc#PED-9993 jsc#PED-10202).
- ALSA: control: Fix unannotated kfree() cleanup (jsc#PED-9993
  jsc#PED-10202).
- ALSA: timer: Fix missing irq-disable at closing (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: catpt: Carefully use PCI bitwise constants
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Changing members of private structure
  (jsc#PED-9993 jsc#PED-10202).
- commit f052e70
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: trace: add event to snd_soc_dapm trace events
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: trace: add component to set_bias_level trace events
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: atom: sst_ipc: Remove unused intel-mid.h
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-core.c: Prefer to return dai->driver->name in
  snd_soc_dai_name_get() (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Prevent bad sign extension in
  cs35l56_read_silicon_uid() (jsc#PED-9993 jsc#PED-10202).
- ASoC: meson: axg-fifo: take continuous rates (jsc#PED-9993
  jsc#PED-10202).
- ASoC: meson: axg-spdifin: use max width for rate detection
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: meson: axg-tdm-interface: update error format error traces
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: rt5660: Simplify mclk initialization (jsc#PED-9993
  jsc#PED-10202).
- commit ef7403b
* Wed Sep  4 2024 tiwai@suse.de
- Refresh patches.suse/ASoC-generic-convert-not-to-use-asoc_xxx.patch
- commit fd7906d
* Wed Sep  4 2024 oneukum@suse.com
- media: v4l: async: Add some debug prints (jsc#PED-8643).
- Refresh
  patches.suse/media-v4l-async-Clean-up-testing-for-duplicate-async.patch.
- Refresh
  patches.suse/media-v4l-async-Make-V4L2-async-match-information-a-.patch.
- Refresh
  patches.suse/media-v4l-async-Rename-V4L2_ASYNC_MATCH_-macros-add-.patch.
- commit a83eedd
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: cs35l56: Apply amp calibration from EFI data (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ASoC-cs35l56-Fix-unintended-bus-access-while-resetti.patch.
- Refresh
  patches.suse/ASoC-cs35l56-Prevent-overwriting-firmware-ASP-config.patch.
- commit d6bb28b
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: cs35l56: Add helper functions for amp calibration
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-cs35l56-Prevent-overwriting-firmware-ASP-config.patch.
- commit b5d27dd
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: codecs: rt5640: Simplify mclk initialization (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: rt5616: Simplify mclk initialization (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: rt5514: Simplify mclk initialization (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: nau8825: Simplify mclk initialization
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: da7213: Simplify mclk initialization (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: tx-macro: correct TX SMIC MUXn widgets on SM8350+
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: tx-macro: split widgets per different LPASS
  versions (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: cs35l56: Apply amp calibration from EFI data
  (jsc#PED-9993 jsc#PED-10202).
- commit 7ddf902
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: Intel: avs: TGL-based platforms support (jsc#PED-9993
  jsc#PED-10202).
- commit 8f33595
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: Intel: avs: ICL-based platforms support (jsc#PED-9993
  jsc#PED-10202).
- commit b044b28
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: Intel: avs: CNL-based platforms support (jsc#PED-9993
  jsc#PED-10202).
- commit b624180
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: cs-amp-lib: Add helpers for factory calibration data
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm_adsp: Add wm_adsp_start() and wm_adsp_stop()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-core: tidyup strcmp() param on
  snd_soc_is_matching_dai() (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: ps: modify ACP register end address macro
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: ps: update license (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wsa884x: Allow sharing reset GPIO (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: ICCMAX recommendations for ICL+ platforms
  (jsc#PED-9993 jsc#PED-10202).
- commit b4c9a2d
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: Intel: avs: Abstract IRQ handling (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: Abstract IPC handling (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: Prefix SKL/APL-specific members (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: Fix sound clipping in single capture scenario
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: L1SEN reference counted (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l42: Remove redundant delays in suspend()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: tas2781: Remove redundant initialization of pointer 'data'
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: fix soundwire dependencies (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: ps: add machine select and register code
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: ps: fix for acp pme wake for soundwire configuration
  (jsc#PED-9993 jsc#PED-10202).
- commit 92bbc5e
* Wed Sep  4 2024 tiwai@suse.de
- Update config files. (jsc#PED-9993 jsc#PED-10202)
- commit a45c76f
* Wed Sep  4 2024 oneukum@suse.com
- media: v4l: async: Rename V4L2_ASYNC_MATCH_ macros, add TYPE_
  (jsc#PED-8643).
- commit e8464cd
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: amd: ps: remove acp_reset flag (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: ps: refactor acp child platform device creation code
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: ps: refactor acp device configuration read logic
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Constify pointer to of_phandle_args (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: remove redundant 'tristate' in
  sound/soc/codecs/Kconfig (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai: add support for dspless mode beyond
  HDAudio (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: lnl: Do not use LNL specific wrappers in
  DSPless mode (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai-ops: add SoundWire dspless mode
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai-ops: use dai_type (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: topology: Parse DAI type token for dspless mode
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: start SoundWire links earlier for LNL+
  devices (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: topology: dynamically allocate and store DAI
  widget->private (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai: remove dspless special case
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: allow chain_dma for all supported DAIs
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-pcm: fix dma_id for CHAIN_DMA capture
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4: store number of playback/capture streams
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-dai-ops: enable chain_dma for ALH
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda: add 'is_chain_dma_supported' callback
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ops: add new 'is_chain_dma_supported' callback
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: change chain_dma handling in
  dai_config (jsc#PED-9993 jsc#PED-10202).
- commit ad61e3b
* Wed Sep  4 2024 tiwai@suse.de
- supported.conf: sync for 6.9 (jsc#PED-9993 jsc#PED-10202)
- commit 41dc584
* Wed Sep  4 2024 oneukum@suse.com
- media: v4l: async: Make V4L2 async match information a struct
  (jsc#PED-8643).
- commit 1024e9a
* Wed Sep  4 2024 tiwai@suse.de
- Update config files: sync with 6.9 (jsc#PED-9993 jsc#PED-10202)
- commit 6fa7644
* Wed Sep  4 2024 oneukum@suse.com
- media: v4l: async: Clean up testing for duplicate async subdevs
  (jsc#PED-8643).
- commit 20947e2
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: codecs: tx-macro: Simplify setting AMIC control
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: tx-macro: Mark AMIC control registers as volatile
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: tx-macro: Drop unimplemented DMIC clock divider
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: va-macro: add npl clk (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: ipc4-topology: set config_length based on
  device_count (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Fix runtime pm usage counter balance after fw
  exception (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: fix TYPO 'reguest' to 'request' in error log
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: imx: Add devicetree support to select topologies
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Expose FW version with sysfs (jsc#PED-9993
  jsc#PED-10202).
- ASoC: tas2781: remove unused acpi_subysystem_id (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: starts non sdw BE id with the highest
  sdw BE id (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-lnl-match: Add rt722 support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi: add RT712 support for LNL (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: Remove unused function prototypes
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: ssp-common: Add stub for sof_ssp_get_codec_name
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: remove .init callbacks (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: add common sdw dai link init (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt5682: use helper to get codec dai by name
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_cs42l42: use helper to get codec dai by
  name (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt700: use helper to get codec dai by name
  (jsc#PED-9993 jsc#PED-10202).
- commit c3d3f31
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: Intel: sof_sdw_rt712_sdca: use helper to get codec dai
  by name (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt711: use helper to get codec dai by name
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_rt_sdca_jack_common: use helper to get
  codec dai by name (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: add get_codec_dai_by_name helper function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: use single rtd_init for rt_amps
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: use common module for DAI link
  generation (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: support DAI link order customization
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: dmi quirk cleanup for mtl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: board id cleanup for mtl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: board id cleanup for rpl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: board id cleanup for adl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: board id cleanup for tgl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: board id cleanup for jsl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Send initial config to module if present
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Add topology parsing support for initial
  config (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: UAPI: Add tokens for initial config feature
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: constify static sdw_slave_ops struct (jsc#PED-9993
  jsc#PED-10202).
- ASoC: pxa: remove duplicated CONFIG_SND_PXA2XX_AC97 entry
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: fix SND_AMD_SOUNDWIRE_ACPI dependencies
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Shut down jack detection on component remove
  (jsc#PED-9993 jsc#PED-10202).
- commit 0371a2a
* Wed Sep  4 2024 tiwai@suse.de
- soundwire: Use snd_soc_substream_to_rtd() to obtain rtd
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: constify the struct device_type usage (jsc#PED-9993
  jsc#PED-10202).
- soundwire: bus_type: make sdw_bus_type const (jsc#PED-9993
  jsc#PED-10202).
- soundwire: intel_auxdevice: remove redundant assignment to
  variable link_flags (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Sync the hp ilimit works when removing the
  component (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Add clear of stashed pointer on component remove
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: refactor acp driver pm ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: amd: select soundwire dependency flag for acp6.3
  based platform (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: update descriptor fields for acp6.3 based
  platform (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: add machine select logic for soundwire based
  platforms (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: Add Soundwire DAI configuration support for
  AMD platforms (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: add interrupt handling for SoundWire manager
  devices (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: add code for invoking soundwire manager helper
  functions (jsc#PED-9993 jsc#PED-10202).
- soundwire: amd: refactor register mask structure (jsc#PED-9993
  jsc#PED-10202).
- soundwire: amd: refactor soundwire pads enable (jsc#PED-9993
  jsc#PED-10202).
- soundwire: amd: implement function to extract slave information
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: amd: refactor amd soundwire manager device node
  creation (jsc#PED-9993 jsc#PED-10202).
- soundwire: amd: update license (jsc#PED-9993 jsc#PED-10202).
- ASoC/soundwire: implement generic api for scanning amd soundwire
  controller (jsc#PED-9993 jsc#PED-10202).
- commit 8cab2b1
* Wed Sep  4 2024 oneukum@suse.com
- media: v4l: async: Drop v4l2_async_nf_parse_fwnode_endpoints()
  (jsc#PED-8643).
- commit 43bd60c
* Wed Sep  4 2024 davide.benini@suse.com
- sctp: Fix null-ptr-deref in reuseport_add_sock()
  (CVE-2024-44935 bsc#1229810).
- commit c34ddb2
* Wed Sep  4 2024 tiwai@suse.de
- soundwire: amd: drop bus freq calculation and set 'max_clk_freq'
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: generic_bandwidth_allocation use
  bus->params.max_dr_freq (jsc#PED-9993 jsc#PED-10202).
- soundwire: qcom: set controller id to hw master id (jsc#PED-9993
  jsc#PED-10202).
- soundwire: stream: constify sdw_port_config when adding devices
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: qcom: move sconfig in qcom_swrm_stream_alloc_ports()
  out of critical section (jsc#PED-9993 jsc#PED-10202).
- soundwire: qcom: drop unneeded qcom_swrm_stream_alloc_ports()
  cleanup (jsc#PED-9993 jsc#PED-10202).
- soundwire: bus: improve error handling for clock stop
  prepare/deprepare (jsc#PED-9993 jsc#PED-10202).
- soundwire: qcom: Log clk_get("iface") failures (jsc#PED-9993
  jsc#PED-10202).
- soundwire: qcom: handle command ignored interrupt (jsc#PED-9993
  jsc#PED-10202).
- soundwire: qcom: use newer link status tregister on v2.0.0
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soundwire: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- commit 72fcbc4
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/uncore: Cleanup unused unit structure (bsc#1230119).
- commit 48a66a6
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: Intel: mtl-match: Add cs42l43_l0 cs35l56_l23 for MTL
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Use fls to calculate the pre-divider for the PLL
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Refactor to use for_each_set_bit() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l43: Use USEC_PER_MSEC rather than hard coding
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Add pm_ptr around the power ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l43: Check error from device_property_read_u32_array()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Minor code tidy ups (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Tidy up header includes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: ES8326: Adding new volume kcontrols (jsc#PED-9993
  jsc#PED-10202).
- commit 8353b66
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: codecs: Add support for the framer codec (jsc#PED-9993
  jsc#PED-10202).
- ASoC: atmel: use devm_snd_soc_register_card() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: use devm_snd_soc_register_card() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ti: use devm_snd_soc_register_card() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl_sai: Add support for i.MX95 platform (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codec: wcd-mbhc-v2: add support when connected behind
  an USB-C audio mux (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: Compute file paths on firmware load
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: core: Skip firmware test for custom loaders
  (jsc#PED-9993 jsc#PED-10202).
- commit 7fc7702
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: amd: acp: Drop redundant initialization of machine driver
  data (jsc#PED-9993 jsc#PED-10202).
- commit d42dbcd
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/uncore: Apply the unit control RB tree to PCI uncore
  units (bsc#1230119).
- commit e202e9f
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: cs35l56: Add support for CS35L54 and CS35L57 (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ASoC-cs35l56-Fix-unintended-bus-access-while-resetti.patch.
- commit 50fe8e5
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: amd: acp: Update MODULE_DESCRIPTION for sof-mach
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Make use of existing *_CODEC_DAI macros
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: j721e-evm: Use devm_kcalloc() instead of
  devm_kzalloc() (jsc#PED-9993 jsc#PED-10202).
- ASoC: nau8540: Add pre-charge actions for input (jsc#PED-9993
  jsc#PED-10202).
- ASoC: p1022_rdk: fix all kernel-doc warnings (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: Use devm_kcalloc() instead of devm_kzalloc()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: cs35l56: Add support for CS35L54 and CS35L57
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: hda_component: Include sound/hda_codec.h
  (jsc#PED-9993 jsc#PED-10202).
- commit 281aa92
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: hda: hda_component: Add missing #include guards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: hda: Cleanup error messages (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: Ignore codecs with no suppoting driver
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: hda: Skip HDMI/DP registration if i915 is missing
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Skip i915 initialization on CNL/LKF-based platforms
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hwdep: Move put_user() call out of scoped_guard() in
  snd_hwdep_control_ioctl() (jsc#PED-9993 jsc#PED-10202).
- ALSA: control_led: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: pcm: oss: Use guard() for setup (jsc#PED-9993
  jsc#PED-10202).
- ALSA: pcm: Use guard() for PCM stream locks (jsc#PED-9993
  jsc#PED-10202).
- ALSA: pcm: Use guard() for locking (jsc#PED-9993 jsc#PED-10202).
- commit 7cd39e2
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: core: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ALSA-Fix-deadlocks-with-kctl-removals-at-disconnecti.patch.
- commit c1053ba
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: seq: prioq: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: virmidi: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: ump: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: midi: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: timer: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: queue: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: ports: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: memory: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: fifo: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- commit 6919b22
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: jack: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ALSA-core-Remove-debugfs-at-disconnection.patch.
- commit 5c94f68
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: timer: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ALSA-timer-Relax-start-tick-time-check-for-slave-tim.patch.
- Refresh
  patches.suse/ALSA-timer-Set-lower-bound-of-start-tick-time.patch.
- commit 0d7101b
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: rawmidi: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: control: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: mixer_oss: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: info: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hwdep: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hrtimer: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: compress_offload: Use guard() for locking (jsc#PED-9993
  jsc#PED-10202).
- ALSA: ump: Use guard() for locking (jsc#PED-9993 jsc#PED-10202).
- commit 2603534
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: seq: ump: Use automatic cleanup of kfree() (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ALSA-seq-ump-Skip-useless-ports-for-static-blocks.patch.
- commit 5d93335
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: pcm_oss: ump: Use automatic cleanup of kfree()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: mixer_oss: ump: Use automatic cleanup of kfree()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: Use CLASS() for fdget()/fdput() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: core: Use automatic cleanup of kfree() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: virmidi: Use automatic cleanup of kfree()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: seq: oss: Use automatic cleanup of kfree() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: vmaster: Use automatic cleanup of kfree() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: timer: Use automatic cleanup of kfree() (jsc#PED-9993
  jsc#PED-10202).
- commit 6e3e441
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: compress_offload: Use automatic cleanup of kfree()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: control: Use automatic cleanup of kfree() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: pcm: Use automatic cleanup of kfree() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: prioq: Unify cell removal functions (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: Downgrade BDL table overflow message (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: Set up BDL table at hw_params (jsc#PED-9993
  jsc#PED-10202).
- ALSA: avoid 'bool' as variable name (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: remove redundant 'tristate' for SND_SEQ_UMP_CLIENT
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: seq: make snd_seq_bus_type const (jsc#PED-9993
  jsc#PED-10202).
- ASoC: pxa2xx-ac97: Replace with DEFINE_SIMPLE_DEV_PM_OPS()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: HDA: intel-sdw-acpi: add kernel parameter to select
  alternate controller (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: Fix snd_pcm_format_name function (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: realtek: Move hda_component implementation to module
  (jsc#PED-9993 jsc#PED-10202).
- commit 5e6f9cb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1825-drm-i915-Fix-HPD-polling-reenabling-the-output-poll-.patch (drm-backport-placeholder)
- commit 7887f8a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-Add-an-HPD-poll-helper-to-reschedule-the-p.patch (drm-backport-placeholder)
- commit 6232a83
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1823-drm-i915-fix-Sphinx-indentation-warning.patch (drm-backport-placeholder)
- commit 755317d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dgfx-Enable-d3cold-at-s2idle.patch (drm-backport-placeholder)
- commit 01ba862
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-vmwgfx-Fix-possible-invalid-drm-gem-put-ca.patch (drm-backport-placeholder)
- commit aba92bc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-vmwgfx-Fix-shader-stage-validation.patch (drm-backport-placeholder)
- commit b5494ed
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/dma-buf-sw_sync-Avoid-recursive-lock-during-fe.patch (drm-backport-placeholder)
- commit 4a30c6f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-display-dp-Fix-the-DP-DSC-Receiver-cap-siz.patch (drm-backport-placeholder)
- commit 5e876c1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-panfrost-Skip-speed-binning-on-EOPNOTSUPP.patch (drm-backport-placeholder)
- commit a155307
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1816-drm-bridge-samsung-dsim-Fix-init-during-host-transfe.patch (drm-backport-placeholder)
- commit a443430
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-goldfishfb-Do-not-check-0-for-platform_get_irq.patch (drm-backport-placeholder)
- commit c23ddbb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1814-fbdev-atmel_lcdfb-Remove-redundant-of_match_ptr.patch (drm-backport-placeholder)
- commit 20ec421
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1813-fbdev-kyro-Remove-unused-declarations.patch (drm-backport-placeholder)
- commit 6eb60c4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1812-fbdev-ssd1307fb-Print-the-PWM-s-label-instead-of-its.patch (drm-backport-placeholder)
- commit fa5cfa4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-mmp-fix-value-check-in-mmphw_probe.patch (drm-backport-placeholder)
- commit 1f92093
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1810-fbdev-amifb-Replace-zero-length-arrays-with-DECLARE_.patch (drm-backport-placeholder)
- commit 3f0ed03
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-qxl-fix-UAF-on-handle-creation.patch (drm-backport-placeholder)
- commit 1876c71
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/Revert-Revert-drm-amdgpu-display-change-pipe-p.patch (drm-backport-placeholder)
- commit 899a235
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-flush-any-delayed-gfxoff-on-suspend-en.patch (drm-backport-placeholder)
- commit c28e8b9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-skip-fence-GFX-interrupts-disable-e.patch (drm-backport-placeholder)
- commit b9b5c77
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1805-drm-amdgpu-skip-xcp-drm-device-allocation-when-out-o.patch (drm-backport-placeholder)
- commit a6b88f3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1804-drm-amd-pm-Update-pci-link-width-for-smu-v13.0.6.patch (drm-backport-placeholder)
- commit 4c78f99
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-Fix-temperature-unit-of-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit eca13dc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-pm-fix-throttle_status-for-other-th.patch (drm-backport-placeholder)
- commit fb56ade
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1801-drm-amdgpu-disable-mcbp-if-parameter-zero-is-set.patch (drm-backport-placeholder)
- commit fea8df1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1800-drm-amd-pm-disallow-the-fan-setting-if-there-is-no-f.patch (drm-backport-placeholder)
- commit 414b938
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/accel-qaic-Clean-up-integer-overflow-checking-.patch (drm-backport-placeholder)
- commit 1bd460a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/accel-qaic-Fix-slicing-memory-leak.patch (drm-backport-placeholder)
- commit 9dbd417
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-simple-Fix-AUO-G121EAN01-panel-timin.patch (drm-backport-placeholder)
- commit 6872c62
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1796-drm-panel-JDI-LT070ME05000-simplify-with-dev_err_pro.patch (drm-backport-placeholder)
- commit 5ce0eb5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1795-drm-i915-fix-display-probe-for-IVB-Q-and-IVB-D-GT2-s.patch (drm-backport-placeholder)
- commit 90ef882
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-sdvo-fix-panel_type-initialization.patch (drm-backport-placeholder)
- commit ab62e30
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-guc-slpc-Restore-efficient-freq-earli.patch (drm-backport-placeholder)
- commit db4f05a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1792-drm-amdkfd-disable-IOMMUv2-support-for-Raven.patch (drm-backport-placeholder)
- commit 5192092
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1791-drm-amdkfd-disable-IOMMUv2-support-for-KV-CZ.patch (drm-backport-placeholder)
- commit 06bd849
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1790-drm-amdkfd-ignore-crat-by-default.patch (drm-backport-placeholder)
- commit cf0db77
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1789-drm-amdgpu-gfx11-only-enable-CP-GFX-shadowing-on-SR-.patch (drm-backport-placeholder)
- commit e16fa70
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-a-regression-on-Polaris-ca.patch (drm-backport-placeholder)
- commit ff67935
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-possible-UAF-in-amdgpu_cs_pass1.patch (drm-backport-placeholder)
- commit 95a5df0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1786-drm-amd-pm-Fix-SMU-v13.0.6-energy-reporting.patch (drm-backport-placeholder)
- commit 050bc01
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-check-attr-flag-before-set-cur.patch (drm-backport-placeholder)
- commit 63269c8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1784-drm-amd-pm-disable-the-SMU13-OD-feature-support-temp.patch (drm-backport-placeholder)
- commit 6a9be39
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-correct-the-pcie-width-for-smu-13.0.patch (drm-backport-placeholder)
- commit aaf71ef
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Don-t-show-stack-trace-for-mis.patch (drm-backport-placeholder)
- commit 27eb8b9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Match-against-exact-bootloader-status.patch (drm-backport-placeholder)
- commit d4a6340
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-skip-the-RLC-stop-when-S0i3-suspend.patch (drm-backport-placeholder)
- commit ba4d69f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Disable-S-G-for-APUs-when-64GB-or-more.patch (drm-backport-placeholder)
- commit de64756
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-shmem-helper-Reset-vma-vm_ops-before-calli.patch (drm-backport-placeholder)
- commit 8f7e21a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-Don-t-spam-logs-in-atomic-check.patch (drm-backport-placeholder)
- commit ff0d479
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/accel-ivpu-Add-set_pages_array_wc-uc-for-inter.patch (drm-backport-placeholder)
- commit e81a07f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-disp-Revert-a-NULL-check-inside-no.patch (drm-backport-placeholder)
- commit 97cd65b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1775-Revert-drm-bridge-lt9611-Do-not-generate-HFP-HBP-HSA.patch (drm-backport-placeholder)
- commit f00180d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-remove-unused-tu102_gr_load-functi.patch (drm-backport-placeholder)
- commit 1b53272
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-nvkm-dp-Add-workaround-to-fix-DP-1.patch (drm-backport-placeholder)
- commit 4bd2826
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-gr-enable-memory-loads-on-helper-i.patch (drm-backport-placeholder)
- commit 15245ca
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-it6505-Check-power-state-with-it650.patch (drm-backport-placeholder)
- commit f26ce6e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1770-drm-i915-gvt-Fix-bug-in-getting-msg-length-in-AUX-CH.patch (drm-backport-placeholder)
- commit 2233974
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Fix-premature-release-of-request-s-re.patch (drm-backport-placeholder)
- commit ad2308f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Support-aux-invalidation-on-all-en.patch (drm-backport-placeholder)
- commit 7a052b2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Poll-aux-invalidation-register-bit.patch (drm-backport-placeholder)
- commit 5aa7968
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Enable-the-CCS_FLUSH-bit-in-the-pi.patch (drm-backport-placeholder)
- commit 988cd35
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Rename-flags-with-bit_group_X-acco.patch (drm-backport-placeholder)
- commit bab983c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Ensure-memory-quiesced-before-inva.patch (drm-backport-placeholder)
- commit d4576cf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Add-the-gen12_needs_ccs_aux_inv-helpe.patch (drm-backport-placeholder)
- commit 86a482a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Cleanup-aux-invalidation-registers.patch (drm-backport-placeholder)
- commit 412d79a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1761-drm-panel-samsung-s6d7aa0-Add-MODULE_DEVICE_TABLE.patch (drm-backport-placeholder)
- commit 0647bd8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-imx-ipuv3-Fix-front-porch-adjustment-upon-.patch (drm-backport-placeholder)
- commit 4eab1d6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-ttm-check-null-pointer-before-accessing-wh.patch (drm-backport-placeholder)
- commit b0e9d34
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/locking-rtmutex-Fix-task-pi_waiters-integrity.patch (drm-backport-placeholder)
- commit e014727
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-Disallow-submit-with-fence-id-0.patch (drm-backport-placeholder)
- commit 90000fb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-Fix-hw_fence-error-path-cleanup.patch (drm-backport-placeholder)
- commit dd1f683
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-Fix-IS_ERR_OR_NULL-vs-NULL-check-in-a5x.patch (drm-backport-placeholder)
- commit 0244dc5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-adreno-Fix-snapshot-BINDLESS_DATA-size.patch (drm-backport-placeholder)
- commit 55e0fcf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1753-drm-msm-a690-Remove-revn-and-name.patch (drm-backport-placeholder)
- commit 4b1ebee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1752-drm-msm-adreno-Fix-warn-splat-for-devices-without-re.patch (drm-backport-placeholder)
- commit 30e0b1b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dsi-Drop-unused-regulators-from-QCM2290.patch (drm-backport-placeholder)
- commit 5d50c87
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-drop-enum-dpu_core_perf_data_bus_id.patch (drm-backport-placeholder)
- commit 977a4e3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-add-missing-flush-and-fetch-bits-fo.patch (drm-backport-placeholder)
- commit dcc2b94
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-mdss-correct-UBWC-programming-for-SM855.patch (drm-backport-placeholder)
- commit ad7c0f4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1747-drm-amdgpu-Restore-HQD-persistent-state-register.patch (drm-backport-placeholder)
- commit 5c86626
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Unlock-on-error-path-in-dm_hand.patch (drm-backport-placeholder)
- commit cee0fc2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Exit-idle-optimizations-before-attem.patch (drm-backport-placeholder)
- commit eb3925a
* Wed Sep  4 2024 tiwai@suse.de
- Update config files. (jsc#PED-9993 jsc#PED-10202)
- commit e905069
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1744-drm-amd-display-Don-t-apply-FIFO-resync-W-A-if-rdivi.patch (drm-backport-placeholder)
- commit b6d2e00
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Guard-DCN31-PHYD32CLK-logic-against-.patch (drm-backport-placeholder)
- commit 87b7659
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-smu-use-AverageGfxclkFrequency-to-replace-pr.patch (drm-backport-placeholder)
- commit 972f074
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Fix-an-error-handling-mistake-in-psp_sw.patch (drm-backport-placeholder)
- commit e35802d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1740-drm-amdgpu-Fix-infinite-loop-in-gfxhub_v1_2_xcc_gart.patch (drm-backport-placeholder)
- commit cc40a8c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1739-drm-amdkfd-fix-trap-handling-work-around-for-debuggi.patch (drm-backport-placeholder)
- commit 3d17abc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Fix-an-error-handling-path-in-igt_writ.patch (drm-backport-placeholder)
- commit d44e0b0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-dpt-Use-shmem-for-dpt-objects.patch (drm-backport-placeholder)
- commit d16041b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1736-drm-fb-helper-Remove-unused-inline-function-drm_fb_h.patch (drm-backport-placeholder)
- commit d2ba4e1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1735-fbdev-Explicitly-include-correct-DT-includes.patch (drm-backport-placeholder)
- commit 5935328
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1734-fbdev-ep93xx-fb-fix-return-value-check-in-ep93xxfb_p.patch (drm-backport-placeholder)
- commit 50d380c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-au1200fb-Fix-missing-IRQ-check-in-au1200f.patch (drm-backport-placeholder)
- commit 1d39a48
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1732-fbdev-kyro-make-some-const-read-only-arrays-static-a.patch (drm-backport-placeholder)
- commit 79c6353
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1731-fbcon-remove-unused-display-p-from-fbcon_redraw.patch (drm-backport-placeholder)
- commit e3631b3
* Wed Sep  4 2024 tiwai@suse.de
- ALSA: seq: Replace with __packed attribute (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-acpi: Add missing kernel doc (jsc#PED-9993
  jsc#PED-10202).
- ALSA: info: Remove unused function declarations (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-dapm.h: Convert macros to return a compound literal
  (jsc#PED-9993 jsc#PED-10202).
- commit 307d9c8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1730-sticon-make-sticon_set_def_font-void-and-remove-op-p.patch (drm-backport-placeholder)
- commit f686277
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1729-vgacon-cache-vc_cell_height-in-vgacon_cursor.patch (drm-backport-placeholder)
- commit 5d7afe5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1728-vgacon-let-vgacon_doresize-return-void.patch (drm-backport-placeholder)
- commit 9f69f30
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1727-vgacon-remove-unused-xpos-from-vgacon_set_cursor_siz.patch (drm-backport-placeholder)
- commit db2aadc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1726-vgacon-remove-unneeded-forward-declarations.patch (drm-backport-placeholder)
- commit 6b4a743
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1725-vgacon-switch-vgacon_scrolldelta-and-vgacon_restore_.patch (drm-backport-placeholder)
- commit 6fb8649
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1724-fbdev-imxfb-remove-unneeded-labels.patch (drm-backport-placeholder)
- commit 9aa525d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1723-fbdev-imxfb-Convert-to-devm_platform_ioremap_resourc.patch (drm-backport-placeholder)
- commit d446c6a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1722-fbdev-imxfb-Convert-to-devm_kmalloc_array.patch (drm-backport-placeholder)
- commit 445fbab
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-imxfb-Removed-unneeded-release_mem_region.patch (drm-backport-placeholder)
- commit 38a5312
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1720-fbdev-imxfb-switch-to-DEFINE_SIMPLE_DEV_PM_OPS.patch (drm-backport-placeholder)
- commit 2d4a59f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-imxfb-warn-about-invalid-left-right-margi.patch (drm-backport-placeholder)
- commit 499a21b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-atomic-Fix-potential-use-after-free-in-nonb.patch (drm-backport-placeholder)
- commit 760fe4c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1717-drm-amdgpu-use-a-macro-to-define-no-xcp-partition-ca.patch (drm-backport-placeholder)
- commit 4d83650
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1716-drm-amdgpu-vm-use-the-same-xcp_id-from-root-PD.patch (drm-backport-placeholder)
- commit bcf895d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1715-drm-amdgpu-fix-slab-out-of-bounds-issue-in-amdgpu_vm.patch (drm-backport-placeholder)
- commit 08651f1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1714-drm-amdgpu-Allocate-root-PD-on-correct-partition.patch (drm-backport-placeholder)
- commit 0736029
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Keep-PHY-active-for-DP-displays.patch (drm-backport-placeholder)
- commit 0dc5adb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Prevent-vtotal-from-being-set-t.patch (drm-backport-placeholder)
- commit 4cb56c8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Disable-MPC-split-by-default-on.patch (drm-backport-placeholder)
- commit 56a947c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-check-TG-is-non-null-before-che.patch (drm-backport-placeholder)
- commit f54e0da
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-polling-method-to-handle-MS.patch (drm-backport-placeholder)
- commit b452b7c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Clean-up-errors-warnings-in-amd.patch (drm-backport-placeholder)
- commit 0bd9ea6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1707-drm-amdgpu-Allow-the-initramfs-generator-to-include-.patch (drm-backport-placeholder)
- commit 51ee7a4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-pm-make-mclk-consistent-for-smu-13.0.patch (drm-backport-placeholder)
- commit 94a3189
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-pm-make-gfxclock-consistent-for-sien.patch (drm-backport-placeholder)
- commit 5087082
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-only-accept-async-flips-for-fas.patch (drm-backport-placeholder)
- commit 78cc454
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-vkms-relax-timer-deactivation-by-hrt.patch (drm-backport-placeholder)
- commit 8fae3c6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1702-drm-amd-display-add-DCN301-specific-logic-for-OTG-pr.patch (drm-backport-placeholder)
- commit ca0ccea
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1701-drm-amd-display-export-some-optc-function-for-reuse.patch (drm-backport-placeholder)
- commit 6547d7e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1700-drm-amd-Use-amdgpu_device_pcie_dynamic_switching_sup.patch (drm-backport-placeholder)
- commit f85415e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1699-Revert-drm-i915-use-localized-__diag_ignore_all-inst.patch (drm-backport-placeholder)
- commit 436ed3f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-perf-add-sentinel-to-xehp_oa_b_counter.patch (drm-backport-placeholder)
- commit 135e172
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-kms-nv50-init-hpd_irq_lock-for-PIOR.patch (drm-backport-placeholder)
- commit 6aa3ad4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-disp-PIOR-DP-uses-GPIO-for-HPD-not-.patch (drm-backport-placeholder)
- commit 54efcbe
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-i2c-fix-number-of-aux-event-slots.patch (drm-backport-placeholder)
- commit 0e498f3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/dma-buf-dma-resv-Stop-leaking-on-krealloc-failu.patch (drm-backport-placeholder)
- commit d0865d2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/accel-qaic-Fix-a-leak-in-map_user_pages.patch (drm-backport-placeholder)
- commit ba922dc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/accel-qaic-Add-consistent-integer-overflow-chec.patch (drm-backport-placeholder)
- commit eb67713
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/accel-qaic-tighten-bounds-checking-in-decode_me.patch (drm-backport-placeholder)
- commit 926a2be
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/accel-qaic-tighten-bounds-checking-in-encode_me.patch (drm-backport-placeholder)
- commit fac35b5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-client-Fix-memory-leak-in-drm_client_modese.patch (drm-backport-placeholder)
- commit 8ff9238
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-client-Fix-memory-leak-in-drm_client_target.patch (drm-backport-placeholder)
- commit 85f716f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Align-SMU11-SMU_MSG_OverridePcieParamet.patch (drm-backport-placeholder)
- commit 5a28c38
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: SOF: Intel: pci-lnl: Change the topology path to
  intel/sof-ipc4-tplg (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-SOF-Intel-add-default-firmware-library-path-for.patch.
- commit 24725dc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Move-helper-for-dynamic-speed-switch-ch.patch (drm-backport-placeholder)
- commit b4df8a7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-conditionally-disable-pcie-lane-spee.patch (drm-backport-placeholder)
- commit e4139fc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-share-the-code-around-SMU13-pcie-par.patch (drm-backport-placeholder)
- commit e4b2ad2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-avoid-restore-process-run-into-dead-.patch (drm-backport-placeholder)
- commit 205f530
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-fix-smu-i2c-data-read-risk.patch (drm-backport-placeholder)
- commit 5879f21
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Fix-one-wrong-caching-mode-enum-usage.patch (drm-backport-placeholder)
- commit 3aa80d6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1684-drm-i915-Remove-dead-code-from-gen8_pte_encode.patch (drm-backport-placeholder)
- commit 6007387
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1683-drm-i915-perf-Consider-OA-buffer-boundary-when-zeroi.patch (drm-backport-placeholder)
- commit 5314a76
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Don-t-preserve-dpll_hw_state-for-slave.patch (drm-backport-placeholder)
- commit 9a8a1ba
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-bring-back-blit-subchannel-for-pre-.patch (drm-backport-placeholder)
- commit 85a2af1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-acr-Abort-loading-ACR-if-no-firmwar.patch (drm-backport-placeholder)
- commit dae83eb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-disp-g94-enable-HDMI.patch (drm-backport-placeholder)
- commit 5dd2a8f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-disp-fix-HDMI-on-gt215.patch (drm-backport-placeholder)
- commit 121adb0
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: amd: yc: add new YC platform variant (0x63) support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-card: Fix missing locking in
  snd_soc_card_get_kcontrol() (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: clarify and fix default msbits value for all formats
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Workaround for ACPI with broken spk-id-gpios
  property (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: pci-tgl: Change the default paths and firmware
  names (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5645: Add DMI quirk for inverted jack-detect on MeeGoPad
  T8 (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: cht_bsw_rt5645: Cleanup codec_name handling
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: Boards: Fix NULL pointer deref in BYT/CHT boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: Fix locking in ACP IRQ handler (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l56: Remove default from IRQ1_CFG register
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Fix dynamic port assignment when TDM is set
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Add system suspend ops to disable IRQ
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Handle error from devm_pm_runtime_enable
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Fix pci_probe() error path (jsc#PED-9993
  jsc#PED-10202).
- commit 395575f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1677-drm-client-Send-hotplug-event-after-registering-a-cl.patch (drm-backport-placeholder)
- commit f3951d3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1676-drm-panel-Fine-tune-Starry-ili9882t-panel-HFP-and-HB.patch (drm-backport-placeholder)
- commit 68479ba
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1675-drm-i915-use-mock-device-info-for-creating-mock-devi.patch (drm-backport-placeholder)
- commit d4c2b70
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-psr-Fix-BDW-PSR-AUX-CH-data-register-o.patch (drm-backport-placeholder)
- commit e31c73f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1672-drm-amd-pm-avoid-unintentional-shutdown-due-to-tempe.patch (drm-backport-placeholder)
- commit 64ecee2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-expose-swctf-threshold-setting-for-.patch (drm-backport-placeholder)
- commit 2ed2a08
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1670-drm-amd-display-3.2.241.patch (drm-backport-placeholder)
- commit 5ffb3d2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1669-drm-amd-display-Take-full-update-path-if-number-of-p.patch (drm-backport-placeholder)
- commit 97ecda5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1668-drm-amd-display-Create-debugging-mechanism-for-Gamin.patch (drm-backport-placeholder)
- commit 9ff200e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-monitor-specific-edid-quirk.patch (drm-backport-placeholder)
- commit 21674c2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1666-drm-amd-display-For-new-fast-update-path-loop-throug.patch (drm-backport-placeholder)
- commit d73a998
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Remove-Phantom-Pipe-Check-When-.patch (drm-backport-placeholder)
- commit 5512fe6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1664-drm-amd-display-Limit-new-fast-update-path-to-addr-a.patch (drm-backport-placeholder)
- commit 020620c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1663-drm-amd-display-Fix-the-delta-clamping-for-shaper-LU.patch (drm-backport-placeholder)
- commit 53e87d3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1662-drm-amdgpu-Keep-non-psp-path-for-partition-switch.patch (drm-backport-placeholder)
- commit 7c54386
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1661-drm-amd-display-program-DPP-shaper-and-3D-LUT-if-upd.patch (drm-backport-placeholder)
- commit 5e1b5f2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amd-display-edp-do-not-add-non-edid-.patch (drm-backport-placeholder)
- commit e4dd72f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1659-drm-amdgpu-share-drm-device-for-pci-amdgpu-device-wi.patch (drm-backport-placeholder)
- commit b78e143
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1658-drm-amd-pm-Add-GFX-v9.4.3-unique-id-to-sysfs.patch (drm-backport-placeholder)
- commit 47ada19
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1657-drm-amd-pm-Enable-pp_feature-attribute.patch (drm-backport-placeholder)
- commit 11c88d0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1656-drm-amdgpu-vcn-Need-to-unpause-dpg-before-stop-dpg.patch (drm-backport-placeholder)
- commit 5fdf805
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1655-drm-amdgpu-remove-duplicated-doorbell-range-init-for.patch (drm-backport-placeholder)
- commit a8cb282
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1654-drm-amdgpu-gpu-recovers-from-fatal-error-in-poison-m.patch (drm-backport-placeholder)
- commit 7c0b3f7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1653-drm-amdgpu-enable-mcbp-by-default-on-gfx9.patch (drm-backport-placeholder)
- commit 700e1a0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1652-drm-amdgpu-make-mcbp-a-per-device-setting.patch (drm-backport-placeholder)
- commit f39159e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1651-drm-amd-Don-t-initialize-PSP-twice-for-Navi3x.patch (drm-backport-placeholder)
- commit 0a75056
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amd-Disable-PSR-SU-on-Parade-0803-TC.patch (drm-backport-placeholder)
- commit c1bd00f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Set-minimum-requirement-for-usi-cd2e31a.patch (drm-backport-placeholder)
- commit 458e451
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: amd: acp: Fix support for a Huawei Matebook laptop
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd9335: drop unused gain hack remnant
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: fix the capture noise issue (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: ES8326: Minimize the pop noise on headphone
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Improving the THD+N performance
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: improving crosstalk performance
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Remove executable bit (jsc#PED-9993
  jsc#PED-10202).
- ASoC: allow up to eight CPU/codec DAIs (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wcd934x: drop unneeded regulator include
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd938x: skip printing deferred probe failuers
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Update platform name for different boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Enable rt5682s clocks in acp slave mode
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: Add missing formats to formats list (jsc#PED-9993
  jsc#PED-10202).
- ASoC: audio-graph-card2: fix index check on
  graph_parse_node_multi_nm() (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: icp3-dtrace: Revert "Fix wrong kfree() usage"
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8195: Remove afe-dai component and rework
  codec link (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8192: Check existence of dai_name before
  dereferencing (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: bxt_rt298: Fix kernel ops due to COMP_DUMMY change
  (jsc#PED-9993 jsc#PED-10202).
- commit 81b27d0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Set-minimum-requirement-for-usi.patch (drm-backport-placeholder)
- commit 57f0af8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Correct-DMUB_FW_VERSION-macro.patch (drm-backport-placeholder)
- commit c6cdc31
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1646-drm-amd-pm-fulfill-the-missing-enablement-for-vega12.patch (drm-backport-placeholder)
- commit aaed644
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1645-drm-amd-display-Remove-asserts.patch (drm-backport-placeholder)
- commit 24f8b11
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1644-drm-amd-display-Work-around-bad-DPCD-state-on-link-l.patch (drm-backport-placeholder)
- commit 4e05a84
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1643-drm-amdgpu-port-SRIOV-VF-missed-changes.patch (drm-backport-placeholder)
- commit 11f5047
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Don-t-try-to-enable-secure-display-TA-m.patch (drm-backport-placeholder)
- commit f1ce2b7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1641-drm-amdkfd-Update-interrupt-handling-for-GFX-9.4.3.patch (drm-backport-placeholder)
- commit 9e6792c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-number-of-fence-calculations.patch (drm-backport-placeholder)
- commit 226d125
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-perform-a-bounds-check-before-f.patch (drm-backport-placeholder)
- commit c1b2104
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1638-drm-amd-pm-Provide-energy-data-in-15.625mJ-units.patch (drm-backport-placeholder)
- commit 8f9c3ee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1637-drm-amdgpu-Modify-for_each_inst-macro.patch (drm-backport-placeholder)
- commit aaa54d6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1636-drm-amdgpu-Remove-sdma-halt-unhalt-during-frontdoor-.patch (drm-backport-placeholder)
- commit ea8c5a2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-check-RAS-irq-existence-for-VCN-JPEG.patch (drm-backport-placeholder)
- commit 38b305e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-add-abnormal-fan-detection-for-smu-1.patch (drm-backport-placeholder)
- commit cdfca36
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1633-drm-amdgpu-remove-vm-sanity-check-from-amdgpu_vm_mak.patch (drm-backport-placeholder)
- commit 32a69eb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-Disable-PSR-SU-on-Parade-0803-TCON.patch (drm-backport-placeholder)
- commit 1c43411
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1631-drm-amdkfd-Enable-GWS-on-GFX9.4.3.patch (drm-backport-placeholder)
- commit b492842
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-update-the-LC_L1_INACTIVITY-setting-to-ad.patch (drm-backport-placeholder)
- commit 3b4720d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1629-drm-amd-display-3.2.240.patch (drm-backport-placeholder)
- commit 42f1125
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1628-drm-amd-display-Enable-dc-mode-clock-switching-for-D.patch (drm-backport-placeholder)
- commit 1a5e58d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-128b132b-link-loss-handling.patch (drm-backport-placeholder)
- commit 27a523e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1626-drm-amd-display-fix-odm-k2-div-calculation.patch (drm-backport-placeholder)
- commit ed21d02
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1625-drm-amd-display-Add-MST-Preferred-Link-Setting-Entry.patch (drm-backport-placeholder)
- commit 48925f0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-disable-seamless-boot-if-force_.patch (drm-backport-placeholder)
- commit 28b58d5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1623-drm-amd-display-Disable-DC-Mode-Capping-On-DCN321.patch (drm-backport-placeholder)
- commit 8d750df
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1622-drm-amd-display-enable-the-new-fast-update-path-for-.patch (drm-backport-placeholder)
- commit f5e362f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1621-drm-amd-display-Clear-update-flags-at-end-of-flip.patch (drm-backport-placeholder)
- commit 9862d7b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1620-drm-amd-display-Fix-pipe-check-condition-for-manual-.patch (drm-backport-placeholder)
- commit f0502d2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1619-drm-amd-display-add-missing-ABM-registers.patch (drm-backport-placeholder)
- commit cbaf4f4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1618-drm-amd-display-Add-Clock-Table-Entry-With-Max-DC-Va.patch (drm-backport-placeholder)
- commit f9f955c
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: tas2781: Add tas2563 into driver (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ASoC-tas2781-Fix-wrong-loading-calibrated-data-seque.patch.
- commit 4125fe4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-add-a-NULL-pointer-check.patch (drm-backport-placeholder)
- commit f5bbfa1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/Partially-revert-drm-amd-display-Fix-possible-underf.patch (drm-backport-placeholder)
- commit 392dcd9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1615-Revert-drm-amd-display-Move-DCN314-DOMAIN-power-cont.patch (drm-backport-placeholder)
- commit 7b6a312
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1614-drm-amd-display-disable-RCO-for-DCN314.patch (drm-backport-placeholder)
- commit 1ad39cf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1613-drm-amd-display-disable-power-gating-for-DCN314.patch (drm-backport-placeholder)
- commit 5f30e5d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1612-drm-amdgpu-Skip-TMR-for-MP0_HWIP-13.0.6.patch (drm-backport-placeholder)
- commit b2b308e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1611-drm-amdgpu-Move-clocks-closer-to-its-only-usage-in-a.patch (drm-backport-placeholder)
- commit f0af4e2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-pm-revise-the-ASPM-settings-for-thunder.patch (drm-backport-placeholder)
- commit a36ef05
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-clearing-mappings-for-BOs-that-a.patch (drm-backport-placeholder)
- commit ee24431
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1608-drm-amdkfd-set-coherent-host-access-capability-flag.patch (drm-backport-placeholder)
- commit 922086f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1607-drm-amdgpu-Add-vbios-attribute-only-if-supported.patch (drm-backport-placeholder)
- commit c2129af
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1606-drm-amdgpu-atomfirmware-fix-LPDDR5-width-reporting.patch (drm-backport-placeholder)
- commit 537838b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1605-drm-amdgpu-Remove-CONFIG_DEBUG_FS-guard-around-body-.patch (drm-backport-placeholder)
- commit 2a5bd06
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1604-drm-amd-pm-remove-unneeded-variable.patch (drm-backport-placeholder)
- commit 927f567
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1603-drm-amdgpu-Move-calculation-of-xcp-per-memory-node.patch (drm-backport-placeholder)
- commit 3f5f9eb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Skip-mark-offset-for-high-priority-r.patch (drm-backport-placeholder)
- commit 0f35f64
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1601-amd-display-dc-remove-repeating-expression.patch (drm-backport-placeholder)
- commit 40d6c9f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1600-drm-i915-Add-missing-forward-declarations-includes-t.patch (drm-backport-placeholder)
- commit d91ffe8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1599-drm-i915-hdcp-Assign-correct-hdcp-content-type.patch (drm-backport-placeholder)
- commit be4edd7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-guc-slpc-Apply-min-softlimit-correctly.patch (drm-backport-placeholder)
- commit eee46f6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-psr-Use-hw.adjusted-mode-when-calculat.patch (drm-backport-placeholder)
- commit 691b19d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1596-drm-i915-mtl-Fix-SSC-selection-for-MPLLA.patch (drm-backport-placeholder)
- commit 9efbd2d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1595-drm-i915-adlp-Allow-DC-states-along-with-PW2-only-fo.patch (drm-backport-placeholder)
- commit 0f556fa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1594-mei-bus-fixup-fix-buffer-type.patch (drm-backport-placeholder)
- commit 334f017
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1593-mei-bus-drop-useless-cldev-null-check.patch (drm-backport-placeholder)
- commit cbc8705
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1592-backlight-led_bl-Take-led_access-lock-when-required.patch (drm-backport-placeholder)
- commit bfaab58
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1591-video-backlight-lp855x-Get-PWM-for-PWM-mode-during-p.patch (drm-backport-placeholder)
- commit f17b61d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1590-backlight-pwm_bl-Remove-unneeded-checks-for-valid-GP.patch (drm-backport-placeholder)
- commit 9a28ebf
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: Intel: bxt_da7219_max98357a: Fix kernel ops due to
  COMP_DUMMY change (jsc#PED-9993 jsc#PED-10202).
- ASoC: tas2781: Add tas2563 into header file for DSP mode
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: tas2562: move tas2563 from tas2562 driver to tas2781
  driver (jsc#PED-9993 jsc#PED-10202).
- i2c: make i2c_bus_type const (jsc#PED-9993 jsc#PED-10202).
- ASoC: pxa: sspa: Don't select SND_ARM (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5663: cancel the work when system suspends (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: imx: Add SNDRV_PCM_INFO_BATCH flag (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: cht_bsw_rt5645: Set card.components string
  (jsc#PED-9993 jsc#PED-10202).
- commit cef462d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1589-backlight-Switch-i2c-drivers-back-to-use-.probe.patch (drm-backport-placeholder)
- commit 7031a23
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1588-backlight-lm3630a-Turn-off-both-led-strings-when-dis.patch (drm-backport-placeholder)
- commit e0ec1ee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1587-sticon-parisc-Fix-STI-console-on-64-bit-only-machine.patch (drm-backport-placeholder)
- commit 0e193dd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1586-sticon-parisc-Allow-64-bit-STI-calls-in-PDC-firmware.patch (drm-backport-placeholder)
- commit 44f06db
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1585-drm-nouveau-stop-using-is_swiotlb_active.patch (drm-backport-placeholder)
- commit f003e3a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1584-drm-i915-Fix-a-NULL-vs-IS_ERR-bug.patch (drm-backport-placeholder)
- commit 26ccf6d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1583-drm-i915-make-i915_drm_client_fdinfo-reference-condi.patch (drm-backport-placeholder)
- commit b18e9f2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1582-drm-i915-huc-Fix-missing-error-code-in-intel_huc_ini.patch (drm-backport-placeholder)
- commit 9bcd778
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1581-drm-i915-gsc-take-a-wakeref-for-the-proxy-init-compl.patch (drm-backport-placeholder)
- commit c34b541
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1580-drm-msm-a6xx-Add-A610-speedbin-support.patch (drm-backport-placeholder)
- commit 1327ea5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1579-drm-msm-a6xx-Add-A619_holi-speedbin-support.patch (drm-backport-placeholder)
- commit 4ff936f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1578-drm-msm-a6xx-Use-adreno_is_aXYZ-macros-in-speedbin-m.patch (drm-backport-placeholder)
- commit 41a5022
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1577-drm-msm-a6xx-Use-else-if-in-GPU-speedbin-rev-matchin.patch (drm-backport-placeholder)
- commit e18ad19
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1576-drm-msm-a6xx-Fix-some-A619-tunables.patch (drm-backport-placeholder)
- commit b1011ab
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1575-drm-msm-a6xx-Add-A610-support.patch (drm-backport-placeholder)
- commit ad21bde
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1574-drm-msm-a6xx-Add-support-for-A619_holi.patch (drm-backport-placeholder)
- commit 319868e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1573-drm-msm-adreno-Disable-has_cached_coherent-in-GMU-wr.patch (drm-backport-placeholder)
- commit 88e6a75
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1572-drm-msm-a6xx-Introduce-GMU-wrapper-support.patch (drm-backport-placeholder)
- commit 3a0b1ba
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1571-drm-msm-a6xx-Move-CX-GMU-power-counter-enablement-to.patch (drm-backport-placeholder)
- commit 180f027
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1570-drm-msm-a6xx-Extend-and-explain-UBWC-config.patch (drm-backport-placeholder)
- commit 1568c74
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1569-drm-msm-a6xx-Remove-both-GBIF-and-RBBM-GBIF-halt-on-.patch (drm-backport-placeholder)
- commit 206db9d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1568-drm-msm-a6xx-Add-a-helper-for-software-resetting-the.patch (drm-backport-placeholder)
- commit b1ef21b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1567-drm-msm-a6xx-Improve-a6xx_bus_clear_pending_transact.patch (drm-backport-placeholder)
- commit f1fa7cb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1566-drm-msm-a6xx-Move-a6xx_bus_clear_pending_transaction.patch (drm-backport-placeholder)
- commit a7a7b07
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1565-drm-msm-a6xx-Move-force-keepalive-vote-removal-to-a6.patch (drm-backport-placeholder)
- commit 248c7d1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1564-drm-msm-a6xx-Remove-static-keyword-from-sptprac-en-d.patch (drm-backport-placeholder)
- commit ec22c3c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1563-drm-msm-adreno-Use-adreno_is_revn-for-A690.patch (drm-backport-placeholder)
- commit ae32e31
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1562-drm-msm-dsi-split-dsi_ctrl_config-function.patch (drm-backport-placeholder)
- commit 9cfcbb5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1561-drm-msm-dsi-dsi_host-drop-unused-clocks.patch (drm-backport-placeholder)
- commit 6e57a4a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1560-drm-msm-dpu-remove-unused-INTF_NONE-interfaces.patch (drm-backport-placeholder)
- commit 7256a6f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-correct-MERGE_3D-length.patch (drm-backport-placeholder)
- commit f804d0c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-fix-sc7280-and-sc7180-PINGPONG-done.patch (drm-backport-placeholder)
- commit 7fdf40b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dp-Free-resources-after-unregistering-t.patch (drm-backport-placeholder)
- commit 43586ff
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dp-Drop-aux-devices-together-with-DP-co.patch (drm-backport-placeholder)
- commit c9f5324
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-provide-fb_dirty-implemenation.patch (drm-backport-placeholder)
- commit 61b8a7d
* Wed Sep  4 2024 oneukum@suse.com
- lib/math: Move dvb_math.c into lib/math/int_log.c
  (jsc#PED-8643).
- Refresh
  patches.suse/media-Explicitly-include-correct-DT-includes.patch.
- commit 27a81aa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dsi-Remove-incorrect-references-to-slic.patch (drm-backport-placeholder)
- commit a547d3d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1553-drm-msm-dpu-Set-DATA_COMPRESS-on-command-mode-for-DC.patch (drm-backport-placeholder)
- commit ecbb8da
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1552-drm-msm-dpu-Add-DPU_INTF_DATA_COMPRESS-feature-flag-.patch (drm-backport-placeholder)
- commit 543ea78
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1551-drm-msm-dsi-Reduce-pclk-rate-for-compression.patch (drm-backport-placeholder)
- commit b6ecea6
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: rt5645: Add mono speaker information to the components
  string (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5645: Add a rt5645_components() helper (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5645: Add rt5645_get_pdata() helper (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5645: Refactor rt5645_parse_dt() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5645: Add platform-data for Acer Switch V 10
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: sc8280xp: Add support for SM8650 (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: mt8188-mt6359: Enable dual amp for
  mt8188-rt5682s (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8188-mt6359: add es8326 support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: mt8188-mt6359: commonize headset codec init/exit
  api (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: vangogh: Switch to {RUNTIME,SYSTEM_SLEEP}_PM_OPS
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: vangogh: Allow probing ACP PCI when SOF is disabled
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc.h: don't create dummy Component via COMP_DUMMY()
  (jsc#PED-9993 jsc#PED-10202).
- commit 417f5a4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1550-msm-drm-dsi-Round-up-DSC-hdisplay-calculation.patch (drm-backport-placeholder)
- commit 4b74fe0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1549-drm-msm-dpu-add-DSC-1.2-hw-blocks-for-relevant-chips.patch (drm-backport-placeholder)
- commit 06087fb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1548-drm-msm-dpu-add-support-for-DSC-encoder-v1.2-engine.patch (drm-backport-placeholder)
- commit b98639d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1547-drm-msm-dsi-update-hdisplay-calculation-for-dsi_timi.patch (drm-backport-placeholder)
- commit bcd6d0a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1546-drm-msm-dsi-Use-MSM-and-DRM-DSC-helper-methods.patch (drm-backport-placeholder)
- commit c2695f8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Fix-slice_last_group_size-calculati.patch (drm-backport-placeholder)
- commit c21733a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1544-drm-msm-dpu-Use-fixed-DRM-DSC-helper-for-det_thresh_.patch (drm-backport-placeholder)
- commit f7a611a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1543-drm-msm-Add-MSM-specific-DSC-helper-methods.patch (drm-backport-placeholder)
- commit c94883b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1542-drm-msm-dsi-use-DRM-DSC-helpers-for-DSC-setup.patch (drm-backport-placeholder)
- commit 9ab0e7d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1541-drm-display-dsc-Add-drm_dsc_get_bpp_int-helper.patch (drm-backport-placeholder)
- commit f9a8f53
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1540-drm-display-dsc-add-helper-to-set-semi-const-paramet.patch (drm-backport-placeholder)
- commit b6e3255
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1539-drm-display-dsc-Add-flatness-and-initial-scale-value.patch (drm-backport-placeholder)
- commit 9a503d3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1538-drm-msm-dpu-catalog-define-DSPP-blocks-found-on-sdm8.patch (drm-backport-placeholder)
- commit 8aa9cfb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-do-not-enable-color-management-if-D.patch (drm-backport-placeholder)
- commit 21d8f5f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1536-drm-msm-adreno-make-adreno_is_a690-s-argument-const.patch (drm-backport-placeholder)
- commit 652ce7f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1535-drm-msm-adreno-change-adreno_is_-functions-to-accept.patch (drm-backport-placeholder)
- commit a886af4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1534-drm-msm-adreno-warn-if-chip-revn-is-verified-before-.patch (drm-backport-placeholder)
- commit 79ec084
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-a5xx-really-check-for-A510-in-a5xx_gpu_.patch (drm-backport-placeholder)
- commit 49fd23f
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: SOF: IPC4: synchronize fw_config_params with fw
  definitions (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: add alignment for topology header file struct
  definition (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: align topology header file with sof topology header
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Deprecate invalid enums in IPC3 (jsc#PED-9993
  jsc#PED-10202).
- commit bae8afb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1532-drm-msm-a6xx-Fix-a690-CP_PROTECT-settings.patch (drm-backport-placeholder)
- commit d62360e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1531-drm-msm-adreno-Add-Adreno-A690-support.patch (drm-backport-placeholder)
- commit 2f48004
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1530-drm-msm-Move-cmdstream-dumping-out-of-sched-kthread.patch (drm-backport-placeholder)
- commit 6fdcb59
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-a6xx-don-t-set-IO_PGTABLE_QUIRK_ARM_OUT.patch (drm-backport-placeholder)
- commit c8b7dd0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1528-drm-msm-drop-unused-ring-variable-in-msm_ioctl_gem_s.patch (drm-backport-placeholder)
- commit cf23244
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-adreno-fix-sparse-warnings-in-a6xx-code.patch (drm-backport-placeholder)
- commit edde071
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1526-drm-msm-mdp5-Add-MDP5-configuration-for-MSM8226.patch (drm-backport-placeholder)
- commit f6eedcf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1525-drm-msm-dsi-Add-phy-configuration-for-MSM8226.patch (drm-backport-placeholder)
- commit eac0e91
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1524-drm-msm-dsi-Add-configuration-for-MSM8226.patch (drm-backport-placeholder)
- commit e194666
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1523-drm-msm-dpu-drop-mostly-unused-DPU_NAME_SIZE-define.patch (drm-backport-placeholder)
- commit bc5339a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1522-drm-msm-dpu-drop-dpu_encoder_phys_ops-late_register.patch (drm-backport-placeholder)
- commit ba8f43c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1521-drm-msm-dsi-use-mult_frac-for-pclk_bpp-calculation.patch (drm-backport-placeholder)
- commit 08f8930
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1520-drm-msm-dsi-remove-extra-call-to-dsi_get_pclk_rate.patch (drm-backport-placeholder)
- commit f8fa4d8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dsi-don-t-allow-enabling-14nm-VCO-with-.patch (drm-backport-placeholder)
- commit e9545e6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1518-drm-msm-dsi-More-properly-handle-errors-in-regards-t.patch (drm-backport-placeholder)
- commit 71d9b0a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1517-drm-msm-dsi-Stop-unconditionally-powering-up-DSI-hos.patch (drm-backport-placeholder)
- commit 767fd8f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1516-drm-msm-dp-Clean-up-pdev-dev-duplication-in-dp_power.patch (drm-backport-placeholder)
- commit 0481a59
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1515-drm-msm-dp-Clean-up-logs-dp_power-module.patch (drm-backport-placeholder)
- commit c49ff1f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1514-drm-msm-dp-remove-most-of-usbpd-related-remains.patch (drm-backport-placeholder)
- commit 8300ee8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1513-drm-msm-dpu-tidy-up-some-error-checking.patch (drm-backport-placeholder)
- commit 1298ddb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1512-drm-msm-dpu-add-DSC-blocks-to-the-catalog-of-MSM8998.patch (drm-backport-placeholder)
- commit 475f463
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1511-drm-msm-dpu-Add-SM6375-support.patch (drm-backport-placeholder)
- commit 40ee317
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1510-drm-msm-dpu-Add-SM6350-support.patch (drm-backport-placeholder)
- commit 4617dff
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1509-drm-msm-dpu-use-PINGPONG_NONE-to-unbind-WB-from-PP.patch (drm-backport-placeholder)
- commit ffd1ed9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1508-drm-msm-dpu-use-PINGPONG_NONE-to-unbind-INTF-from-PP.patch (drm-backport-placeholder)
- commit 367762f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1507-drm-msm-dpu-simplify-dpu_encoder_phys_wb_init.patch (drm-backport-placeholder)
- commit 2400f1d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1506-drm-msm-dpu-drop-temp-variable-from-dpu_encoder_phys.patch (drm-backport-placeholder)
- commit ba14741
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1505-drm-msm-dpu-call-dpu_rm_get_intf-from-dpu_encoder_ge.patch (drm-backport-placeholder)
- commit aaaf179
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1504-drm-msm-dpu-inline-dpu_encoder_get_wb.patch (drm-backport-placeholder)
- commit 429e0db
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1503-drm-msm-dpu-drop-duplicated-intf-wb-indices-from-enc.patch (drm-backport-placeholder)
- commit 3c99ba2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1502-drm-msm-dpu-separate-common-function-to-init-physica.patch (drm-backport-placeholder)
- commit c2eec51
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1501-drm-msm-dpu-merge-dpu_encoder_init-and-dpu_encoder_s.patch (drm-backport-placeholder)
- commit 8d4bf06
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-clean-up-dpu_kms_get_clk_rate-returns.patch (drm-backport-placeholder)
- commit ccdf562
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1499-drm-msm-dpu-Tear-down-DSC-datapath-on-encoder-cleanu.patch (drm-backport-placeholder)
- commit 6134b7c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1498-drm-msm-dpu-separate-DSC-flush-update-out-of-interfa.patch (drm-backport-placeholder)
- commit b0bc9c1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-always-clear-every-individual-pendi.patch (drm-backport-placeholder)
- commit 9834c16
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1496-drm-msm-dpu-Introduce-PINGPONG_NONE-to-disconnect-DS.patch (drm-backport-placeholder)
- commit e840c9d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1495-drm-msm-dpu-Guard-PINGPONG-DSC-ops-behind-DPU_PINGPO.patch (drm-backport-placeholder)
- commit 2b708c0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1494-drm-msm-dpu-add-DPU_PINGPONG_DSC-feature-bit-for-DPU.patch (drm-backport-placeholder)
- commit 6cc42e8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-set-DSC-flush-bit-correctly-at-MDP-.patch (drm-backport-placeholder)
- commit 3448f38
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1492-drm-msm-dpu-use-common-helper-for-WB-and-SSPP-QoS-se.patch (drm-backport-placeholder)
- commit 2ac40fb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1491-drm-msm-dpu-remove-struct-dpu_hw_pipe_qos_cfg.patch (drm-backport-placeholder)
- commit ac6d5cf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1490-drm-msm-dpu-drop-DPU_PLANE_QOS_PANIC_CTRL.patch (drm-backport-placeholder)
- commit 5902b75
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1489-drm-msm-dpu-simplify-qos_ctrl-handling.patch (drm-backport-placeholder)
- commit 020864b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1488-drm-msm-dpu-drop-DPU_PLANE_QOS_VBLANK_CTRL.patch (drm-backport-placeholder)
- commit 24e361f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1487-drm-msm-dpu-rearrange-QoS-setting-code.patch (drm-backport-placeholder)
- commit 4d51ef7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1486-drm-msm-dpu-fix-the-condition-for-not-applying-QoS-t.patch (drm-backport-placeholder)
- commit 6c2101f
* Wed Sep  4 2024 oneukum@suse.com
- media: videobuf2: Don't assert held reservation lock for
  dma-buf mmapping (jsc#PED-8643).
- commit d104fcf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1485-drm-msm-dpu-simplify-CDP-programming.patch (drm-backport-placeholder)
- commit de5f592
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1484-drm-msm-dpu-fix-SSPP-register-definitions.patch (drm-backport-placeholder)
- commit adf75c2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1483-drm-msm-dpu-move-PINGPONG_NONE-check-to-dpu_lm_init.patch (drm-backport-placeholder)
- commit 254ede5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1482-drm-msm-dpu-use-PINGPONG_NONE-for-LMs-with-no-PP-att.patch (drm-backport-placeholder)
- commit 26c0f91
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1481-drm-msm-dpu-remove-futile-checks-from-dpu_rm_init.patch (drm-backport-placeholder)
- commit f4b9aa7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1480-drm-msm-dpu-replace-IS_ERR_OR_NULL-with-IS_ERR-durin.patch (drm-backport-placeholder)
- commit b36c8b5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Set-DPU_DATA_HCTL_EN-for-in-INTF_SC.patch (drm-backport-placeholder)
- commit b07801c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1478-drm-msm-dpu-access-CSC-CSC10-registers-directly.patch (drm-backport-placeholder)
- commit 7c0ea15
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1477-drm-msm-dpu-access-QSEED-registers-directly.patch (drm-backport-placeholder)
- commit 8d8a837
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1476-drm-msm-dpu-drop-SSPP-s-SRC-subblock.patch (drm-backport-placeholder)
- commit 964ab3e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1475-drm-msm-dpu-Remove-intr_rdptr-from-DPU-5.0.0-pingpon.patch (drm-backport-placeholder)
- commit 09e81e8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1474-drm-msm-dpu-Implement-tearcheck-support-on-INTF-bloc.patch (drm-backport-placeholder)
- commit 772761e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1473-drm-msm-dpu-Merge-setup_-and-enable_tearcheck-pingpo.patch (drm-backport-placeholder)
- commit 2d1c657
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1472-drm-msm-dpu-Add-TEAR-READ-pointer-interrupt-to-INTF-.patch (drm-backport-placeholder)
- commit 099dc0c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1471-drm-msm-dpu-Describe-TEAR-interrupt-registers-for-DS.patch (drm-backport-placeholder)
- commit 6d588b7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1470-drm-msm-dpu-Factor-out-shared-interrupt-register-in-.patch (drm-backport-placeholder)
- commit b80c489
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1469-drm-msm-dpu-Move-dpu_hw_-tear_check-pp_vsync_info-to.patch (drm-backport-placeholder)
- commit be2fdf1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1468-drm-msm-dpu-Disable-MDP-vsync-source-selection-on-DP.patch (drm-backport-placeholder)
- commit 6479154
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Disable-pingpong-TE-on-DPU-5.0.0-an.patch (drm-backport-placeholder)
- commit b70d2e0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Move-autorefresh-disable-from-CMD-e.patch (drm-backport-placeholder)
- commit 1453b8f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Drop-unused-poll_timeout_wr_ptr-PIN.patch (drm-backport-placeholder)
- commit efedbc7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1464-drm-msm-dpu-Take-INTF-index-as-parameter-in-interrup.patch (drm-backport-placeholder)
- commit 1b2081d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1463-drm-msm-dpu-Sort-INTF-registers-numerically.patch (drm-backport-placeholder)
- commit 4d76263
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1462-drm-msm-dpu-Remove-extraneous-register-define-indent.patch (drm-backport-placeholder)
- commit f5706d9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-Use-V4.0-PCC-DSPP-sub-block-in-SC7-.patch (drm-backport-placeholder)
- commit a097d8c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1460-drm-msm-dpu-add-writeback-support-for-sc7280.patch (drm-backport-placeholder)
- commit 4a3f784
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1459-drm-msm-dpu-drop-unused-SSPP-sub-block-information.patch (drm-backport-placeholder)
- commit 9fa9fb9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1458-drm-msm-dpu-drop-DSPP_MSM8998_MASK-from-hw-catalog.patch (drm-backport-placeholder)
- commit 88aabda
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1457-drm-msm-dpu-remove-GC-and-IGC-related-code-from-dpu-.patch (drm-backport-placeholder)
- commit 6da496a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1456-drm-msm-dpu-remove-DPU_DSPP_IGC-handling-in-dspp-flu.patch (drm-backport-placeholder)
- commit 3225bb8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1455-drm-msm-dpu-remove-DPU_DSPP_GC-handling-in-dspp-flus.patch (drm-backport-placeholder)
- commit e44469b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1454-drm-msm-dpu-Pass-catalog-pointers-in-RM-to-replace-f.patch (drm-backport-placeholder)
- commit 0c9f2eb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1453-drm-msm-dpu-Drop-unused-members-from-HW-structs.patch (drm-backport-placeholder)
- commit f679258
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1452-drm-msm-dpu-stop-mapping-the-regdma-region.patch (drm-backport-placeholder)
- commit 6b59ad3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-drop-the-regdma-configuration.patch (drm-backport-placeholder)
- commit 74906ea
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1450-drm-msm-dpu-set-max-cursor-width-to-512x512.patch (drm-backport-placeholder)
- commit 19e77bc
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: remove asoc_xxx() compatible macro (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ASoC-makes-CPU-Codec-channel-connection-map-more-gen.patch.
- commit f49caee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-fix-cursor-block-register-bit-offse.patch (drm-backport-placeholder)
- commit d1e881a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1448-drm-msm-dpu-use-hsync-vsync-polarity-set-by-the-enco.patch (drm-backport-placeholder)
- commit d9cf6a6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1447-drm-msm-dpu-add-HDMI-output-support.patch (drm-backport-placeholder)
- commit 96383ac
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1446-drm-msm-dpu-simplify-intf-allocation-code.patch (drm-backport-placeholder)
- commit b5f1dd9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1445-drm-msm-dpu-use-CTL_SC7280_MASK-for-sm8450-s-ctl_0.patch (drm-backport-placeholder)
- commit 11b33a0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1444-drm-msm-dpu-enable-DSPP-and-DSC-on-sc8180x.patch (drm-backport-placeholder)
- commit 48be455
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-msm-dpu-enable-DSPP_2-3-for-LM_2-3-on-sm845.patch (drm-backport-placeholder)
- commit aac5410
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1442-drm-msm-dpu-enable-DPU_CTL_SPLIT_DISPLAY-for-sc8280x.patch (drm-backport-placeholder)
- commit 07b8d34
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1441-drm-msm-mdss-Add-SM6375-support.patch (drm-backport-placeholder)
- commit 20d1a9b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1440-drm-msm-mdss-Add-SM6350-support.patch (drm-backport-placeholder)
- commit 238178f
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: sof: use snd_soc_dummy_dlc (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: hdaudio.c: use snd_soc_dummy_dlc (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: odroid: don't need DUMMY Platform (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: fsl-asoc-card: don't need DUMMY Platform
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: simple-card-utils: Drop GPIO include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: sc7180: Drop GPIO include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: hisilicon: Drop GPIO include (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc.h: replace custom COUNT_ARGS() & CONCATENATE()
  implementations (jsc#PED-9993 jsc#PED-10202).
- commit 0dcf8ab
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1439-drm-msm-Remove-unnecessary-void-conversions.patch (drm-backport-placeholder)
- commit 69c7549
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-dp_mst-Clear-MSG_RDY-flag-before-sending-ne.patch (drm-backport-placeholder)
- commit 440e11b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1437-drm-amdgpu-Increase-hmm-range-get-pages-timeout.patch (drm-backport-placeholder)
- commit 7da47b6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1436-drm-amdgpu-Enable-translate-further-for-GC-v9.4.3.patch (drm-backport-placeholder)
- commit 46a3146
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1435-drm-amdgpu-Remove-unused-NBIO-interface.patch (drm-backport-placeholder)
- commit b0d4863
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1434-drm-amdkfd-bump-kfd-ioctl-minor-version-for-event-ag.patch (drm-backport-placeholder)
- commit 3d284a8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1433-drm-amdkfd-update-user-space-last_event_age.patch (drm-backport-placeholder)
- commit c58ded2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1432-drm-amdkfd-set-activated-flag-true-when-event-age-un.patch (drm-backport-placeholder)
- commit d8b750c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1431-drm-amdkfd-add-event_age-tracking-when-receiving-int.patch (drm-backport-placeholder)
- commit 0412efc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1430-drm-amdkfd-add-event-age-tracking.patch (drm-backport-placeholder)
- commit c5614c0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1429-drm-scheduler-avoid-infinite-loop-if-entity-s-depend.patch (drm-backport-placeholder)
- commit fdc748a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1428-drm-amdgpu-add-entity-error-check-in-amdgpu_ctx_get_.patch (drm-backport-placeholder)
- commit a8d2b20
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1427-drm-amdgpu-add-VM-generation-token.patch (drm-backport-placeholder)
- commit 4d06d51
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1426-drm-amdgpu-reset-VM-when-an-error-is-detected.patch (drm-backport-placeholder)
- commit 3b29964
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1425-drm-amdgpu-abort-submissions-during-prepare-on-error.patch (drm-backport-placeholder)
- commit 75c27a9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1424-drm-amdgpu-mark-soft-recovered-fences-with-ENODATA.patch (drm-backport-placeholder)
- commit 35892ca
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1423-drm-amdgpu-mark-force-completed-fences-with-ECANCELE.patch (drm-backport-placeholder)
- commit 70e14af
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1422-drm-amdgpu-add-amdgpu_error_-debugfs-file.patch (drm-backport-placeholder)
- commit f51843a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1421-drm-amdgpu-mark-GC-9.4.3-experimental-for-now.patch (drm-backport-placeholder)
- commit d8390bf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1420-drm-amdgpu-Use-PSP-FW-API-for-partition-switch.patch (drm-backport-placeholder)
- commit baf06dc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1419-drm-amdgpu-Change-nbio-v7.9-xcp-status-definition.patch (drm-backport-placeholder)
- commit d5d8add
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-make-sure-that-BOs-have-a-backing-st.patch (drm-backport-placeholder)
- commit 4d8ce96
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-make-sure-BOs-are-locked-in-amdgpu_v.patch (drm-backport-placeholder)
- commit ccf5954
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1416-drm-amdgpu-Add-checking-mc_vram_size.patch (drm-backport-placeholder)
- commit 29878b3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1415-drm-amdgpu-Optimize-checking-ras-supported.patch (drm-backport-placeholder)
- commit 7ac704e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1414-drm-amdgpu-Add-channel_dis_num-to-ras-init-flags.patch (drm-backport-placeholder)
- commit 45b85c6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1413-drm-amdgpu-Update-total-channel-number-for-umc-v8_10.patch (drm-backport-placeholder)
- commit 1779aba
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1412-drm-amd-pm-Align-eccinfo-table-structure-with-smu-v1.patch (drm-backport-placeholder)
- commit c7dc7c9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1411-drm-amd-display-Convert-to-kdoc-formats-in-dc-core-d.patch (drm-backport-placeholder)
- commit 6938f81
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1410-drm-amdkfd-decrement-queue-count-on-mes-queue-destro.patch (drm-backport-placeholder)
- commit b1e3fce
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1409-drm-amd-pm-enable-more-Pstates-profile-levels-for-SM.patch (drm-backport-placeholder)
- commit a02e597
* Wed Sep  4 2024 oneukum@suse.com
- media: Add NV15_4L4 pixel format (jsc#PED-8643).
- commit 2d3e640
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1408-drm-radeon-Fix-missing-prototypes-in-radeon_atpx_han.patch (drm-backport-placeholder)
- commit 7358ae6
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: sprd: Simplify memory allocation in
  sprd_platform_compr_dma_config() (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: Add acp-psp mailbox interface for iram-dram
  fence register modification (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Rename amd_bt sof_dai_type (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Add i2s bt dai configuration support for AMD
  platforms (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Refactor sof_i2s_tokens reading to update acpbt dai
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: Refactor spinlock_irq(&sdev->ipc_lock) sequence
  in irq_handler (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Remove redundant ret variable (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: Fix trivial code style issues (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-pcm.c: Complete the active count for components
  without DAIs (jsc#PED-9993 jsc#PED-10202).
- commit 017004c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-usage-of-UMC-fill-record-in-RAS.patch (drm-backport-placeholder)
- commit 192c4cc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1405-drm-amdgpu-Report-ras_num_recs-in-debugfs.patch (drm-backport-placeholder)
- commit 5fc64c7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1404-drm-amdkfd-Remove-DUMMY_VRAM_SIZE.patch (drm-backport-placeholder)
- commit a2d95f1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1403-drm-amdgpu-Release-SDMAv4.4.2-ecc-irq-properly.patch (drm-backport-placeholder)
- commit b74fd0f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1402-drm-amdgpu-add-wait_for-helper-for-spirom-update.patch (drm-backport-placeholder)
- commit 5329c5e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1401-drm-amd-display-Clean-up-dcn10_optc.c-kdoc.patch (drm-backport-placeholder)
- commit 4197e3c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1400-drm-amd-display-Correct-kdoc-formats-in-dcn32_resour.patch (drm-backport-placeholder)
- commit 028bc2a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1399-drm-amd-display-Provide-function-name-for-optc32_ena.patch (drm-backport-placeholder)
- commit f8fe331
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1398-drm-amd-display-Correct-and-remove-excess-function-p.patch (drm-backport-placeholder)
- commit 6d70389
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1397-drm-amd-display-Correct-kdoc-formats-in-dcn10_opp.c.patch (drm-backport-placeholder)
- commit b199251
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: amd: acp: add pm ops support for renoir platform
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: check fw_context_save for library reload
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: IPC4: query fw_context_save feature from fw
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl_mqs: remove duplicated including (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: amd: remove duplicated including (jsc#PED-9993
  jsc#PED-10202).
- ASoC: audio-graph-card2: Introduce playback-only/capture-only
  DAI link flags (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Add missing statics for hp_ilimit functions
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Allow HP amp to cool off after current limit
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codec: wsa884x: make use of new mute_unmute_on_trigger
  flag (jsc#PED-9993 jsc#PED-10202).
- commit 63124e1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1396-drm-amdgpu-Add-missing-function-parameter-optc-enabl.patch (drm-backport-placeholder)
- commit 9550502
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1395-drm-amdgpu-Print-client-id-for-the-unregistered-inte.patch (drm-backport-placeholder)
- commit 75686ce
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1394-drm-amdkfd-To-enable-traps-for-GC_11_0_4-and-up.patch (drm-backport-placeholder)
- commit 3531d5b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1393-drm-amd-display-don-t-free-stolen-console-memory-dur.patch (drm-backport-placeholder)
- commit ea033f5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1392-Revert-drm-amd-display-fix-dpms_off-issue-when-disab.patch (drm-backport-placeholder)
- commit 468687c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1391-drm-amdkfd-fix-null-queue-check-on-debug-setting-exc.patch (drm-backport-placeholder)
- commit a764dac
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1390-drm-amd-pm-enable-vclk-and-dclk-Pstates-for-SMU-v13..patch (drm-backport-placeholder)
- commit 185a004
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-memcpy-in-sienna_cichlid_append_.patch (drm-backport-placeholder)
- commit e70b13c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1388-drm-amd-pm-fix-vclk-setting-failed-for-SMU-v13.0.5.patch (drm-backport-placeholder)
- commit d862aec
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1387-drm-amd-display-3.2.239.patch (drm-backport-placeholder)
- commit 03aa12e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1386-drm-amd-display-fix-pixel-rate-update-sequence.patch (drm-backport-placeholder)
- commit 18b1793
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1385-Revert-drm-amd-display-reallocate-DET-for-dual-displ.patch (drm-backport-placeholder)
- commit 70c3d5f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1384-drm-amd-display-Include-CSC-updates-in-new-fast-upda.patch (drm-backport-placeholder)
- commit 637fd3a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1383-drm-amd-display-Limit-Minimum-FreeSync-Refresh-Rate.patch (drm-backport-placeholder)
- commit e5461f2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1382-drm-amd-display-Bug-fix-in-dcn315_populate_dml_pipes.patch (drm-backport-placeholder)
- commit 5a65d99
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1381-drm-amd-display-Block-SubVP-DRR-if-the-DRR-is-PSR-ca.patch (drm-backport-placeholder)
- commit 589cb10
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1380-drm-amd-display-Do-not-disable-phantom-pipes-in-driv.patch (drm-backport-placeholder)
- commit f0c7053
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1379-drm-amd-display-Re-enable-SubVP-high-refresh.patch (drm-backport-placeholder)
- commit f9db4b2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1378-drm-amd-display-Re-enable-DPP-HUBP-Power-Gating.patch (drm-backport-placeholder)
- commit e826946
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1377-drm-amd-display-SubVP-high-refresh-only-if-all-displ.patch (drm-backport-placeholder)
- commit 5c1fcff
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1376-drm-amd-display-Fix-disbling-PSR-slow-response-issue.patch (drm-backport-placeholder)
- commit 3cffaeb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1375-drm-amd-display-Promote-DAL-to-3.2.238.patch (drm-backport-placeholder)
- commit 60e7d77
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1374-drm-amd-display-Add-Error-Code-for-Dml-Validation-Fa.patch (drm-backport-placeholder)
- commit fa66191
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1373-drm-amd-display-Add-DP2-Metrics.patch (drm-backport-placeholder)
- commit 0a93dbf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1372-drm-amd-display-add-debugfs-for-allow_edp_hotplug_de.patch (drm-backport-placeholder)
- commit 04ba085
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1371-drm-amdgpu-expose-num_hops-and-num_links-xgmi-info-t.patch (drm-backport-placeholder)
- commit 997eab8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1370-drm-amd-amdgpu-enable-W-1-for-amdgpu.patch (drm-backport-placeholder)
- commit b7fa784
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1369-drm-amdgpu-Fix-kdoc-warning.patch (drm-backport-placeholder)
- commit e98b04e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Enable-dcn314-DPP-RCO.patch (drm-backport-placeholder)
- commit 8711b36
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1367-drm-amdgpu-Rename-DRM-schedulers-in-amdgpu-TTM.patch (drm-backport-placeholder)
- commit b78866a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1366-drm-amd-display-amdgpu_dm-amdgpu_dm_helpers-Move-SYN.patch (drm-backport-placeholder)
- commit 10e1cae
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Skip-DPP-DTO-update-if-root-cl.patch (drm-backport-placeholder)
- commit 5c13ea0
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: qcom: audioreach: Add 4 channel support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: audioreach: drop duplicate channel defines
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: audioreach: Commonize setting channel mappings
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm1250-ev1: Fix uninitialized ret (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm8996: Convert to GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm5100: Convert to GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm2200: Convert to GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm1250-ev1: Convert to GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm0010: Convert to GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: audio-graph-card2: fix off by one in
  graph_parse_node_multi_nm() (jsc#PED-9993 jsc#PED-10202).
- commit bc95cd6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1364-fbdev-Use-comment-in-initializer-macro.patch (drm-backport-placeholder)
- commit 856fda6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1363-drm-i915-selftests-add-local-workqueue-for-SW-fence-.patch (drm-backport-placeholder)
- commit 62e0e39
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1362-drm-i915-add-a-dedicated-workqueue-inside-drm_i915_p.patch (drm-backport-placeholder)
- commit 0b9381a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1361-drm-i915-use-pointer-to-i915-instead-of-rpm-in-waker.patch (drm-backport-placeholder)
- commit 11fe92c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1360-drm-i915-re-enable-Wunused-but-set-variable.patch (drm-backport-placeholder)
- commit eabee4d
* Wed Sep  4 2024 oneukum@suse.com
- media: v4l2-common: Add support for fractional bpp
  (jsc#PED-8643).
- commit 447cf61
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1358-drm-i915-display-Include-of-display-limits-doesn-t-n.patch (drm-backport-placeholder)
- commit 407be53
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1357-drm-i915-mtl-Add-support-for-PM-DEMAND.patch (drm-backport-placeholder)
- commit 535b199
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1356-drm-i915-mtl-find-the-best-QGV-point-for-the-SAGV-co.patch (drm-backport-placeholder)
- commit 9b73826
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1355-drm-i915-modify-max_bw-to-return-index-to-intel_bw_i.patch (drm-backport-placeholder)
- commit 69585f8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1354-drm-i915-extract-intel_bw_check_qgv_points.patch (drm-backport-placeholder)
- commit 21b9072
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1353-drm-i915-store-the-peak-bw-per-QGV-point.patch (drm-backport-placeholder)
- commit ac7b479
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1352-drm-i915-update-the-QGV-point-frequency-calculations.patch (drm-backport-placeholder)
- commit befb978
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1351-drm-i915-fix-the-derating-percentage-for-MTL.patch (drm-backport-placeholder)
- commit a79b4ed
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1350-drm-i915-dp-Fix-log-level-for-CDS-interlane-align-do.patch (drm-backport-placeholder)
- commit 5e6ba24
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1349-drm-i915-annotate-maybe-unused-but-set-intel_crtc_st.patch (drm-backport-placeholder)
- commit 2d71817
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1348-drm-i915-annotate-maybe-unused-but-set-intel_plane_s.patch (drm-backport-placeholder)
- commit 09d9dd6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1347-drm-i915-selftest-annotate-maybe-unused-but-set-vari.patch (drm-backport-placeholder)
- commit 9af8c6b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1346-drm-i915-gem-annotate-maybe-unused-but-set-variable-.patch (drm-backport-placeholder)
- commit 555b4c8
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: amd: acp: modify config flag read logic (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: acp: Set bclk as source to set pll for rt5682s codec
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Enable dpcm_capture for MAX98388 codec
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Add i2s bt support for nau8821-max card
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Add new cpu dai and dailink creation for I2S
  BT instance (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: Remove extra dmi parameter (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: vangogh: Add condition check for acp config flag
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: Add new dmi entries for acp5x platform (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Wire up buffer flags (jsc#PED-9993 jsc#PED-10202).
- commit 2b01d20
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1345-drm-i915-gem-drop-unused-but-set-variable-unpinned.patch (drm-backport-placeholder)
- commit 84bd987
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1344-drm-i915-gt-uc-drop-unused-but-set-variable-sseu.patch (drm-backport-placeholder)
- commit 226a252
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1343-drm-i915-irq-drop-unused-but-set-variable-tmp.patch (drm-backport-placeholder)
- commit b2d74a9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1342-drm-i915-fb-drop-unused-but-set-variable-cpp.patch (drm-backport-placeholder)
- commit 63e3a42
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1341-drm-i915-dpll-drop-unused-but-set-variables-bestn-an.patch (drm-backport-placeholder)
- commit 0f8e3fc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1340-drm-i915-dsi-drop-unused-but-set-variable-vbp.patch (drm-backport-placeholder)
- commit c56ff14
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1339-drm-i915-dsi-drop-unused-but-set-variable-data.patch (drm-backport-placeholder)
- commit 3a9cd61
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1338-drm-i915-ddi-drop-unused-but-set-variable-intel_dp.patch (drm-backport-placeholder)
- commit 3a27013
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1337-drm-i915-plane-warn-on-non-zero-plane-offset.patch (drm-backport-placeholder)
- commit cd92a4d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1336-drm-i915-debugfs-stop-using-edid_blob_ptr.patch (drm-backport-placeholder)
- commit cf2f631
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1335-drm-i915-Fix-error-handling-if-driver-creation-fails.patch (drm-backport-placeholder)
- commit 91b3598
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1334-drm-i915-display-Extract-display-init-from-intel_dev.patch (drm-backport-placeholder)
- commit 432c49f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1333-drm-i915-No-10bit-gamma-on-desktop-gen3-parts.patch (drm-backport-placeholder)
- commit 6fd9a74
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1332-drm-i915-display-Print-useful-information-on-error.patch (drm-backport-placeholder)
- commit c82d0fa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1331-drm-amd-display-Filter-out-AC-mode-frequencies-on-DC.patch (drm-backport-placeholder)
- commit 3daee07
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1330-drm-amd-display-DSC-Programming-Deltas.patch (drm-backport-placeholder)
- commit 028252d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1329-Revert-drm-amd-display-cache-trace-buffer-size.patch (drm-backport-placeholder)
- commit b6bcb5c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1328-drm-amd-display-add-NULL-pointer-check.patch (drm-backport-placeholder)
- commit b646ed6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1327-drm-amd-pm-enable-more-Pstates-profile-levels-for-ye.patch (drm-backport-placeholder)
- commit 74960cd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1326-drm-amdgpu-add-option-params-to-enforce-process-isol.patch (drm-backport-placeholder)
- commit 712c23d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1325-drm-amdgpu-Wrap-Wunused-but-set-variable-in-cc-optio.patch (drm-backport-placeholder)
- commit 3d4a458
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1324-drm-amdgpu-add-the-accelerator-PCIe-class.patch (drm-backport-placeholder)
- commit a596397
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1323-Revert-Revert-drm-amd-display-Enable-Freesync-Video-.patch (drm-backport-placeholder)
- commit c87652a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1322-drm-amdkfd-fix-and-enable-debugging-for-gfx11.patch (drm-backport-placeholder)
- commit 5a4cbbf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1321-drm-amd-pm-enable-more-Pstates-profile-levels-for-SM.patch (drm-backport-placeholder)
- commit e0547d7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1320-drm-amd-pm-enable-vclk-and-dclk-Pstates-for-SMU-v13..patch (drm-backport-placeholder)
- commit d2ada94
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1319-drm-amd-pm-fix-vclk-setting-failed-for-SMU-v13.0.4.patch (drm-backport-placeholder)
- commit 0c975fa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1318-drm-amdgpu-skip-to-resume-rlcg-for-gc-9.4.3-in-vf-si.patch (drm-backport-placeholder)
- commit fbe8a88
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1317-drm-amdgpu-disable-virtual-display-support-on-APP-de.patch (drm-backport-placeholder)
- commit 03b20b7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-unmap-and-remove-csa_va-properly.patch (drm-backport-placeholder)
- commit 47d4307
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1315-drm-amd-display-Refactor-avi_info_frame-colorimetry-.patch (drm-backport-placeholder)
- commit 99feab2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1314-drm-amd-display-Add-debugfs-for-testing-output-color.patch (drm-backport-placeholder)
- commit 36eea5c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1313-drm-amd-display-Always-set-crtcinfo-from-create_stre.patch (drm-backport-placeholder)
- commit 952f907
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1312-drm-amd-display-Send-correct-DP-colorspace-infopacke.patch (drm-backport-placeholder)
- commit a49ebef
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1311-drm-amd-display-Signal-mode_changed-if-colorspace-ch.patch (drm-backport-placeholder)
- commit 226ceb6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1310-drm-amd-display-Register-Colorspace-property-for-DP-.patch (drm-backport-placeholder)
- commit 3d72fb3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1309-drm-amd-display-Always-pass-connector_state-to-strea.patch (drm-backport-placeholder)
- commit e654f32
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1308-drm-connector-Allow-drivers-to-pass-list-of-supporte.patch (drm-backport-placeholder)
- commit e074a13
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1307-drm-connector-Print-connector-colorspace-in-state-de.patch (drm-backport-placeholder)
- commit 12c6132
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1306-drm-connector-Use-common-colorspace_names-array.patch (drm-backport-placeholder)
- commit f635b8b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1305-drm-connector-Pull-out-common-create_colorspace_prop.patch (drm-backport-placeholder)
- commit 125d5b8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1304-drm-connector-Add-enum-documentation-to-drm_colorspa.patch (drm-backport-placeholder)
- commit 1378217
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1303-drm-connector-Convert-DRM_MODE_COLORIMETRY-to-enum.patch (drm-backport-placeholder)
- commit ef484f5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1302-drm-amdkfd-Fix-reserved-SDMA-queues-handling.patch (drm-backport-placeholder)
- commit b04695a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1301-drm-amd-Check-that-a-system-is-a-NUMA-system-before-.patch (drm-backport-placeholder)
- commit fc3bf76
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1300-drm-amdkfd-fix-vmfault-signalling-with-additional-da.patch (drm-backport-placeholder)
- commit 581cc1c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1299-drm-amdgpu-Set-EEPROM-ras-info.patch (drm-backport-placeholder)
- commit 638af93
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1298-drm-amdgpu-Calculate-EEPROM-table-ras-info-bytes-sum.patch (drm-backport-placeholder)
- commit f002e54
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1297-drm-amdgpu-Add-support-EEPROM-table-v2.1.patch (drm-backport-placeholder)
- commit 1c383b4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1296-drm-amdgpu-Support-setting-EEPROM-table-version.patch (drm-backport-placeholder)
- commit f8c3bb0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1295-drm-amdgpu-Add-RAS-table-v2.1-macro-definition.patch (drm-backport-placeholder)
- commit 63f26aa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1294-drm-amdgpu-Rename-ras-table-version.patch (drm-backport-placeholder)
- commit b68f81c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1293-drm-amdgpu-mmsch-Correct-the-definition-for-mmsch-in.patch (drm-backport-placeholder)
- commit 6ae6134
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1292-drm-amdkfd-potential-error-pointer-dereference-in-io.patch (drm-backport-placeholder)
- commit ea98d9c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1291-drm-amd-display-Only-use-ODM2-1-policy-for-high-pixe.patch (drm-backport-placeholder)
- commit 84c533e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1290-drm-amd-pm-Fix-memory-some-memory-corruption.patch (drm-backport-placeholder)
- commit bdcb8ff
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1289-drm-amdgpu-display-Kconfig-replace-leading-spaces-wi.patch (drm-backport-placeholder)
- commit d4dafb9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1288-drm-amd-display-mark-dml314-s-UseMinimumDCFCLK-as-no.patch (drm-backport-placeholder)
- commit 00599cd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1287-drm-amd-display-mark-dml31-s-UseMinimumDCFCLK-as-noi.patch (drm-backport-placeholder)
- commit e28da82
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1286-drm-amd-display-Fix-unused-variable-should_lock_all_.patch (drm-backport-placeholder)
- commit 57e3db7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1285-drm-amd-display-Add-control-flag-to-dc_stream_state-.patch (drm-backport-placeholder)
- commit 4d9d85f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1284-drm-amd-display-Wrong-index-type-for-pipe-iterator.patch (drm-backport-placeholder)
- commit 9311c19
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1283-drm-amd-display-Refactor-fast-update-to-use-new-HWSS.patch (drm-backport-placeholder)
- commit 9d94574
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-dcn315-single-stream-crb-al.patch (drm-backport-placeholder)
- commit bb04659
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1281-drm-amdgpu-convert-vcn-jpeg-logical-mask-to-physical.patch (drm-backport-placeholder)
- commit 2fe936d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1280-drm-amdgpu-support-check-vcn-jpeg-block-mask.patch (drm-backport-placeholder)
- commit 75b2989
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1279-drm-amdgpu-pass-xcc-mask-to-ras-ta.patch (drm-backport-placeholder)
- commit cc48cf9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1278-drm-amd-pm-update-smu-driver-if-header-for-smu-13.0..patch (drm-backport-placeholder)
- commit 0e395a5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1277-drm-amdgpu-pm-notify-driver-unloading-to-PMFW-for-SM.patch (drm-backport-placeholder)
- commit 6073db1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1276-drm-amdgpu-Mark-kgd_gfx_aldebaran_clear_address_watc.patch (drm-backport-placeholder)
- commit 8efb01d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1275-drm-amd-display-Program-OTG-vtotal-min-max-selectors.patch (drm-backport-placeholder)
- commit 7797e1f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1274-Revert-drm-amd-display-Only-use-ODM2-1-policy-for-hi.patch (drm-backport-placeholder)
- commit a4dda2c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1273-drm-amd-display-Add-gnu_printf-format-attribute-for-.patch (drm-backport-placeholder)
- commit 8bfb7a5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1272-drm-amd-display-Address-kdoc-warnings-in-dcn30_fpu.c.patch (drm-backport-placeholder)
- commit 9691a75
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1271-drm-amd-display-fix-compilation-error-due-to-shiftin.patch (drm-backport-placeholder)
- commit 773cb12
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1270-drm-amdgpu-discovery-Replace-fake-flex-arrays-with-f.patch (drm-backport-placeholder)
- commit c4b6656
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/amdgpu-validate-offset_in_bo-of-drm_amdgpu_gem_.patch (drm-backport-placeholder)
- commit 3f8f408
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1268-drm-amdgpu-fix-debug-wait-on-idle-for-gfx9.4.1.patch (drm-backport-placeholder)
- commit bdb76ee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-seamless-odm-transitions.patch (drm-backport-placeholder)
- commit 9044471
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1266-drm-amd-display-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 4f20f41
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1265-drm-amd-display-Fix-dc-dcn20-dcn20_optc.c-kdoc.patch (drm-backport-placeholder)
- commit cd56a48
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: Intel: sof_sdw_rt_sdca_jack_common: check
  ctx->headset_codec_dev instead of playback (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_nau8825: board id cleanup for rpl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: board id cleanup for adl boards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw_cs_amp: Connect outputs to a speaker widget
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: lnl: add core get and set support for dsp core
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs4271: Fix spelling mistake "retrieveing" -> "retrieving"
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt722-sdca: Set lane_control_support for multilane
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-tgl-match: add cs42l43 and cs35l56
  support (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: bytcht_es8316: Determine quirks/routing with
  codec-dev ACPI DSM (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: bytcht_es8316: Add is_bytcr helper variable
  (jsc#PED-9993 jsc#PED-10202).
- commit e3b693c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1264-drm-amd-pm-fulfill-the-OD-support-for-SMU13.0.7.patch (drm-backport-placeholder)
- commit 34ae1fa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1263-drm-amd-pm-Fill-metrics-data-for-SMUv13.0.6.patch (drm-backport-placeholder)
- commit e0aa8d4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1262-drm-amd-pm-fulfill-the-OD-support-for-SMU13.0.0.patch (drm-backport-placeholder)
- commit dd6a481
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1261-drm-amd-pm-fulfill-SMU13-OD-settings-init-and-restor.patch (drm-backport-placeholder)
- commit 1e3b44d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1260-drm-amdkfd-bump-kfd-ioctl-minor-version-for-debug-ap.patch (drm-backport-placeholder)
- commit 7bf3c16
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1259-drm-amdkfd-add-debug-device-snapshot-operation.patch (drm-backport-placeholder)
- commit 9ff4b73
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1258-drm-amdkfd-add-debug-queue-snapshot-operation.patch (drm-backport-placeholder)
- commit c56c05c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1257-drm-amdkfd-add-debug-query-exception-info-operation.patch (drm-backport-placeholder)
- commit 13cb005
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1256-drm-amdkfd-add-debug-query-event-operation.patch (drm-backport-placeholder)
- commit be86289
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1255-drm-amdkfd-add-debug-set-flags-operation.patch (drm-backport-placeholder)
- commit 4e566de
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1254-drm-amdkfd-add-debug-set-and-clear-address-watch-poi.patch (drm-backport-placeholder)
- commit 8471ea0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1253-drm-amdkfd-add-debug-suspend-and-resume-process-queu.patch (drm-backport-placeholder)
- commit 33dc8a8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1252-drm-amdkfd-add-debug-wave-launch-mode-operation.patch (drm-backport-placeholder)
- commit 0987ec3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1251-drm-amdkfd-add-debug-wave-launch-override-operation.patch (drm-backport-placeholder)
- commit 9ff30bf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1250-drm-amdkfd-add-debug-set-exceptions-enabled-operatio.patch (drm-backport-placeholder)
- commit d3abfd6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1249-drm-amdkfd-update-process-interrupt-handling-for-deb.patch (drm-backport-placeholder)
- commit c89ef5d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1248-drm-amd-pm-update-SMU13-header-files-for-coming-OD-s.patch (drm-backport-placeholder)
- commit 03cf76e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1247-drm-amdkfd-add-debug-trap-enabled-flag-to-tma.patch (drm-backport-placeholder)
- commit e7960f1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1246-drm-amdkfd-add-runtime-enable-operation.patch (drm-backport-placeholder)
- commit 97fa35a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1245-drm-amdkfd-add-send-exception-operation.patch (drm-backport-placeholder)
- commit 882fa8e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1244-drm-amdkfd-add-raise-exception-event-function.patch (drm-backport-placeholder)
- commit 76e4651
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1243-drm-amdkfd-apply-trap-workaround-for-gfx11.patch (drm-backport-placeholder)
- commit 459f277
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1242-drm-amdkfd-add-per-process-hw-trap-enable-and-disabl.patch (drm-backport-placeholder)
- commit 3d716e8
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: Intel: bytcht_es8316: Dump basic _DSM information
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: es83xx: add ACPI DSM helper module (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Move sof_of_machine_select() to core.c from
  sof-of-dev.c (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs4349: Drop legacy include (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs43130: Drop legacy includes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l42: Drop legacy include (jsc#PED-9993 jsc#PED-10202).
- ASoC: cirrus: edb93xx: Drop legacy include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs4271: Convert to GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l36: Drop legacy includes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l35: Drop legacy includes (jsc#PED-9993
  jsc#PED-10202).
- commit 784fd31
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1241-drm-amdgpu-expose-debug-api-for-mes.patch (drm-backport-placeholder)
- commit 19523dc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1240-drm-amdgpu-prepare-map-process-for-multi-process-deb.patch (drm-backport-placeholder)
- commit 1aa2dd6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1239-drm-amdkfd-prepare-map-process-for-single-process-de.patch (drm-backport-placeholder)
- commit a02162a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1238-drm-amdgpu-add-configurable-grace-period-for-unmap-q.patch (drm-backport-placeholder)
- commit d017c40
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1237-drm-amdgpu-add-gfx11-hw-debug-mode-enable-and-disabl.patch (drm-backport-placeholder)
- commit 3836bca
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1236-drm-amdgpu-add-gfx9.4.2-hw-debug-mode-enable-and-dis.patch (drm-backport-placeholder)
- commit b3bceea
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1235-drm-amdgpu-add-gfx10-hw-debug-mode-enable-and-disabl.patch (drm-backport-placeholder)
- commit b834208
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1234-drm-amdkfd-fix-kfd_suspend_all_processes.patch (drm-backport-placeholder)
- commit 2d91e42
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1233-drm-amdgpu-add-gfx9.4.1-hw-debug-mode-enable-and-dis.patch (drm-backport-placeholder)
- commit ef80eb5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1232-drm-amdgpu-add-gfx9-hw-debug-mode-enable-and-disable.patch (drm-backport-placeholder)
- commit f64f059
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1231-drm-amdkfd-clean-up-one-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 58126ce
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1230-drm-amd-display-Drop-unused-DCN_BASE-variable-in-dcn.patch (drm-backport-placeholder)
- commit c3645c6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1229-drm-amdgpu-setup-hw-debug-registers-on-driver-initia.patch (drm-backport-placeholder)
- commit c92e4c3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1228-drm-amdgpu-add-kgd-hw-debug-mode-setting-interface.patch (drm-backport-placeholder)
- commit 29d43b1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1227-drm-amdkfd-prepare-per-process-debug-enable-and-disa.patch (drm-backport-placeholder)
- commit e4126ec
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1226-drm-amdkfd-display-debug-capabilities.patch (drm-backport-placeholder)
- commit 5f8dabb
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: cs35l34: Fix GPIO name and drop legacy include
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l32: Drop legacy include (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: sc8280xp: Add support for SM8450 and SM8550
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: sc8280xp: set card driver name from match data
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: core: Implement IPC version fallback if firmware
  files are missing (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: Do not use resource managed allocation for
  ipc4_data (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: core: Add helper for initialization of paths, ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: sof-pci-dev: Rely on core to create the file paths
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: sof-of-dev: Rely on core to create the file paths
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: sof-acpi-dev: Rely on core to create the file paths
  (jsc#PED-9993 jsc#PED-10202).
- commit e616ec9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1225-drm-amdkfd-add-debug-and-runtime-enable-interface.patch (drm-backport-placeholder)
- commit c46f9fd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1224-amd-amdkfd-drop-unused-KFD_IOCTL_SVM_FLAG_UNCACHED-f.patch (drm-backport-placeholder)
- commit ebd59c3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1223-drm-amd-pm-add-unique-serial-number-support-for-smu_.patch (drm-backport-placeholder)
- commit b90df6e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1222-drm-amd-pm-Fix-SMUv13.0.6-throttle-status-report.patch (drm-backport-placeholder)
- commit b1066b3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1221-drm-amd-pm-Update-SMUv13.0.6-PMFW-headers.patch (drm-backport-placeholder)
- commit c11ccac
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1220-drm-amdgpu-Add-function-parameter-event-to-kdoc-in-s.patch (drm-backport-placeholder)
- commit 2e20993
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1219-drm-amdgpu-Fix-up-kdoc-in-amdgpu_device.c.patch (drm-backport-placeholder)
- commit 5457ea5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1218-drm-amdgpu-Fix-up-kdoc-ring-parameter-in-sdma_v6_0_r.patch (drm-backport-placeholder)
- commit 8db7a12
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1217-drm-amd-display-Fix-up-kdoc-formatting-in-display_mo.patch (drm-backport-placeholder)
- commit 09f0ce1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1216-drm-amd-amdgpu-introduce-DRM_AMDGPU_WERROR.patch (drm-backport-placeholder)
- commit b5269b6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1215-drm-amdkfd-remove-unused-sq_int_priv-variable.patch (drm-backport-placeholder)
- commit e0636c7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1214-drm-amd-display-Correct-kdoc-formatting-for-DCN32_CR.patch (drm-backport-placeholder)
- commit 46d528e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1213-drm-amd-display-Fix-up-missing-dc-pipe_ctx-kdoc-para.patch (drm-backport-placeholder)
- commit 3f911d2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1212-drm-amd-display-Fix-up-kdoc-formatting-in-dcn32_reso.patch (drm-backport-placeholder)
- commit 06a8d34
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1211-drm-amdxcp-fix-Makefile-to-build-amdxcp-module.patch (drm-backport-placeholder)
- commit c45edcb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1210-drm-amdgpu-Fix-up-missing-parameters-kdoc-in-svm_mig.patch (drm-backport-placeholder)
- commit cd7f045
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1209-drm-amdgpu-set-finished-fence-error-if-job-timedout.patch (drm-backport-placeholder)
- commit d19fc40
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1208-drm-amdgpu-Fix-missing-parameter-desc-for-xcp_id-in-.patch (drm-backport-placeholder)
- commit 2fcfa12
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1207-drm-amdgpu-Fix-up-missing-parameter-in-kdoc-for-inst.patch (drm-backport-placeholder)
- commit c16032c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1206-drm-amdgpu-Fix-up-missing-kdoc-parameter-inst-in-get.patch (drm-backport-placeholder)
- commit be2ee89
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1205-drm-amdgpu-Fix-missing-parameter-desc-for-xcc_id-in-.patch (drm-backport-placeholder)
- commit a7f649f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1204-drm-amdkfd-flag-added-to-handle-errors-from-svm-vali.patch (drm-backport-placeholder)
- commit 6fa2ecc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1203-drm-amdgpu-Initialize-xcc-mask.patch (drm-backport-placeholder)
- commit f35450f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1202-drm-amd-display-Fix-up-kdoc-formats-in-dcn32_fpu.c.patch (drm-backport-placeholder)
- commit 173651b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1201-drm-amd-display-Add-missing-kdoc-entries-in-update_p.patch (drm-backport-placeholder)
- commit cb8ba4d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1200-drm-amdgpu-Fix-create_dmamap_sg_bo-kdoc-warnings.patch (drm-backport-placeholder)
- commit 32baaa9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1199-drm-amdkfd-Fix-MEC-pipe-interrupt-enablement.patch (drm-backport-placeholder)
- commit 7eb48c3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1198-drm-amdkfd-Add-new-gfx_target_versions-for-GC-9.4.3.patch (drm-backport-placeholder)
- commit 1d7f236
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1197-drm-amdgpu-Fix-up-missing-kdoc-in-sdma_v6_0.c.patch (drm-backport-placeholder)
- commit 1d7f114
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1196-drm-amdgpu-Fix-up-kdoc-in-amdgpu_acpi.c.patch (drm-backport-placeholder)
- commit a8be13b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1195-drm-amdgpu-Fix-up-kdoc-in-sdma_v4_4_2.c.patch (drm-backport-placeholder)
- commit f535047
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1194-drm-amdkfd-fix-gfx_target_version-for-certain-11.0.3.patch (drm-backport-placeholder)
- commit fc37683
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-keep-irq-count-in-amdgpu_irq_disabl.patch (drm-backport-placeholder)
- commit e6a6b43
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1192-drm-amd-amdgpu-Fix-up-locking-etc-in-amdgpu_debugfs_.patch (drm-backport-placeholder)
- commit ac4e894
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1191-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit 95e9597
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1190-drm-amdgpu-use-amdxcp-platform-device-as-spatial-par.patch (drm-backport-placeholder)
- commit ee3c739
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1189-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit 31f983d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1188-drm-amdxcp-add-platform-device-driver-for-amdxcp.patch (drm-backport-placeholder)
- commit e254561
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1187-drm-amdgpu-Mark-mmhub_v1_8_mmea_err_status_reg-as-__.patch (drm-backport-placeholder)
- commit 2ea1f28
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1186-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit e655679
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1185-drm-amd-display-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit fd96dae
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1184-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit d27866a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1183-drm-amd-display-clean-up-some-inconsistent-indenting.patch (drm-backport-placeholder)
- commit 20bc21a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1182-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit 2a04720
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1181-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit adf8271
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1180-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit 3c7aea1
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/uncore: Apply the unit control RB tree to MSR uncore
  units (bsc#1230119).
- commit 8a1e34d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1179-drm-amdgpu-add-the-accelerator-pcie-class.patch (drm-backport-placeholder)
- commit 87a8a3d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1178-drm-amdgpu-save-restore-part-of-xcp-drm_device-field.patch (drm-backport-placeholder)
- commit 64ff2ed
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1177-drm-amdgpu-set-the-APU-flag-based-on-package-type.patch (drm-backport-placeholder)
- commit 1e54e2e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1176-drm-jpeg-add-init-value-for-num_jpeg_rings.patch (drm-backport-placeholder)
- commit 93f637f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1175-drm-amdgpu-complement-the-4-6-and-8-XCC-cases.patch (drm-backport-placeholder)
- commit 7da1e78
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1174-drm-amdgpu-golden-settings-for-ASIC-rev_id-0.patch (drm-backport-placeholder)
- commit a06f26f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1173-drm-amdgpu-bypass-bios-dependent-operations.patch (drm-backport-placeholder)
- commit 58a6813
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1172-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit 9f7768b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1171-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit 9a8301a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1170-drm-amdgpu-Fix-unused-variable-in-amdgpu_gfx.c.patch (drm-backport-placeholder)
- commit 305d015
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1169-drm-amdgpu-Fix-defined-but-not-used-gfx9_cs_data-in-.patch (drm-backport-placeholder)
- commit 894be85
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1168-drm-amdgpu-Fix-return-types-of-certain-NBIOv7.9-call.patch (drm-backport-placeholder)
- commit 34db345
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1167-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit 41df5ca
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1166-drm-amd-Drop-debugfs-access-to-the-DPCD.patch (drm-backport-placeholder)
- commit 4dfaeff
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1165-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit 1522d00
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1164-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit 82634a7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1163-drm-amd-display-remove-unused-definition.patch (drm-backport-placeholder)
- commit 39e7507
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1162-drm-amdgpu-Use-single-copy-per-SDMA-instance-type-v2.patch (drm-backport-placeholder)
- commit 9a87b25
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1161-drm-amdgpu-switch-to-unified-amdgpu_ring_test_helper.patch (drm-backport-placeholder)
- commit 4db3945
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1160-drm-amdgpu-gfx-set-sched.ready-status-after-ring-IB-.patch (drm-backport-placeholder)
- commit 272341e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1159-drm-amdgpu-sdma-set-sched.ready-status-after-ring-IB.patch (drm-backport-placeholder)
- commit 34b7cd8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1158-drm-amdgpu-Fix-warnings.patch (drm-backport-placeholder)
- commit 4fb0a67
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1157-drm-amdkfd-Set-event-interrupt-class-for-GFX-9.4.3.patch (drm-backport-placeholder)
- commit ba37dd8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1156-Revert-drm-amd-display-Do-not-set-drr-on-pipe-commit.patch (drm-backport-placeholder)
- commit 4e4a775
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1155-drm-amd-amdgpu-Fix-warnings-in-amdgpu_irq.c.patch (drm-backport-placeholder)
- commit d454477
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1154-Revert-drm-amd-display-Block-optimize-on-consecutive.patch (drm-backport-placeholder)
- commit 7a2e1bf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1153-drm-amdgpu-Add-a-low-priority-scheduler-for-VRAM-cle.patch (drm-backport-placeholder)
- commit a75da3c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1152-drm-amdgpu-vcn-Modify-mismatched-function-name.patch (drm-backport-placeholder)
- commit f523f50
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1151-drm-amdgpu-Modify-mismatched-function-name.patch (drm-backport-placeholder)
- commit eaefbf6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1150-drm-amdgpu-Remove-duplicate-include.patch (drm-backport-placeholder)
- commit ad07c24
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1149-drm-amd-display-remove-unused-variables-res_create_m.patch (drm-backport-placeholder)
- commit cffa9aa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1148-drm-amd-display-avoid-calling-missing-.resync_fifo_d.patch (drm-backport-placeholder)
- commit 2d8b9e6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1147-drm-amdkfd-Align-partition-memory-size-to-page-size.patch (drm-backport-placeholder)
- commit 0dc0cfb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1146-drm-amdgpu-remove-unused-variable-num_xcc.patch (drm-backport-placeholder)
- commit ddf486d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1145-drm-amdgpu-fix-acpi-build-warnings.patch (drm-backport-placeholder)
- commit 74df7f5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1144-drm-amdgpu-use-pad-format-string-for-dma_addr_t.patch (drm-backport-placeholder)
- commit f953935
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1143-drm-amdgpu-mark-aqua_vanjaram_reg_init.c-function-as.patch (drm-backport-placeholder)
- commit 4334631
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1142-drm-amdkfd-mark-local-functions-as-static.patch (drm-backport-placeholder)
- commit f3fe7ff
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1141-drm-amd-pm-mark-irq-functions-as-static.patch (drm-backport-placeholder)
- commit 9bc45f1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1140-drm-amdgpu-Fix-unsigned-comparison-with-zero-in-gmc_.patch (drm-backport-placeholder)
- commit 75199e1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1139-drm-amdgpu-Fix-a-couple-of-spelling-mistakes-in-info.patch (drm-backport-placeholder)
- commit 112de13
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1138-drm-amdgpu-Disable-interrupt-tracker-on-NBIOv7.9.patch (drm-backport-placeholder)
- commit 6e912bb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-fix-possible-division-by-zero-errors.patch (drm-backport-placeholder)
- commit cc6dbe1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1136-drm-radeon-stop-including-swiotlb.h.patch (drm-backport-placeholder)
- commit d89eeea
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1135-drm-amdgpu-init-the-XCC_DOORBELL_FENCE-regs.patch (drm-backport-placeholder)
- commit 678ffc5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1134-drm-amdgpu-remove-unused-definition.patch (drm-backport-placeholder)
- commit 0b63abf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1133-drm-amdgpu-Fix-uninitialized-variable-in-gfxhub_v1_2.patch (drm-backport-placeholder)
- commit 97068fd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1132-drm-amdgpu-Fix-unused-amdgpu_acpi_get_numa_info-func.patch (drm-backport-placeholder)
- commit 8515b3f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1131-drm-amd-display-3.2.237.patch (drm-backport-placeholder)
- commit c7a34dd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1130-drm-amd-display-cache-trace-buffer-size.patch (drm-backport-placeholder)
- commit a5f1ec8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1129-drm-amd-display-Reorganize-DCN30-Makefile.patch (drm-backport-placeholder)
- commit a2578b7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1128-drm-amd-display-Trigger-DIO-FIFO-resync-on-commit-st.patch (drm-backport-placeholder)
- commit aa9f571
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Update-correct-DCN314-register-.patch (drm-backport-placeholder)
- commit e451a6b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1126-drm-amd-display-Clean-FPGA-code-in-dc.patch (drm-backport-placeholder)
- commit 55bf2c9
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/uncore: Apply the unit control RB tree to MMIO uncore
  units (bsc#1230119).
- commit 956825c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Apply-60us-prefetch-for-DCFCLK.patch (drm-backport-placeholder)
- commit 34e37cc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1124-drm-amd-display-Fix-possible-underflow-for-displays-.patch (drm-backport-placeholder)
- commit d6c4c7b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1123-drm-amd-display-Revert-vblank-change-that-causes-nul.patch (drm-backport-placeholder)
- commit 4e71048
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1122-drm-amd-display-Trigger-DIO-FIFO-resync-on-commit-st.patch (drm-backport-placeholder)
- commit 6680e4a
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: SOF: core: Implement firmware, topology path setup in core
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: sof-pci-dev: Save the default IPC type and path
  overrides (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: sof-of-dev: Save the default IPC type and path
  overrides (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: sof-acpi-dev: Save the default IPC type and path
  overrides (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Add placeholder for platform IPC type and path
  overrides (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Move sof_machine_* functions from sof-audio.c to
  core.c (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Move sof_of_machine_select() to sof-of-dev.c from
  sof-audio.c (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: Move Soundwire runtime stream alloc to soundcards
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: Add helper for allocating Soundwire stream runtime
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl_rpmsg: update Kconfig dependencies (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Add module ID print during module
  set up (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Drop unused IPC type defines (jsc#PED-9993
  jsc#PED-10202).
- commit 7d5e848
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1121-drm-amd-display-fix-dcn315-pixel-rate-crb-scaling-ch.patch (drm-backport-placeholder)
- commit c9254ce
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1120-drm-amd-display-lower-dp-link-training-message-level.patch (drm-backport-placeholder)
- commit 228f81a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1119-drm-amd-display-Update-SR-watermarks-for-DCN314.patch (drm-backport-placeholder)
- commit d1bdd26
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1118-drm-amd-display-disable-dcn315-pixel-rate-crb-when-s.patch (drm-backport-placeholder)
- commit 2b85c6f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1117-drm-amd-display-Fix-DMUB-debugging-print-issue.patch (drm-backport-placeholder)
- commit 72246eb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1116-drm-amdgpu-stop-including-swiotlb.h.patch (drm-backport-placeholder)
- commit e131f2a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1115-drm-amdgpu-Fix-uninitalized-variable-in-kgd2kfd_devi.patch (drm-backport-placeholder)
- commit 2b8aac3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1114-drm-amdgpu-Fix-uninitalized-variable-in-jpeg_v4_0_3_.patch (drm-backport-placeholder)
- commit bf19ffc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1113-drm-amd-amdgpu-Fix-errors-warnings-in-mmhub_v1_8.c.patch (drm-backport-placeholder)
- commit 3dc472f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1112-drm-amdgpu-retire-set_vga_state-for-some-ASIC.patch (drm-backport-placeholder)
- commit fad785b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1111-drm-amd-display-improve-the-message-printed-when-loa.patch (drm-backport-placeholder)
- commit 8bb7ab7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1110-drm-amdgpu-fix-vga_set_state-NULL-pointer-issue.patch (drm-backport-placeholder)
- commit bade892
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1109-drm-amdgpu-Fix-uninitialized-variable-in-gfx_v9_4_3_.patch (drm-backport-placeholder)
- commit ddc742d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1108-drm-amdgpu-Remove-IMU-ucode-in-vf2pf.patch (drm-backport-placeholder)
- commit 04b63c8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1107-drm-amdgpu-fix-the-memory-override-in-kiq-ring-struc.patch (drm-backport-placeholder)
- commit 4ead6e0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1106-drm-amdgpu-add-the-smu_v13_0_6-and-gfx_v9_4_3-ip-blo.patch (drm-backport-placeholder)
- commit 7824fc1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1105-drm-radeon-Remove-unnecessary-void-conversions.patch (drm-backport-placeholder)
- commit 53ccbf7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-artifacting-on-eDP-panels-w.patch (drm-backport-placeholder)
- commit 6e89803
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Validate-VM-ioctl-flags.patch (drm-backport-placeholder)
- commit 459a20e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1102-drm-amd-Update-driver-misc.html-for-Rembrandt-R.patch (drm-backport-placeholder)
- commit 51f050b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1101-drm-amdgpu-remove-unnecessary-void-conversions.patch (drm-backport-placeholder)
- commit 18f2bad
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1100-drm-amd-Update-driver-misc.html-for-Dragon-Range.patch (drm-backport-placeholder)
- commit e28d2c0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1099-drm-amd-Update-driver-misc.html-for-Phoenix.patch (drm-backport-placeholder)
- commit 6d54200
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1098-drm-amdgpu-fix-incorrect-pcie_gen_mask-in-passthroug.patch (drm-backport-placeholder)
- commit 2addf21
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1097-drm-amd-display-drop-unused-count-variable-in-create.patch (drm-backport-placeholder)
- commit bd5ea5d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1096-drm-amd-display-drop-unused-function-set_abm_event.patch (drm-backport-placeholder)
- commit 8b1c55e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1094-drm-amdgpu-fix-S3-issue-if-MQD-in-VRAM.patch (drm-backport-placeholder)
- commit e159f9e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1093-drm-amdgpu-Fix-warnings-in-amdgpu-_sdma-_ucode.c.patch (drm-backport-placeholder)
- commit 43b3eed
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1092-drm-amd-amdgpu-Fix-errors-warnings-in-amdgpu-_uvd-_v.patch (drm-backport-placeholder)
- commit fc725df
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1091-drm-amdgpu-perform-mode2-reset-for-sdma-fed-error-on.patch (drm-backport-placeholder)
- commit a6b9ad2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1090-drm-amd-amdgpu-Fix-errors-warnings-in-amdgpu_vcn.c.patch (drm-backport-placeholder)
- commit 8ee2c60
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1089-drm-amd-amdgpu-Fix-warnings-in-amdgpu_encoders.c.patch (drm-backport-placeholder)
- commit d64ef12
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1088-drm-amdkfd-fix-stack-size-in-svm_range_validate_and_.patch (drm-backport-placeholder)
- commit faf248e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1087-drm-amd-amdgpu-Fix-errors-warnings-in-amdgpu_ttm.c.patch (drm-backport-placeholder)
- commit ca5f6f8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1086-drm-amdgpu-vcn4-fix-endian-conversion.patch (drm-backport-placeholder)
- commit 96e7751
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1085-drm-amdgpu-gmc9-fix-64-bit-division-in-partition-cod.patch (drm-backport-placeholder)
- commit 5d04bf0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1084-drm-amdgpu-initialize-RAS-for-gfx_v9_4_3.patch (drm-backport-placeholder)
- commit 24a80fc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1083-drm-amdgpu-add-sq-timeout-status-functions-for-gfx_v.patch (drm-backport-placeholder)
- commit c02f77d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1082-drm-amdgpu-add-RAS-error-count-reset-for-gfx_v9_4_3.patch (drm-backport-placeholder)
- commit cc09ecc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1081-drm-amdgpu-add-RAS-error-count-query-for-gfx_v9_4_3.patch (drm-backport-placeholder)
- commit 80af200
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1080-drm-amdgpu-add-RAS-error-count-definitions-for-gfx_v.patch (drm-backport-placeholder)
- commit 1e93123
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1079-drm-amdgpu-add-RAS-definitions-for-GFX.patch (drm-backport-placeholder)
- commit 349ea68
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: core: Fix a handful of spelling mistakes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: ipc4: Move window offset configuration earlier
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: icp3-dtrace: Fix wrong kfree() usage (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-mtl-match: Add rt722 support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi: add Gen4.1 SDCA board support for LNL
  RVP (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi: rt713+rt1316, no sdw-dmic config
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Add rt722 support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_sdw: remove unused function declaration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Make use of dev_err_probe() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use common module for DAI link
  generation (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4: Add data struct for module notification
  message from firmware (jsc#PED-9993 jsc#PED-10202).
- commit f53a245
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1078-drm-amdgpu-Add-gc-v9_4_3-ras-error-status-registers.patch (drm-backport-placeholder)
- commit 84c6afa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1077-drm-amdgpu-add-RAS-status-reset-for-gfx_v9_4_3.patch (drm-backport-placeholder)
- commit e9ae94e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1076-drm-amdgpu-add-RAS-status-query-for-gfx_v9_4_3.patch (drm-backport-placeholder)
- commit 3fa1285
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1075-drm-amdgpu-add-GFX-RAS-common-function.patch (drm-backport-placeholder)
- commit 2469f15
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1074-drm-amdgpu-Do-not-access-members-of-xcp-w-o-check-v2.patch (drm-backport-placeholder)
- commit 226d6ac
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1073-drm-amdkfd-Fix-null-ptr-access.patch (drm-backport-placeholder)
- commit 7757f68
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/uncore: Retrieve the unit ID from the unit control
  RB tree (bsc#1230119).
- commit 81ab2f7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1072-drm-amdgpu-add-check-for-RAS-instance-mask.patch (drm-backport-placeholder)
- commit be0564d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1071-drm-amdgpu-remove-RAS-GFX-injection-for-gfx_v9_4-gfx.patch (drm-backport-placeholder)
- commit 47d1796
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1070-drm-amdgpu-reorganize-RAS-injection-flow.patch (drm-backport-placeholder)
- commit 2d95686
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1069-drm-amdgpu-add-instance-mask-for-RAS-inject.patch (drm-backport-placeholder)
- commit 6fbf223
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1068-drm-amdgpu-convert-logical-instance-mask-to-physical.patch (drm-backport-placeholder)
- commit e9ed41b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1067-drm-amdgpu-Enable-IH-CAM-on-GFX9.4.3.patch (drm-backport-placeholder)
- commit d627ae9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1066-drm-amdgpu-Correct-get_xcp_mem_id-calculation.patch (drm-backport-placeholder)
- commit a0e4351
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1065-drm-amdkfd-Refactor-migrate-init-to-support-partitio.patch (drm-backport-placeholder)
- commit 1a97e6b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1064-drm-amdgpu-route-ioctls-on-primary-node-of-XCPs-to-p.patch (drm-backport-placeholder)
- commit 749211c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1063-drm-amdkfd-APU-mode-set-max-svm-range-pages.patch (drm-backport-placeholder)
- commit 263b9b0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1062-drm-amdkfd-Fix-memory-reporting-on-GFX-9.4.3.patch (drm-backport-placeholder)
- commit e850104
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1061-drm-amdkfd-Move-local_mem_info-to-kfd_node.patch (drm-backport-placeholder)
- commit 4e8b763
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1060-drm-amdgpu-use-xcp-partition-ID-for-amdgpu_gem.patch (drm-backport-placeholder)
- commit ab9065a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1059-drm-amdgpu-KFD-graphics-interop-support-compute-part.patch (drm-backport-placeholder)
- commit 7d21212
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1058-drm-amdkfd-Store-xcp-partition-id-to-amdgpu-bo.patch (drm-backport-placeholder)
- commit 2f490c3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1057-drm-amdgpu-dGPU-mode-set-VRAM-range-lpfn-as-exclusiv.patch (drm-backport-placeholder)
- commit 5c9e37f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1056-drm-amdgpu-Alloc-page-table-on-correct-memory-partit.patch (drm-backport-placeholder)
- commit 4e32992
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1055-drm-amdkfd-Update-MTYPE-for-far-memory-partition.patch (drm-backport-placeholder)
- commit 3e50e96
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1054-drm-amdgpu-dGPU-mode-placement-support-memory-partit.patch (drm-backport-placeholder)
- commit 65a5a83
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1053-drm-amdkfd-SVM-range-allocation-support-memory-parti.patch (drm-backport-placeholder)
- commit 772073a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1052-drm-amdkfd-Alloc-memory-of-GPU-support-memory-partit.patch (drm-backport-placeholder)
- commit c149d38
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1051-drm-amdgpu-Add-memory-partition-mem_id-to-amdgpu_bo.patch (drm-backport-placeholder)
- commit 897c433
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1050-drm-amdkfd-Show-KFD-node-memory-partition-info.patch (drm-backport-placeholder)
- commit 00e2aee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1049-drm-amdgpu-Add-memory-partition-id-to-amdgpu_vm.patch (drm-backport-placeholder)
- commit 936c470
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1048-drm-amdkfd-Store-drm-node-minor-number-for-kfd-nodes.patch (drm-backport-placeholder)
- commit 1f83e6d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1047-drm-amdgpu-Add-xcp-manager-num_xcp_per_mem_partition.patch (drm-backport-placeholder)
- commit 4e74036
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1046-drm-amdgpu-update-ref_cnt-before-ctx-free.patch (drm-backport-placeholder)
- commit 1bf057e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1045-drm-amdgpu-run-partition-schedule-if-it-is-supported.patch (drm-backport-placeholder)
- commit d179673
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1044-drm-amdgpu-add-partition-schedule-for-GC-9-4-3.patch (drm-backport-placeholder)
- commit ac92014
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1043-drm-amdgpu-keep-amdgpu_ctx_mgr-in-ctx-structure.patch (drm-backport-placeholder)
- commit 7969322
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1042-drm-amdgpu-add-partition-scheduler-list-update.patch (drm-backport-placeholder)
- commit ef1e7dc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1041-drm-amdgpu-update-header-to-support-partition-schedu.patch (drm-backport-placeholder)
- commit 3067897
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1040-drm-amdgpu-add-partition-ID-track-in-ring.patch (drm-backport-placeholder)
- commit 3230549
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: Intel: sof_nau8825: use common module for DAI link
  generation (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: support DAI link array generation
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: use common module for HDMI-In link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use common module for HDMI-In link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: support HDMI-In link initialization
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: simplify HDMI-In quirks (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: use common module for BT offload link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use common module for BT offload link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: use common module for BT offload link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: use common module for BT offload link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: support BT offload link
  initialization (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: rename function parameter
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: use common module for amp link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use common module for amp link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: use common module for amp link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: use common module for amp link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: support amp link initialization
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use common module for codec link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: use common module for codec link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: use common module for codec link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: support codec link initialization
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: ssp-common: get codec name function (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: cht_bsw_rt5672: check return value (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_maxim_common: check return value (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_maxim_common: add else between 2 if test
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: remove dead code (jsc#PED-9993
  jsc#PED-10202).
- ASoC: audio-graph-card2-custom-sample: add CPU/Codec = N:M
  sample (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card2-custom-sample: Add connection image
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card2: add CPU:Codec = N:M support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card2: use better image for Multi connection
  (jsc#PED-9993 jsc#PED-10202).
- commit 29eb7bb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1039-drm-amdgpu-find-partition-ID-when-open-device.patch (drm-backport-placeholder)
- commit c0a6f36
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/uncore: Support per PMU cpumask (bsc#1230119).
- commit e0b1be5
* Wed Sep  4 2024 pjakobsson@suse.de
- Refresh patches.suse/0058-drm-amdgpu-Remove-struct-drm_driver.gem_prime_mmap.patch.
- Update patches.suse/1038-drm-amdgpu-support-partition-drm-devices.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit af07cca
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1037-drm-amdgpu-bu-update-mtype_local-parameter-settings.patch (drm-backport-placeholder)
- commit 7556fa7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1036-drm-amdgpu-bu-add-mtype_local-as-a-module-parameter.patch (drm-backport-placeholder)
- commit 7abc9d9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1035-drm-amdgpu-Override-MTYPE-per-page-on-GFXv9.4.3-APUs.patch (drm-backport-placeholder)
- commit 5367be8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1034-drm-amdgpu-Fix-per-BO-MTYPE-selection-for-GFXv9.4.3.patch (drm-backport-placeholder)
- commit 59daea0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1033-drm-amdgpu-bu-Add-use_mtype_cc_wa-module-param.patch (drm-backport-placeholder)
- commit 9bebfc3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1032-drm-amdgpu-Use-legacy-TLB-flush-for-gfx943.patch (drm-backport-placeholder)
- commit f3d0593
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1031-drm-amdgpu-For-GFX-9.4.3-APU-fix-vram_usage-value.patch (drm-backport-placeholder)
- commit 9369b33
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1030-drm-amdgpu-Enable-NPS4-CPX-mode.patch (drm-backport-placeholder)
- commit 9fa13ee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1029-drm-amdkfd-Move-pgmap-to-amdgpu_kfd_dev-structure.patch (drm-backport-placeholder)
- commit 1793b5f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1028-drm-amdgpu-Skip-halting-RLC-on-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit 9fe729d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1027-drm-amdgpu-Fix-register-accesses-in-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit eeb6e09
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1026-drm-amdkfd-Increase-queue-number-per-process-to-255-.patch (drm-backport-placeholder)
- commit 121517a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1025-drm-amdgpu-Adjust-the-sequence-to-query-ras-error-in.patch (drm-backport-placeholder)
- commit 67fbd2b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1024-drm-amdgpu-Initialize-jpeg-v4_0_3-ras-function.patch (drm-backport-placeholder)
- commit 1aff66d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1023-drm-amdgpu-Add-reset_ras_error_count-for-jpeg-v4_0_3.patch (drm-backport-placeholder)
- commit 51cb40e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1022-drm-amdgpu-Add-query_ras_error_count-for-jpeg-v4_0_3.patch (drm-backport-placeholder)
- commit 9f2b9ee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1021-drm-amdgpu-Re-enable-VCN-RAS-if-DPG-is-enabled.patch (drm-backport-placeholder)
- commit 0072475
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1020-drm-amdgpu-Initialize-vcn-v4_0_3-ras-function.patch (drm-backport-placeholder)
- commit f613710
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1019-drm-amdgpu-Add-reset_ras_error_count-for-vcn-v4_0_3.patch (drm-backport-placeholder)
- commit c0e262d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1018-drm-amdgpu-Add-query_ras_error_count-for-vcn-v4_0_3.patch (drm-backport-placeholder)
- commit 06edb12
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1017-drm-amdgpu-Add-vcn-jpeg-ras-err-status-registers.patch (drm-backport-placeholder)
- commit 71d640d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1016-drm-amdgpu-Checked-if-the-pointer-NULL-before-use-it.patch (drm-backport-placeholder)
- commit 33c640e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1015-drm-amdgpu-Set-memory-partitions-to-1-for-SRIOV.patch (drm-backport-placeholder)
- commit 1937774
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1014-drm-amdgpu-Skip-using-MC-FB-Offset-when-APU-flag-is-.patch (drm-backport-placeholder)
- commit 3db1a38
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1013-drm-amdgpu-Add-PSP-supporting-PSP-13.0.6-SRIOV-ucode.patch (drm-backport-placeholder)
- commit b9000f4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1012-drm-amdgpu-Add-PSP-spatial-parition-interface.patch (drm-backport-placeholder)
- commit 8460fa0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1011-drm-amdgpu-Return-error-on-invalid-compute-mode.patch (drm-backport-placeholder)
- commit c050ce2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1010-drm-amdgpu-Add-compute-mode-descriptor-function.patch (drm-backport-placeholder)
- commit a339350
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1009-drm-amdgpu-Fix-unmapping-of-aperture.patch (drm-backport-placeholder)
- commit 46f2047
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1008-drm-amdgpu-Fix-xGMI-access-P2P-mapping-failure-on-GF.patch (drm-backport-placeholder)
- commit f67f328
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1007-drm-amdkfd-Native-mode-memory-partition-support.patch (drm-backport-placeholder)
- commit 852d44a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1006-drm-amdgpu-Set-TTM-pools-for-memory-partitions.patch (drm-backport-placeholder)
- commit 2871b8a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1005-drm-ttm-export-ttm_pool_fini-for-cleanup.patch (drm-backport-placeholder)
- commit d2a9e70
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1004-drm-amdgpu-Add-auto-mode-for-compute-partition.patch (drm-backport-placeholder)
- commit b47a91d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1003-drm-amdgpu-Check-memory-ranges-for-valid-xcp-mode.patch (drm-backport-placeholder)
- commit 45683cd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1002-drm-amdkfd-Use-xcc-mask-for-identifying-xcc.patch (drm-backport-placeholder)
- commit fbafd6c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1001-drm-amdkfd-Add-xcp-reference-to-kfd-node.patch (drm-backport-placeholder)
- commit 4a1ce9a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/1000-drm-amdgpu-Move-initialization-of-xcp-before-kfd.patch (drm-backport-placeholder)
- commit 325cd85
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0999-drm-amdgpu-Fill-xcp-mem-node-in-aquavanjaram.patch (drm-backport-placeholder)
- commit 35621f6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0998-drm-amdgpu-Add-callback-to-fill-xcp-memory-id.patch (drm-backport-placeholder)
- commit 38df784
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0997-drm-amdgpu-Initialize-memory-ranges-for-GC-9.4.3.patch (drm-backport-placeholder)
- commit 695cabc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0996-drm-amdgpu-Add-memory-partitions-to-gmc.patch (drm-backport-placeholder)
- commit a0900c5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0995-drm-amdgpu-Add-API-to-get-numa-information-of-XCC.patch (drm-backport-placeholder)
- commit 9d2e0b0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0994-drm-amdgpu-Store-additional-numa-node-information.patch (drm-backport-placeholder)
- commit aa83223
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0993-drm-amdgpu-Get-supported-memory-partition-modes.patch (drm-backport-placeholder)
- commit b212db5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0992-drm-amdgpu-Move-memory-partition-query-to-gmc.patch (drm-backport-placeholder)
- commit fbe44c3
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/uncore: Save the unit control address of all units
  (bsc#1230119).
- commit 3062251
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0991-drm-amdgpu-Add-utility-functions-for-xcp.patch (drm-backport-placeholder)
- commit 47c04d3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0990-drm-amdgpu-Use-apt-name-for-FW-reserved-region.patch (drm-backport-placeholder)
- commit 96952b8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0989-drm-amdgpu-Use-GPU-VA-space-for-IH-v4.4.2-in-APU.patch (drm-backport-placeholder)
- commit 9673191
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0988-drm-amdgpu-Simplify-aquavanjram-instance-mapping.patch (drm-backport-placeholder)
- commit 0721406
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0987-drm-amdgpu-vcn-Use-buffer-object-s-deletion-logic.patch (drm-backport-placeholder)
- commit 6830d74
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0986-drm-amdgpu-Use-a-different-value-than-0xDEADBEEF-for.patch (drm-backport-placeholder)
- commit 335949c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0985-drm-amdgpu-Add-a-read-after-write-DB_CTRL-for-vcn_v4.patch (drm-backport-placeholder)
- commit c9c9107
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0984-drm-amdgpu-fixes-a-JPEG-get-write-read-pointer-bug.patch (drm-backport-placeholder)
- commit 5ccc9c5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0983-drm-amdgpu-A-workaround-for-JPEG_v4_0_3-ring-test-fa.patch (drm-backport-placeholder)
- commit d8e904f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0982-drm-amdgpu-use-physical-AID-index-for-ring-name.patch (drm-backport-placeholder)
- commit 8ec9741
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0981-drm-amdgpu-vcn-use-dummy-register-selects-AID-for-VC.patch (drm-backport-placeholder)
- commit d498507
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0980-drm-amdgpu-Fix-harvest-reporting-of-VCN.patch (drm-backport-placeholder)
- commit f72e17a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0979-drm-amdgpu-Use-logical-ids-for-VCN-JPEG-v4.0.3.patch (drm-backport-placeholder)
- commit f793730
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0978-drm-amdgpu-Add-VCN-logical-to-physical-id-mapping.patch (drm-backport-placeholder)
- commit ed727d4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0977-drm-amdgpu-Add-instance-mask-for-VCN-and-JPEG.patch (drm-backport-placeholder)
- commit fa0dbb5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0976-drm-amdgpu-Load-vcn_v4_0_3-ucode-during-early_init.patch (drm-backport-placeholder)
- commit f69684c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0975-drm-amdgpu-preserve-the-num_links-in-case-of-reflect.patch (drm-backport-placeholder)
- commit 5488128
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0974-drm-amdgpu-Fix-discovery-sys-node-harvest-info.patch (drm-backport-placeholder)
- commit 48f086e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0973-drm-amdkfd-Flush-TLB-after-unmapping-for-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit 53bd9a2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0972-drm-amdgpu-Add-fallback-path-for-discovery-info.patch (drm-backport-placeholder)
- commit fb40e3c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0971-drm-amdgpu-Read-discovery-info-from-system-memory.patch (drm-backport-placeholder)
- commit 0bca8b8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0970-drm-amdgpu-Add-API-to-get-tmr-info-from-acpi.patch (drm-backport-placeholder)
- commit 2363357
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0969-drm-amdgpu-Add-parsing-of-acpi-xcc-objects.patch (drm-backport-placeholder)
- commit 49bab77
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0968-drm-amdkfd-Enable-SVM-on-Native-mode.patch (drm-backport-placeholder)
- commit a3f770b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0967-drm-amdgpu-Add-FGCG-for-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit 3dcd16c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0966-drm-amdgpu-Use-transient-mode-during-xcp-switch.patch (drm-backport-placeholder)
- commit f711d18
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0965-drm-amdgpu-Add-flags-for-partition-mode-query.patch (drm-backport-placeholder)
- commit 35eea13
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0964-drm-amd-pm-fix-wrong-smu-socclk-value.patch (drm-backport-placeholder)
- commit 06d2fa9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0963-drm-amdgpu-Add-mode-2-reset-in-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit 323e893
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0962-drm-amd-pm-Notify-PMFW-about-driver-unload-cases.patch (drm-backport-placeholder)
- commit 48cfa28
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0961-drm-amd-pm-Update-PMFW-headers-for-version-85.54.patch (drm-backport-placeholder)
- commit 1a7cf32
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0960-drm-amd-pm-Expose-mem-temperature-for-GC-version-9.4.patch (drm-backport-placeholder)
- commit 53496f4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0959-drm-amd-pm-Update-hw-mon-attributes-for-GC-version-9.patch (drm-backport-placeholder)
- commit e1c55e2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0958-drm-amd-pm-Initialize-power-limit-for-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit b303a43
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0957-drm-amd-pm-Keep-interface-version-in-PMFW-header.patch (drm-backport-placeholder)
- commit 1db0e58
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0956-drm-amd-pm-Add-ih-for-SMU-v13.0.6-thermal-throttling.patch (drm-backport-placeholder)
- commit 8f2e870
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0955-drm-amd-pm-Update-pmfw-header-files-for-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit 6482fc3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0954-drm-amd-pm-Update-gfx-clock-frequency-for-SMU-v13.0..patch (drm-backport-placeholder)
- commit 4f6847d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0953-drm-amd-pm-Update-pmfw-header-files-for-SMU-v13.0.6.patch (drm-backport-placeholder)
- commit 396c57c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0952-drm-amdgpu-fix-sdma-instance.patch (drm-backport-placeholder)
- commit 26e778f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0951-drm-amdgpu-change-the-print-level-to-warn-for-ip-blo.patch (drm-backport-placeholder)
- commit 1e8a93d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0950-drm-amdgpu-Increase-Max-GPU-instance-to-64.patch (drm-backport-placeholder)
- commit 5835789
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0949-drm-amdgpu-increase-AMDGPU_MAX_RINGS.patch (drm-backport-placeholder)
- commit adfc5b2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0948-drm-amdgpu-Create-VRAM-BOs-on-GTT-for-GFXIP9.4.3.patch (drm-backport-placeholder)
- commit b518124
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0947-drm-amdgpu-Implement-new-dummy-vram-manager.patch (drm-backport-placeholder)
- commit d260d1d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0946-drm-amdgpu-Handle-VRAM-dependencies-on-GFXIP9.4.3.patch (drm-backport-placeholder)
- commit be397f8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0945-drm-amdgpu-Enable-CG-for-IH-v4.4.2.patch (drm-backport-placeholder)
- commit b549d59
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0944-drm-amdgpu-Enable-persistent-edc-harvesting-in-APP-A.patch (drm-backport-placeholder)
- commit 779e218
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0943-drm-amdgpu-Initialize-mmhub-v1_8-ras-function.patch (drm-backport-placeholder)
- commit cb193b6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0942-drm-amdgpu-Add-reset_ras_error_status-for-mmhub-v1_8.patch (drm-backport-placeholder)
- commit a10a0b0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0941-drm-amdgpu-Add-query_ras_error_status-for-mmhub-v1_8.patch (drm-backport-placeholder)
- commit 6e21129
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0940-drm-amdgpu-Add-reset_ras_error_count-for-mmhub-v1_8.patch (drm-backport-placeholder)
- commit 37ce903
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0939-drm-amdgpu-Add-query_ras_error_count-for-mmhub-v1_8.patch (drm-backport-placeholder)
- commit ffa8c3d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0938-drm-amdgpu-Add-mmhub-v1_8_0-ras-err-status-registers.patch (drm-backport-placeholder)
- commit bfbebe6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0937-drm-amdgpu-Initialize-sdma-v4_4_2-ras-function.patch (drm-backport-placeholder)
- commit 64c59dc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0936-drm-amdgpu-Add-reset_ras_error_count-for-sdma-v4_4_2.patch (drm-backport-placeholder)
- commit 6e1c729
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0935-drm-amdgpu-Add-query_ras_error_count-for-sdma-v4_4_2.patch (drm-backport-placeholder)
- commit 70988da
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0934-drm-amdgpu-Add-sdma-v4_4_2-ras-registers.patch (drm-backport-placeholder)
- commit d468ee7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0933-drm-amdgpu-Add-common-helper-to-reset-ras-error.patch (drm-backport-placeholder)
- commit 9bc5919
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0932-drm-amdgpu-Add-common-helper-to-query-ras-error-v2.patch (drm-backport-placeholder)
- commit d15c671
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0931-drm-amdgpu-Enable-MGCG-on-SDMAv4.4.2.patch (drm-backport-placeholder)
- commit 6ff48f3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0930-drm-amdgpu-enable-context-empty-interrupt-on-sdma-v4.patch (drm-backport-placeholder)
- commit 3660bed
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0929-drm-amdgpu-add-vcn_4_0_3-codec-query.patch (drm-backport-placeholder)
- commit 8051aad
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0928-drm-amdkfd-bind-cpu-and-hiveless-gpu-to-a-hive-if-xg.patch (drm-backport-placeholder)
- commit d7c106a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0927-drm-amdkfd-Cleanup-KFD-nodes-creation.patch (drm-backport-placeholder)
- commit dfd1a1d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0926-drm-ttm-add-NUMA-node-id-to-the-pool.patch (drm-backport-placeholder)
- commit 8331cab
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0925-drm-amdgpu-Fix-mqd-init-on-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit 2248864
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0924-drm-amd-fix-compiler-error-to-support-older-compiler.patch (drm-backport-placeholder)
- commit 737d8b2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0923-drm-amdgpu-Enable-CGCG-LS-for-GC-9.4.3.patch (drm-backport-placeholder)
- commit bbd499b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0922-drm-amdgpu-Use-unique-doorbell-range-per-xcc.patch (drm-backport-placeholder)
- commit d5ea89d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0921-drm-amdgpu-Keep-SDMAv4.4.2-active-during-reset.patch (drm-backport-placeholder)
- commit 533f592
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0920-drm-amdkfd-Report-XGMI-IOLINKs-for-GFXIP9.4.3.patch (drm-backport-placeholder)
- commit fad8f0c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0919-drm-amdgpu-add-num_xcps-return.patch (drm-backport-placeholder)
- commit 55226a7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0918-drm-amdgpu-increase-AMDGPU_MAX_HWIP_RINGS.patch (drm-backport-placeholder)
- commit c8b3047
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0917-drm-amdgpu-vcn_v4_0_3-load-vcn-fw-once-for-all-AIDs.patch (drm-backport-placeholder)
- commit 7f0ac5d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0916-drm-amdgpu-Populate-VCN-JPEG-harvest-information.patch (drm-backport-placeholder)
- commit 8286b5a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0915-drm-amdgpu-Correct-dGPU-MTYPE-settings-for-gfx943.patch (drm-backport-placeholder)
- commit 6819c8c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0914-drm-amdgpu-Remove-SMU-powergate-message-call-for-SDM.patch (drm-backport-placeholder)
- commit 73250a7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0913-drm-amdgpu-enable-vcn-jpeg-on-vcn_v4_0_3.patch (drm-backport-placeholder)
- commit 56b4cee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0912-drm-amdgpu-enable-indirect_sram-mode-on-vcn_v4_0_3.patch (drm-backport-placeholder)
- commit 8948fa5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0911-drm-amdgpu-add-unified-queue-support-on-vcn_v4_0_3.patch (drm-backport-placeholder)
- commit 01a0ffe
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0910-drm-amdgpu-add-fwlog-support-on-vcn_v4_0_3.patch (drm-backport-placeholder)
- commit aab0119
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0909-drm-amdgpu-increase-MAX-setting-to-hold-more-jpeg-in.patch (drm-backport-placeholder)
- commit e3c5711
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0908-drm-amdgpu-Use-discovery-to-get-XCC-SDMA-mask.patch (drm-backport-placeholder)
- commit 51fe30b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0907-drm-amdgpu-Make-VRAM-discovery-read-optional.patch (drm-backport-placeholder)
- commit fed2e32
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0906-drm-amdgpu-Allocate-GART-table-in-RAM-for-AMD-APU.patch (drm-backport-placeholder)
- commit 2ee71b8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0905-drm-amdgpu-Add-FGCG-logic-for-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit e8c012d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0904-drm-amdgpu-Make-UTCL2-snoop-CPU-caches.patch (drm-backport-placeholder)
- commit 6661304
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0903-amd-amdgpu-Set-MTYPE_UC-for-access-over-PCIe.patch (drm-backport-placeholder)
- commit 57467fb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0902-drm-amdgpu-Fix-GFX-v9.4.3-EOP-buffer-allocation.patch (drm-backport-placeholder)
- commit a872e83
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0901-drm-amdgpu-Fix-GFX-9.4.3-dma-address-capability.patch (drm-backport-placeholder)
- commit 4d12997
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0900-drm-amdgpu-Fix-semaphore-release.patch (drm-backport-placeholder)
- commit 68953b0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0899-drm-amdkfd-Setup-current_logical_xcc_id-in-MQD.patch (drm-backport-placeholder)
- commit 6795c0c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0898-drm-amdgpu-Remove-unnecessary-return-value-check.patch (drm-backport-placeholder)
- commit e3cd88c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0897-drm-amdgpu-correct-the-vmhub-index-when-page-fault-o.patch (drm-backport-placeholder)
- commit 77979c3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0896-drm-amdkfd-Update-packet-manager-for-GFX9.4.3.patch (drm-backport-placeholder)
- commit bf59406
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0895-drm-amdgpu-set-MTYPE-in-PTE-for-GFXIP-9.4.3.patch (drm-backport-placeholder)
- commit f73f925
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0894-drm-amdgpu-Use-mask-for-active-clusters.patch (drm-backport-placeholder)
- commit d020551
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0893-drm-amdgpu-Derive-active-clusters-from-SDMA.patch (drm-backport-placeholder)
- commit 1c2ad6f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0892-drm-amdgpu-Move-generic-logic-to-soc-config.patch (drm-backport-placeholder)
- commit d2adaa0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0891-drm-amdgpu-Fix-the-KCQ-hang-when-binding-back.patch (drm-backport-placeholder)
- commit f9f6000
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0890-drm-amdgpu-Skip-TMR-allocation-if-not-required.patch (drm-backport-placeholder)
- commit 8116474
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0889-drm-amdgpu-Add-XCP-IP-callback-funcs-for-each-IP.patch (drm-backport-placeholder)
- commit 1e3e174
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0888-drm-amdgpu-Add-XCP-functions-for-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit be0f6d5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0887-drm-amdgpu-Add-SDMA-v4.4.2-XCP-funcs.patch (drm-backport-placeholder)
- commit 32434b5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0886-drm-amdgpu-Add-GFXHUB-v1.2-XCP-funcs.patch (drm-backport-placeholder)
- commit e071a07
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0885-drm-amdgpu-Switch-to-SOC-partition-funcs.patch (drm-backport-placeholder)
- commit 8dbe031
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0884-drm-amdgpu-Add-soc-config-init-for-GC9.4.3-ASICs.patch (drm-backport-placeholder)
- commit b607a36
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0883-drm-amdgpu-Add-SOC-partition-funcs-for-GC-v9.4.3.patch (drm-backport-placeholder)
- commit 71228c5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0882-drm-amdgpu-Add-initial-version-of-XCP-routines.patch (drm-backport-placeholder)
- commit 4743cc9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0881-drm-amdgpu-Add-sdma-instance-specific-functions.patch (drm-backport-placeholder)
- commit 0757f57
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0880-drm-amdgpu-Add-xcc-specific-functions-for-gfxhub.patch (drm-backport-placeholder)
- commit 808237c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0879-drm-amdgpu-Add-xcc-specific-functions.patch (drm-backport-placeholder)
- commit 4e91e66
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0878-drm-amdgpu-Rename-xcc-specific-functions.patch (drm-backport-placeholder)
- commit bfa4424
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0877-drm-amdgpu-Check-APU-supports-true-APP-mode.patch (drm-backport-placeholder)
- commit a60cbd4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0876-drm-amdgpu-more-GPU-page-fault-info-for-GC-v9.4.3.patch (drm-backport-placeholder)
- commit 64b67d1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0875-drm-amdgpu-remove-partition-attributes-sys-file-for-.patch (drm-backport-placeholder)
- commit 97b4d66
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0874-drm-amdgpu-fix-kcq-mqd_backup-buffer-double-free-for.patch (drm-backport-placeholder)
- commit 9e334d6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0873-drm-amdgpu-Skip-runtime-db-read-for-PSP-13.0.6.patch (drm-backport-placeholder)
- commit b555f07
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0872-drm-amdgpu-fix-vm-context-register-assignment-in-mmh.patch (drm-backport-placeholder)
- commit ad85026
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0871-drm-amdgpu-Revert-programming-of-CP_PSP_XCP_CTL.patch (drm-backport-placeholder)
- commit 5a53583
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0870-drm-amdgpu-detect-current-GPU-memory-partition-mode.patch (drm-backport-placeholder)
- commit a2d7c4e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0869-drm-amdgpu-init-smuio-funcs-for-smuio-v13_0_3.patch (drm-backport-placeholder)
- commit 18e88f8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0868-drm-amdgpu-implement-smuio-v13_0_3-callbacks.patch (drm-backport-placeholder)
- commit 19cd05c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0867-drm-amdgpu-add-smuio-v13_0_3-ip-headers.patch (drm-backport-placeholder)
- commit 97f3bb4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0866-drm-amdgpu-retire-render-backend-setup-from-gfx_v9_4.patch (drm-backport-placeholder)
- commit a25ca65
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0865-drm-amd-amdgpu-Update-debugfs-for-XCC-support-v3.patch (drm-backport-placeholder)
- commit 876023b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0864-drm-amdgpu-Add-SDMA-v4.4.2-golden-settings.patch (drm-backport-placeholder)
- commit db3e3e3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0863-drm-amdgpu-init-gfx_v9_4_3-external_rev_id.patch (drm-backport-placeholder)
- commit 3539bc8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0862-drm-amdgpu-Fix-interrupt-handling-in-GFX-v9.4.3.patch (drm-backport-placeholder)
- commit 20a65b3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0861-drm-amdgpu-consolidate-the-access-helpers-in-nbio-v7.patch (drm-backport-placeholder)
- commit 690b9f8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0860-drm-amdgpu-add-helpers-to-access-registers-on-differ.patch (drm-backport-placeholder)
- commit 59c7e43
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0859-drm-amdgpu-parse-base-address-from-new-ip-discovery-.patch (drm-backport-placeholder)
- commit bf12119
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0858-drm-amdgpu-upgrade-amdgpu_discovery-struct-ip-to-ip_.patch (drm-backport-placeholder)
- commit 8405476
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0857-drm-amdgpu-do-some-register-access-cleanup-in-nbio-v.patch (drm-backport-placeholder)
- commit dd0c5b9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0856-drm-amdgpu-extend-max-instances.patch (drm-backport-placeholder)
- commit 65b6391
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0855-drm-amdgpu-increase-DISCOVERY_TMR_SIZE.patch (drm-backport-placeholder)
- commit 4ed1a55
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0854-drm-amdgpu-update-ip-discovery-header-to-v4.patch (drm-backport-placeholder)
- commit b0f9718
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0853-drm-amdgpu-switch-to-aqua_vanjaram_doorbell_index_in.patch (drm-backport-placeholder)
- commit 568aab0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0852-drm-amdgpu-Use-SDMA-instance-table-for-aqua-vanjaram.patch (drm-backport-placeholder)
- commit 50ff0eb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0851-drm-amdgpu-Add-mask-for-SDMA-instances.patch (drm-backport-placeholder)
- commit b2e41a8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0850-drm-amdgpu-Add-IP-instance-map-for-aqua-vanjaram.patch (drm-backport-placeholder)
- commit 963b8dd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0849-drm-amdgpu-add-new-doorbell-assignment-table-for-aqu.patch (drm-backport-placeholder)
- commit e78bb04
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0848-drm-amdgpu-Fix-register-access-on-GC-v9.4.3.patch (drm-backport-placeholder)
- commit 495bd88
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0847-drm-amdgpu-Fix-programming-of-initial-XCP-mode.patch (drm-backport-placeholder)
- commit b030372
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0846-drm-amdkfd-Update-interrupt-handling-for-GFX9.4.3.patch (drm-backport-placeholder)
- commit 31835ec
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0845-drm-amdgpu-Fix-failure-when-switching-to-DPX-mode.patch (drm-backport-placeholder)
- commit 210988a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0844-drm-amdkfd-Use-instance-table-for-GFX-9.4.3.patch (drm-backport-placeholder)
- commit 244fdca
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0843-drm-amdgpu-Fix-SWS-on-multi-XCD-GPU.patch (drm-backport-placeholder)
- commit 2405399
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0842-drm-amdgpu-drop-redundant-csb-init-for-gfx943.patch (drm-backport-placeholder)
- commit c75bcdb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0841-drm-amdgpu-adjust-s2a-entry-register-for-sdma-doorbe.patch (drm-backport-placeholder)
- commit 114f10c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0840-drm-amdkfd-Update-SMI-events-for-GFX9.4.3.patch (drm-backport-placeholder)
- commit 5fb2160
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0839-drm-amdgpu-Use-status-register-for-partition-mode.patch (drm-backport-placeholder)
- commit e227cea
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0838-drm-amdkfd-pass-kfd_node-ref-to-svm-migration-api.patch (drm-backport-placeholder)
- commit 882acdf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0837-drm-amdgpu-Conform-to-SET_UCONFIG_REG-spec.patch (drm-backport-placeholder)
- commit 2a914c6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0836-drm-amdgpu-vcn-add-vcn-multiple-AIDs-support.patch (drm-backport-placeholder)
- commit b128eb9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0835-drm-amdgpu-vcn-update-clock-gate-setting-for-VCN-4.0.patch (drm-backport-placeholder)
- commit 6e25344
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0834-drm-amdgpu-jpeg-add-JPEG-multiple-AIDs-support.patch (drm-backport-placeholder)
- commit 72727c0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0833-drm-amdgpu-nbio-add-vcn-doorbell-multiple-AIDs-suppo.patch (drm-backport-placeholder)
- commit 08a3153
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0832-drm-amdgpu-Fix-GRBM-programming-sequence.patch (drm-backport-placeholder)
- commit a34d683
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0831-drm-amdgpu-Use-instance-table-for-sdma-4.4.2.patch (drm-backport-placeholder)
- commit 86c2aa2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0830-drm-amdgpu-Add-mask-for-SDMA-instances.patch (drm-backport-placeholder)
- commit b62b04a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0829-drm-amdgpu-Use-instance-lookup-table-for-GC-9.4.3.patch (drm-backport-placeholder)
- commit 73652cb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0828-drm-amdgpu-Add-map-of-logical-to-physical-inst.patch (drm-backport-placeholder)
- commit 3c06b5b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0827-drm-amdkfd-Add-device-repartition-support.patch (drm-backport-placeholder)
- commit d544a84
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0826-drm-amdkfd-Rework-kfd_locked-handling.patch (drm-backport-placeholder)
- commit aa4693b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0825-drm-amdgpu-configure-the-doorbell-settings-for-sdma-.patch (drm-backport-placeholder)
- commit 4efd305
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0824-drm-amdgpu-add-indirect-r-w-interface-for-smn-addres.patch (drm-backport-placeholder)
- commit e502645
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0823-drm-amdkfd-EOP-Removal-Handle-size-0-correctly.patch (drm-backport-placeholder)
- commit 406793c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0822-drm-amdgpu-reflect-psp-xgmi-topology-info-for-gfx9.4.patch (drm-backport-placeholder)
- commit 0ac5bde
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0821-drm-amdgpu-vcn-update-amdgpu_fw_shared-to-amdgpu_vcn.patch (drm-backport-placeholder)
- commit 81bfd19
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0820-drm-amdgpu-vcn-remove-unused-code.patch (drm-backport-placeholder)
- commit 1a507de
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0819-drm-amdgpu-vcn-update-ucode-setup.patch (drm-backport-placeholder)
- commit fbacef2
* Wed Sep  4 2024 oneukum@suse.com
- media: video-mux: update driver to active state (jsc#PED-8643).
- commit a5f332b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0818-drm-amdgpu-vcn-update-new-doorbell-map.patch (drm-backport-placeholder)
- commit 1736c10
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0817-drm-amdgpu-jpeg-update-jpeg-header-to-support-multip.patch (drm-backport-placeholder)
- commit b172974
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0816-drm-amdgpu-vcn-update-vcn-header-to-support-multiple.patch (drm-backport-placeholder)
- commit c6fab2e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0815-drm-amdgpu-vcn-use-vcn4-irqsrc-header-for-VCN-4.0.3.patch (drm-backport-placeholder)
- commit bf6c5be
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0814-drm-amdgpu-Change-num_xcd-to-xcc_mask.patch (drm-backport-placeholder)
- commit 453a743
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0813-drm-amdgpu-add-the-support-of-XGMI-link-for-GC-9.4.3.patch (drm-backport-placeholder)
- commit 54caee2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0812-drm-amdgpu-add-new-vram-type-for-dgpu.patch (drm-backport-placeholder)
- commit f449841
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0811-drm-amdkfd-Populate-memory-info-before-adding-GPU-no.patch (drm-backport-placeholder)
- commit a0db9ab
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0810-drm-amdkfd-Add-SDMA-info-for-SDMA-4.4.2.patch (drm-backport-placeholder)
- commit 44b5fba
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0809-drm-amdkfd-Fix-SDMA-in-CPX-mode.patch (drm-backport-placeholder)
- commit 575d4b6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0808-drm-amdkfd-add-gpu-compute-cores-io-links-for-gfx9.4.patch (drm-backport-placeholder)
- commit 228e517
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0807-drm-amdgpu-introduce-new-doorbell-assignment-table-f.patch (drm-backport-placeholder)
- commit 86ef2f0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0806-drm-amdgpu-program-GRBM_MCM_ADDR-for-non-AID0-GRBM.patch (drm-backport-placeholder)
- commit 80d16ef
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0805-drm-amdgpu-convert-the-doorbell_index-to-2-dwords-of.patch (drm-backport-placeholder)
- commit 2682d4d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0804-drm-amdgpu-set-mmhub-bitmask-for-multiple-AIDs.patch (drm-backport-placeholder)
- commit 99438db
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0803-drm-amdgpu-complement-the-IH-node_id-table-for-multi.patch (drm-backport-placeholder)
- commit 5543227
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0802-drm-amdgpu-correct-the-vmhub-reference-for-each-XCD-.patch (drm-backport-placeholder)
- commit d0cbeb3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0801-drm-amdgpu-do-mmhub-init-for-multiple-AIDs.patch (drm-backport-placeholder)
- commit 4187608
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0800-drm-amdgpu-assign-the-doorbell-index-for-sdma-on-non.patch (drm-backport-placeholder)
- commit 40a0a6f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0799-drm-amdgpu-add-support-for-SDMA-on-multiple-AIDs.patch (drm-backport-placeholder)
- commit ee9bc93
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0798-drm-amdgpu-adjust-some-basic-elements-for-multiple-A.patch (drm-backport-placeholder)
- commit 4f26c98
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0797-drm-amdgpu-assign-the-doorbell-index-in-1st-page-to-.patch (drm-backport-placeholder)
- commit 609efa9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0796-drm-amdgpu-Set-XNACK-per-process-on-GC-9.4.3.patch (drm-backport-placeholder)
- commit 19b8489
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0795-drm-amdgpu-Use-new-atomfirmware-init-for-GC-9.4.3.patch (drm-backport-placeholder)
- commit 4b30be6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0794-drm-amdkfd-Update-coherence-settings-for-svm-ranges.patch (drm-backport-placeholder)
- commit db4fd7d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0793-drm-amdgpu-Fix-CP_HYP_XCP_CTL-register-programming-i.patch (drm-backport-placeholder)
- commit 3eead8e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0792-drm-amdkfd-Update-SDMA-queue-management-for-GFX9.4.3.patch (drm-backport-placeholder)
- commit f0523ee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0791-drm-amdkfd-Update-sysfs-node-properties-for-multi-XC.patch (drm-backport-placeholder)
- commit 8149b22
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0790-drm-amdkfd-Call-DQM-stop-during-DQM-uninitialize.patch (drm-backport-placeholder)
- commit 1920d10
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0789-drm-amdgpu-Fix-VM-fault-reporting-on-XCC1.patch (drm-backport-placeholder)
- commit 491b264
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0788-drm-amdkfd-Update-context-save-handling-for-multi-XC.patch (drm-backport-placeholder)
- commit 807a099
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0787-drm-amdgpu-Add-XCC-inst-to-PASID-TLB-flushing.patch (drm-backport-placeholder)
- commit ecd87b2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0786-drm-amdkfd-Add-XCC-instance-to-kgd2kfd-interface-v3.patch (drm-backport-placeholder)
- commit 2212005
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0785-drm-amdkfd-Add-PM4-target-XCC.patch (drm-backport-placeholder)
- commit db14718
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0784-drm-amdkfd-Update-MQD-management-on-multi-XCC-setup.patch (drm-backport-placeholder)
- commit 98ab10d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0783-drm-amdkfd-Add-spatial-partitioning-support-in-KFD.patch (drm-backport-placeholder)
- commit adb9fbd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0782-drm-amdkfd-Introduce-kfd_node-struct-v5.patch (drm-backport-placeholder)
- commit 7bdb8e7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0781-drm-amdgpu-Add-mode2-reset-logic-for-v13.0.6.patch (drm-backport-placeholder)
- commit c061e2b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0780-drm-amdgpu-Add-some-XCC-programming.patch (drm-backport-placeholder)
- commit 153c952
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0779-drm-amdgpu-add-node_id-to-physical-id-conversion-in-.patch (drm-backport-placeholder)
- commit 4dc5eac
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0778-drm-amdgpu-enable-the-ring-and-IB-test-for-slave-kcq.patch (drm-backport-placeholder)
- commit d2a0da4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0777-drm-amdgpu-support-gc-v9_4_3-ring_test-running-on-al.patch (drm-backport-placeholder)
- commit 478f4ec
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0776-drm-amdgpu-fix-vcn-doorbell-range-setting.patch (drm-backport-placeholder)
- commit 65287a7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0775-drm-amdgpu-jpeg-enable-jpeg-doorbell-for-jpeg4.0.3.patch (drm-backport-placeholder)
- commit c663c9d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0774-drm-amdgpu-vcn-enable-vcn-doorbell-for-vcn4.0.3.patch (drm-backport-placeholder)
- commit dfb603e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0773-drm-amdgpu-nbio-update-vcn-doorbell-range.patch (drm-backport-placeholder)
- commit 84f8c05
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0772-drm-amdkfd-Set-F8_MODE-for-gc_v9_4_3.patch (drm-backport-placeholder)
- commit dc36ab3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0771-drm-amdgpu-jpeg-add-multiple-jpeg-rings-support-for-.patch (drm-backport-placeholder)
- commit c60f4eb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0770-drm-amdgpu-jpeg-add-multiple-jpeg-rings-support.patch (drm-backport-placeholder)
- commit 23573e9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0769-drm-amdgpu-vcn-enable-vcn-DPG-mode-for-VCN4_0_3.patch (drm-backport-placeholder)
- commit c26977b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0768-drm-amdgpu-vcn-enable-vcn-pg-for-VCN4_0_3.patch (drm-backport-placeholder)
- commit 2c0fe0f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0767-drm-amdgpu-vcn-enable-vcn-cg-for-VCN4_0_3.patch (drm-backport-placeholder)
- commit 60cf231
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0766-drm-amdgpu-jpeg-enable-jpeg-pg-for-VCN4_0_3.patch (drm-backport-placeholder)
- commit fd73524
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0765-drm-amdgpu-jpeg-enable-jpeg-cg-for-VCN4_0_3.patch (drm-backport-placeholder)
- commit 33472e3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0764-drm-amdgpu-vcn-add-vcn-support-for-VCN4_0_3.patch (drm-backport-placeholder)
- commit da3e8d6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0763-drm-amdgpu-jpeg-add-jpeg-support-for-VCN4_0_3.patch (drm-backport-placeholder)
- commit 538edf2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0762-drm-amdgpu-add-VCN4_0_3-firmware.patch (drm-backport-placeholder)
- commit 350d57a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0761-drm-amdgpu-add-vcn-v4_0_3-ip-headers.patch (drm-backport-placeholder)
- commit 5e7e1c0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0760-drm-amdgpu-add-more-macro-to-support-offset-variant.patch (drm-backport-placeholder)
- commit e09ce8e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0759-drm-amdgpu-Use-the-correct-API-to-read-register.patch (drm-backport-placeholder)
- commit a4d51d0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0758-drm-amdgpu-Add-kgd2kfd-for-GC-9.4.3.patch (drm-backport-placeholder)
- commit 6ccaffc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0757-drm-amdgpu-alloc-vm-inv-engines-for-every-vmhub.patch (drm-backport-placeholder)
- commit e7b83d0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0756-drm-amdgpu-override-partition-mode-through-module-pa.patch (drm-backport-placeholder)
- commit 0b663d4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0755-drm-amdgpu-make-the-WREG32_SOC15_xx-macro-to-support.patch (drm-backport-placeholder)
- commit 9eb3140
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0754-drm-amdgpu-add-sysfs-node-for-compute-partition-mode.patch (drm-backport-placeholder)
- commit 4adb759
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0753-drm-amdgpu-assign-different-AMDGPU_GFXHUB-for-rings-.patch (drm-backport-placeholder)
- commit 5fdd485
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0752-drm-amdgpu-init-vmhubs-bitmask-for-GC-9.4.3.patch (drm-backport-placeholder)
- commit a811ae2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0751-drm-amdgpu-add-bitmask-to-iterate-vmhubs.patch (drm-backport-placeholder)
- commit 71dca3c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0750-drm-amdgpu-assign-register-address-for-vmhub-object-.patch (drm-backport-placeholder)
- commit 86ae784
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0749-drm-amdgpu-introduce-vmhub-definition-for-multi-part.patch (drm-backport-placeholder)
- commit 9ca3cef
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0748-drm-amd-display-3.2.236.patch (drm-backport-placeholder)
- commit e26ddf1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Remove-v_startup-workaround-fo.patch (drm-backport-placeholder)
- commit 5db592c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0746-drm-amd-display-Remove-unnecessary-variable.patch (drm-backport-placeholder)
- commit 4726b7e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0745-drm-amd-display-Make-unbounded-req-update-separate-f.patch (drm-backport-placeholder)
- commit b577d48
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0744-drm-amd-display-Add-visual-confirm-color-support-for.patch (drm-backport-placeholder)
- commit b39d682
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-possible-underflow-for-disp.patch (drm-backport-placeholder)
- commit e0fb682
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0742-drm-amd-display-Convert-connector-signal-id-to-strin.patch (drm-backport-placeholder)
- commit 41fdc7f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0741-drm-amd-display-Update-vactive-margin-and-max-vblank.patch (drm-backport-placeholder)
- commit da86e9e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0740-drm-amd-display-Only-skip-update-for-DCFCLK-UCLK-FCL.patch (drm-backport-placeholder)
- commit 1814e8b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0739-drm-amdgpu-improve-wait-logic-at-fence-polling.patch (drm-backport-placeholder)
- commit 82167ad
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0738-drm-amd-display-Simplify-the-calculation-of-variable.patch (drm-backport-placeholder)
- commit b6e6688
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdkfd-Fix-potential-deallocation-of-previo.patch (drm-backport-placeholder)
- commit 1dbeb76
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0736-drm-amd-amdgpu-Fix-warnings-in-amdgpu-_object-_ring..patch (drm-backport-placeholder)
- commit 99b03bf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0735-drm-amdgpu-release-correct-lock-in-amdgpu_gfx_enable.patch (drm-backport-placeholder)
- commit 7cbed1b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0734-drm-amdgpu-display-Enable-DC_FP-for-LoongArch.patch (drm-backport-placeholder)
- commit 604a8ea
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0733-drm-amd-display-Promote-DAL-to-3.2.235.patch (drm-backport-placeholder)
- commit c90a872
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0732-drm-amd-display-Block-SubVP-on-displays-that-have-pi.patch (drm-backport-placeholder)
- commit b8d47c0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0731-drm-amd-display-Block-SubVP-high-refresh-when-VRR-ac.patch (drm-backport-placeholder)
- commit 453a956
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0730-drm-amd-display-Check-Vactive-for-VRR-active-for-FPO.patch (drm-backport-placeholder)
- commit 53de8d9
* Wed Sep  4 2024 oneukum@suse.com
- media: video-mux: fix error paths (jsc#PED-8643).
- commit ec35a19
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0729-drm-amdgpu-set-default-num_kcq-to-2-under-sriov.patch (drm-backport-placeholder)
- commit a8a24c0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-install-stub-fence-into-potential-u.patch (drm-backport-placeholder)
- commit 22d6e05
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0727-drm-amd-display-Show-the-DCN-DCE-version-in-the-log.patch (drm-backport-placeholder)
- commit 3fb0d64
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0726-drm-amdgpu-Remove-the-unused-variable-golden_setting.patch (drm-backport-placeholder)
- commit 3664536
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0725-drm-amdkfd-Don-t-trigger-evictions-unmapping-dmabuf-.patch (drm-backport-placeholder)
- commit 40e7993
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0724-drm-amd-display-Add-additional-pstate-registers-to-H.patch (drm-backport-placeholder)
- commit aa9e8cb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0723-drm-amdgpu-remove-unneeded-semicolon.patch (drm-backport-placeholder)
- commit d233171
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0722-drm-amdgpu-do-gfxhub-init-for-all-XCDs.patch (drm-backport-placeholder)
- commit d92925c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0721-drm-amdgpu-unlock-on-error-in-gfx_v9_4_3_kiq_resume.patch (drm-backport-placeholder)
- commit 36152b2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0720-drm-amdgpu-unlock-the-correct-lock-in-amdgpu_gfx_ena.patch (drm-backport-placeholder)
- commit a80db28
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0719-drm-amdgpu-drop-unused-function.patch (drm-backport-placeholder)
- commit 29a9028
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0718-drm-amdgpu-drop-invalid-IP-revision.patch (drm-backport-placeholder)
- commit ffa5ef0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0717-drm-amdgpu-put-MQDs-in-VRAM.patch (drm-backport-placeholder)
- commit a474eb6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0716-drm-amd-amdgpu-Fix-errors-warnings-in-amdgpu-_bios-_.patch (drm-backport-placeholder)
- commit a069103
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0715-drm-amdgpu-gfx11-always-restore-kcq-kgq-MQDs.patch (drm-backport-placeholder)
- commit fc3d99e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0714-drm-amd-display-mark-amdgpu_dm_connector_funcs_force.patch (drm-backport-placeholder)
- commit 86f9445
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0713-drm-amdgpu-gfx10-always-restore-kcq-kgq-MQDs.patch (drm-backport-placeholder)
- commit 04854a4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0712-drm-amdgpu-gfx9-always-restore-kcq-MQDs.patch (drm-backport-placeholder)
- commit 307ea01
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0711-drm-amdgpu-gfx8-always-restore-kcq-MQDs.patch (drm-backport-placeholder)
- commit d70c0cb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0710-drm-amdgpu-gfx11-drop-unused-variable.patch (drm-backport-placeholder)
- commit 79eac63
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0709-drm-amdgpu-gfx10-drop-unused-variable.patch (drm-backport-placeholder)
- commit b07455e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0708-drm-amd-Downgrade-message-about-watermarks-table-aft.patch (drm-backport-placeholder)
- commit 2e50b8c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0707-drm-amdgpu-gfx11-use-generic-en-dis-able_kgq-helpers.patch (drm-backport-placeholder)
- commit 8a24c5c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0706-drm-amdgpu-gfx10-use-generic-en-dis-able_kgq-helpers.patch (drm-backport-placeholder)
- commit f687237
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0705-drm-amdgpu-add-en-dis-able_kgq-functions.patch (drm-backport-placeholder)
- commit 08ae580
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0704-drm-amd-display-3.2.234.patch (drm-backport-placeholder)
- commit 4fe3081
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0703-drm-amd-display-FW-Promotion-Release-0.0.165.0.patch (drm-backport-placeholder)
- commit 798802b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0702-drm-amd-display-Add-w-a-to-disable-DP-dual-mode-on-c.patch (drm-backport-placeholder)
- commit e3a52f6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0701-drm-amd-display-revert-Update-scaler-recout-data-for.patch (drm-backport-placeholder)
- commit 6978b3d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0700-drm-amd-display-Adding-debug-option-to-override-Z8-w.patch (drm-backport-placeholder)
- commit 7f5a4f0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0699-drm-amd-display-Workaround-wrong-HDR-colorimetry-wit.patch (drm-backport-placeholder)
- commit 15e88df
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0698-drm-amd-display-Add-logging-when-DP-link-training-Ch.patch (drm-backport-placeholder)
- commit 559cb16
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0697-drm-amd-amdgpu-Fix-style-problems-in-amdgpu_psp.c.patch (drm-backport-placeholder)
- commit a3dc8ca
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0696-drm-amdgpu-gfx10-drop-old-bring-up-code.patch (drm-backport-placeholder)
- commit 3dee2fe
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0695-drm-amdgpu-gfx11-drop-old-bring-up-code.patch (drm-backport-placeholder)
- commit 3c81faf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0694-drm-amdkfd-Optimize-svm-range-map-to-GPU-with-XNACK-.patch (drm-backport-placeholder)
- commit 419718d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0693-drm-amd-display-Add-logging-for-eDP-v1.4-supported-s.patch (drm-backport-placeholder)
- commit 5ce3674
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0692-drm-amd-display-Fix-possible-NULL-dereference-in-dc_.patch (drm-backport-placeholder)
- commit 0152e30
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0691-drm-amd-amdgpu-Fix-style-problems-in-amdgpu_debugfs..patch (drm-backport-placeholder)
- commit 0fc8199
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0690-drm-amdgpu-Enable-mcbp-under-sriov-by-default.patch (drm-backport-placeholder)
- commit dd1fb33
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0689-drm-amdgpu-remove-pasid_src-field-from-IV-entry.patch (drm-backport-placeholder)
- commit 12f524a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0688-drm-amd-amdgpu-Simplify-switch-case-statements-in-am.patch (drm-backport-placeholder)
- commit 28efdad
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0687-drm-amdgpu-Add-SDMA_UTCL1_WR_FIFO_SED-field-for-sdma.patch (drm-backport-placeholder)
- commit 5f412cf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0686-drm-amdkfd-Update-KFD-TTM-mem-limit.patch (drm-backport-placeholder)
- commit fbfe7c2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0685-drm-amdgpu-Set-GTT-size-equal-to-TTM-mem-limit.patch (drm-backport-placeholder)
- commit 10f95d5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0684-drm-ttm-Helper-function-to-get-TTM-mem-limit.patch (drm-backport-placeholder)
- commit b42e992
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0683-drm-amdgpu-mark-gfx_v9_4_3_disable_gpa_mode-static.patch (drm-backport-placeholder)
- commit a533fc4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0682-drm-amdgpu-check-correct-allocated-mqd_backup-object.patch (drm-backport-placeholder)
- commit c68f0a5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0681-drm-amdgpu-fix-a-build-warning-by-a-typo-in-amdgpu_g.patch (drm-backport-placeholder)
- commit 5e541a3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0680-drm-amd-display-return-status-of-dmub_srv_get_fw_boo.patch (drm-backport-placeholder)
- commit d0bd3ef
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0679-drm-amd-display-set-variable-custom_backlight_curve0.patch (drm-backport-placeholder)
- commit eb4081c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0678-drm-amd-amdgpu-Fix-style-errors-in-amdgpu_display.c.patch (drm-backport-placeholder)
- commit 1a3d48b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0677-drm-amd-display-DSC-passthrough-is-for-DP-HDMI-pcon-.patch (drm-backport-placeholder)
- commit e4d21f0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0676-drm-amdgpu-add-new-flag-to-AMDGPU_CTX_QUERY2.patch (drm-backport-placeholder)
- commit d74d002
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-a-test-dml32_rq_dlg_get_rq_.patch (drm-backport-placeholder)
- commit 29f8ded
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-a-test-CalculatePrefetchSch.patch (drm-backport-placeholder)
- commit 303b7fb
* Wed Sep  4 2024 oneukum@suse.com
- media: video-mux: Add missing media_entity_cleanup upon async
  register fail (jsc#PED-8643).
- commit 5e42fcf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0673-drm-amd-amdgpu-Fix-missing-bo-unlock-in-failure-path.patch (drm-backport-placeholder)
- commit ed82e81
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0672-drm-amd-display-remove-unused-variables-dispclk_dela.patch (drm-backport-placeholder)
- commit 251f341
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0671-drm-amdgpu-support-psp-vbflash-sysfs-for-MP0-13_0_10.patch (drm-backport-placeholder)
- commit 7f9b05f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/Revert-drm-amd-display-disable-SubVP-DRR-to-pr.patch (drm-backport-placeholder)
- commit 71d89ae
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0669-drm-amd-display-3.2.233.patch (drm-backport-placeholder)
- commit f4ff806
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Keep-disable-aux-i-delay-as-0.patch (drm-backport-placeholder)
- commit 9dd88b1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0667-drm-amd-display-Query-GECC-enable-for-SubVP-disable.patch (drm-backport-placeholder)
- commit b1d6acf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0666-drm-amd-display-Enable-SubVP-for-high-refresh-rate-d.patch (drm-backport-placeholder)
- commit df74883
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0665-drm-amd-display-For-no-plane-case-set-pstate-support.patch (drm-backport-placeholder)
- commit f24710a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0664-drm-amd-display-Add-p-state-debugging.patch (drm-backport-placeholder)
- commit ed26873
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-update-extended-blank-for-dcn31.patch (drm-backport-placeholder)
- commit cd70c1f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Fix-in-secure-display-context-c.patch (drm-backport-placeholder)
- commit f2e4219
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0661-drm-amd-display-Update-scaler-recout-data-for-visual.patch (drm-backport-placeholder)
- commit ed689aa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0660-drm-amd-display-Program-OTG-vtotal-min-max-selectors.patch (drm-backport-placeholder)
- commit 9ef98ed
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0659-drm-amd-display-add-option-to-use-custom-backlight-c.patch (drm-backport-placeholder)
- commit 89bf91d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0658-drm-amd-display-Enable-SubVP-on-PSR-panels-if-single.patch (drm-backport-placeholder)
- commit 64317a6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-add-pixel-rate-based-CRB-alloca.patch (drm-backport-placeholder)
- commit f2d14f9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Limit-DCN32-8-channel-or-less-p.patch (drm-backport-placeholder)
- commit e3f1766
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0655-drm-amd-display-Restore-rptr-wptr-for-DMCUB-as-worka.patch (drm-backport-placeholder)
- commit eb61288
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0654-drm-amd-display-Update-FW-feature-caps-struct.patch (drm-backport-placeholder)
- commit 6b48753
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0653-drm-amd-display-implement-force-function-in-amdgpu_d.patch (drm-backport-placeholder)
- commit 3781f63
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0652-drm-amd-display-3.2.232.patch (drm-backport-placeholder)
- commit 9edbf50
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0651-drm-amd-display-FW-Promotion-Release-0.0.163.0.patch (drm-backport-placeholder)
- commit 635b45d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0650-drm-amdgpu-add-debugfs-interface-for-reading-MQDs.patch (drm-backport-placeholder)
- commit 6d6dc5c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0649-drm-amdgpu-track-MQD-size-for-gfx-and-compute.patch (drm-backport-placeholder)
- commit 42a3815
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0648-drm-amdgpu-bump-driver-version-number-for-CP-GFX-sha.patch (drm-backport-placeholder)
- commit 7932f91
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0647-drm-amdkfd-Fix-an-issue-at-userptr-buffer-validation.patch (drm-backport-placeholder)
- commit 79d2c20
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Convert-Delaying-Aux-I-Disable-.patch (drm-backport-placeholder)
- commit 40874bf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0645-drm-amd-display-assign-edid_blob_ptr-with-edid-from-.patch (drm-backport-placeholder)
- commit 636cbb2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0644-drm-amdgpu-add-support-for-new-GFX-shadow-size-query.patch (drm-backport-placeholder)
- commit ae7ab2a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0643-drm-amdgpu-add-get_gfx_shadow_info-callback-for-gfx1.patch (drm-backport-placeholder)
- commit 4d76e94
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0642-drm-amdgpu-add-gfx-shadow-callback.patch (drm-backport-placeholder)
- commit 02e31a9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0641-drm-amdgpu-add-UAPI-to-query-GFX-shadow-sizes.patch (drm-backport-placeholder)
- commit 23e0917
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0640-drm-amdgpu-don-t-require-a-job-for-cond_exec-and-sha.patch (drm-backport-placeholder)
- commit b865309
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0639-drm-amdgpu-add-gfx11-emit-shadow-callback.patch (drm-backport-placeholder)
- commit ee3a149
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0638-drm-amdgpu-add-gfx-shadow-CS-IOCTL-support.patch (drm-backport-placeholder)
- commit 42afd79
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0637-drm-amdgpu-UAPI-add-new-CS-chunk-for-GFX-shadow-buff.patch (drm-backport-placeholder)
- commit 88ff018
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0636-drm-amdgpu-gfx11-check-the-CP-FW-version-CP-GFX-shad.patch (drm-backport-placeholder)
- commit 4bc2a6e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-memory-leak-in-mes-self-test.patch (drm-backport-placeholder)
- commit 4302553
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0634-drm-amdgpu-gfx11-add-FW-version-check-for-new-CP-GFX.patch (drm-backport-placeholder)
- commit b229ec0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0633-drm-amd-display-dumb_abm_lcd-avoid-missing-prototype.patch (drm-backport-placeholder)
- commit 4d29082
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0632-drm-amd-display-3.2.231.patch (drm-backport-placeholder)
- commit ba85bbe
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0631-drm-amd-display-Add-FAMS-related-definitions-and-doc.patch (drm-backport-placeholder)
- commit 9d4840d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-Fix-integer-overflow-in-amdgpu_cs_p.patch (drm-backport-placeholder)
- commit 701c543
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-radeon-Fix-integer-overflow-in-radeon_cs_pa.patch (drm-backport-placeholder)
- commit 696af77
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0628-drm-amd-display-Add-FAMS-capability-to-DCN31.patch (drm-backport-placeholder)
- commit dc2b84a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Explicitly-specify-update-type-.patch (drm-backport-placeholder)
- commit 569fd97
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0626-drm-amd-display-fix-dpms_off-issue-when-disabling-bi.patch (drm-backport-placeholder)
- commit 475c3fd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0625-drm-amd-display-update-GSP1-generic-info-packet-for-.patch (drm-backport-placeholder)
- commit 8081bca
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0624-drm-amd-display-Adjust-dmub-outbox-notification-enab.patch (drm-backport-placeholder)
- commit 2ba7cd0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0623-drm-amd-display-3-plane-MPO-enablement-for-DCN321.patch (drm-backport-placeholder)
- commit fd2f464
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0622-drm-amd-display-Add-extra-check-for-444-16-format.patch (drm-backport-placeholder)
- commit 8dd5f37
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0621-drm-amd-display-correct-DML-calc-error.patch (drm-backport-placeholder)
- commit c34e16c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0620-drm-amd-display-Limit-nv21-dst_y.patch (drm-backport-placeholder)
- commit 6113c09
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0619-drm-amd-display-Add-check-for-PState-change-in-DCN32.patch (drm-backport-placeholder)
- commit 0a267ca
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0618-drm-amd-display-Set-DRAM-clock-if-retraining-is-requ.patch (drm-backport-placeholder)
- commit 16d75e0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0617-drm-amd-display-add-support-for-low-bpc.patch (drm-backport-placeholder)
- commit 705a6d6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0616-drm-amd-amdgpu-Fix-style-issues-in-amdgpu_discovery..patch (drm-backport-placeholder)
- commit b79307f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0615-drm-amd-display-Remove-unused-variables-in-dcn21_hws.patch (drm-backport-placeholder)
- commit 44acec0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0614-drm-amdgpu-allocate-doorbell-index-for-multi-die-cas.patch (drm-backport-placeholder)
- commit 2f64311
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0613-drm-amd-amdgpu-Fix-style-errors-in-amdgpu_drv.c-amdg.patch (drm-backport-placeholder)
- commit e64e71a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0612-drm-amd-amdgpu-Fix-spaces-in-array-indexing-and-inde.patch (drm-backport-placeholder)
- commit 4fd2c3d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0611-drm-amdgpu-Drop-pcie_bif-ras-check-from-fatal-error-.patch (drm-backport-placeholder)
- commit 16a9e7c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amdgpu-fix-calltrace-warning-in-amddrm_bud.patch (drm-backport-placeholder)
- commit b0c6249
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0609-drm-amdgpu-initialize-num_xcd-to-1-for-gfx-v9_0.patch (drm-backport-placeholder)
- commit 5539c8f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0608-drm-amdgpu-add-master-slave-check-in-init-phase.patch (drm-backport-placeholder)
- commit ce10c01
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0607-drm-amd-display-Clear-GPINT1-before-taking-DMCUB-out.patch (drm-backport-placeholder)
- commit 1e497c9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0606-drm-amdgpu-add-xcc-index-argument-to-rlc-safe_mode-f.patch (drm-backport-placeholder)
- commit 985d2b9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0605-drm-amdgpu-add-xcc-index-argument-to-select_sh_se-fu.patch (drm-backport-placeholder)
- commit d0202b9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0604-drm-amdgpu-add-xcc-index-argument-to-gfx-v9_4_3-func.patch (drm-backport-placeholder)
- commit b5e8e32
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0603-drm-amdgpu-add-multi-XCC-initial-support-in-gfx_v9_4.patch (drm-backport-placeholder)
- commit d0c8d91
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0602-drm-amdgpu-add-xcc-index-argument-to-soc15_grbm_sele.patch (drm-backport-placeholder)
- commit 412bc7d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0601-drm-amdgpu-split-gc-v9_4_3-functionality-from-gc-v9_.patch (drm-backport-placeholder)
- commit 11c8946
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0600-drm-amdgpu-add-multi-xcc-support-to-amdgpu_gfx-inter.patch (drm-backport-placeholder)
- commit c84c303
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0599-drm-amdgpu-separate-the-mqd_backup-for-kiq-from-kcq.patch (drm-backport-placeholder)
- commit 4d5326b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0598-drm-amdgpu-move-queue_bitmap-to-an-independent-struc.patch (drm-backport-placeholder)
- commit 7aa2705
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0597-drm-amdgpu-convert-gfx.kiq-to-array-type-v3.patch (drm-backport-placeholder)
- commit a93bbf3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/radeon-avoid-double-free-in-ci_dpm_init.patch (drm-backport-placeholder)
- commit f26dc4b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0595-drm-amd-display-remove-unused-variable-oldest_index.patch (drm-backport-placeholder)
- commit 32506f2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0594-drm-amd-pm-Fix-spelling-mistake-aquire-acquire.patch (drm-backport-placeholder)
- commit b208937
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0593-drm-amdgpu-Add-support-for-querying-the-max-ibs-in-a.patch (drm-backport-placeholder)
- commit 895cab8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0592-drm-amdgpu-Add-a-max-ibs-per-submission-limit.patch (drm-backport-placeholder)
- commit b29a884
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0591-drm-amdgpu-Increase-GFX6-graphics-ring-size.patch (drm-backport-placeholder)
- commit 9f24aef
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Update-DTBCLK-for-DCN32.patch (drm-backport-placeholder)
- commit 1618e6c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-fix-is_timing_changed-prototype.patch (drm-backport-placeholder)
- commit 668dea5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-logging-for-display-MALL-re.patch (drm-backport-placeholder)
- commit 8aa3ed6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0587-drm-amd-display-Write-TEST_EDID_CHECKSUM_WRITE-for-E.patch (drm-backport-placeholder)
- commit 71060df
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0586-drm-amd-display-add-mechanism-to-skip-DCN-init.patch (drm-backport-placeholder)
- commit c1aa7bc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0585-drm-amd-display-add-extra-dc-odm-debug-options.patch (drm-backport-placeholder)
- commit 37849dd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0584-drm-amd-display-FW-Promotion-Release-0.0.162.0.patch (drm-backport-placeholder)
- commit 44c1128
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0583-drm-amd-display-Enable-FPO-Vactive.patch (drm-backport-placeholder)
- commit 4e89cf9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0582-drm-amd-display-Set-watermarks-set-D-equal-to-A.patch (drm-backport-placeholder)
- commit 670738b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0581-drm-amd-display-Correct-output-color-space-during-HW.patch (drm-backport-placeholder)
- commit 66aa6cf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0580-drm-amd-display-DSC-policy-override-when-ODM-combine.patch (drm-backport-placeholder)
- commit 1b15c1b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0579-drm-amd-display-Adding-support-for-VESA-SCR.patch (drm-backport-placeholder)
- commit 03e521a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Add-FAMS-validation-before-tryi.patch (drm-backport-placeholder)
- commit 3a23a30
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0577-drm-amd-display-drain-dmub-inbox-if-queue-is-full.patch (drm-backport-placeholder)
- commit 109f5c0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0576-drm-amd-display-refactor-dmub-commands-into-single-f.patch (drm-backport-placeholder)
- commit f5edadd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0575-drm-amd-display-Only-consider-DISPCLK-when-using-opt.patch (drm-backport-placeholder)
- commit 2661d4e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0574-drm-amd-display-update-max-streams-per-surface.patch (drm-backport-placeholder)
- commit 0714541
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0573-drm-amd-display-Fix-in-disabling-secure-display.patch (drm-backport-placeholder)
- commit 04280d4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0572-drm-amd-display-Block-optimize-on-consecutive-FAMS-e.patch (drm-backport-placeholder)
- commit 4371975
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0571-drm-amd-display-Do-not-set-drr-on-pipe-commit.patch (drm-backport-placeholder)
- commit 5fc8572
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0570-drm-amd-display-Fix-ABM-pipe-backlight-issues-when-c.patch (drm-backport-placeholder)
- commit d73b9c3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0569-drm-amd-display-Check-log-if-receiver-supports-MST-D.patch (drm-backport-placeholder)
- commit 5841f25
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-amd-display-Unconditionally-print-when-DP-s.patch (drm-backport-placeholder)
- commit da1fc6e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0567-drm-amd-display-Refactor-ABM-feature.patch (drm-backport-placeholder)
- commit 6c7e397
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0566-drm-i915-gsc-Fix-error-code-in-intel_gsc_uc_heci_cmd.patch (drm-backport-placeholder)
- commit 8c80e12
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0565-i915-perf-Do-not-add-ggtt-offset-to-hw_tail.patch (drm-backport-placeholder)
- commit 89800fd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0564-i915-perf-Drop-the-aging_tail-logic-in-perf-OA.patch (drm-backport-placeholder)
- commit a1b1baa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0563-drm-i915-Allow-user-to-set-cache-at-BO-creation.patch (drm-backport-placeholder)
- commit 1db498c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0562-drm-i915-guc-Remove-some-obsolete-definitions.patch (drm-backport-placeholder)
- commit 99f9bfb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0561-drm-i915-rename-I915_PMU_MAX_GTS-to-I915_PMU_MAX_GT.patch (drm-backport-placeholder)
- commit a2d7564
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0560-drm-i915-Reduce-I915_MAX_GT-to-2.patch (drm-backport-placeholder)
- commit 1685a76
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0559-drm-i915-Use-the-fdinfo-helper.patch (drm-backport-placeholder)
- commit 71331b7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0558-drm-i915-huc-define-HuC-FW-version-for-MTL.patch (drm-backport-placeholder)
- commit 315292e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0557-drm-i915-mtl-huc-Use-the-media-gt-for-the-HuC-getpar.patch (drm-backport-placeholder)
- commit 7ed07ef
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0556-drm-i915-mtl-huc-auth-HuC-via-GSC.patch (drm-backport-placeholder)
- commit b87e52b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0555-drm-i915-huc-differentiate-the-2-steps-of-the-MTL-Hu.patch (drm-backport-placeholder)
- commit 26787c2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0554-drm-i915-huc-Load-GSC-enabled-HuC-via-DMA-xfer-if-th.patch (drm-backport-placeholder)
- commit f7b533e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0553-drm-i915-huc-Parse-the-GSC-enabled-HuC-binary.patch (drm-backport-placeholder)
- commit fed3759
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0552-drm-i915-uc-perma-pin-firmwares.patch (drm-backport-placeholder)
- commit 567f47f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-gt-Add-workaround-14016712196.patch (drm-backport-placeholder)
- commit f023fad
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0550-drm-i915-pxp-Fix-size_t-format-specifier-in-gsccs_se.patch (drm-backport-placeholder)
- commit d23a26e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0549-drm-i915-gt-limit-lmem-allocation-size-to-succeed-on.patch (drm-backport-placeholder)
- commit be42e32
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0548-drm-i915-gt-Fix-parameter-in-gmch_ggtt_insert_-entri.patch (drm-backport-placeholder)
- commit f699256
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0547-drm-i915-gt-Fix-second-parameter-type-of-pre-gen8-pt.patch (drm-backport-placeholder)
- commit 602426c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0546-drm-i915-pmu-Make-PMU-sample-array-two-dimensional.patch (drm-backport-placeholder)
- commit 573d353
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0545-drm-i915-pmu-Turn-off-the-timer-to-sample-frequencie.patch (drm-backport-placeholder)
- commit edc8544
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0544-drm-i915-guc-Drop-legacy-CTB-definitions.patch (drm-backport-placeholder)
- commit 1884a34
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0543-drm-i915-guc-Track-all-sent-actions-to-GuC.patch (drm-backport-placeholder)
- commit 71d8506
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0542-drm-i915-guc-Update-log-for-unsolicited-CTB-response.patch (drm-backport-placeholder)
- commit 7e1c8c3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0541-drm-i915-guc-Use-FAST_REQUEST-for-non-blocking-H2G-c.patch (drm-backport-placeholder)
- commit 3e79dbe
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0540-drm-i915-gem-Use-large-rings-for-compute-contexts.patch (drm-backport-placeholder)
- commit d6198d3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0539-drm-i915-gsc-use-system-include-style-for-drm-header.patch (drm-backport-placeholder)
- commit efa802a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0538-drm-i915-mtl-Reset-only-one-lane-in-case-of-MFD.patch (drm-backport-placeholder)
- commit a816ccc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0537-drm-i915-Flush-power-delayed-put-when-connector-init.patch (drm-backport-placeholder)
- commit 517633e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0536-drm-i915-Remove-i915_drm_suspend_mode.patch (drm-backport-placeholder)
- commit 6f1d627
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0535-drm-i915_drm.h-fix-a-typo.patch (drm-backport-placeholder)
- commit 63c30ec
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0534-drm-i915-display-switch-the-rest-of-the-connectors-t.patch (drm-backport-placeholder)
- commit 4c4ef9d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0533-drm-display-dp_mst-convert-to-struct-drm_edid.patch (drm-backport-placeholder)
- commit d91bb66
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0532-drm-edid-make-drm_edid_duplicate-safe-to-call-with-N.patch (drm-backport-placeholder)
- commit 27d2d43
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0531-drm-i915-lvds-switch-to-drm_edid_read_switcheroo.patch (drm-backport-placeholder)
- commit 7f8dedd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0530-drm-edid-add-drm_edid_read_switcheroo.patch (drm-backport-placeholder)
- commit 85a7154
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0529-drm-i915-sdvo-stop-caching-has_hdmi_audio-in-struct-.patch (drm-backport-placeholder)
- commit 680d3f3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0528-drm-i915-sdvo-stop-caching-has_hdmi_monitor-in-struc.patch (drm-backport-placeholder)
- commit 11bc913
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0527-drm-i915-hdmi-stop-caching-has_hdmi_sink-in-struct-i.patch (drm-backport-placeholder)
- commit 73fc917
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0526-drm-i915-hdmi-stop-caching-has_audio-in-struct-intel.patch (drm-backport-placeholder)
- commit f566550
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0525-drm-i915-dp-stop-caching-has_hdmi_sink-in-struct-int.patch (drm-backport-placeholder)
- commit f04fda2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0524-drm-i915-dp-stop-caching-has_audio-in-struct-intel_d.patch (drm-backport-placeholder)
- commit 36e3068
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0523-drm-display-dp_mst-drop-has_audio-from-struct-drm_dp.patch (drm-backport-placeholder)
- commit 9950b4c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0522-drm-edid-parse-display-info-has_audio-similar-to-is_.patch (drm-backport-placeholder)
- commit 9008723
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0521-drm-i915-use-localized-__diag_ignore_all-instead-of-.patch (drm-backport-placeholder)
- commit da1c4a3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0520-drm-i915-hdcp-Rename-comp_mutex-to-hdcp_mutex.patch (drm-backport-placeholder)
- commit 8b4fd7d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0519-drm-i915-hdcp-Move-away-from-master-naming-to-arbite.patch (drm-backport-placeholder)
- commit 74e4e8a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0518-drm-i915-hdcp-Rename-dev_priv-to-i915.patch (drm-backport-placeholder)
- commit ccf0a3a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0517-drm-i915-Implement-CTM-property-support-for-VLV.patch (drm-backport-placeholder)
- commit 6292e78
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0516-drm-i915-Always-enable-CGM-CSC-on-CHV.patch (drm-backport-placeholder)
- commit db0f1ad
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0515-drm-i915-Fix-CHV-CGM-CSC-coefficient-sign-handling.patch (drm-backport-placeholder)
- commit 09ae6a3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0514-drm-i915-Expose-crtc-CTM-property-on-ilk-snb.patch (drm-backport-placeholder)
- commit 52f7b60
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0513-drm-i915-Fix-clang-Wimplicit-fallthrough-in-intel_as.patch (drm-backport-placeholder)
- commit cec0f74
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0512-drm-i915-display-Move-feature-test-macros-to-intel_d.patch (drm-backport-placeholder)
- commit 4f6eba9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0511-drm-i915-display-Handle-GMD_ID-identification-in-dis.patch (drm-backport-placeholder)
- commit e82a572
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0510-drm-i915-display-Make-display-responsible-for-probin.patch (drm-backport-placeholder)
- commit 1e9f86f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0509-drm-i915-display-Move-display-runtime-info-to-displa.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh patches.suse/0510-drm-i915-display-Make-display-responsible-for-probin.patch.
- Refresh patches.suse/0512-drm-i915-display-Move-feature-test-macros-to-intel_d.patch.
- commit 3aed6cb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0508-drm-i915-Convert-INTEL_INFO-display-to-a-pointer.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh patches.suse/0509-drm-i915-display-Move-display-runtime-info-to-displa.patch.
- Refresh patches.suse/0510-drm-i915-display-Make-display-responsible-for-probin.patch.
- commit 917a287
* Wed Sep  4 2024 oneukum@suse.com
- media: mc: Make media_entity_get_fwnode_pad() fwnode argument
  const (jsc#PED-8643).
- commit 3898743
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-display-Move-display-device-info-to-he.patch (drm-backport-placeholder)
- commit a7046dc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0506-drm-i915-Replace-all-non-returning-strlcpy-with-strs.patch (drm-backport-placeholder)
- commit 0634c00
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0505-drm-i915-Wait-for-active-retire-before-i915_active_f.patch (drm-backport-placeholder)
- commit 2b16f3d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0504-drm-i915-Support-Async-Flip-on-Linear-buffers.patch (drm-backport-placeholder)
- commit c84f6f9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0503-drm-i915-constify-pointers-to-hwmon_channel_info.patch (drm-backport-placeholder)
- commit 38a30ec
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0502-drm-display-dsc-add-YCbCr-4-2-2-and-4-2-0-RC-paramet.patch (drm-backport-placeholder)
- commit f7e01d0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0501-drm-display-dsc-include-the-rest-of-pre-SCR-paramete.patch (drm-backport-placeholder)
- commit 4de417e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0500-drm-display-dsc-split-DSC-1.2-and-DSC-1.1-pre-SCR-pa.patch (drm-backport-placeholder)
- commit c2c50cb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0499-drm-display-dsc-use-flat-array-for-rc_parameters-loo.patch (drm-backport-placeholder)
- commit d38bf5a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0498-drm-i915-dsc-stop-using-interim-structure-for-calcul.patch (drm-backport-placeholder)
- commit 4b4573f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0497-drm-i915-dsc-move-DSC-tables-to-DRM-DSC-helper.patch (drm-backport-placeholder)
- commit f0a816b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0496-drm-i915-dsc-move-rc_buf_thresh-values-to-common-hel.patch (drm-backport-placeholder)
- commit 2cd0696
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0495-drm-i915-dsc-change-DSC-param-tables-to-follow-the-D.patch (drm-backport-placeholder)
- commit 7362c80
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0494-drm-i915-hdmi-C20-computed-PLL-frequencies.patch (drm-backport-placeholder)
- commit c74a4fb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0493-drm-i915-Add-16bit-register-mask-operators.patch (drm-backport-placeholder)
- commit 912a697
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0492-drm-i915-mtl-Fix-expected-reg-value-for-Thunderbolt-.patch (drm-backport-placeholder)
- commit 6304f71
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0491-drm-i915-tweak-language-in-fastset-pipe-config-compa.patch (drm-backport-placeholder)
- commit 85e4df8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0490-drm-i915-fix-intel_display_irq.c-include-order.patch (drm-backport-placeholder)
- commit 49447fc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0489-drm-i915-tc-Reset-TypeC-PHYs-left-enabled-in-DP-alt-.patch (drm-backport-placeholder)
- commit f66f1a4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0488-drm-i915-tc-Call-TypeC-port-flush_work-cleanup-witho.patch (drm-backport-placeholder)
- commit 51959f8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0487-drm-i915-Factor-out-a-helper-for-handling-atomic-mod.patch (drm-backport-placeholder)
- commit b45571b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0486-drm-i915-dp-Factor-out-intel_dp_get_active_pipes.patch (drm-backport-placeholder)
- commit 2438daa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0485-drm-i915-dp-Prevent-link-training-fallback-on-discon.patch (drm-backport-placeholder)
- commit 4f0d9ec
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0484-drm-i915-dp-Convert-link-training-error-to-debug-mes.patch (drm-backport-placeholder)
- commit dd0116e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0483-drm-i915-dp-Add-link-training-debug-and-error-printi.patch (drm-backport-placeholder)
- commit 0ef8a76
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0482-drm-i915-Add-support-for-disabling-any-CRTCs-during-.patch (drm-backport-placeholder)
- commit a29ca12
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0481-drm-i915-Factor-out-set_encoder_for_connector.patch (drm-backport-placeholder)
- commit 3b4a528
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0480-drm-i915-Separate-intel_crtc_disable_noatomic_begin-.patch (drm-backport-placeholder)
- commit 4688fa0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0479-drm-i915-Update-connector-atomic-state-before-crtc-s.patch (drm-backport-placeholder)
- commit 56c72b4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0478-drm-i915-Make-the-CRTC-state-consistent-during-sanit.patch (drm-backport-placeholder)
- commit 5e498ed
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0477-drm-i915-Add-helpers-to-reference-unreference-a-DPLL.patch (drm-backport-placeholder)
- commit 93784b4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0476-drm-i915-hdcp-Fill-hdcp2_streamid_type-and-k-in-appr.patch (drm-backport-placeholder)
- commit 489164e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0475-drm-i915-hdcp-Fix-modeset-locking-issue-in-hdcp-mst.patch (drm-backport-placeholder)
- commit 1abd46b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0474-drm-i915-hdcp-Remove-enforce_type0-check-outside-loo.patch (drm-backport-placeholder)
- commit 6abf0c4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0473-drm-i915-hdcp-add-intel_atomic_state-argument-to-hdc.patch (drm-backport-placeholder)
- commit 168232d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0472-drm-i915-irq-split-out-display-irq-handling.patch (drm-backport-placeholder)
- commit 9f7dd1e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0471-drm-i915-irq-split-out-hotplug-irq-handling.patch (drm-backport-placeholder)
- commit c62d73b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0470-drm-i915-irq-convert-gen8_de_irq_handler-to-void.patch (drm-backport-placeholder)
- commit b61c2c2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0469-drm-i915-display-add-i915-parameter-to-I915_STATE_WA.patch (drm-backport-placeholder)
- commit 64687bc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0468-drm-i915-display-remove-I915_STATE_WARN_ON.patch (drm-backport-placeholder)
- commit 2ac69ec
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0467-drm-i915-crtc-replace-I915_STATE_WARN_ON-with-I915_S.patch (drm-backport-placeholder)
- commit 1548980
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0466-drm-i915-dpll-drop-a-useless-I915_STATE_WARN_ON.patch (drm-backport-placeholder)
- commit bd71df7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0465-drm-i915-mtl-Add-handling-for-MTL-ccs-modifiers.patch (drm-backport-placeholder)
- commit ee73e9b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0464-drm-fourcc-define-Intel-Meteorlake-related-ccs-modif.patch (drm-backport-placeholder)
- commit c7c5b91
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0463-drm-i915-bios-add-helper-for-reading-SPI.patch (drm-backport-placeholder)
- commit 3a9efa2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0462-drm-i915-gt-drop-dependency-on-VLV_DISPLAY_BASE.patch (drm-backport-placeholder)
- commit 383ad57
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0461-drm-i915-irq-relocate-gmbus-and-dp-aux-irq-handlers.patch (drm-backport-placeholder)
- commit 2bf1e9e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0460-drm-i915-Nuke-intel_bios_is_port_dp_dual_mode.patch (drm-backport-placeholder)
- commit cf88983
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0459-drm-i915-Flip-VBT-DDC-pin-maps-around.patch (drm-backport-placeholder)
- commit 32d8e1a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0458-drm-i915-Split-map_aux_ch-into-per-platform-arrays.patch (drm-backport-placeholder)
- commit e42fc01
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0457-drm-i915-Use-REG_BIT-co.-for-AUX-CH-registers.patch (drm-backport-placeholder)
- commit ef8a960
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0456-drm-i915-Define-more-PS_CTRL-bits.patch (drm-backport-placeholder)
- commit 6fd579a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0455-drm-i915-hdcp-drop-display-prefix-from-include.patch (drm-backport-placeholder)
- commit 347c9fe
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0454-drm-i915-Fix-wrong-condition-in-bxt_set_cdclk-for-DG.patch (drm-backport-placeholder)
- commit 8d9f505
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0453-drm-i915-Pick-one-HDMI-port-for-infoframe-audio-tran.patch (drm-backport-placeholder)
- commit 6778452
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0452-drm-i915-Move-has_hdmi_sink-out-from-intel_hdmi_comp.patch (drm-backport-placeholder)
- commit 650a96b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0451-drm-i915-dp-Rearrange-check-for-illegal-mode-and-com.patch (drm-backport-placeholder)
- commit fc50ece
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0450-drm-i915-dp-Add-helper-to-get-sink_format.patch (drm-backport-placeholder)
- commit 16cd0fe
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0449-drm-i915-display-Use-sink_format-instead-of-ycbcr420.patch (drm-backport-placeholder)
- commit 5d724e6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0448-drm-i915-dp-Configure-PCON-for-conversion-of-output_.patch (drm-backport-placeholder)
- commit 1787811
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0447-drm-i915-dp-Replace-intel_dp.dfp-members-with-the-ne.patch (drm-backport-placeholder)
- commit fdd795e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0446-drm-i915-display-Add-new-member-to-configure-PCON-co.patch (drm-backport-placeholder)
- commit 306b689
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0445-drm-i915-Communicate-display-power-demands-to-pcode.patch (drm-backport-placeholder)
- commit b956cb5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0444-drm-i915-Use-REG_BIT-co.-for-pipe-scaler-registers.patch (drm-backport-placeholder)
- commit 4b5cb25
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0443-drm-i915-Define-bitmasks-for-skl-scaler-window-pos-s.patch (drm-backport-placeholder)
- commit eacbc26
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0442-drm-i915-s-PS_COEE_INDEX_AUTO_INC-PS_COEF_INDEX_AUTO.patch (drm-backport-placeholder)
- commit ec1da7d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0441-drm-i915-Rename-skl-scaler-binding-bits.patch (drm-backport-placeholder)
- commit 0fd43d0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0440-drm-i915-Remove-dead-scaler-register-defines.patch (drm-backport-placeholder)
- commit 3f2b7f9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0439-drm-i915-Define-bitmasks-for-ilk-pfit-window-pos-siz.patch (drm-backport-placeholder)
- commit 24fe9df
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0438-drm-i915-display-dp-128-132b-LT-requirement.patch (drm-backport-placeholder)
- commit 8b09d5f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0437-drm-i915-mtl-Enable-TC-ports.patch (drm-backport-placeholder)
- commit ceb4661
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0436-drm-i915-mtl-Pin-assignment-for-TypeC.patch (drm-backport-placeholder)
- commit d5308ea
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0435-drm-i915-mtl-TypeC-HPD-live-status-query.patch (drm-backport-placeholder)
- commit 1f1a058
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0434-drm-i915-mtl-Power-up-TCSS.patch (drm-backport-placeholder)
- commit c4e98a9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0433-drm-i915-mtl-Define-mask-for-DDI-AUX-interrupts.patch (drm-backport-placeholder)
- commit 4000340
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0432-drm-i915-mtl-Readout-Thunderbolt-HW-state.patch (drm-backport-placeholder)
- commit d86dbf5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0431-drm-i915-mtl-Enabling-disabling-sequence-Thunderbolt.patch (drm-backport-placeholder)
- commit 0f7ce27
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0430-drm-i915-mtl-For-DP2.0-10G-and-20G-rates-use-MPLLA.patch (drm-backport-placeholder)
- commit acd87d5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0429-drm-i915-mtl-Add-voltage-swing-sequence-for-C20.patch (drm-backport-placeholder)
- commit efcca6a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0428-drm-i915-mtl-C20-port-clock-calculation.patch (drm-backport-placeholder)
- commit fcc9e2a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0427-drm-i915-mtl-Dump-C20-pll-hw-state.patch (drm-backport-placeholder)
- commit 5571b32
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0426-drm-i915-mtl-C20-HW-readout.patch (drm-backport-placeholder)
- commit 54605f5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0425-drm-i915-mtl-C20-PLL-programming.patch (drm-backport-placeholder)
- commit 59d222c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0424-drm-i915-display-Increase-AUX-timeout-for-Type-C.patch (drm-backport-placeholder)
- commit fdf73e6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0423-drm-i915-adlp-Disable-DC5-6-states-for-TC-port-DDI-A.patch (drm-backport-placeholder)
- commit 543653e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0422-drm-i915-mtl-Skip-pcode-qgv-restrictions-for-MTL.patch (drm-backport-placeholder)
- commit 2d6433a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0421-drm-i915-Initialize-dkl_phy-spin-lock-from-display-c.patch (drm-backport-placeholder)
- commit ac0463f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0420-drm-i915-psr-Sprinkle-cpu_transcoder-variables-aroun.patch (drm-backport-placeholder)
- commit ae9c741
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0419-drm-i915-psr-Include-PSR_PERF_CNT-in-debugfs-output-.patch (drm-backport-placeholder)
- commit 2b7ed1b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0418-drm-i915-psr-Add-a-FIXME-for-the-PSR-vs.-AUX-usage-c.patch (drm-backport-placeholder)
- commit 2c0d70d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0417-drm-i915-psr-Define-more-PSR-mask-bits.patch (drm-backport-placeholder)
- commit 545db46
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0416-drm-i915-psr-Use-intel_de_rmw.patch (drm-backport-placeholder)
- commit 41459b7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0415-drm-i915-psr-Clean-up-PSR-register-defininitions.patch (drm-backport-placeholder)
- commit 8d1ff7a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0414-drm-i915-Clean-up-various-display-chicken-registers.patch (drm-backport-placeholder)
- commit 30ddf2f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0413-drm-i915-Fix-up-whitespace-in-some-display-chicken-r.patch (drm-backport-placeholder)
- commit 543e9c4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0412-drm-i915-Drop-a-useless-forward-declararion.patch (drm-backport-placeholder)
- commit b090003
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0411-drm-i915-Use-REG_BIT-co.-for-ilk-pfit-registers.patch (drm-backport-placeholder)
- commit 7ee1797
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0410-drm-i915-Namespace-pfit-registers-properly.patch (drm-backport-placeholder)
- commit 3fa5021
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0409-drm-i915-Use-REG_BIT-co-for-the-pre-ilk-pfit-registe.patch (drm-backport-placeholder)
- commit 9fd2f9e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0408-drm-i915-Relocate-skl_get_pfit_config.patch (drm-backport-placeholder)
- commit 8f8ac92
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0407-drm-i915-Relocate-intel_atomic_setup_scalers.patch (drm-backport-placeholder)
- commit e1c7b8d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0406-drm-i915-Relocate-VBLANK_EVASION_TIME_US.patch (drm-backport-placeholder)
- commit 542325a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0405-drm-i915-display-throw-out-struct-intel_load_detect_.patch (drm-backport-placeholder)
- commit 2e78fda
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0404-drm-i915-display-split-out-load-detect-to-a-separate.patch (drm-backport-placeholder)
- commit c2a578e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0403-drm-i915-wm-remove-stale-and-unused-ilk_wm_max_level.patch (drm-backport-placeholder)
- commit b12088a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0402-drm-i915-mtl-Re-use-ADL-P-s-DC-off-power-well.patch (drm-backport-placeholder)
- commit 97a1427
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0401-drm-i915-Use-separate-DC-off-power-well-for-ADL-P-an.patch (drm-backport-placeholder)
- commit 954900d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0400-drm-i915-use-explicit-includes-for-i915_reg.h-and-i9.patch (drm-backport-placeholder)
- commit 6dc8c82
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0399-drm-i915-Reuse-platform-_hotplug_mask-in-.hpd_detect.patch (drm-backport-placeholder)
- commit 7f89496
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0398-drm-i915-Check-HPD-live-state-during-eDP-probe.patch (drm-backport-placeholder)
- commit 4f51a5c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0397-drm-i915-Introduce-intel_hpd_enable_detection.patch (drm-backport-placeholder)
- commit d6411b5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0396-drm-i915-Introduce-platform-_hotplug_mask.patch (drm-backport-placeholder)
- commit 792581c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0395-drm-i915-pps-use-intel_de_rmw-for-panel-unlock.patch (drm-backport-placeholder)
- commit 33bf5bc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0394-drm-i915-display-add-intel_display_driver_early_prob.patch (drm-backport-placeholder)
- commit 7a83435
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0393-drm-i915-display-rename-intel_display_driver_suspend.patch (drm-backport-placeholder)
- commit 9286d19
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0392-drm-i915-display-move-display-suspend-resume-to-inte.patch (drm-backport-placeholder)
- commit 362aa2b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0391-drm-i915-display-add-intel_display_reset.-ch.patch (drm-backport-placeholder)
- commit e2d1e0f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0390-drm-i915-display-rename-intel_display_driver_-functi.patch (drm-backport-placeholder)
- commit fba5209
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0389-drm-i915-display-move-modeset-probe-remove-functions.patch (drm-backport-placeholder)
- commit 03f28b0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0388-drm-i915-display-rename-intel_modeset_probe_defer-in.patch (drm-backport-placeholder)
- commit 683a200
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0387-drm-i915-display-move-intel_modeset_probe_defer-to-i.patch (drm-backport-placeholder)
- commit a3f8551
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0386-drm-i915-display-start-high-level-display-driver-fil.patch (drm-backport-placeholder)
- commit ab5a58d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0385-drm-i915-display-remove-intel_display_commit_duplica.patch (drm-backport-placeholder)
- commit d61417a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0384-drm-i915-Make-intel_-mpllb-c10pll-_state_verify-safe.patch (drm-backport-placeholder)
- commit 525813a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0383-drm-i915-mtl-Initial-DDI-port-setup.patch (drm-backport-placeholder)
- commit c2e9deb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0382-drm-i915-display-mtl-Fill-port-width-in-DDI_BUF_-TRA.patch (drm-backport-placeholder)
- commit 82bb461
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0381-drm-i915-mtl-Add-C10-phy-programming-for-HDMI.patch (drm-backport-placeholder)
- commit 66dc482
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0380-drm-i915-mtl-display-Implement-DisplayPort-sequences.patch (drm-backport-placeholder)
- commit 28a56c5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0379-drm-i915-mtl-MTL-PICA-hotplug-detection.patch (drm-backport-placeholder)
- commit 26d6e2e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0378-drm-i915-mtl-Add-vswing-programming-for-C10-phys.patch (drm-backport-placeholder)
- commit ce21ce2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0377-drm-i915-mtl-Add-Support-for-C10-PHY-message-bus-and.patch (drm-backport-placeholder)
- commit 4e00cc5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0376-drm-i915-mtl-Create-separate-reg-file-for-PICA-regis.patch (drm-backport-placeholder)
- commit e9d594c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0375-drm-i915-mtl-Add-DP-rates.patch (drm-backport-placeholder)
- commit 86b9fb2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-hide-mkwrite_device_info-better.patch (drm-backport-placeholder)
- commit 9ba051d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0373-drm-i915-debugfs-New-debugfs-for-display-clock-frequ.patch (drm-backport-placeholder)
- commit df62e85
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0372-drm-i915-Use-min-instead-of-hand-rolling-it.patch (drm-backport-placeholder)
- commit 4683c62
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0371-drm-i915-Evade-transcoder-s-vblank-when-doing-seamle.patch (drm-backport-placeholder)
- commit 707dd60
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0370-drm-i915-Allow-arbitrary-refresh-rates-with-VRR-eDP-.patch (drm-backport-placeholder)
- commit 4b6446a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0369-drm-i915-Flag-purely-internal-commits-to-not-clear-c.patch (drm-backport-placeholder)
- commit 597ea77
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0368-drm-i915-vrr-Allow-VRR-to-be-toggled-during-fastsets.patch (drm-backport-placeholder)
- commit 0662cb3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0367-drm-i915-vrr-Relocate-VRR-enable-disable.patch (drm-backport-placeholder)
- commit 0e2109d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0366-drm-i915-vrr-Tell-intel_crtc_update_active_timings-a.patch (drm-backport-placeholder)
- commit 1a4dab3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0365-drm-i915-vrr-Make-delayed-vblank-operational-in-VRR-.patch (drm-backport-placeholder)
- commit b0e43cb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0364-drm-i915-vrr-Eliminate-redundant-function-arguments.patch (drm-backport-placeholder)
- commit 56b4237
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0363-drm-i915-Generalize-planes_-enabling-disabling.patch (drm-backport-placeholder)
- commit 9ec16f4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0362-drm-i915-display-remove-unnecessary-i915_debugfs.h-i.patch (drm-backport-placeholder)
- commit f7d29a5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0361-drm-i915-Hook-up-csc-into-state-checker.patch (drm-backport-placeholder)
- commit 9a65dc9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0360-drm-i915-Include-the-csc-matrices-in-the-crtc-state-.patch (drm-backport-placeholder)
- commit 4bbce93
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0359-drm-i915-Implement-chv-cgm-csc-readout.patch (drm-backport-placeholder)
- commit dfac395
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0358-drm-i915-Add-hardware-csc-readout-for-ilk.patch (drm-backport-placeholder)
- commit 43302b3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0357-drm-i915-Sprinke-a-few-sanity-check-WARNS-during-csc.patch (drm-backport-placeholder)
- commit a584b5d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0356-drm-i915-Utilize-crtc_state-csc-on-chv.patch (drm-backport-placeholder)
- commit 6e226cb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0355-drm-i915-Store-ilk-csc-matrices-in-the-crtc-state.patch (drm-backport-placeholder)
- commit 3867796
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0354-drm-i915-Start-using-struct-intel_csc_matrix-for-chv.patch (drm-backport-placeholder)
- commit 9a43dcc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0353-drm-i915-Split-chv_load_cgm_csc-into-pieces.patch (drm-backport-placeholder)
- commit c797016
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0352-drm-i915-Introduce-intel_csc_matrix-struct.patch (drm-backport-placeholder)
- commit aaa81f1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-Fix-limited-range-csc-matrix.patch (drm-backport-placeholder)
- commit 4b20613
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0350-drm-panel-simple-add-support-for-Rocktech-RK043FN48H.patch (drm-backport-placeholder)
- commit 48987cd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0349-drm-bridge-imx-turn-imx8-qm-qxp-ldb-into-single-obje.patch (drm-backport-placeholder)
- commit bd824b0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0348-drm-bridge-imx-fix-mixed-module-builtin-object.patch (drm-backport-placeholder)
- commit b7dfe9e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0347-drm-virtio-Wait-for-each-dma-fence-of-in-fence-array.patch (drm-backport-placeholder)
- commit eb05b01
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0346-drm-virtio-Refactor-and-optimize-job-submission-code.patch (drm-backport-placeholder)
- commit f65e2fb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0345-drm-meson-venc-include-linux-bitfield.h.patch (drm-backport-placeholder)
- commit 1eacba9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0344-drm-meson-Remove-unneeded-semicolon.patch (drm-backport-placeholder)
- commit 2e7fd5d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0343-drm-panel-Support-for-Starry-ili9882t-TDDI-MIPI-DSI-.patch (drm-backport-placeholder)
- commit af827a1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0342-drm-panel-Support-for-Starry-himax83102-j02-TDDI-MIP.patch (drm-backport-placeholder)
- commit e5ee736
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0341-drm-panel-khadas-ts050-update-timings-to-achieve-60H.patch (drm-backport-placeholder)
- commit 11acf3a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0340-drm-meson-add-support-for-MIPI-DSI-transceiver.patch (drm-backport-placeholder)
- commit 1286a3d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0339-drm-meson-add-DSI-encoder.patch (drm-backport-placeholder)
- commit b7bf7c4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0338-drm-meson-venc-add-ENCL-encoder-setup-for-MIPI-DSI-o.patch (drm-backport-placeholder)
- commit f00380c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0337-drm-meson-only-use-components-with-dw-hdmi.patch (drm-backport-placeholder)
- commit 29e715f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0336-drm-meson-fix-unbind-path-if-HDMI-fails-to-bind.patch (drm-backport-placeholder)
- commit 3ee3967
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0335-drm-bridge-tc358762-Add-reset-GPIO-support.patch (drm-backport-placeholder)
- commit 294d28b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0334-accel-habanalabs-add-description-to-several-info-ioc.patch (drm-backport-placeholder)
- commit af67b06
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0333-drm-Place-Renesas-drivers-in-a-separate-dir.patch (drm-backport-placeholder)
- commit 3049d5d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-rcar-du-remove-R-Car-H3-ES1.-workarounds.patch (drm-backport-placeholder)
- commit 2242fad
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0331-drm-i915-Implement-dedicated-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 539b360
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0330-drm-fbdev-generic-Implement-dedicated-fbdev-I-O-help.patch (drm-backport-placeholder)
- commit 8dde108
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0329-drm-msm-Use-regular-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 313e059
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0328-drm-fb-helper-Export-helpers-for-marking-damage-area.patch (drm-backport-placeholder)
- commit 9a00bd1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0327-drm-tegra-Use-regular-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit ed3901c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0326-drm-omapdrm-Use-regular-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 7e21c3f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0325-drm-fbdev-dma-Use-regular-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 1701450
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0324-drm-radeon-Use-regular-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 2056867
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0323-drm-gma500-Use-regular-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit d6c49da
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0322-drm-exynos-Use-regular-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 73d9657
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0321-drm-armada-Use-regular-fbdev-I-O-helpers.patch (drm-backport-placeholder)
- commit 4ce7aec
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0320-fbdev-Add-initializer-macros-for-struct-fb_ops.patch (drm-backport-placeholder)
- commit ff37955
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0319-fbdev-Add-Kconfig-options-to-select-different-fb_ops.patch (drm-backport-placeholder)
- commit 3e07f39
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0318-drm-i915-mtl-end-support-for-set-caching-ioctl.patch (drm-backport-placeholder)
- commit 1c01dd7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0317-drm-i915-pmu-Export-counters-from-all-tiles.patch (drm-backport-placeholder)
- commit b7f9e2c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0316-drm-i915-pmu-Prepare-for-multi-tile-non-engine-count.patch (drm-backport-placeholder)
- commit d22d638
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0315-drm-i915-pmu-Add-reference-counting-to-the-sampling-.patch (drm-backport-placeholder)
- commit 6035c61
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0314-drm-i915-pmu-Transform-PMU-parking-code-to-be-GT-bas.patch (drm-backport-placeholder)
- commit 5e7b8de
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0313-drm-i915-pmu-Skip-sampling-engines-with-no-enabled-c.patch (drm-backport-placeholder)
- commit fe2930d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0312-drm-i915-pmu-Support-PMU-for-all-engines.patch (drm-backport-placeholder)
- commit edd5b62
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0311-drm-i915-pmu-Change-bitmask-of-enabled-events-to-u32.patch (drm-backport-placeholder)
- commit 6892b94
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0310-drm-i915-Fix-memory-leaks-in-function-live_nop_switc.patch (drm-backport-placeholder)
- commit acaaa0d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0309-drm-i915-mtl-Extend-Wa_16014892111-to-MTL-A-step.patch (drm-backport-placeholder)
- commit 587ea1a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0308-drm-i915-mtl-Add-MTL-performance-tuning-changes.patch (drm-backport-placeholder)
- commit 5c42cf0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0307-drm-i915-mtl-do-not-enable-render-power-gating-on-MT.patch (drm-backport-placeholder)
- commit 4ba2a7c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0306-drm-i915-guc-slpc-Disable-rps_boost-debugfs.patch (drm-backport-placeholder)
- commit a44e71f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0305-drm-i915-guc-Dump-error-capture-to-dmesg-on-CTB-erro.patch (drm-backport-placeholder)
- commit 18e8685
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0304-drm-i915-Dump-error-capture-to-kernel-log.patch (drm-backport-placeholder)
- commit 2a43a71
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0303-drm-i915-hwmon-Silence-UBSAN-uninitialized-bool-vari.patch (drm-backport-placeholder)
- commit 3b2d2d6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0302-drm-i915-guc-Fix-confused-register-capture-list-crea.patch (drm-backport-placeholder)
- commit 3412bf2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0301-drm-i1915-guc-Fix-probe-injection-CI-failures-after-.patch (drm-backport-placeholder)
- commit 248ad31
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0300-drm-i915-pxp-Enable-PXP-with-MTL-GSC-CS.patch (drm-backport-placeholder)
- commit 71b3fdd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0299-drm-i915-pxp-On-MTL-KCR-enabling-doesn-t-wait-on-tee.patch (drm-backport-placeholder)
- commit d77a16d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0298-drm-i915-uapi-pxp-Add-a-GET_PARAM-for-PXP.patch (drm-backport-placeholder)
- commit 8b2ca1a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0297-drm-i915-pxp-Add-ARB-session-creation-and-cleanup.patch (drm-backport-placeholder)
- commit f51b83d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0296-drm-i915-pxp-Add-GSC-CS-backend-to-send-GSC-fw-messa.patch (drm-backport-placeholder)
- commit c057a5e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0295-drm-i915-pxp-Add-MTL-helpers-to-submit-Heci-Cmd-Pack.patch (drm-backport-placeholder)
- commit 4da4214
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0294-drm-i915-pxp-Add-MTL-hw-plumbing-enabling-for-KCR-op.patch (drm-backport-placeholder)
- commit 1cc6ca7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0293-drm-i915-pxp-Add-GSC-CS-back-end-resource-init-and-c.patch (drm-backport-placeholder)
- commit d5c361d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0292-drm-i915-use-pat_index-instead-of-cache_level.patch (drm-backport-placeholder)
- commit 8af4209
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0291-drm-i915-preparation-for-using-PAT-index.patch (drm-backport-placeholder)
- commit 2451dba
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0290-drm-i915-mtl-Fix-the-wa-number-for-Wa_22016670082.patch (drm-backport-placeholder)
- commit 5ea2134
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0289-drm-i915-mtl-Add-MTL-for-remapping-CCS-FBs.patch (drm-backport-placeholder)
- commit ecd7a45
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0288-drm-i915-mtl-Drop-FLAT-CCS-check.patch (drm-backport-placeholder)
- commit 58f3016
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0287-drm-i915-uc-Make-unexpected-firmware-versions-an-err.patch (drm-backport-placeholder)
- commit 3b9cc06
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0286-drm-i915-uc-Reject-duplicate-entries-in-firmware-tab.patch (drm-backport-placeholder)
- commit d6e062b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0285-drm-i915-uc-Enhancements-to-firmware-table-validatio.patch (drm-backport-placeholder)
- commit 9335913
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0284-drm-i915-guc-Print-status-register-when-waiting-for-.patch (drm-backport-placeholder)
- commit bc8eb03
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0283-drm-i915-guc-Decode-another-GuC-load-failure-case.patch (drm-backport-placeholder)
- commit 067abb1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0282-drm-i915-mtl-Define-GuC-firmware-version-for-MTL.patch (drm-backport-placeholder)
- commit 1358a57
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0281-drm-i915-uc-Track-patch-level-versions-on-reduced-ve.patch (drm-backport-placeholder)
- commit e117a23
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0280-drm-i915-use-kernel-doc-Werror-when-CONFIG_DRM_I915_.patch (drm-backport-placeholder)
- commit eeb2a63
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0279-drm-i915-ttm-fix-i915_ttm_to_gem-kernel-doc.patch (drm-backport-placeholder)
- commit b609496
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0278-drm-i915-scatterlist-fix-kernel-doc.patch (drm-backport-placeholder)
- commit 5ee48c5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0277-drm-i915-gem-fix-function-pointer-member-kernel-doc.patch (drm-backport-placeholder)
- commit 71a2695
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0276-drm-i915-vma-fix-struct-i915_vma_bindinfo-kernel-doc.patch (drm-backport-placeholder)
- commit 57ed420
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0275-drm-i915-gsc-add-support-for-GSC-proxy-interrupt.patch (drm-backport-placeholder)
- commit 2c98a55
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0274-drm-i915-gsc-add-initial-support-for-GSC-proxy.patch (drm-backport-placeholder)
- commit 34338b9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0273-mei-gsc_proxy-add-gsc-proxy-driver.patch (drm-backport-placeholder)
- commit f92182f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0272-drm-i915-mtl-Define-GSC-Proxy-component-interface.patch (drm-backport-placeholder)
- commit a9583a1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0271-drm-i915-scatterlist-fix-kernel-doc-parameter-docume.patch (drm-backport-placeholder)
- commit a29553c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0270-drm-i915-pxp-fix-kernel-doc-for-member-dev_link.patch (drm-backport-placeholder)
- commit 0d18177
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0269-drm-i915-pmu-drop-kernel-doc.patch (drm-backport-placeholder)
- commit 96044b5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0268-drm-i915-active-fix-kernel-doc-for-function-paramete.patch (drm-backport-placeholder)
- commit f1e2947
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0267-drm-i915-guc-add-intel_guc_state_capture-member-docs.patch (drm-backport-placeholder)
- commit 1639221
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0266-drm-i915-guc-drop-lots-of-kernel-doc-markers.patch (drm-backport-placeholder)
- commit 91ebbd9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0265-drm-i915-guc-add-dbgfs_node-member-kernel-doc.patch (drm-backport-placeholder)
- commit 368de47
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0264-drm-i915-engine-hide-preempt_hang-selftest-member-fr.patch (drm-backport-placeholder)
- commit 5090b5a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0263-drm-i915-gtt-fix-i915_vm_resv_put-kernel-doc-paramet.patch (drm-backport-placeholder)
- commit 6f7a359
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0262-drm-i915-context-fix-kernel-doc-parameter-descriptio.patch (drm-backport-placeholder)
- commit 98640c6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0261-drm-i915-engine-fix-kernel-doc-function-name-for-int.patch (drm-backport-placeholder)
- commit 8aad4b8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0260-drm-i915-gem-fix-i915_gem_object_lookup_rcu-kernel-d.patch (drm-backport-placeholder)
- commit aa96852
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0259-drm-i915-request-drop-kernel-doc.patch (drm-backport-placeholder)
- commit aeffcd5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0258-drm-i915-error-fix-i915_capture_error_state-kernel-d.patch (drm-backport-placeholder)
- commit 4303b65
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0257-drm-i915-perf-fix-i915_perf_ioctl_version-kernel-doc.patch (drm-backport-placeholder)
- commit c2ca975
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0256-drm-i915-vma-document-struct-i915_vma_resource-waker.patch (drm-backport-placeholder)
- commit c86d5ab
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0255-drm-i915-utils-drop-kernel-doc-from-__wait_for.patch (drm-backport-placeholder)
- commit 045d1ec
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0254-drm-i915-vma-fix-kernel-doc-function-name-for-i915_v.patch (drm-backport-placeholder)
- commit 478ec1a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0253-drm-i915-gvt-fix-intel_vgpu_alloc_resource-kernel-do.patch (drm-backport-placeholder)
- commit 5061709
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0252-drm-i915-guc-Fix-error-capture-for-virtual-engines.patch (drm-backport-placeholder)
- commit b9430fd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0251-drm-i915-guc-Capture-list-naming-clean-up.patch (drm-backport-placeholder)
- commit f6fe97d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0250-drm-i915-guc-Consolidate-duplicated-capture-list-cod.patch (drm-backport-placeholder)
- commit d0eed3d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0249-drm-i915-selftests-Use-gt_err-for-GT-info.patch (drm-backport-placeholder)
- commit bbd86b3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0248-drm-i915-gt-Use-gt_err-for-GT-info.patch (drm-backport-placeholder)
- commit 5822b14
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0247-drm-i915-fdinfo-Enable-fdinfo-for-GuC-backends.patch (drm-backport-placeholder)
- commit bf71ea6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0246-i915-pmu-Add-support-for-total-context-runtime-for-G.patch (drm-backport-placeholder)
- commit 0c9eed3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0245-drm-i915-rc6-throw-out-set-wrapper.patch (drm-backport-placeholder)
- commit 86d5331
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0244-drm-i915-selftest-Update-the-SLPC-selftest.patch (drm-backport-placeholder)
- commit bc50b0c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-i915-guc-slpc-Provide-sysfs-for-efficient-f.patch (drm-backport-placeholder)
- commit db2634f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0242-drm-i915-Use-correct-huge-page-manager-for-MTL.patch (drm-backport-placeholder)
- commit 4ff9b15
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0241-drm-i915-Migrate-platform-dependent-mock-hugepage-se.patch (drm-backport-placeholder)
- commit 02fddd5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0240-drm-i915-mtl-Implement-Wa_14019141245.patch (drm-backport-placeholder)
- commit cebb650
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0239-drm-i915-hwmon-Block-waiting-for-GuC-reset-to-comple.patch (drm-backport-placeholder)
- commit 8232e10
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0238-drm-i915-guc-Disable-PL1-power-limit-when-loading-Gu.patch (drm-backport-placeholder)
- commit 730ad22
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0237-drm-i915-hwmon-Get-mutex-and-rpm-ref-just-once-in-hw.patch (drm-backport-placeholder)
- commit 27af82b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0236-drm-i915-mtl-Add-workaround-14018778641.patch (drm-backport-placeholder)
- commit 4d81199
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0235-drm-i915-selftest-Record-GT-error-for-gt-failure.patch (drm-backport-placeholder)
- commit ceeda84
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0234-drm-i915-mtl-workaround-coherency-issue-for-Media.patch (drm-backport-placeholder)
- commit d63c2a3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0233-drm-i915-mtl-Add-PTE-encode-function.patch (drm-backport-placeholder)
- commit a33f560
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0232-drm-i915-i915_drv-Use-i915-instead-of-dev_priv-insie.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- Refresh patches.suse/0508-drm-i915-Convert-INTEL_INFO-display-to-a-pointer.patch.
- Refresh patches.suse/0512-drm-i915-display-Move-feature-test-macros-to-intel_d.patch.
- commit 66a3300
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0231-drm-i915-i915_drv-Use-proper-parameter-naming-in-for.patch (drm-backport-placeholder)
- commit 8478a67
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0230-drm-i915-mtl-fix-mocs-selftest.patch (drm-backport-placeholder)
- commit 66b66d3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0229-drm-i915-mtl-Define-MOCS-and-PAT-tables-for-MTL.patch (drm-backport-placeholder)
- commit e6ca94f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0228-drm-i915-mtl-Set-has_llc-0.patch (drm-backport-placeholder)
- commit baace4a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0227-drm-i915-mtl-WA-to-clear-RDOP-clock-gating.patch (drm-backport-placeholder)
- commit cc24f84
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0226-drm-i915-mtl-Extend-Wa_22011802037-to-MTL-A-step.patch (drm-backport-placeholder)
- commit b387722
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0225-drm-i915-selftests-Consider-multi-gt-instead-of-to_g.patch (drm-backport-placeholder)
- commit cab2435
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0224-drm-i915-gem-Consider-multi-gt-instead-of-to_gt.patch (drm-backport-placeholder)
- commit d22d40d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0223-drm-i915-gt-Consider-multi-gt-instead-of-to_gt.patch (drm-backport-placeholder)
- commit 2b019d3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0222-drm-i915-Make-IRQ-reset-and-postinstall-multi-gt-awa.patch (drm-backport-placeholder)
- commit f862545
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0221-drm-i915-mtl-Disable-stolen-memory-backed-FB-for-A0.patch (drm-backport-placeholder)
- commit 1a9293d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0220-drm-i915-display-Implement-fb_mmap-callback-function.patch (drm-backport-placeholder)
- commit b661903
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0219-drm-i915-display-Add-helper-func-to-get-intel_fbdev-.patch (drm-backport-placeholder)
- commit 6237c25
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0218-drm-i915-Add-a-function-to-mmap-framebuffer-obj.patch (drm-backport-placeholder)
- commit 5390791
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0217-drm-i915-display-Set-I915_BO_ALLOC_USER-for-fb.patch (drm-backport-placeholder)
- commit ff47690
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0216-drm-i915-ttm-Add-I915_BO_PREALLOC.patch (drm-backport-placeholder)
- commit aab57a6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0215-drm-ttm-Remove-redundant-code-in-ttm_tt_init_fields.patch (drm-backport-placeholder)
- commit e6472a8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0214-drm-bridge-display-connector-handle-hdmi-pwr-supply.patch (drm-backport-placeholder)
- commit 8b17b37
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0213-drm-bridge-display-connector-rename-dp_pwr-to-connec.patch (drm-backport-placeholder)
- commit f46a02d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0212-drm-panel-edp-Convert-to-platform-remove-callback-re.patch (drm-backport-placeholder)
- commit 07de373
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0211-drm-Switch-i2c-drivers-back-to-use-.probe.patch (drm-backport-placeholder)
- commit 058e5d7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0210-drm-lcdif-Add-i.MX93-LCDIF-compatible-string.patch (drm-backport-placeholder)
- commit bd84418
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0209-drm-lcdif-Add-multiple-encoders-and-first-bridges-su.patch (drm-backport-placeholder)
- commit 64d7d76
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0208-drm-lcdif-Check-consistent-bus-format-and-flags-acro.patch (drm-backport-placeholder)
- commit 0a087e7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0207-drm-lcdif-Determine-bus-format-and-flags-in-atomic_c.patch (drm-backport-placeholder)
- commit 8048e4e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0206-drm-lcdif-Drop-unnecessary-NULL-pointer-check-on-lcd.patch (drm-backport-placeholder)
- commit dcf6c5c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-stm-ltdc-fix-late-dereference-check.patch (drm-backport-placeholder)
- commit 4e84e98
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0204-drm-stm-dsi-Use-devm_platform_ioremap_resource.patch (drm-backport-placeholder)
- commit 6bd227b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-simple-fix-active-size-for-Ampire-AM-.patch (drm-backport-placeholder)
- commit 9480cae
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0202-drm-panel-simple-Add-Ampire-AM-800480L1TMQW-T00H.patch (drm-backport-placeholder)
- commit 34e1f2f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0201-drm-bridge-samsung-dsim-Support-non-burst-mode.patch (drm-backport-placeholder)
- commit 47d2440
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0200-drm-bridge-samsung-dsim-Dynamically-configure-DPHY-t.patch (drm-backport-placeholder)
- commit ad5bfb2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0199-drm-bridge-samsung-dsim-Select-GENERIC_PHY_MIPI_DPHY.patch (drm-backport-placeholder)
- commit 80e469f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0198-drm-bridge-samsung-dsim-Fetch-pll-clock-frequency-au.patch (drm-backport-placeholder)
- commit 86e1287
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-samsung-dsim-Fix-PMS-Calculator-on-i.patch (drm-backport-placeholder)
- commit a71993d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0196-drm-bridge-samsung-dsim-fix-blanking-packet-size-cal.patch (drm-backport-placeholder)
- commit be1b2bc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0195-drm-amdgpu-Fix-no-procfs-build.patch (drm-backport-placeholder)
- commit 481845a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-ti-sn65dsi83-Fix-enable-disable-flow.patch (drm-backport-placeholder)
- commit d4fe0d1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0193-drm-bridge-samsung-dsim-Fix-i.MX8M-enable-flow-to-me.patch (drm-backport-placeholder)
- commit c069be4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0192-drm-bridge-tc358767-explicitly-set-readable-register.patch (drm-backport-placeholder)
- commit 2490089
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0191-drm-doc-Relax-fdinfo-string-constraints.patch (drm-backport-placeholder)
- commit ca00d3a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0190-drm-msm-Add-memory-stats-to-fdinfo.patch (drm-backport-placeholder)
- commit ca24510
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0189-drm-Add-fdinfo-memory-stats.patch (drm-backport-placeholder)
- commit 5e903d0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0188-drm-amdgpu-Switch-to-fdinfo-helper.patch (drm-backport-placeholder)
- commit 66cb9a5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0187-drm-msm-Switch-to-fdinfo-helper.patch (drm-backport-placeholder)
- commit d2139db
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0186-drm-Add-common-fdinfo-helper.patch (drm-backport-placeholder)
- commit 95d509f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0185-drm-docs-Fix-usage-stats-typos.patch (drm-backport-placeholder)
- commit 031ad80
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0184-drm-shmobile-Make-DRM_SHMOBILE-visible-on-Renesas-So.patch (drm-backport-placeholder)
- commit 7b49730
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0183-drm-shmobile-Add-missing-call-to-drm_fbdev_generic_s.patch (drm-backport-placeholder)
- commit 95e3663
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0182-drm-shmobile-Switch-to-drm_crtc_init_with_planes.patch (drm-backport-placeholder)
- commit 022e3e0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0181-drm-shmobile-Add-support-for-DRM_FORMAT_XRGB8888.patch (drm-backport-placeholder)
- commit 2ec9dc8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0180-drm-shmobile-Use-p4cc-to-print-fourcc-codes.patch (drm-backport-placeholder)
- commit 9702fe6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0179-dma-buf-sw_sync-Replace-all-non-returning-strlcpy-wi.patch (drm-backport-placeholder)
- commit 5421751
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0178-drm-panel-samsung-s6d7aa0-use-pointer-for-drm_mode-i.patch (drm-backport-placeholder)
- commit d17d5e2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0177-drm-bridge-dw-hdmi-Replace-all-non-returning-strlcpy.patch (drm-backport-placeholder)
- commit 1f7d1aa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-anx7625-Prevent-endless-probe-loop.patch (drm-backport-placeholder)
- commit ebd4ba4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0175-drm-msm-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit 22927b6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0174-drm-nouveau-acr-ga102-set-variable-ga102_gsps-storag.patch (drm-backport-placeholder)
- commit b4e5c73
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0173-drm-nouveau-constify-pointers-to-hwmon_channel_info.patch (drm-backport-placeholder)
- commit 58b4911
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-nouveau-dispnv50-fix-missing-prototypes-war.patch (drm-backport-placeholder)
- commit b7185f8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0171-drm-bridge-samsung-dsim-Implement-support-for-clock-.patch (drm-backport-placeholder)
- commit b3a3126
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0170-drm-panel-Add-Samsung-S6D7AA0-panel-controller-drive.patch (drm-backport-placeholder)
- commit 2946fa4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0169-drm-sched-Rename-to-drm_sched_wakeup_if_can_queue.patch (drm-backport-placeholder)
- commit cea77bb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0168-drm-sched-Rename-to-drm_sched_can_queue.patch (drm-backport-placeholder)
- commit eed5a68
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0016-fbdev-Rename-fb_mem-helpers.patch (drm-backport-placeholder)
- commit 4952f6d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0015-fbdev-Move-framebuffer-I-O-helpers-into-asm-fb.h.patch (drm-backport-placeholder)
- commit 036d63b
* Wed Sep  4 2024 oneukum@suse.com
- media: dvbdev: fix most coding style issues (jsc#PED-8643).
- Refresh patches.suse/media-dvbdev-Initialize-sbuf.patch.
- Refresh
  patches.suse/media-edia-dvbdev-fix-a-use-after-free.patch.
- commit a085dbc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0014-fbdev-Include-linux-fb.h-instead-of-asm-fb.h.patch (drm-backport-placeholder)
- commit d250f20
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0013-fbdev-Include-linux-io.h-in-various-drivers.patch (drm-backport-placeholder)
- commit ea2340a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0167-ipu-v3-Include-linux-io.h.patch (drm-backport-placeholder)
- commit 0aefbea
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0166-fbdev-matrox-Remove-trailing-whitespaces.patch (drm-backport-placeholder)
- commit 53d1c12
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0165-fbdev-hitfb-Cast-I-O-offset-to-address.patch (drm-backport-placeholder)
- commit a3ee3ac
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358767-Switch-to-devm-MIPI-DSI-hel.patch (drm-backport-placeholder)
- commit 32fea7b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0163-drm-ttm-let-struct-ttm_device_funcs-be-placed-in-rod.patch (drm-backport-placeholder)
- commit 147d98c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0162-drm-drm_atomic_helper.c-fix-a-typo.patch (drm-backport-placeholder)
- commit 1c221fc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0161-drm-panel-Modify-innolux-hj110iz-panel-initial-code.patch (drm-backport-placeholder)
- commit febaee6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0160-drm-bridge-tc358768-remove-unneeded-semicolon.patch (drm-backport-placeholder)
- commit dc7b4aa
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0159-gpu-drm-bridge-No-need-to-set-device_driver-owner.patch (drm-backport-placeholder)
- commit c2d92b9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-vkms-Fix-RGB565-pixel-conversion.patch (drm-backport-placeholder)
- commit d08562b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-Add-fixed-point-helper-to-get-rounded-integ.patch (drm-backport-placeholder)
- commit 4080aac
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0156-drm-panel-boe-tv101wum-nl6-Fine-tune-the-panel-power.patch (drm-backport-placeholder)
- commit cd00f9d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0155-drm-panel-boe-tv101wum-nl6-Remove-extra-delay.patch (drm-backport-placeholder)
- commit 8121c5e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0154-drm-ssd130x-Fix-include-guard-name.patch (drm-backport-placeholder)
- commit 74ac6e0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0153-drivers-firmware-Move-sysfb_init-from-device_initcal.patch (drm-backport-placeholder)
- commit 01026e2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0152-drm-panel-panel-simple-Add-BOE-EV121WXM-N10-1850-pan.patch (drm-backport-placeholder)
- commit 32cb664
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0151-drm-panel-sharp-ls043t1le01-drop-dummy-functions-and.patch (drm-backport-placeholder)
- commit 2af7cb1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-sharp-ls043t1le01-adjust-mode-setting.patch (drm-backport-placeholder)
- commit 2b760d5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-sun4i_tcon-use-devm_clk_get_enabled-in-sun4.patch (drm-backport-placeholder)
- commit 83c3e23
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0148-drm-sun4i-calculate-proper-DCLK-rate-for-DSI.patch (drm-backport-placeholder)
- commit 5efa092
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0147-drm-sun4i-rename-sun4i_dotclock-to-sun4i_tcon_dclk.patch (drm-backport-placeholder)
- commit c52f8d8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0146-drm-connector-document-enum-drm_connector_tv_mode-DR.patch (drm-backport-placeholder)
- commit f6cd796
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0145-Documentation-vkms-clarify-devres-managed-reference-.patch (drm-backport-placeholder)
- commit 7bdc749
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0144-drm-fb-helper-Use-fb_-cfb-sys-_-read-write.patch (drm-backport-placeholder)
- commit 841dd22
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0143-fbdev-Move-I-O-read-and-write-code-into-helper-funct.patch (drm-backport-placeholder)
- commit 31210d7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0142-fbdev-Validate-info-screen_-base-buffer-in-fb_ops-im.patch (drm-backport-placeholder)
- commit f921535
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0141-fbdev-Don-t-re-validate-info-state-in-fb_ops-impleme.patch (drm-backport-placeholder)
- commit 7130d63
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0140-fbdev-Use-screen_buffer-in-fb_sys_-read-write.patch (drm-backport-placeholder)
- commit 8b19d72
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0139-fbdev-Return-number-of-bytes-read-or-written.patch (drm-backport-placeholder)
- commit a3ad4a0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0138-fbdev-xen-fbfront-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit 24562d8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0137-fbdev-vfb-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit 80da9e2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0136-fbdev-udlfb-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit 911e81d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0135-fbdev-smscufx-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit e94cfea
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0134-fbdev-ps3fb-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit f3d58f2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0133-fbdev-metronomefb-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit ee18344
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0132-fbdev-hecubafb-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit ac74506
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0131-fbdev-broadsheetfb-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit 10de5ad
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0130-fbdev-au1200fb-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit 2fb0651
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0129-fbdev-arcfb-Use-struct-fb_info.screen_buffer.patch (drm-backport-placeholder)
- commit df8dd49
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0128-drm-vkms-drop-Rotation-TODO.patch (drm-backport-placeholder)
- commit 885292b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0127-drm-vkms-add-rotate-270-property.patch (drm-backport-placeholder)
- commit 97a371a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0126-drm-vkms-add-rotate-90-property.patch (drm-backport-placeholder)
- commit be3d5fc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0125-drm-vkms-add-reflect-y-and-rotate-180-property.patch (drm-backport-placeholder)
- commit eb22094
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0124-drm-vkms-add-rotate-0-and-reflect-x-property.patch (drm-backport-placeholder)
- commit 9e082fe
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-vram-helper-fix-function-names-in-vram-help.patch (drm-backport-placeholder)
- commit b8905d5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0122-drm-bridge-lt9611-Do-not-generate-HFP-HBP-HSA-and-EO.patch (drm-backport-placeholder)
- commit afe74f7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0121-drm-bridge-lt9211-Do-not-generate-HFP-HBP-HSA-and-EO.patch (drm-backport-placeholder)
- commit 25dc7bd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0120-drm-bridge-tc358768-remove-unused-variable.patch (drm-backport-placeholder)
- commit 510cbc5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-fix-THS_TRAILCNT-computatio.patch (drm-backport-placeholder)
- commit c46978c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-fix-TXTAGOCNT-computation.patch (drm-backport-placeholder)
- commit 450d4b6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-fix-THS_ZEROCNT-computation.patch (drm-backport-placeholder)
- commit 81cfdf4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-fix-TCLK_TRAILCNT-computati.patch (drm-backport-placeholder)
- commit 64ac142
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-fix-TCLK_ZEROCNT-computatio.patch (drm-backport-placeholder)
- commit 9cee2f9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-fix-PLL-target-frequency.patch (drm-backport-placeholder)
- commit 9088045
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-fix-PLL-parameters-computat.patch (drm-backport-placeholder)
- commit d225e78
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-always-enable-HS-video-mode.patch (drm-backport-placeholder)
- commit ecf4b28
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-rockchip-vop-Leave-vblank-enabled-in-self-r.patch (drm-backport-placeholder)
- commit 83160ac
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-atomic-Allow-vblank-enabled-self-refresh-di.patch (drm-backport-placeholder)
- commit ce928ba
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-ti-sn65dsi83-Fix-enable-error-path.patch (drm-backport-placeholder)
- commit b7d2662
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0108-drm-udl-delete-dead-code.patch (drm-backport-placeholder)
- commit bf6483a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0107-drm-scheduler-mark-jobs-without-fence-as-canceled.patch (drm-backport-placeholder)
- commit 16c3d3c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0106-drm-rockchip-cdn-dp-call-drm_connector_update_edid_p.patch (drm-backport-placeholder)
- commit c888c03
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0105-drm-sti-sti_hdmi-convert-to-using-is_hdmi-from-displ.patch (drm-backport-placeholder)
- commit 2507be1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0104-drm-sysfs-Link-DRM-connectors-to-corresponding-Type-.patch (drm-backport-placeholder)
- commit ada320f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0103-drm-sysfs-Expose-DRM-connector-id-in-each-connector-.patch (drm-backport-placeholder)
- commit 295bc71
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-it6505-Move-a-variable-assignment-be.patch (drm-backport-placeholder)
- commit bdcb354
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0101-drm-uapi-Document-CTM-matrix-better.patch (drm-backport-placeholder)
- commit 8889d06
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0100-drm-meson-set-variables-meson_hdmi_-storage-class-sp.patch (drm-backport-placeholder)
- commit 39c6930
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0099-drm-panel-st7703-Add-Anbernic-RG353V-V2-Panel-Suppor.patch (drm-backport-placeholder)
- commit 0b781c5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0098-drm-panel-st7703-Rename-CMD_UNKNOWN_C6-to-CMD_SETECO.patch (drm-backport-placeholder)
- commit 56e034c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0097-drm-doc-rfc-Introduce-the-merge-plan-for-the-Xe-driv.patch (drm-backport-placeholder)
- commit 02c3ebe
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0096-drm-vkms-drop-full-alpha-blending-TODO.patch (drm-backport-placeholder)
- commit 50f59b1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0095-drm-vkms-allow-full-alpha-blending-on-all-planes.patch (drm-backport-placeholder)
- commit 4c37876
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0012-arch-x86-Include-asm-fb.h-in-fbdev-source-file.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 226a17d
* Wed Sep  4 2024 marco.crivellari@suse.com
- perf/x86/intel/uncore: Support HBM and CXL PMON counters
  (bsc#1230119).
- commit a4c2665
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-tc358768-Add-atomic_get_input_bus_fm.patch (drm-backport-placeholder)
- commit e012013
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0093-drm-vc4-hdmi-Add-BT.2020-Support.patch (drm-backport-placeholder)
- commit ade7f13
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0092-drm-vc4-hdmi-Add-BT.601-Support.patch (drm-backport-placeholder)
- commit 93e1ed1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0091-drm-vc4-hdmi-Add-a-function-to-retrieve-the-CSC-matr.patch (drm-backport-placeholder)
- commit 25e14dd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0090-drm-vc4-hdmi-Rework-the-CSC-matrices-organization.patch (drm-backport-placeholder)
- commit f47bcdd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0089-drm-vc4-hdmi-Swap-CSC-matrix-channels-for-YUV444.patch (drm-backport-placeholder)
- commit a3e4e5c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0088-drm-vc4-hdmi-Rename-full-range-helper.patch (drm-backport-placeholder)
- commit b29e589
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0087-drm-vc4-hdmi-Add-Broadcast-RGB-property-to-allow-ove.patch (drm-backport-placeholder)
- commit 5779383
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0086-drm-vc4-hdmi-Update-all-the-planes-if-the-TV-margins.patch (drm-backport-placeholder)
- commit 7e5e589
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0085-drm-vc4-Switch-to-container_of_const.patch (drm-backport-placeholder)
- commit 08f39ab
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-vkms-isolate-pixel-conversion-functionality.patch (drm-backport-placeholder)
- commit 7157159
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0083-drm-test-Add-test-cases-for-drm_rect_rotate_inv.patch (drm-backport-placeholder)
- commit 81df4cf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0082-drm-tests-Add-test-cases-for-drm_rect_rotate.patch (drm-backport-placeholder)
- commit d228d4e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0081-drm-tests-Add-test-cases-for-drm_rect_calc_vscale.patch (drm-backport-placeholder)
- commit 92cce65
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0080-drm-tests-Add-test-cases-for-drm_rect_calc_hscale.patch (drm-backport-placeholder)
- commit 12aa2de
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0079-drm-tests-Add-test-cases-for-drm_rect_intersect.patch (drm-backport-placeholder)
- commit 00f77b5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0078-drm-scheduler-add-drm_sched_entity_error-and-use-rcu.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 97bea26
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0077-drm-scheduler-properly-forward-fence-errors.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 0ad788e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0076-drm-tve200-Use-devm_platform_ioremap_resource.patch (drm-backport-placeholder)
- commit 350340e
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0075-drm-sti-Drop-of_gpio-header.patch (drm-backport-placeholder)
- commit 86e9bbf
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0074-drm-bridge-anx7625-Drop-of_gpio-header.patch (drm-backport-placeholder)
- commit 5029b58
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0073-drm-display-Add-missing-OLED-Vesa-brightnesses-defin.patch (drm-backport-placeholder)
- commit 721ed3a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0072-drm-panel-simple-Add-InnoLux-G070ACE-L01.patch (drm-backport-placeholder)
- commit 7e0d39c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0071-drm-armada-Implement-fbdev-emulation-as-in-kernel-cl.patch (drm-backport-placeholder)
- commit 322e9b1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0070-drm-armada-Initialize-fbdev-DRM-client.patch (drm-backport-placeholder)
- commit bb9ba1f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0069-drm-armada-Hide-fbdev-support-behind-config-option.patch (drm-backport-placeholder)
- commit d33a0dc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0068-drm-armada-Include-linux-of.h.patch (drm-backport-placeholder)
- commit 8f13aed
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0067-drm-bridge-ti-sn65dsi86-Implement-wait_hpd_asserted.patch (drm-backport-placeholder)
- commit 44a191c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0004-arch-x86-Implement-asm-fb.h-with-generic-helpers.patch (drm-backport-placeholder)
- commit 6c9d63a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0011-arch-sparc-Implement-asm-fb.h-with-generic-helpers.patch (drm-backport-placeholder)
- commit 4612877
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0007-arch-sparc-Implement-fb_is_primary_device-in-source-.patch (drm-backport-placeholder)
- commit 334da3d
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0066-arch-parisc-Implement-fb_is_primary_device-under-arc.patch (drm-backport-placeholder)
- commit 3fcaf79
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0065-video-Move-HP-PARISC-STI-core-code-to-shared-locatio.patch (drm-backport-placeholder)
- commit 4a3449b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0064-video-Remove-trailing-whitespaces.patch (drm-backport-placeholder)
- commit c486bd8
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0006-arch-arm64-Implement-asm-fb.h-with-generic-helpers.patch (drm-backport-placeholder)
- commit ca3b807
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0010-arch-mips-Implement-asm-fb.h-with-generic-helpers.patch (drm-backport-placeholder)
- commit 60d3aa2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0009-arch-loongarch-Implement-asm-fb.h-with-generic-helpe.patch (drm-backport-placeholder)
- commit 1411ad4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0008-arch-ia64-Implement-asm-fb.h-with-generic-helpers.patch (drm-backport-placeholder)
- commit 89abd41
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0003-fbdev-Prepare-generic-architecture-helpers.patch (drm-backport-placeholder)
- commit 9f9ad68
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0063-drm-gem-Check-for-valid-formats.patch (drm-backport-placeholder)
- commit 6ea4fa0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-scheduler-set-entity-to-NULL-in-drm_sched_.patch (drm-backport-placeholder)
- commit 3e1991c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0061-drm-nouveau-therm-Move-an-assignment-statement-behin.patch (drm-backport-placeholder)
- commit a83ca67
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0060-drm-nouveau-pci-Move-an-expression-into-a-function-c.patch (drm-backport-placeholder)
- commit d9d5d91
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0059-drm-nouveau-pci-Move-a-variable-assignment-behind-co.patch (drm-backport-placeholder)
- commit ffb2220
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0058-drm-nouveau-clk-Move-a-variable-assignment-behind-a-.patch (drm-backport-placeholder)
- commit dc1b979
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0057-drm-nouveau-bios-power_budget-Move-an-expression-int.patch (drm-backport-placeholder)
- commit 927c9a9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0056-drm-nouveau-debugfs-Replace-five-seq_printf-calls-by.patch (drm-backport-placeholder)
- commit 443b0c0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0055-drm-nouveau-debugfs-Use-seq_putc-in-nouveau_debugfs_.patch (drm-backport-placeholder)
- commit 224c14c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0054-drm-nouveau-debugfs-Move-a-variable-assignment-behin.patch (drm-backport-placeholder)
- commit 34d1f14
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0053-drm-nouveau-debugfs-Move-an-expression-into-a-functi.patch (drm-backport-placeholder)
- commit 9c652dd
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0052-drm-panel-nt36523-Add-Lenovo-J606F-panel.patch (drm-backport-placeholder)
- commit ba09eb7
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0051-drm-panel-nt36523-Get-orientation-from-OF.patch (drm-backport-placeholder)
- commit b7dcda4
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0050-drm-panel-nt36523-Add-DCS-backlight-support.patch (drm-backport-placeholder)
- commit 2473fa2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0049-dma-buf-dma-resv.c-fix-a-typo.patch (drm-backport-placeholder)
- commit a06f09c
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0048-video-aperture-Provide-a-VGA-helper-for-gma500-and-i.patch (drm-backport-placeholder)
- commit ace61b1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0002-fbdev-Simplify-fb_is_primary_device-for-x86.patch (drm-backport-placeholder)
- commit 9dcea97
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0047-video-aperture-Only-remove-sysfb-on-the-default-vga-.patch (drm-backport-placeholder)
- commit 095dccb
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0046-video-aperture-Drop-primary-argument.patch (drm-backport-placeholder)
- commit 2654a19
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0045-video-aperture-Move-vga-handling-to-pci-function.patch (drm-backport-placeholder)
- commit 27b4fd0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0044-video-aperture-Only-kick-vgacon-when-the-pdev-is-dec.patch (drm-backport-placeholder)
- commit b258f0b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0043-drm-aperture-Remove-primary-argument.patch (drm-backport-placeholder)
- commit e26f663
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0042-video-aperture-use-generic-code-to-figure-out-the-vg.patch (drm-backport-placeholder)
- commit 846fef3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0041-drm-gma500-Use-drm_aperture_remove_conflicting_pci_f.patch (drm-backport-placeholder)
- commit 1dd9b8a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-imx-lcdc-fix-a-NULL-vs-IS_ERR-bug-in-probe.patch (drm-backport-placeholder)
- commit 4e002cc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0039-drm-bridge-fsl-ldb-Add-i.MX6SX-support.patch (drm-backport-placeholder)
- commit 9ff8564
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0038-drm-vkms-Use-drmm_mode_config_init.patch (drm-backport-placeholder)
- commit 999f7f3
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0037-drm-vkms-Use-drmm_crtc_init_with_planes.patch (drm-backport-placeholder)
- commit a04b476
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-fix-potential-OOB-read-in-fast_imageblit.patch (drm-backport-placeholder)
- commit 75de597
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0035-fbdev-sh7760fb-Fix-Wimplicit-fallthrough-warnings.patch (drm-backport-placeholder)
- commit 3275c66
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0034-fbdev-sh_mobile_lcdcfb-Fix-ARGB32-overlay-format-typ.patch (drm-backport-placeholder)
- commit 6707353
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0033-fbdev-hitfb-Use-NULL-for-pointers.patch (drm-backport-placeholder)
- commit 09eebf5
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0032-fbdev-hitfb-Fix-integer-to-pointer-cast.patch (drm-backport-placeholder)
- commit 069cd79
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0031-fbdev-media-Use-GPIO-descriptors-for-VIA-GPIO.patch (drm-backport-placeholder)
- commit f555a28
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0030-video-hdmi-Reorder-fields-in-struct-hdmi_avi_infofra.patch (drm-backport-placeholder)
- commit e2e67dc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0029-fbdev-broadsheetfb-Add-MODULE_FIRMWARE-macro.patch (drm-backport-placeholder)
- commit 8fc7e50
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0028-fbdev-metronomefb-Add-MODULE_FIRMWARE-macro.patch (drm-backport-placeholder)
- commit 31a0e7a
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0027-fbdev-hitfb-Declare-hitfb_blank-as-static.patch (drm-backport-placeholder)
- commit 23e9dad
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/fbdev-omapfb-lcd_mipid-Fix-an-error-handling-pa.patch (drm-backport-placeholder)
- commit e09f25f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/Input-ads7846-Convert-to-use-software-nodes.patch (drm-backport-placeholder)
- commit d070ef0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0024-mm-gup-remove-unused-vmas-parameter-from-get_user_pa.patch (drm-backport-placeholder)
- commit 18a4db0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0023-drm-i2c-tda998x-Replace-all-non-returning-strlcpy-wi.patch (drm-backport-placeholder)
- commit 0c2502f
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0022-drm-sun4i-hdmi-Replace-all-non-returning-strlcpy-wit.patch (drm-backport-placeholder)
- commit 59312c2
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0021-drm-mediatek-Replace-all-non-returning-strlcpy-with-.patch (drm-backport-placeholder)
- commit 8e371c6
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0020-drm-rockchip-Replace-all-non-returning-strlcpy-with-.patch (drm-backport-placeholder)
- commit c420455
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0019-drm-display-dp_mst-Replace-all-non-returning-strlcpy.patch (drm-backport-placeholder)
- commit 7a555f0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0018-drm-amd-pm-Replace-all-non-returning-strlcpy-with-st.patch (drm-backport-placeholder)
- commit 8f1aadc
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0017-drm-radeon-Replace-all-non-returning-strlcpy-with-st.patch (drm-backport-placeholder)
- commit f0716d9
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-ttm-never-consider-pinned-BOs-for-eviction-.patch (drm-backport-placeholder)
- commit 111a71b
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-fbdev-dma-Fix-documented-default-preferred_.patch (drm-backport-placeholder)
- commit 4fb03a1
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/dma-buf-fix-an-error-pointer-vs-NULL-bug.patch (drm-backport-placeholder)
- commit c96cd43
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/dma-buf-keep-the-signaling-time-of-merged-fence.patch (drm-backport-placeholder)
- commit 11083db
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-panel-simple-Add-Powertip-PH800480T013-drm_.patch (drm-backport-placeholder)
- commit 583b3e0
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-ttm-Don-t-leak-a-resource-on-swapout-move-e.patch (drm-backport-placeholder)
- commit 6366826
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-ttm-Don-t-leak-a-resource-on-eviction-error.patch (drm-backport-placeholder)
- commit 8c4dfda
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-ti-sn65dsi86-Fix-auxiliary-bus-lifet.patch (drm-backport-placeholder)
- commit 96d4152
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0007-drm-sched-Call-drm_sched_fence_set_parent-from-drm_s.patch (drm-backport-placeholder jsc#PED-3527 jsc#PED-5475 jsc#PED-6068 jsc#PED-6070 jsc#PED-6116 jsc#PED-6120 jsc#PED-5065 jsc#PED-5477 jsc#PED-5511 jsc#PED-6041 jsc#PED-6069 jsc#PED-6071).
- commit 0452183
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0006-drm-nouveau-kms-nv50-Fix-drm_dp_remove_payload-invoc.patch (drm-backport-placeholder)
- commit b247882
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0005-drm-ttm-fix-warning-that-we-shouldn-t-mix-and.patch (drm-backport-placeholder)
- commit dd076ee
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-ttm-fix-bulk_move-corruption-when-adding-a-.patch (drm-backport-placeholder)
- commit 1d3ceff
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/drm-bridge-dw_hdmi-fix-connector-access-for-scd.patch (drm-backport-placeholder)
- commit cee7120
* Wed Sep  4 2024 pjakobsson@suse.de
- Update patches.suse/0002-drm-sched-Make-sure-we-wait-for-all-dependencies-in-.patch (drm-backport-placeholder)
- commit ab64432
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: makes CPU/Codec channel connection map more generic
  (jsc#PED-9993 jsc#PED-10202).
- commit f1175d7
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: SOF: ipc4: Handle ALSA kcontrol change notification from
  firmware (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-SOF-ipc4-check-return-value-of-snd_sof_ipc_msg_.patch.
- commit 350be84
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: SOF: Intel: Use existing helpers to change GPROCEN and
  PIE bits (jsc#PED-9993 jsc#PED-10202).
- ASoC: sh: convert not to use dma_request_slave_channel()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-control: Implement control update for
  switch/enum controls (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Helper to find an swidget by
  module/instance id (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs43130: Allow configuration of bit clock and frame
  inversion (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs43130: Allow driver to work without IRQ connection
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl: mpc8610_hpcd: Remove unused driver (jsc#PED-9993
  jsc#PED-10202).
- ASoC: imx-rpmsg: Force codec power on in low power audio mode
  (jsc#PED-9993 jsc#PED-10202).
- commit f4da865
* Wed Sep  4 2024 tiwai@suse.de
- supported.conf: add snd-acp70 (jsc#PED-9993 jsc#PED-10202)
- commit 9b30e8e
* Wed Sep  4 2024 tiwai@suse.de
- Update config files: CONFIG_SND_AMD_ASOC_ACP70=m (jsc#PED-9993 jsc#PED-10202)
- commit ee03f99
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: nau8810: Fix incorrect type in assignment and cast to
  restricted __be16 (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl_mqs: Remove duplicate linux/of.h header (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs43130: Add switch to control normal and alt hp inputs
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs43130: Add handling of ACPI (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs43130: Store device in private struct and use it more
  consistently (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: add missing SND_SOC_AMD_ACP_LEGACY_COMMON flag
  for ACP70 (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5682s: Add LDO output selection for dacref (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: acp: add Kconfig options for acp7.0 based platform
  driver (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: add mtl_rt5650 support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l43: Add missing static from runtime PM ops
  (jsc#PED-9993 jsc#PED-10202).
- commit b5ee0ec
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: codecs: ES8326: Changing the headset detection time
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Changing initialisation and broadcasting
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Add chip version flag (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Add support for configuring PDM interface from
  topology (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: imx8m: Add DAI driver entry for MICFIL PDM
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: ssm4567: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: rt5682: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: rt5663: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: rt5514: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: rt298: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: rt286: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: rt274: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: probe: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: nau8825: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: max98927: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: max98373: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: max98357a: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: i2s_test: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: hdaudio: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: es8336: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: dmic: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: da7219: Add proper id_table (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: mediatek: remove unused variables (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: mediatek: mt8186: clean up unused code (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: mediatek: mt8195: clean up unused code (jsc#PED-9993
  jsc#PED-10202).
- ASoC: nau8821: Add slew rate controls (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: acp: remove unnecessary NULL check (jsc#PED-9993
  jsc#PED-10202).
- ASoC: tegra: convert not to use dma_request_slave_channel()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: correct the format order (jsc#PED-9993
  jsc#PED-10202).
- commit 08aaee4
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: amd: acp: Fix for indentation issue (jsc#PED-9993
  jsc#PED-10202).
- ASoC: dapm: Simplify widget clone (jsc#PED-9993 jsc#PED-10202).
- ASoC: sti-uniperf: Use default pcm_config instead (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: fix kvmalloc_array() arguments order (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: pci-mtl: add HDA_ARL PCI support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: pci-mtl: fix ARL-S definitions (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: Unhardcode HDAudio BE DAI drivers description
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Kill S24_LE format (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: Drop snd_hdac_calc_stream_format() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: Switch to new stream-format interface
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: Switch to new stream-format interface
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel Skylake: Switch to new stream-format interface
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: hdac_hdmi: Switch to new stream-format interface
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: hdac_hda: Switch to new stream-format interface
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: hda: Switch to new stream-format interface
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda/ca0132: Switch to new stream-format interface
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda/hdmi: Switch to new stream-format interface
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Switch to new stream-format interface (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: Upgrade stream-format infrastructure (jsc#PED-9993
  jsc#PED-10202).
- commit 9a3a0fe
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: pcm: Honor subformat when configuring runtime
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Honor subformat when querying PCMs (jsc#PED-9993
  jsc#PED-10202).
- ALSA: pcm: Introduce MSBITS subformat interface (jsc#PED-9993
  jsc#PED-10202).
- soc: fsl: cpm1: qmc: Extend the API to provide Rx status
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: topology: Replace fake root_device with kunit_device in
  tests (jsc#PED-9993 jsc#PED-10202).
- commit 1f42fbc
* Wed Sep  4 2024 lhenriques@suse.de
- fuse: update stats for pages in dropped aux writeback list
  (bsc#1230125).
- fuse: fix memory leak in fuse_create_open (bsc#1230124).
- fuse: use unsigned type for getxattr/listxattr size truncation
  (bsc#1230123).
- commit c8902bc
* Wed Sep  4 2024 oneukum@suse.com
- thunderbolt: Add support for Intel Lunar Lake (jsc#PED-10232).
- commit 8f81652
* Wed Sep  4 2024 oneukum@suse.com
- usb: typec: tcpci: Fix error code in
  tcpci_check_std_output_cap() (jsc#PED-10361).
- commit 3866a89
* Wed Sep  4 2024 mwilck@suse.com
- Split kabi part of dm_blk_ioctl-implement-path-failover-for-SG_IO.patch
- kabi: dm_blk_ioctl: implement path failover for SG_IO
  (bsc#1183045, bsc#1216776).
- Refresh
  patches.suse/dm_blk_ioctl-implement-path-failover-for-SG_IO.patch.
- commit 9a2ecb0
* Wed Sep  4 2024 tiwai@suse.de
- supported.conf: add snd-soc-intel-sof-ssp-common (jsc#PED-9993 jsc#PED-10202)
- commit ba95831
* Wed Sep  4 2024 tiwai@suse.de
- ASoC: drm/vc4: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- iov_iter: Export import_ubuf() (jsc#PED-9993 jsc#PED-10202).
- commit 773b247
* Wed Sep  4 2024 neilb@suse.de
- NFSD: Fix frame size warning in svc_export_parse() (git-fixes).
- NFSD: Rewrite synopsis of nfsd_percpu_counters_init()
  (git-fixes).
- commit 3ab58b8
* Wed Sep  4 2024 neilb@suse.de
- blacklist.conf: These aren't wanted for various reasons.
- commit 39478da
* Wed Sep  4 2024 neilb@suse.de
- SUNRPC: increase size of rpc_wait_queue.qlen from unsigned
  short to unsigned int (git-fixes).
- commit f718248
* Wed Sep  4 2024 neilb@suse.de
- blacklist.conf: remove a breaks-kabi commit
- commit 11603af
* Tue Sep  3 2024 krisman@suse.de
- kABI: Split kABI out of io_uring/kbuf: protect io_buffer_list teardown with a
  reference
  When introducing this patch, I merged the kABI patch with the actual
  backport, which is not recommended.  Split it up, such that the backport
  is similar to the upstream patch and handle the kABI issue exactly the
  same way, but through a separate kABI patch.
- commit 08e57d6
* Tue Sep  3 2024 lduncan@suse.com
- scsi: sd: Use READ(16) when reading block zero on large capacity
  disks (git-fixes).
- ata: libata-scsi: Fix ata_scsi_dev_rescan() error path
  (git-fixes).
- commit ab07c19
* Tue Sep  3 2024 tiwai@suse.de
- media: solo6x10: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- commit 3c3ece3
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: cs42l43: Don't enable bias sense during type detect
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-mtl-match: Change CS35L56 prefixes
  to AMPn (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: mediatek: mt8186: Revert Add Google Steelix topology
  compatible (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Add support for a new Huawei Matebook laptop
  (jsc#PED-9993 jsc#PED-10202).
- commit d311bc7
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: imx-rpmsg: SND_SOC_IMX_RPMSG should depend on OF and I2C
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: Always register the HDMI dai links
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: mediatek: mt8186: Add Google Steelix topology
  compatible (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: i915: Alays handle -EPROBE_DEFER (jsc#PED-9993
  jsc#PED-10202).
- ASoC: nau8540: Add self recovery to improve capture quility
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: da7219: Improve system suspend and resume handling
  (jsc#PED-9993 jsc#PED-10202).
- commit 79422d7
* Tue Sep  3 2024 tiwai@suse.de
- supported.conf: add snd-soc-avs-rt5514 (jsc#PED-9993 jsc#PED-10202)
- commit a6c1561
* Tue Sep  3 2024 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_INTEL_AVS_MACH_RT5514=m (jsc#PED-9993 jsc#PED-10202)
- commit 08780dd
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: amd: acp: fix for i2s mode register field update
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt712-sdca: fix speaker route missing issue (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rockchip: Fix unused rockchip_i2s_tdm_match warning for
  !CONFIG_OF (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Add rt5514 machine board (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: acp: select SND_SOC_AMD_ACP_LEGACY_COMMON for ACP63
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: add ACPI dependency (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: bytcr_wm5102: Add BYT_WM5102_IN_MAP quirk
  (jsc#PED-9993 jsc#PED-10202).
- commit 61ee659
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: Intel: bytcr_wm5102: Add BYT_WM5102_OUT_MAP quirk
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: bytcr_wm5102: Add BYT_WM5102_MCLK_19_2MHZ quirk
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: bytcr_wm5102: Add BYT_WM5102_SSP2 quirk
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: sc7180: Add support for qdsp6 baked sound
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: tegra: machine: Handle component name prefix (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: speyside: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8192: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8188: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8186: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8183: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- commit c606f52
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: codecs: wm8995: Handle component name prefix (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wm8994: Handle component name prefix (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wm8962: Handle component name prefix (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wcd9335: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: rt5682s: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: max9867: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: lpass-rx-macro: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: adav80x: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: adau1373: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- commit a67be05
* Tue Sep  3 2024 tiwai@suse.de
- Fix compile warnings due to merge errors
- Refresh:
  patches.suse/ASoC-SOF-Make-return-of-remove_late-void-too.patch
  patches.suse/ASoC-SOF-make-.remove-callback-return-void.patch
- commit 8d4b3da
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: codecs: 88pm860x: Handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: Add code for bin parsing compatible with aw88399
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: add machine driver support for acp7.0
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Add pci legacy driver support for acp7.0
  platform (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: change acp power on mask macro value
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: change acp-deinit function arguments
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: add machine driver support for pdm use case
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: add condition check for i2s clock generation
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: add platform and flag data to acp data structure
  (jsc#PED-9993 jsc#PED-10202).
- commit f278ea0
* Tue Sep  3 2024 mkoutny@suse.com
- blacklist.conf: Add cf3f9a593dab mm: optimize the redundant loop of mm_update_owner_next()
- commit 3184f0b
* Tue Sep  3 2024 tiwai@suse.de
- supported.conf: add snd-acp63 (jsc#PED-9993 jsc#PED-10202)
- commit 2f19099
* Tue Sep  3 2024 tiwai@suse.de
- Update config files: CONFIG_SND_AMD_ASOC_ACP63=m (jsc#PED-9993 jsc#PED-10202)
- commit a51249d
* Tue Sep  3 2024 mkoutny@suse.com
- blacklist.conf: d24f05987ce8 cgroup: Avoid extra dereference in css_populate_dir()
- commit 922f944
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: amd: acp: add code for scanning acp pdm controller
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: add Kconfig options for acp6.3 based platform
  driver (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: add machine driver support for acp6.3 platform
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: add i2s clock generation support for acp6.3
  based platforms (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: refactor acp i2s clock generation code
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Add acp6.3 pci legacy driver support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: Skylake: add an error code check in skl_pcm_trigger
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wcd938x: use defines for entries in
  snd_soc_dai_driver array (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: q6apm-lpass-dais: pass max number of channels to
  Audioreach (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: bytcr_wm5102: Add support for Lenovo Yoga Tab 3
  Pro YT3-X90 (jsc#PED-9993 jsc#PED-10202).
- commit fb81d26
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: mediatek: mt8186: remove redundant assignments to variable
  tdm_con (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt7986: add sample rate checker (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: rt298: remove redundant assignment to d_len_code
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: ams-delta: Allow it to be test compiled (jsc#PED-9993
  jsc#PED-10202).
- ASoC: uniphier: Make uniphier_aio_remove() return void
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: lpass: Make asoc_qcom_lpass_cpu_platform_remove()
  return void (jsc#PED-9993 jsc#PED-10202).
- ASoC: meson: Make meson_card_remove() return void (jsc#PED-9993
  jsc#PED-10202).
- ASoC: simple-card-utils: Make simple_util_remove() return void
  (jsc#PED-9993 jsc#PED-10202).
- commit 5297af4
* Tue Sep  3 2024 tiwai@suse.de
- supported.conf: add snd-sof-amd-acp63 (jsc#PED-9993 jsc#PED-10202)
- commit ae4f709
* Tue Sep  3 2024 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_SOF_AMD_ACP63=m (jsc#PED-9993 jsc#PED-10202)
- commit b47eccf
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: cs42l43: Convert to platform remove callback returning
  void (jsc#PED-9993 jsc#PED-10202).
- ASoC: rockchip: i2s_tdm: Convert to platform remove callback
  returning void (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: add option to use sram for data bin loading
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: refactor acp dram usage for data bin loading
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: amd: increase DSP cache window range (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: amd: add support for acp6.3 based platform
  (jsc#PED-9993 jsc#PED-10202).
- commit 71b62b5
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: amd: Add acpi machine id for acp6.3 version based platform
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-amd-acp-config-Add-missing-MODULE_DESCRIPTION.patch.
- commit fc71cee
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: es8328: Use rounded rate for es8328_set_sysclk()
  (jsc#PED-9993 jsc#PED-10202).
- commit b06fe21
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: SOF: Make return of remove_late void, too (jsc#PED-9993
  jsc#PED-10202).
- commit ede1beb
* Tue Sep  3 2024 tiwai@suse.de
- ALSA: rawmidi: Replace with __packed attribute (jsc#PED-9993
  jsc#PED-10202).
- ALSA: pcm: Replace with __packed attribute (jsc#PED-9993
  jsc#PED-10202).
- ALSA: control: Replace with __packed attribute (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: use common module for DMIC links
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use common module for DMIC links
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: use common module for DMIC links
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: use common module for DMIC links
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: support dmic link initialization
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: add RPL support for MAX98360A amp
  (jsc#PED-9993 jsc#PED-10202).
- commit 5668bb4
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: intel: sof_sdw: Move the builtin microphones to dataport 1
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw_cs42l43: Create separate jacks for hp
  and mic (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw_cs42l43: Some trivial formatting clean ups
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: tlv320aic31xx: switch to gpiod_set_value_cansleep
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8186_mt6366_rt1019_rt5682s: add rt5650 support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: da7213: Add new kcontrol for tonegen (jsc#PED-9993
  jsc#PED-10202).
- ASoC: tas2781: make const read-only array magic_number static
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: ps: enable wake capability for acp pci driver
  (jsc#PED-9993 jsc#PED-10202).
- commit 265fa70
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: SOF: make .remove callback return void (jsc#PED-9993
  jsc#PED-10202).
- commit 4053352
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: SOF: ipc4: Dump the notification payload (jsc#PED-9993
  jsc#PED-10202).
- commit aa58961
* Tue Sep  3 2024 tiwai@suse.de
- supported.conf: add snd-soc-intel-sof-board-helpers (jsc#PED-9993 jsc#PED-10202)
- commit 943e516
* Tue Sep  3 2024 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_INTEL_SOF_BOARD_HELPERS=m (jsc#PED-9993 jsc#PED-10202)
- commit c3a8033
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: SOF: Intel: pci-mtl: use ARL specific firmware definitions
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt715: reorder the argument in error log (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt715-sdca: reorder the argument in error log
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: use common module for HDMI link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use common module for HDMI link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: use common module for HDMI link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: use common module for HDMI link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: board_helpers: new module for common functions
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: use sof_hdmi_private to init HDMI
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: use sof_hdmi_private to init HDMI
  (jsc#PED-9993 jsc#PED-10202).
- commit 1cc4108
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: Intel: sof_rt5682: use sof_hdmi_private to init HDMI
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: use sof_hdmi_private to init HDMI
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: use sof_hdmi_private to init HDMI
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: use sof_hdmi_private to init HDMI
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_hdmi: add common header for HDMI (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: remove hdac-hdmi support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_rt5682: remove hdac-hdmi support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_nau8825: remove hdac-hdmi support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_da7219: remove hdac-hdmi support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_cs42l42: remove hdac-hdmi support (jsc#PED-9993
  jsc#PED-10202).
- commit 4cc6cb7
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: Intel: sof_sdw_rt712_sdca: construct cards->components
  by name_prefix (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: MTL: Add entry for HDMI-In capture support to
  non-I2S codec boards (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-mtl-match: add rt713 rt1316 config
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-rpl-match: add rt711-l0-rt1316-l12
  support (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_sdw: update HP Omen match (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sigmadsp: Add __counted_by for struct sigmadsp_data and
  use struct_size() (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: ssm4567: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: rt5663: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: rt286: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: nau8825: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- commit b3e370a
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: Intel: avs: max98927: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: max98373: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: es8336: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: da7219: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: rt298: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: max98357a: Validate machine board
  configuration (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: rt5682: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: rt274: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: i2s_test: Validate machine board configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Improve topology parsing of dynamic strings
  (jsc#PED-9993 jsc#PED-10202).
- commit 86c4d4e
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: Use device_get_match_data() (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-rockchip-i2s-tdm-Fix-inaccurate-sampling-rates.patch.
- commit b13dc1c
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: Intel: avs: Introduce helper functions for SSP and TDM
  handling (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Only create SSP%%d snd_soc_dai_driver when
  requested (jsc#PED-9993 jsc#PED-10202).
- ASoC: tegra: Fix -Wuninitialized in
  tegra210_amx_platform_probe() (jsc#PED-9993 jsc#PED-10202).
- ASoC: apple: mca: Annotate struct mca_data with __counted_by
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Convert to platform remove callback returning void
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8188-mt6359: add rt5682s support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom/lpass: Constify struct lpass_variant (jsc#PED-9993
  jsc#PED-10202).
- ASoC: da7218: Use i2c_get_match_data() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Drop unnecessary of_match_device() calls (jsc#PED-9993
  jsc#PED-10202).
- commit 94228f4
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: Explicitly include correct DT includes (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ASoC-cs35l33-Fix-GPIO-name-and-drop-legacy-include.patch.
- commit a2cc63c
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: mt8192-afe-gpio: Drop unused include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mt8186-mt6366-rt1019-rt5682s: Drop unused include
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mt8173-rt5650: Drop unused includes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mt8173-rt5650-rt5676: Drop unused includes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mt8173-rt5650-rt5514: Drop unused includes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mt8173-max98090: Drop unused include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: mt2701-cs42448: Convert to GPIO descriptors
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rockchip: Drop includes from Rockchip RT5645 (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rockchip: Drop includes from Rockchip MAX98090
  (jsc#PED-9993 jsc#PED-10202).
- commit 34e6400
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: rockchip: Drop includes from RK3399 (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rockchip: Convert RK3288 HDMI to GPIO descriptors
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: reduce number of binding headers includes
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: explicitly include binding headers when used
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: sof-client: fix build when only IPC4 is selected
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: IPC4: sort pipeline based on priority (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: IPC4: get pipeline priority from topology
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Enable low-power hibernation mode on SPI
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Enable low-power hibernation mode on i2c
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Change hibernate sequence to use allow auto
  hibernate (jsc#PED-9993 jsc#PED-10202).
- commit 4fd311f
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: cs35l56: Initialise a variable to silence possible static
  analysis error (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-dapm: Annotate struct snd_soc_dapm_widget_list with
  __counted_by (jsc#PED-9993 jsc#PED-10202).
- ASoC: Adds support for TAS575x to the pcm512x driver
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: osk5912: Drop unused include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ti: Convert TWL4030 to use GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ti: Convert N810 ASoC to GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ti: Convert RX51 to use exclusively GPIO descriptors
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: tas2781: fixed compiling issue in m68k (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: Remove unused variable (jsc#PED-9993
  jsc#PED-10202).
- commit e9e2283
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: intel: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ASoC-Intel-skl_hda_dsp_generic-Drop-HDMI-routes-when.patch.
- commit f7a12f5
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Update documentation with Sub-NUMA cluster changes (jsc#PED-10246).
- commit 2f6a8c1
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Detect Sub-NUMA Cluster (SNC) mode (jsc#PED-10246).
- commit a736a9f
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Enable shared RMID mode on Sub-NUMA Cluster (SNC) systems (jsc#PED-10246).
- commit 8470ab8
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Make __mon_event_count() handle sum domains (jsc#PED-10246).
- commit e12fa7f
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Fill out rmid_read structure for smp_call*() to read a  counter (jsc#PED-10246).
- commit 35c1e43
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Handle removing directories in Sub-NUMA Cluster (SNC)  mode (jsc#PED-10246).
- commit f516863
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: Intel: avs: Drop superfluous stream decoupling
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Disable DSP before loading basefw
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Keep module refcount up when gathering traces
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Preallocate memory for module configuration
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Use generic size defines (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: avs: Move IPC error messages one level down
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: Add code for bin parsing compatible with aw87390
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: Modify i2c driver name (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: Modify the transmission method of parameters
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: Rename "sound-channel" to "awinic,audio-channel"
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: Remove the "fade-enable property" (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l43: Remove useless else (jsc#PED-9993 jsc#PED-10202).
- ASoC: sof: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-generic-dmaengine-pcm: convert not to use asoc_xxx()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-component: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-compress: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-topology: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-utils: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-link: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-dapm: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-core: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-pcm: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- commit 07347ce
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Create Sub-NUMA Cluster (SNC) monitor files (jsc#PED-10246).
- commit a08d01f
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Allocate a new field in union mon_data_bits (jsc#PED-10246).
- commit cc5e5f7
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Refactor mkdir_mondata_subdir() with a helper function (jsc#PED-10246).
- commit 0fb57c1
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Initialize on-stack struct rmid_read instances (jsc#PED-10246).
- commit c8eae6e
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Add a new field to struct rmid_read for summation of  domains (jsc#PED-10246).
- commit d4617d3
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Prepare for new Sub-NUMA Cluster (SNC) monitor files (jsc#PED-10246).
- commit 25a8f57
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Block use of mba_MBps mount option on Sub-NUMA Cluster  (SNC) systems (jsc#PED-10246).
- commit c78bcda
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: sof: intel: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/Revert-ASoC-SOF-Intel-hda-dai-ops-only-allocate-rele.patch.
- commit 2a3aaf9
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: soc-dai: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sof: mediatek: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sof: amd: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codec: cs47lxx: convert not to use asoc_xxx()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codec: rt5677: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codec: wm: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: intel: avs: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: uniphier: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- commit 2fe8f96
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Introduce snc_nodes_per_l3_cache (jsc#PED-10246).
- commit d2a023a
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Add node-scope to the options for feature scope (jsc#PED-10246).
- commit 7ee61bb
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: rockchip: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: kirkwood: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: extensa: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: generic: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cirrus: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ux500: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: tegra: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- commit 68c0e0d
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: qcom: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ASoC-qcom-Fix-uninitialized-pointer-dmactl.patch.
- commit 9005a88
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Split the rdt_domain and rdt_hw_domain structures (jsc#PED-10246).
- commit 7d8730a
* Tue Sep  3 2024 oneukum@suse.com
- usb: typec: Update sysfs when setting ops (jsc#PED-10361).
- commit 1a222d3
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: sunxi: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: meson: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: atmel: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: apple: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sprd: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: au1x: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: stm: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: pxa: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mxs: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- commit 70687c7
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Prepare for different scope for control/monitor operations (jsc#PED-10246).
- commit 8396324
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: fsl: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- commit 514decd
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Prepare to split rdt_domain structure  (jsc#PED-10246).
- commit 209dab8
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: sh: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- commit af8fea3
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Simplify call convention for MSR update functions (jsc#PED-10246).
- commit 9309a0c
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Remove lockdep annotation that triggers false positive (git-fixes).
- Refresh patches.suse/x86-resctrl-Pass-domain-to-target-CPU.patch.
- commit 90d6a70
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Pass domain to target CPU (jsc#PED-10246).
- commit 6fa6f8f
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: img: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: dwc: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: bcm: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ti: convert not to use asoc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: simple_card_utils.h: convert not to use asoc_xxx()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc.h: convert asoc_xxx() to snd_soc_xxx() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sh: dma-sh7760: Use %%pad and %%zu to format dma_addr_t
  and size_t (jsc#PED-9993 jsc#PED-10202).
- commit 937299e
* Tue Sep  3 2024 oneukum@suse.com
- usb: typec: ucsi: Wait 20ms before reading CCI after a reset
  (git-fixes).
- commit 26d16be
* Tue Sep  3 2024 tiwai@suse.de
- ASoC: hdac_hda: fix HDA patch loader support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l43: Extend timeout on bias sense timeout
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Move headset bias sense enable earlier in process
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Enable bias sense by default (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l43: Lower default type detect time (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: hda: add ipc4 FW panic support on CAVS 2.5+
  platforms (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: mtl: dump dsp stack (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: add telemetry retrieval support on Intel
  platforms (jsc#PED-9993 jsc#PED-10202).
- commit 9a7e8b3
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Prepare for new domain scope (jsc#PED-10246).
- commit 841df76
* Tue Sep  3 2024 oneukum@suse.com
- usb: typec: tcpci: add support to set connector orientation
  (jsc#PED-10361).
- commit ce79fa0
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Separate arch and fs resctrl locks (jsc#PED-10246).
- commit 59dcdf2
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Move domain helper migration into resctrl_offline_cpu() (jsc#PED-10246).
- commit d9d6be2
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Add CPU offline callback for resctrl work (jsc#PED-10246).
- commit 0239fcf
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Allow overflow/limbo handlers to be scheduled on any-but  CPU (jsc#PED-10246).
- commit 2f1b99a
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Add CPU online callback for resctrl work (jsc#PED-10246).
- commit f61b83a
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Add helpers for system wide mon/alloc capable (jsc#PED-10246).
- commit 7a99070
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Make rdt_enable_key the arch's decision to switch (jsc#PED-10246).
- commit 0343158
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Move alloc/mon static keys into helpers (jsc#PED-10246).
- commit 40a257e
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Make resctrl_mounted checks explicit (jsc#PED-10246).
- commit 4130fd7
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Allow arch to allocate memory needed in resctrl_arch_rmid_read() (jsc#PED-10246).
- commit beffd86
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Allow resctrl_arch_rmid_read() to sleep (jsc#PED-10246).
- commit f673a82
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Queue mon_event_read() instead of sending an IPI (jsc#PED-10246).
- commit 4044104
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Add cpumask_any_housekeeping() for limbo/overflow (jsc#PED-10246).
- commit b70a155
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Move CLOSID/RMID matching and setting to use helpers (jsc#PED-10246).
- commit a397168
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Allocate the cleanest CLOSID by searching closid_num_dirty_rmid (jsc#PED-10246).
- commit 3147061
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Use __set_bit()/__clear_bit() instead of open coding (jsc#PED-10246).
- commit cfbc94d
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Track the number of dirty RMID a CLOSID has (jsc#PED-10246).
- commit 67aa65d
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Allow RMID allocation to be scoped by CLOSID (jsc#PED-10246).
- commit 0d248f5
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Access per-rmid structures by index (jsc#PED-10246).
- commit 5c53c09
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Track the closid with the rmid (jsc#PED-10246).
- commit e319879
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Move RMID allocation out of mkdir_rdt_prepare() (jsc#PED-10246).
- commit 7104a62
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Create helper for RMID allocation and mondata dir  creation (jsc#PED-10246).
- commit ff5a028
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Free rmid_ptrs from resctrl_exit() (jsc#PED-10246).
- commit 9df1f34
* Tue Sep  3 2024 nik.borisov@suse.com
- tick/nohz: Move tick_nohz_full_mask declaration outside the #ifdef (jsc#PED-10246).
- commit 4eae403
* Tue Sep  3 2024 nik.borisov@suse.com
- x86/resctrl: Replace open coded cacheinfo searches (jsc#PED-10246).
- commit 7cb6f10
* Tue Sep  3 2024 nik.borisov@suse.com
- cacheinfo: Add function to get cacheinfo for a given CPU and cache  level (jsc#PED-10246).
- commit 7646391
* Tue Sep  3 2024 nik.borisov@suse.com
- cpu: Drop "extern" from function declarations in cpuhplock.h (jsc#PED-10246).
- commit 469d1ac
* Tue Sep  3 2024 nik.borisov@suse.com
- cpu: Move CPU hotplug function declarations into their own header (jsc#PED-10246).
- commit 3838f46
* Mon Sep  2 2024 msuchanek@suse.de
- Update config files (jsc#PED-10537).
  ppc64le: NR_CPUS=8192
  This alings with x86.
- commit e432f98
* Mon Sep  2 2024 lduncan@suse.com
- scsi: sd: Fix TCG OPAL unlock on system resume (git-fixes).
- commit d2a3c0c
* Mon Sep  2 2024 tiwai@suse.de
- supported.conf: add cs42l43 mfd stuff (jsc#PED-9993 jsc#PED-10202)
- commit cbf3c59
* Mon Sep  2 2024 tiwai@suse.de
- Update config files.
- commit 62b9c41
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: SOF: ipc4: add definition of telemetry slot for exception
  handling (jsc#PED-9993 jsc#PED-10202).
- commit a0f002f
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: SOF: ipc4-topology: Add definition for generic switch/enum
  control (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-SOF-ipc4-topology-Correct-data-structures-for-t-e238b68.patch.
- commit 2f55301
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: SOF: ipc4: add exception node in sof debugfs directory
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4: add a helper function to search debug slot
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-mtrace: move debug slot related definitions
  to header.h (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Xtensa: dump ar registers to restore call stack
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-control: Add support for ALSA enum control
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-control: Add support for ALSA switch control
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: soc-acpi-intel-mtl-match: add acpi match table
  for cdb35l56-eight-c (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Add CS42L43 CODEC support (jsc#PED-9993
  jsc#PED-10202).
- commit 2622d6f
* Mon Sep  2 2024 tiwai@suse.de
- mfd: cs42l43: Add support for cs42l43 core driver (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ALSA-hda-cs35l56-Add-support-for-speaker-id.patch.
- commit 7a6f06f
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: cs42l43: Update values for bias sense (jsc#PED-9993
  jsc#PED-10202).
- mfd: cs42l43: Use correct macro for new-style PM runtime ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Add shared IRQ flag for shutters (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l43: Fix missing error code in cs42l43_codec_probe()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Use new-style PM runtime macros (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l43: Initialize ret in default case in
  cs42l43_pll_ev() (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l43: Add support for the cs42l43 (jsc#PED-9993
  jsc#PED-10202).
- commit a8e4694
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: SOF: Intel: Use generic names for IPC types (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ASoC-SOF-Intel-add-default-firmware-library-path-for.patch.
- commit 6f1113b
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: SOF: mediatek: Use generic names for IPC types
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: imx: Use generic names for IPC types (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: amd: Use generic names for IPC types (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Introduce generic names for IPC types (jsc#PED-9993
  jsc#PED-10202).
- commit 318d3b1
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: SOF: Use generic names for IPC types (jsc#PED-9993
  jsc#PED-10202).
- commit 709a77b
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: SOF: Kconfig: Rename SND_SOC_SOF_INTEL_IPC4 to
  SND_SOC_SOF_IPC4 (jsc#PED-9993 jsc#PED-10202).
- Update config files.
- commit c737115
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: SOF: sof-pci-dev: Update the ipc_type module parameter
  description (jsc#PED-9993 jsc#PED-10202).
- ASoC: hdac_hda: add HDA patch loader support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: da7213: add .auto_selectable_formats support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: da7213: tidyup SND_SOC_DAIFMT_xxx (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm8782: Use wlf,fsampen device tree property (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm8782: Constrain maximum audio rate at runtime
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-pcm: fixup dailink based on copier format
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4-topology: export
  sof_ipc4_copier_is_single_format (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Increment be_id in init_dai_link
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Make create_sdw_dailink allocate link
  components (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Add simple DAI link creation helper
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: sof_sdw: Move sdw_pin_index into private struct
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda-loader: Add support for split library
  loading (jsc#PED-9993 jsc#PED-10202).
- commit 198b013
* Mon Sep  2 2024 tiwai@suse.de
- supported.conf: rename to snd-soc-sof-da7219 (jsc#PED-9993 jsc#PED-10202)
- commit 9530d42
* Mon Sep  2 2024 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_INTEL_SOF_DA7219_MACH=m (jsc#PED-9993 jsc#PED-10202)
- commit 07ccb03
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: SOF: ipc4: Add new message type:
  SOF_IPC4_GLB_LOAD_LIBRARY_PREPARE (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: hda: Add definition for SDxFIFOS.FIFOS mask
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4: Convert status code 2 and 15 to -EOPNOTSUPP
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Omit cs35l56_pm_ops_i2c_spi if I2C/SPI not
  enabled (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l56: Use new export macro for dev_pm_ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l56: Use pm_ptr() (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: use ssp-common module to detect codec
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: add adl_mx98360_da7219 board config
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_da7219: use maxim-common module (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_da7219: rename driver file and kernel option
  (jsc#PED-9993 jsc#PED-10202).
- commit 69c3a63
* Mon Sep  2 2024 tiwai@suse.de
- supported.conf: add snd-soc-intel-sof-nuvoton-common (jsc#PED-9993 jsc#PED-10202)
- commit 4536dea
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: Intel: sof_nau8825: use realtek-common module
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: use nuvoton-common module
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: nuvoton-common: support nau8318 amplifier
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: do not create amp link for nocodec
  board (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: add HDMI_In capture feature support
  for RPL (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: add adl_rt5650 board config
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: Modify number of HDMI to 3 for MTL/Rex
  devices (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: Add support for Rex with discrete BT
  offload (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_nau8825: use ssp-common module to detect codec
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_ssp_amp: use ssp-common module to detect codec
  (jsc#PED-9993 jsc#PED-10202).
- commit 16b6cac
* Mon Sep  2 2024 lduncan@suse.com
- scsi: sd: Remove the number of forward declarations (git-fixes).
- Refresh
  patches.suse/scsi-sd-Differentiate-system-and-runtime-start-stop-management.patch.
- commit 69a1f4f
* Mon Sep  2 2024 tiwai@suse.de
- supported.conf: add snd-soc-sof-ssp-common (jsc#PED-9993 jsc#PED-10202)
- commit c8b93b2
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: Intel: sof_cs42l42: use ssp-common module to detect codec
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: sof_rt5682: use ssp-common module to detect codec
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: use ACPI HID definition in ssp-common (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: ssp-common: support codec detection (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: sof_rt5682: cleanup unnecessary quirk flag
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: ps: Fix -Wformat-truncation warning (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt1015: fix the first word being cut off (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: ipc4-topology: Add deep buffer size to debug prints
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ipc4: Dump the payload also when set_get_data fails
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: ops.h: Change the error code for not supported to
  EOPNOTSUPP (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Fix -Wmissing-prototypes warning (jsc#PED-9993
  jsc#PED-10202).
- ASoC: nau8821: Revise MICBIAS control for power saving
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: hdac_hdmi: Remove temporary string use in
  create_fill_jack_kcontrols (jsc#PED-9993 jsc#PED-10202).
- ASoC: rsnd: remove unneeded of_node_put() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: lpass-tx-macro: Add SM6115 support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: tlv320aic32x4-spi: Simplify probe() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: tlv320aic32x4-i2c: Simplify probe() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codec: tlv320aic32x4: Add enum aic32x4_type to
  aic32x4_probe() (jsc#PED-9993 jsc#PED-10202).
- ASoC: max98927: Drop pointless includes (jsc#PED-9993
  jsc#PED-10202).
- commit d9e22c1
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: max98520: Drop pointless includes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: max98396: Drop pointless include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: max98388: Correct the includes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: max98373: Convert to use GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: max98357a: Drop pointless include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: max9768: Convert to use GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: mt8188-mt6359: add SOF support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: common: revise SOF common code (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ak4642: Simplify probe() (jsc#PED-9993 jsc#PED-10202).
- ASoC: ak4642: Minor cleanups in probe() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: amd: acp: Add machine driver that enables sound for
  systems with a ES8336 codec (jsc#PED-9993 jsc#PED-10202).
- ASoC: amd: acp: Add support for splitting the codec specific
  code from the ACP driver (jsc#PED-9993 jsc#PED-10202).
- ASoC: es8316: Enable support for MCLK div by 2 (jsc#PED-9993
  jsc#PED-10202).
- ASoC: es8316: Replace NR_SUPPORTED_MCLK_LRCK_RATIOS with
  ARRAY_SIZE() (jsc#PED-9993 jsc#PED-10202).
- ASoC: es8316: Enable support for S32 LE format (jsc#PED-9993
  jsc#PED-10202).
- ASoC: tas571x: Simplify probe() (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l45: Add AMP Enable Switch control (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l45: Connect DSP to the monitoring signals
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l45: Analog PCM Volume and Amplifier Mode controls
  (jsc#PED-9993 jsc#PED-10202).
- commit 2cb38d8
* Mon Sep  2 2024 tiwai@suse.de
- ASoC: cs42xx8-i2c: Simplify probe() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm8580: Simplify probe() (jsc#PED-9993 jsc#PED-10202).
- ASoC: meson: axg: extend TDM maximum sample rate to 384kHz
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: i915: Remove extra argument from snd_hdac_i915_init
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SOF: Intel: Move binding to display driver outside of
  deferred probe (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: Skylake: Move snd_hdac_i915_init to before
  probe_work (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Intel: Move snd_hdac_i915_init to before probe_work
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Move snd_hdac_i915_init to before probe_work
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: i915: Allow xe as match for
  i915_component_master_match (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: i915: Add an allow_modprobe argument to
  snd_hdac_i915_init (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: i915: Allow override of gpu binding (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: Fix error handling in hda_init() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: Intel: hda: start splitting the probe (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SOF: core: Add probe_early and remove_late callbacks
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Add code_loading parameter to stream setup
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Fix stream fifo_size initialization (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Intel: Skylake: Use helper to setup HOST stream
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Intel: avs: Use helper to setup HOST stream (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: Introduce HOST stream setup mechanism (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: Poll SDxFIFOS after programming SDxFMT (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hda: Annotate struct hda_conn_list with __counted_by
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: hda: Use pci_get_base_class() to reduce duplicated code
  (jsc#PED-9993 jsc#PED-10202).
- sound: Fix snd_pcm_readv()/writev() to use iov access functions
  (jsc#PED-9993 jsc#PED-10202).
- commit 34c3bbb
* Mon Sep  2 2024 lhenriques@suse.de
- ceph: periodically flush the cap releases (bsc#1230057).
- commit e3f19db
* Mon Sep  2 2024 lhenriques@suse.de
- ceph: periodically flush the cap releases (bsc#1230056).
- commit e22b6e0
* Mon Sep  2 2024 denis.kirjanov@suse.com
- Bluetooth: Fix usage of __hci_cmd_sync_status (git-fixes).
- commit 1bec58d
* Mon Sep  2 2024 denis.kirjanov@suse.com
- Bluetooth: L2CAP: Fix deadlock (git-fixes).
- commit 13aba13
* Mon Sep  2 2024 sjaeckel@suse.de
- net/sched: act_ct: fix skb leak and crash on ooo frags
  (CVE-2023-52610 bsc#1221610).
- commit 7a32533
* Mon Sep  2 2024 denis.kirjanov@suse.com
- bluetooth/l2cap: sync sock recv cb and release (bsc#1228576
  CVE-2024-41062).
- commit 6553526
* Mon Sep  2 2024 osalvador@suse.de
- mm: prevent derefencing NULL ptr in pfn_section_valid()
  (git-fixes).
- commit 35f619d
* Mon Sep  2 2024 osalvador@suse.de
- mm, kmsan: fix infinite recursion due to RCU critical section
  (git-fixes).
- commit 16ad73a
* Mon Sep  2 2024 osalvador@suse.de
- mm/sparsemem: fix race in accessing memory_section->usage
  (bsc#1221326 CVE-2023-52489).
- commit 6aa8957
* Mon Sep  2 2024 ohering@suse.de
- net: mana: Fix race of mana_hwc_post_rx_wqe and new hwc response (git-fixes).
- commit 4dc1da1
* Sun Sep  1 2024 ailiop@suse.com
- xfs: Fix missing interval for missing_owner in xfs fsmap
  (git-fixes).
- commit 5448ab5
* Sun Sep  1 2024 ailiop@suse.com
- xfs: use XFS_BUF_DADDR_NULL for daddrs in getfsmap code
  (git-fixes).
- commit 288ad9b
* Sun Sep  1 2024 ailiop@suse.com
- xfs: Fix the owner setting issue for rmap query in xfs fsmap
  (git-fixes).
- commit 49b5eec
* Sun Sep  1 2024 tiwai@suse.de
- usb: cdnsp: fix for Link TRB with TC (git-fixes).
- usb: dwc3: st: add missing depopulate in probe error path
  (git-fixes).
- usb: dwc3: st: fix probed platform device ref count on probe
  error path (git-fixes).
- usb: core: sysfs: Unmerge @usb3_hardware_lpm_attr_group in
  remove_power_attributes() (git-fixes).
- usb: typec: fsa4480: Relax CHIP_ID check (git-fixes).
- usb: dwc3: omap: add missing depopulate in probe error path
  (git-fixes).
- usb: cdnsp: fix incorrect index in cdnsp_get_hw_deq function
  (git-fixes).
- soc: qcom: pmic_glink: Actually communicate when remote goes
  down (git-fixes).
- soc: qcom: cmd-db: Map shared memory as WC, not WB (git-fixes).
- commit 7121142
* Sat Aug 31 2024 lduncan@suse.com
- scsi: sd: usb_storage: uas: Access media prior to querying
  device properties (git-fixes).
- commit b52ca33
* Sat Aug 31 2024 lduncan@suse.com
- blacklist.conf: Remove 2 commits that broke kABI
  Removing two entries for SCSI upstream commits that
  broke the kABI in the previous release. The commits
  in question will be added in separate commits.
- commit d8b4368
* Sat Aug 31 2024 tiwai@suse.de
- dmaengine: dw: Add memory bus width verification (git-fixes).
- dmaengine: dw: Add peripheral bus width verification
  (git-fixes).
- soundwire: stream: fix programming slave ports for non-continous
  port maps (git-fixes).
- commit b7e9784
* Fri Aug 30 2024 mkoutny@suse.com
- Update patches.suse/Bluetooth-HCI-Remove-HCI_AMP-support.patch
  (git-fixes CVE-2024-38620 bsc#1226869).
- Update
  patches.suse/serial-core-Clearing-the-circular-buffer-before-NULLifying-it.patch
  (git-fixes CVE-2024-26998 bsc#1223736).
- Update patches.suse/wifi-mac80211-fix-TTLM-teardown-work.patch
  (jsc#PED-10412 CVE-2024-43848 bsc#1229302).
- commit 6b31cec
* Fri Aug 30 2024 mkoutny@suse.com
- Update
  patches.suse/0001-net-rds-fix-possible-cp-null-dereference.patch
  (git-fixes CVE-2024-35902 bsc#1224496).
- Update
  patches.suse/ASoC-TAS2781-Fix-tasdev_load_calibrated_data.patch
  (git-fixes CVE-2024-42278 bsc#1229403).
- Update
  patches.suse/ASoC-amd-Adjust-error-handling-in-case-of-absent-cod.patch
  (git-fixes CVE-2024-43818 bsc#1229296).
- Update
  patches.suse/ASoC-fsl-fsl_qmc_audio-Check-devm_kasprintf-returned.patch
  (git-fixes CVE-2024-42298 bsc#1229369).
- Update
  patches.suse/Bluetooth-MGMT-Add-error-handling-to-pair_device.patch
  (git-fixes CVE-2024-43884 bsc#1229739).
- Update
  patches.suse/KVM-Always-flush-async-PF-workqueue-when-vCPU-is-bei.patch
  (git-fixes CVE-2024-26976 bsc#1223635).
- Update
  patches.suse/PCI-DPC-Fix-use-after-free-on-concurrent-DPC-and-hot.patch
  (git-fixes CVE-2024-42302 bsc#1229366).
- Update
  patches.suse/PCI-endpoint-Clean-up-error-handling-in-vpci_scan_bu.patch
  (git-fixes CVE-2024-43875 bsc#1229486).
- Update
  patches.suse/PCI-endpoint-pci-epf-test-Make-use-of-cached-epc_fea.patch
  (git-fixes CVE-2024-43824 bsc#1229320).
- Update
  patches.suse/PCI-keystone-Fix-NULL-pointer-dereference-in-case-of.patch
  (git-fixes CVE-2024-43823 bsc#1229303).
- Update
  patches.suse/PCI-rcar-Demote-WARN-to-dev_warn_ratelimited-in-rcar.patch
  (git-fixes CVE-2024-43876 bsc#1229485).
- Update
  patches.suse/RDMA-hns-Fix-soft-lockup-under-heavy-CEQE-load.patch
  (git-fixes CVE-2024-43872 bsc#1229489).
- Update
  patches.suse/RDMA-iwcm-Fix-a-use-after-free-related-to-destroying.patch
  (git-fixes CVE-2024-42285 bsc#1229381).
- Update
  patches.suse/Revert-ALSA-firewire-lib-operate-for-period-elapse-e.patch
  (bsc#1208783 CVE-2024-42274 bsc#1229417).
- Update
  patches.suse/SUNRPC-add-a-missing-rpc_stat-for-TCP-TLS.patch
  (git-fixes CVE-2024-36907 bsc#1225751).
- Update
  patches.suse/bpf-arm64-Fix-trampoline-for-BPF_TRAMP_F_CALL_ORIG.patch
  (git-fixes CVE-2024-43840 bsc#1229344).
- Update
  patches.suse/btrfs-fix-double-inode-unlock-for-direct-IO-sync-wri.patch
  (git-fixes CVE-2024-43885 bsc#1229747).
- Update
  patches.suse/btrfs-fix-extent-map-use-after-free-when-adding-page.patch
  (git-fixes CVE-2024-42314 bsc#1229355).
- Update
  patches.suse/cgroup-cpuset-Prevent-UAF-in-proc_cpuset_show.patch
  (bsc#1228801 CVE-2024-43853 bsc#1229292).
- Update
  patches.suse/crypto-ccp-Fix-null-pointer-dereference-in-__sev_snp.patch
  (git-fixes CVE-2024-43874 bsc#1229487).
- Update
  patches.suse/devres-Fix-memory-leakage-caused-by-driver-API-devm_.patch
  (git-fixes CVE-2024-43871 bsc#1229490).
- Update
  patches.suse/dma-fix-call-order-in-dmam_free_coherent.patch
  (git-fixes CVE-2024-43856 bsc#1229346).
- Update
  patches.suse/drm-admgpu-fix-dereferencing-null-pointer-context.patch
  (stable-fixes CVE-2024-43906 bsc#1229785).
- Update
  patches.suse/drm-amd-display-Add-NULL-check-for-afb-before-derefe.patch
  (stable-fixes CVE-2024-43903 bsc#1229781).
- Update
  patches.suse/drm-amd-display-Add-null-checker-before-passing-vari.patch
  (stable-fixes CVE-2024-43902 bsc#1229767).
- Update
  patches.suse/drm-amd-display-Skip-Recompute-DSC-Params-if-no-Stre.patch
  (stable-fixes CVE-2024-43895 bsc#1229755).
- Update
  patches.suse/drm-amd-pm-Fix-the-null-pointer-dereference-for-vega.patch
  (stable-fixes CVE-2024-43905 bsc#1229784).
- Update
  patches.suse/drm-amdgpu-Fix-the-null-pointer-dereference-to-ras_m.patch
  (stable-fixes CVE-2024-43908 bsc#1229788).
- Update
  patches.suse/drm-amdgpu-pm-Fix-the-null-pointer-dereference-for-s.patch
  (stable-fixes CVE-2024-43909 bsc#1229789).
- Update
  patches.suse/drm-amdgpu-pm-Fix-the-null-pointer-dereference-in-ap.patch
  (stable-fixes CVE-2024-43907 bsc#1229787).
- Update
  patches.suse/drm-client-fix-null-pointer-dereference-in-drm_clien.patch
  (git-fixes CVE-2024-43894 bsc#1229746).
- Update
  patches.suse/drm-gma500-fix-null-pointer-dereference-in-cdv_intel.patch
  (git-fixes CVE-2024-42310 bsc#1229358).
- Update
  patches.suse/drm-gma500-fix-null-pointer-dereference-in-psb_intel.patch
  (git-fixes CVE-2024-42309 bsc#1229359).
- Update
  patches.suse/drm-nouveau-prime-fix-refcount-underflow.patch
  (git-fixes CVE-2024-43867 bsc#1229493).
- Update patches.suse/drm-qxl-Add-check-for-drm_cvt_mode.patch
  (git-fixes CVE-2024-43829 bsc#1229341).
- Update
  patches.suse/drm-vmwgfx-Fix-a-deadlock-in-dma-buf-fence-polling.patch
  (git-fixes CVE-2024-43863 bsc#1229497).
- Update
  patches.suse/exfat-fix-potential-deadlock-on-__exfat_get_dentry_set.patch
  (git-fixes CVE-2024-42315 bsc#1229354).
- Update
  patches.suse/gpio-prevent-potential-speculation-leaks-in-gpio_dev.patch
  (stable-fixes CVE-2024-44931 bsc#1229837).
- Update
  patches.suse/hfs-fix-to-initialize-fields-of-hfs_inode_info-after-hfs_alloc_inode.patch
  (git-fixes CVE-2024-42311 bsc#1229413).
- Update
  patches.suse/iio-Fix-the-sorting-functionality-in-iio_gts_build_a.patch
  (git-fixes CVE-2024-43825 bsc#1229298).
- Update
  patches.suse/jfs-Fix-array-index-out-of-bounds-in-diFree.patch
  (git-fixes CVE-2024-43858 bsc#1229414).
- Update
  patches.suse/jfs-Fix-shift-out-of-bounds-in-dbDiscardAG.patch
  (git-fixes CVE-2024-44938 bsc#1229792).
- Update
  patches.suse/jfs-fix-null-ptr-deref-in-dtInsertEntry.patch
  (git-fixes CVE-2024-44939 bsc#1229820).
- Update
  patches.suse/kobject_uevent-Fix-OOB-access-within-zap_modalias_en.patch
  (git-fixes CVE-2024-42292 bsc#1229373).
- Update
  patches.suse/kvm-s390-Reject-memory-region-operations-for-ucontrol-VMs.patch
  (git-fixes bsc#1229168 CVE-2024-43819 bsc#1229290).
- Update
  patches.suse/leds-trigger-Unregister-sysfs-attributes-before-call.patch
  (git-fixes CVE-2024-43830 bsc#1229305).
- Update
  patches.suse/lib-objagg-Fix-general-protection-fault.patch
  (git-fixes CVE-2024-43846 bsc#1229360).
- Update
  patches.suse/libbpf-Use-OPTS_SET-macro-in-bpf_xdp_query.patch
  (git-fixes CVE-2024-27050 bsc#1223767).
- Update
  patches.suse/mISDN-Fix-a-use-after-free-in-hfcmulti_tx.patch
  (git-fixes CVE-2024-42280 bsc#1229388).
- Update
  patches.suse/mailbox-mtk-cmdq-Move-devm_mbox_controller_register-.patch
  (git-fixes CVE-2024-42319 bsc#1229350).
- Update
  patches.suse/md-raid5-fix-deadlock-that-raid5d-wait-for-itself-to-clear-MD_SB_CHANGE_PENDING-151f.patch
  (git-fixes CVE-2024-39476 bsc#1227437).
- Update
  patches.suse/media-imx-pxp-Fix-ERR_PTR-dereference-in-pxp_probe.patch
  (git-fixes CVE-2024-42303 bsc#1229365).
- Update
  patches.suse/media-pci-ivtv-Add-check-for-DMA-map-result.patch
  (git-fixes CVE-2024-43877 bsc#1229484).
- Update
  patches.suse/media-v4l-async-Fix-NULL-pointer-dereference-in-addi.patch
  (git-fixes CVE-2024-43833 bsc#1229299).
- Update
  patches.suse/media-venus-fix-use-after-free-in-vdec_close.patch
  (git-fixes CVE-2024-42313 bsc#1229356).
- Update
  patches.suse/media-xc2028-avoid-use-after-free-in-load_firmware_c.patch
  (stable-fixes CVE-2024-43900 bsc#1229756).
- Update
  patches.suse/memcg-protect-concurrent-access-to-mem_cgroup_idr.patch
  (git-fixes CVE-2024-43892 bsc#1229761).
- Update
  patches.suse/net-drop-bad-gso-csum_start-and-offset-in-virtio_net.patch
  (git-fixes CVE-2024-43897 bsc#1229752).
- Update
  patches.suse/net-iucv-fix-use-after-free-in-iucv_sock_close.patch
  (bsc#1228973 CVE-2024-42271 bsc#1229400).
- Update patches.suse/net-missing-check-virtio.patch (git-fixes
  CVE-2024-43817 bsc#1229312).
- Update
  patches.suse/net-usb-qmi_wwan-fix-memory-leak-for-not-ip-packets.patch
  (git-fixes CVE-2024-43861 bsc#1229500).
- Update
  patches.suse/nfs-pass-explicit-offset-count-to-trace-events.patch
  (git-fixes CVE-2024-43826 bsc#1229294).
- Update
  patches.suse/nvme-pci-add-missing-condition-check-for-existence-o.patch
  (git-fixes CVE-2024-42276 bsc#1229410).
- Update
  patches.suse/padata-Fix-possible-divide-by-0-panic-in-padata_mt_h.patch
  (git-fixes CVE-2024-43889 bsc#1229743).
- Update
  patches.suse/remoteproc-imx_rproc-Skip-over-memory-region-when-no.patch
  (git-fixes CVE-2024-43860 bsc#1229319).
- Update
  patches.suse/s390-dasd-fix-error-checks-in-dasd_copy_pair_store.patch
  (git-fixes bsc#1229173 CVE-2024-42320 bsc#1229349).
- Update
  patches.suse/scsi-lpfc-Revise-lpfc_prep_embed_io-routine-with-pro.patch
  (bsc#1228857 CVE-2024-43816 bsc#1229318).
- Update
  patches.suse/scsi-qla2xxx-Complete-command-early-within-lock.patch
  (bsc#1228850 CVE-2024-42287 bsc#1229392).
- Update
  patches.suse/scsi-qla2xxx-During-vport-delete-send-async-logout-e.patch
  (bsc#1228850 CVE-2024-42289 bsc#1229399).
- Update
  patches.suse/scsi-qla2xxx-Fix-for-possible-memory-corruption.patch
  (bsc#1228850 CVE-2024-42288 bsc#1229398).
- Update
  patches.suse/scsi-qla2xxx-validate-nvme_local_port-correctly.patch
  (bsc#1228850 CVE-2024-42286 bsc#1229395).
- Update
  patches.suse/serial-core-check-uartclk-for-zero-to-avoid-divide-b.patch
  (stable-fixes CVE-2024-43893 bsc#1229759).
- Update
  patches.suse/soc-qcom-pdr-protect-locator_addr-with-the-main-mute.patch
  (git-fixes CVE-2024-43849 bsc#1229307).
- Update
  patches.suse/soc-xilinx-rename-cpu_number1-to-dummy_cpu_number.patch
  (git-fixes CVE-2024-43851 bsc#1229313).
- Update
  patches.suse/spi-microchip-core-ensure-TX-and-RX-FIFOs-are-empty-.patch
  (git-fixes CVE-2024-42279 bsc#1229390).
- Update
  patches.suse/usb-vhci-hcd-Do-not-drop-references-before-new-refer.patch
  (stable-fixes CVE-2024-43883 bsc#1229707).
- Update
  patches.suse/vhost-vsock-always-initialize-seqpacket_allow.patch
  (git-fixes CVE-2024-43873 bsc#1229488).
- Update
  patches.suse/wifi-ath12k-change-DMA-direction-while-mapping-reinj.patch
  (git-fixes CVE-2024-43881 bsc#1229480).
- Update
  patches.suse/wifi-ath12k-fix-invalid-memory-access-while-processi.patch
  (git-fixes CVE-2024-43847 bsc#1229291).
- Update
  patches.suse/wifi-cfg80211-handle-2x996-RU-allocation-in-cfg80211.patch
  (git-fixes CVE-2024-43879 bsc#1229482).
- Update
  patches.suse/wifi-nl80211-disallow-setting-special-AP-channel-wid.patch
  (stable-fixes CVE-2024-43912 bsc#1229830).
- Update
  patches.suse/wifi-rtw89-Fix-array-index-mistake-in-rtw89_sta_info.patch
  (git-fixes CVE-2024-43842 bsc#1229317).
- Update
  patches.suse/wifi-virt_wifi-avoid-reporting-connection-success-wi.patch
  (git-fixes CVE-2024-43841 bsc#1229304).
- commit 140ec33
* Fri Aug 30 2024 tiwai@suse.de
- soundwire: intel_auxdevice: add hybrid IDA-based device_number
  allocation (jsc#PED-9993 jsc#PED-10202).
- commit 6b2c29c
* Fri Aug 30 2024 tiwai@suse.de
- soundwire: bus: add callbacks for device_number allocation
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/soundwire-bus-introduce-controller_id.patch.
- Refresh patches.suse/soundwire-suse-kabi-padding.patch.
- commit 57520f2
* Fri Aug 30 2024 tiwai@suse.de
- soundwire: bus: Make IRQ handling conditionally built
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel_ace2x: add DAI hw_params/prepare/hw_free
  callbacks (jsc#PED-9993 jsc#PED-10202).
- soundwire: extend parameters of new_peripheral_assigned()
  callback (jsc#PED-9993 jsc#PED-10202).
- soundWire: intel_auxdevice: resume 'sdw-master' on startup
  and system resume (jsc#PED-9993 jsc#PED-10202).
- soundwire: intel_auxdevice: enable pm_runtime earlier on startup
  (jsc#PED-9993 jsc#PED-10202).
- soundwire: Explicitly include correct DT includes (jsc#PED-9993
  jsc#PED-10202).
- soundwire: bus: Allow SoundWire peripherals to register IRQ
  handlers (jsc#PED-9993 jsc#PED-10202).
- commit 1cef7db
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: dwc: Fix non-DT instantiation (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wsa-macro: handle component name prefix
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5682: Fix regulator enable/disable sequence
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: core: Print component name when printing log (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-generic-dmaengine-pcm: Fix function name in comment
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: aw88395: Fix some error codes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-pcm: Shrink stack frame for __soc_pcm_hw_params
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8960: Fix error handling in probe (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rsnd: add missing of_node_put (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: midi: Fix -Wformat-truncation warning (jsc#PED-9993
  jsc#PED-10202).
- ALSA: core: Use dev_name of card_dev as debugfs directory name
  (jsc#PED-9993 jsc#PED-10202).
- commit 678dced
* Fri Aug 30 2024 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_WCD_CLASSH=m (jsc#PED-9993 jsc#PED-10202)
- commit bf5114f
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: rt5645: NULL pointer access when removing jack
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l45: Rename DACPCM1 Source control (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l45: Fix "Dead assigment" warning (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs35l45: Add support for Chip ID 0x35A460 (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: wcd93xx: fix object added to multiple drivers
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: Fix error checks of default read/write copy ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: Name iov_iter argument as iterator instead of buffer
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: dmaengine: Drop unused iov_iter for process callback
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: dwc: i2s: Fix unused functions (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-core.c: Do not error if a DAI link component is not
  found (jsc#PED-9993 jsc#PED-10202).
- ASoC: audio-graph-card.c: move audio_graph_parse_of()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: dwc: i2s: Add StarFive JH7110 SoC support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: dwc: Use ops to get platform data (jsc#PED-9993
  jsc#PED-10202).
- commit 3c6994b
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: rsnd: setup BRGCKR/BRRA/BRRB on rsnd_adg_clk_control()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rsnd: remove default division of clock out (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rsnd: tidyup brga/brgb default value (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rsnd: setup clock-out only when all conditions are right
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rsnd: enable clk_i approximate rate usage (jsc#PED-9993
  jsc#PED-10202).
- ASoC: audio-graph-card2: add comment for format property
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: nau8821: Improve AMIC recording performance (jsc#PED-9993
  jsc#PED-10202).
- ASoC: Delete UDA134x/L3 audio codec (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: pxa: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- commit 95a6f09
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: rt5640: fix typos (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-rt5640-Do-not-disable-enable-IRQ-twice-on-suspe.patch.
- Refresh
  patches.suse/ASoC-rt5640-Revert-Fix-sleep-in-atomic-context.patch.
- commit 938877f
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: rt5682s: Convert to use GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5682: Convert to use GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5668: Convert to use GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5665: Convert to use GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5640: Convert to just use GPIO descriptors (jsc#PED-9993
  jsc#PED-10202).
- commit ffc61a3
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: mediatek: mt7986: support etdm in platform driver
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt7986: add common header (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: tm2_wm5110: parse audio-routing (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: odroid: parse audio-routing (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: midas_wm1811: parse audio-routing (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: aries_wm8994: parse audio-routing (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: odroid: use of_property_present to check for
  property (jsc#PED-9993 jsc#PED-10202).
- ASoC: rockchip: Fix Wvoid-pointer-to-enum-cast warning
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: wm8904: Fix Wvoid-pointer-to-enum-cast warning
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: tlv320aic32x4: Fix Wvoid-pointer-to-enum-cast
  warning (jsc#PED-9993 jsc#PED-10202).
- ASoC: tas5805m: Use devm_kmemdup to replace devm_kmalloc +
  memcpy (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-jack: calling snd_soc_jack_report causes a null
  pointer access (jsc#PED-9993 jsc#PED-10202).
- ASoC: tlv320aic32x4: Fix the divide by zero (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ak4613: Simplify probe() (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-dai.h: remove unused call back functions (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs/hdmi-codec: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs/cx2072x: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs/cs47lxx: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-topology: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- commit 126b638
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: rockchip: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-rockchip-i2s-tdm-Fix-inaccurate-sampling-rates.patch.
- commit 269ee55
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: meson: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-meson-spdifin-start-hw-on-dai-probe.patch.
- commit 152318d
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: amd: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ASoC-amd-acp-remove-i2s-configuration-check-in-acp_i.patch.
- commit 0dec43f
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: codecs/wm*: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: hisilicon: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: uniphier: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: samsung: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cirrus: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: jz4740: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: intel: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: atmel: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: tegra: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: sunxi: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ux500: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: au1x: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rsnd: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: pxa: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: stm: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sti: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sof: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: img: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: bcm: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: pxa: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: dwc: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: adi: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- commit 5a7ffea
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: adi: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: ti: merge DAI call back functions into ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-dai.h: merge DAI call back functions into ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt715: Drop GPIO includes (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5682-sdw: Drop GPIO includes (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5660: Drop GPIO includes (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5659: Drop legacy GPIO include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5645: Drop legacy GPIO include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5514: Drop GPIO include (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5514-spi: Drop GPIO include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt1308: Drop GPIO includes (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt1305: Drop GPIO includes (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt1019: Drop GPIO include (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt1016: Drop GPIO include (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt1015p: Drop legacy GPIO include (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt1015: Drop GPIO include (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt1011: Drop GPIO includes (jsc#PED-9993 jsc#PED-10202).
- ASoC: ssm3515: Remove redundant of_match_ptr() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sunxi: sun4i-spdif: Remove redundant of_match_ptr()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: atmel: tse850-pcm5142: Remove redundant of_match_ptr()
  (jsc#PED-9993 jsc#PED-10202).
- commit bdb3b5a
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: atmel: Remove redundant of_match_ptr() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cygnus: Remove unused declarations (jsc#PED-9993
  jsc#PED-10202).
- ASoC: q6dsp: Remove unused declaration (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt715: Add software reset in io init (jsc#PED-9993
  jsc#PED-10202).
- ASoC: samsung: midas_wm1811: Fix 'Headphone Switch' control
  creation (jsc#PED-9993 jsc#PED-10202).
- ASoC: rsnd: call of_node_put() when break (jsc#PED-9993
  jsc#PED-10202).
- ASoC: pxa: address unused variable warning (jsc#PED-9993
  jsc#PED-10202).
- ASoC: imx-audio-rpmsg: Remove redundant initialization owner
  in imx_audio_rpmsg_driver (jsc#PED-9993 jsc#PED-10202).
- ASoC: samsung: midas_wm1811: Map missing jack kcontrols
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: samsung: lowland: Split Line Out jack kcontrol from
  Headphone (jsc#PED-9993 jsc#PED-10202).
- ASoC: samsung: littlemill: Map missing jack kcontrols
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rockchip: rockchip_rt5645: Map missing jack kcontrols
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rk3399-gru-sound: Map missing Line Out jack kcontrol
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: sdm845: Map missing jack kcontrols (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: sc7280: Map missing jack kcontrols (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: sc7180: Map missing jack kcontrols (jsc#PED-9993
  jsc#PED-10202).
- ASoC: qcom: apq8016_sbc: Map missing jack kcontrols
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8186-mt6366-da7219-max98357: Map missing
  jack kcontrols (jsc#PED-9993 jsc#PED-10202).
- commit d22636a
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: mediatek: mt8183-mt6358-ts3a227-max98357: Map missing
  jack kcontrols (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8183-da7219-max98357: Map missing jack
  kcontrols (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8173-rt5650: Map missing jack kcontrols
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8173-rt5650-rt5676: Map missing jack kcontrols
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8173-rt5650-rt5514: Map missing jack kcontrols
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8173-max98090: Configure jack as a Headset
  jack (jsc#PED-9993 jsc#PED-10202).
- ASoC: imx-es8328: Map missing jack kcontrols (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: Add code for bin parsing compatible with aw88261
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: max98373-sdw: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- commit ac1ae66
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: rt1308-sdw: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- commit f43c4a3
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: max98363: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5682-sdw: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt1318-sdw: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt1316-sdw: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt715-sdca: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt715: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt712-sdca-dmic: enable pm_runtime in probe, keep status
  as 'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt1712-sdca: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt700: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt711-sdca: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt711: enable pm_runtime in probe, keep status as
  'suspended' (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5682-sdw: make regmap cache-only in probe (jsc#PED-9993
  jsc#PED-10202).
- ASoC: SoundWire codecs: make regmap cache-only in probe
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: SoundWire codecs: return error status in probe
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: jz4740: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: max9892x: Reformat to coding style (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: max9892x: Unify interleave mode OF property
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: davinci-evm: simplify the code with
  module_platform_driver (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8960: Add support for the power supplies (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: mt8186: Remove unused mutex (jsc#PED-9993
  jsc#PED-10202).
- ASoC: fsl_micfil: Use SET_SYSTEM_SLEEP_PM_OPS to simplify PM
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl_micfil: Add fsl_micfil_use_verid function
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl_micfil: Add new registers and new bit definition
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-acpi: improve log messagesin link_slaves_found()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8960: Make automatic the default clocking mode
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8960: Read initial MCLK rate from clock API
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rsnd: enable multi Component support for Audio Graph
  Card/Card2 (jsc#PED-9993 jsc#PED-10202).
- ASoC: rsnd: cleanup rsnd_dai_of_node() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rsnd: use DAI driver ID instead of DAI ID (jsc#PED-9993
  jsc#PED-10202).
- commit 5fb5dde
* Fri Aug 30 2024 vkarasulli@suse.de
- iommu/amd: Convert comma to semicolon (git-fixes).
- commit 2714d8b
* Fri Aug 30 2024 lduncan@suse.com
- scsi: lpfc: Fix a possible null pointer dereference (bsc#1229315
  CVE-2024-43821).
- commit eb73e94
* Fri Aug 30 2024 vkarasulli@suse.de
- iommu/vt-d: Fix identity map bounds in si_domain_init()
  (git-fixes).
- commit b4d27e5
* Fri Aug 30 2024 tiwai@suse.de
- Update config files: CONFIG_SND_SOC_RT1017_SDCA_SDW=m (jsc#PED-9993
  jsc#PED-10202)
- commit eb0aada
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: fsl_micfil: refactor deprecated strncpy (jsc#PED-9993
  jsc#PED-10202).
- ASoC: 88pm860x: refactor deprecated strncpy (jsc#PED-9993
  jsc#PED-10202).
- ASoC: sti-sas: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: stac9766: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: sta529: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: sta350: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: sta32x: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt1017: Remove unused function (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt1316: fix key tone missing (jsc#PED-9993 jsc#PED-10202).
- commit 75ad411
* Fri Aug 30 2024 vkarasulli@suse.de
- iommufd/device: Fix hwpt at err_unresv in
  iommufd_device_do_replace() (git-fixes).
- commit bbc9a65
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: dmaengine: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- Refresh
  patches.suse/ALSA-dmaengine-Synchronize-dma-channel-after-drop.patch.
- commit 231e587
* Fri Aug 30 2024 tiwai@suse.de
- ALSA: xen: Fix -Wformat-truncation warning (jsc#PED-9993
  jsc#PED-10202).
- ALSA: sb: Fix wrong argument in commented code (jsc#PED-9993
  jsc#PED-10202).
- ASoC: cs42l51: change cs42l51_of_match to static (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt1017: Add RT1017 SDCA amplifier driver (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: ES8326: Update jact detection function
  (jsc#PED-9993 jsc#PED-10202).
- ASOC: codecs: ES8326: Add calibration support for version_b
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Fix power-up sequence (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: ES8326: Change Volatile Reg function (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: ES8326: Change Hp_detect register names
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-dai: don't call PCM audio ops if the stream is not
  supported (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: Drop obsoleted PCM copy_user and copy_kernel ops
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: pcm: Drop obsoleted PCM copy_user ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: dmaengine: Use iov_iter for process callback, too
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: qcom: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ASoC: component: Add generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: xen: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: sh: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: rme9652: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: hdsp: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: rme96: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: rme32: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: nm256: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: korg1212: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: es1938: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: emu8000: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: gus: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: dummy: Convert to generic PCM copy ops (jsc#PED-9993
  jsc#PED-10202).
- ALSA: core: Add memory copy helpers between iov_iter and iomem
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: Add copy ops with iov_iter (jsc#PED-9993
  jsc#PED-10202).
- ALSA: core: Drop snd_device_initialize() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: seq: Create device with snd_device_alloc() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: timer: Create device with snd_device_alloc() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: compress: Don't embed device (jsc#PED-9993 jsc#PED-10202).
- ALSA: rawmidi: Don't embed device (jsc#PED-9993 jsc#PED-10202).
- ALSA: hwdep: Don't embed device (jsc#PED-9993 jsc#PED-10202).
- ALSA: pcm: Don't embed device (jsc#PED-9993 jsc#PED-10202).
- ALSA: control: Don't embed ctl_dev (jsc#PED-9993 jsc#PED-10202).
- ALSA: core: Introduce snd_device_alloc() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: xen-front: refactor deprecated strncpy (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: lpass: Log clk_get() failures (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wm8960: Add DAC filter characteristics selection
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: msm8916-wcd-analog: Properly handle probe errors
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: msm8916-wcd-analog: Drop invalid mclk
  (jsc#PED-9993 jsc#PED-10202).
- commit 490299c
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: ti: omap-mcbsp: Ignore errors for getting fck_src
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-ti-omap-mcbsp-Fix-runtime-PM-underflow-warnings.patch.
- commit 26b90d6
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: fsl_spdif: Add support for 22.05 kHz sample rate
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8188: DPCM used FE and BE merged parameters
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm9713: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm9712: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm9705: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8988: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8985: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8983: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- commit 133853a
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: wm8978: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8971: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8955: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8940: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8996: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8995: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8993: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8991: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8962: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8961: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8960: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8904: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8903: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8900: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8804: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8776: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8770: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8753: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8750: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8741: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8737: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8731: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8728: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8711: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8580: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8523: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm8510: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm9090: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm9081: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm5100: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wm2200: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs4349: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42xx8: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l56: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l52: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs4270: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs4265: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs42l51: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l45: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: cs35l36: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- commit af28055
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: simple-card.c: enable multi Component support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: simple-card-utils.c: enable multi Component support
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-core.c: add snd_soc_copy_dai_args() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-core.c: add snd_soc_dlc_use_cpu_as_platform()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-core.c: add snd_soc_get_dai_via_args() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-core.c: enable multi Component (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-dai.c: add DAI get/match functions (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codec: wm8960: add additional probe check for codec
  identification (jsc#PED-9993 jsc#PED-10202).
- ASoC: fsl_rpmsg: Add support for i.MX93 platform (jsc#PED-9993
  jsc#PED-10202).
- ASoC: wsa883x: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wsa881x: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wcd938x: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: wcd9335: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: tegra: tegra20_ac97: Use
  devm_platform_get_and_ioremap_resource() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: pxa: Use devm_platform_get_and_ioremap_resource()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: mediatek: mt8186: Convert to
  devm_platform_ioremap_resource() (jsc#PED-9993 jsc#PED-10202).
- ASoC: ti: Convert to devm_platform_ioremap_resource_byname()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: bcm: bcm63xx-i2s-whistler: Convert to
  devm_platform_ioremap_resource() (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: ES8326: Add es8326_mute function (jsc#PED-9993
  jsc#PED-10202).
- ASoC: adav80x: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: adau7118: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: adau1977: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: adau1781: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: adau1761: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: adau1701: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: adau1373: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: adau1372: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ad1980: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: ad1836: Update to use maple tree register cache
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: q6dsp: q6apm: make g_apm static (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5677: Sort headers alphabetically (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5677: Use device_get_match_data() (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt5677: Use agnostic irq_domain_create_linear()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5677: Refactor GPIO support code (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: mt8188: add memory-region support (jsc#PED-9993
  jsc#PED-10202).
- ASoC: codecs: es8316: Add support for S24_3LE format
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: codecs: es8316: Add support for 24 MHz MCLK (jsc#PED-9993
  jsc#PED-10202).
- commit 6e0117f
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: rt5645: add the system level suspend-resume callback
  (jsc#PED-9993 jsc#PED-10202).
- Refresh
  patches.suse/ASoC-rt5645-Fix-the-electric-noise-due-to-the-CBJ-co.patch.
- commit 455a70c
* Fri Aug 30 2024 tiwai@suse.de
- ASoC: dwc: Add TDM mode support (jsc#PED-9993 jsc#PED-10202).
- ASoC: tas2781: No need to set device_driver owner (jsc#PED-9993
  jsc#PED-10202).
- ASoC: rt722-sdca: Remove redundant sdca mask (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-core: protect dlc->of_node under mutex (jsc#PED-9993
  jsc#PED-10202).
- ASoC: imx-pcm-rpmsg: Set PCM hardware parameters separately
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: rt5645: implement set_jack callback (jsc#PED-9993
  jsc#PED-10202).
- ASoC: soc-core.c: cleanup soc_dai_link_sanity_check()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: soc-core.c: initialize dlc on snd_soc_get_dai_id()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: vmaster: Add snd_ctl_add_followers() helper (jsc#PED-9993
  jsc#PED-10202).
- ASoC: mediatek: mt8188: Simplify with snd_ctl_find_id_mixer()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: control: Introduce snd_ctl_find_id_mixer() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: control: Take lock in snd_ctl_find_id() and
  snd_ctl_find_numid() (jsc#PED-9993 jsc#PED-10202).
- ALSA: control: Introduce unlocked version for snd_ctl_find_*()
  helpers (jsc#PED-9993 jsc#PED-10202).
- ALSA: control: Make snd_ctl_find_id() argument const
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: sigmadsp: Simplify with snd_ctl_activate_id()
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: control: Add lockdep warning to internal functions
  (jsc#PED-9993 jsc#PED-10202).
- ALSA: control: Take controls_rwsem lock in snd_ctl_remove()
  (jsc#PED-9993 jsc#PED-10202).
- ASoC: atmel: mchp-pdmc: Use snd_ctl_remove_id() (jsc#PED-9993
  jsc#PED-10202).
- ALSA: control: Take card->controls_rwsem in snd_ctl_rename()
  (jsc#PED-9993 jsc#PED-10202).
- commit f22a438
* Fri Aug 30 2024 tiwai@suse.de
- i2c: i801: Add support for Intel Arrow Lake-H (jsc#PED-10247).
- commit b1771c7
* Fri Aug 30 2024 tiwai@suse.de
- Update patch reference for Intel PMC patch (jsc#PED-10192)
- commit 8d1db2d
* Fri Aug 30 2024 lhenriques@suse.de
- blacklist.conf: add 053fc4f755ad fuse: fix UAF in rcu pathwalks
  This commit breaks kABI and the data structure has no free room for the
  extra field, i.e. memcpy would fail to copy the additional member added by
  this patch.
- commit 941b81c
* Fri Aug 30 2024 lhenriques@suse.de
- virtiofs: forbid newlines in tags (bsc#1229942).
- fuse: fix UAF in rcu pathwalks (bsc#1229941).
- commit 2ea5064
* Fri Aug 30 2024 lhenriques@suse.de
- virtiofs: forbid newlines in tags (bsc#1229940).
- commit 61514ce
* Fri Aug 30 2024 petr.pavlu@suse.com
- trace/pid_list: Change gfp flags in pid_list_fill_irq()
  (git-fixes).
- commit 88d1dac
* Fri Aug 30 2024 petr.pavlu@suse.com
- blacklist.conf: add a not-relevant tracing commit
- commit 9e3013e
* Fri Aug 30 2024 ailiop@suse.com
- evm: don't copy up 'security.evm' xattr (git-fixes).
- commit d3bb5af
* Fri Aug 30 2024 ailiop@suse.com
- afs: fix __afs_break_callback() / afs_drop_open_mmap() race
  (git-fixes).
- commit 150e615
* Fri Aug 30 2024 ailiop@suse.com
- jfs: define xtree root and page independently (git-fixes).
- commit fc62e49
* Fri Aug 30 2024 ailiop@suse.com
- kernfs: fix false-positive WARN(nr_mmapped) in
  kernfs_drain_open_files (git-fixes).
- commit 7fa46d1
* Fri Aug 30 2024 ailiop@suse.com
- gfs2: setattr_chown: Add missing initialization (git-fixes).
- commit 9b6ef3b
* Fri Aug 30 2024 tiwai@suse.de
- ACPI: EC: Evaluate _REG outside the EC scope more carefully
  (git-fixes).
- ACPICA: Add a depth argument to acpi_execute_reg_methods()
  (stable-fixes).
- Revert "ACPI: EC: Evaluate orphan _REG under EC device"
  (stable-fixes).
- commit 3e803e9
* Fri Aug 30 2024 tiwai@suse.de
- wifi: rtw89: pci: fix RX tag race condition resulting in wrong
  RX length (stable-fixes).
- wifi: ath12k: fix race due to setting
  ATH12K_FLAG_EXT_IRQ_ENABLED too early (stable-fixes).
- wifi: rtlwifi: handle return value of usb init TX/RX
  (stable-fixes).
- ALSA: hda: beep: Drop stale mutex (git-fixes).
- commit a5a55ef
* Fri Aug 30 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: allow 6 GHz channels in MLO scan
  (git-fixes).
- wifi: iwlwifi: mvm: take the mutex before running link selection
  (git-fixes).
- commit a430bfe
* Fri Aug 30 2024 tiwai@suse.de
- nfc: pn533: Add poll mod list filling check (git-fixes).
- wifi: wfx: repair open network AP mode (git-fixes).
- wifi: iwlwifi: fw: fix wgds rev 3 exact size (git-fixes).
- wifi: mwifiex: duplicate static structs used in driver instances
  (git-fixes).
- Input: i8042 - use new forcenorestore quirk to replace old
  buggy quirk combination (stable-fixes).
- Input: i8042 - add forcenorestore quirk to leave controller
  untouched even on s3 (stable-fixes).
- platform/surface: aggregator: Fix warning when controller is
  destroyed in probe (git-fixes).
- thunderbolt: Mark XDomain as unplugged when router is removed
  (stable-fixes).
- Input: MT - limit max slots (stable-fixes).
- usb: dwc3: core: Skip setting event buffers for host only
  controllers (stable-fixes).
- platform/x86: lg-laptop: fix %%s null argument warning
  (stable-fixes).
- rtc: nct3018y: fix possible NULL dereference (stable-fixes).
- usb: gadget: fsl: Increase size of name buffer for endpoints
  (stable-fixes).
- media: drivers/media/dvb-core: copy user arrays safely
  (stable-fixes).
- media: pci: cx23885: check cx23885_vdev_init() return
  (stable-fixes).
- memory: stm32-fmc2-ebi: check regmap_read return value
  (stable-fixes).
- memory: tegra: Skip SID programming if SID registers aren't set
  (stable-fixes).
- Revert "usb: gadget: uvc: cleanup request when not in correct
  state" (stable-fixes).
- usb: gadget: uvc: cleanup request when not in correct state
  (stable-fixes).
- staging: ks7010: disable bh on tx_dev_lock (stable-fixes).
- staging: iio: resolver: ad2s1210: fix use before initialization
  (stable-fixes).
- ssb: Fix division by zero issue in ssb_calc_clock_rate
  (stable-fixes).
- commit b84d799
* Fri Aug 30 2024 tiwai@suse.de
- drm/vmwgfx: Fix prime with external buffers (git-fixes).
- drm/i915/dsi: Make Lenovo Yoga Tab 3 X90F DMI match less strict
  (git-fixes).
- drm/amd/display: avoid using null object of framebuffer
  (git-fixes).
- Bluetooth: hci_core: Fix not handling hibernation actions
  (git-fixes).
- drm/amdgpu: Validate TA binary size (stable-fixes).
- drm/msm/dpu: take plane rotation into account for wide planes
  (git-fixes).
- drm/msm/dpu: move dpu_encoder's connector assignment to
  atomic_enable() (git-fixes).
- char: xillybus: Refine workqueue handling (git-fixes).
- char: xillybus: Don't destroy workqueue from work item running
  on it (stable-fixes).
- drm/amdgpu: Actually check flags for all context ops
  (stable-fixes).
- drm/amdgpu/jpeg4: properly set atomics vmid field
  (stable-fixes).
- drm/amdgpu/jpeg2: properly set atomics vmid field
  (stable-fixes).
- drm/amd/display: fix s2idle entry for DCN3.5+ (stable-fixes).
- drm/amdgpu: fix dereference null return value for the function
  amdgpu_vm_pt_parent (stable-fixes).
- hwmon: (ltc2992) Fix memory leak in ltc2992_parse_dt()
  (git-fixes).
- firmware: cirrus: cs_dsp: Initialize debugfs_root to invalid
  (stable-fixes).
- drm/msm/dpu: capture snapshot on the first commit_done timeout
  (stable-fixes).
- drm/msm/dpu: split dpu_encoder_wait_for_event into two functions
  (stable-fixes).
- drm/lima: set gp bus_stop bit before hard reset (stable-fixes).
- drm/panel: nt36523: Set 120Hz fps for xiaomi,elish panels
  (stable-fixes).
- gpio: sysfs: extend the critical section for unregistering
  sysfs devices (stable-fixes).
- Bluetooth: bnep: Fix out-of-bound access (stable-fixes).
- hwmon: (pc87360) Bounds check data->innr usage (stable-fixes).
- ASoC: SOF: ipc4: check return value of snd_sof_ipc_msg_data
  (stable-fixes).
- drm/msm/dpu: drop MSM_ENC_VBLANK support (stable-fixes).
- drm/msm/dpu: use drmm-managed allocation for dpu_encoder_phys
  (stable-fixes).
- drm/msm/mdss: Rename path references to mdp_path (stable-fixes).
- drm/msm/mdss: switch mdss to use devm_of_icc_get()
  (stable-fixes).
- drm/msm/dpu: try multirect based on mdp clock limits
  (stable-fixes).
- drm/msm: Reduce fallout of fence signaling vs reclaim hangs
  (stable-fixes).
- drm/rockchip: vop2: clear afbc en and transform bit for cluster
  window at linear mode (stable-fixes).
- Bluetooth: hci_conn: Check non NULL function before calling
  for HFP offload (stable-fixes).
- i2c: stm32f7: Add atomic_xfer method to driver (stable-fixes).
- i2c: riic: avoid potential division by zero (stable-fixes).
- i3c: mipi-i3c-hci: Do not unmap region not mapped for transfer
  (stable-fixes).
- i3c: mipi-i3c-hci: Remove BUG() when Ring Abort request times
  out (stable-fixes).
- ASoC: SOF: Intel: hda-dsp: Make sure that no irq handler is
  pending before suspend (stable-fixes).
- ASoC: cs35l45: Checks index of cs35l45_irqs[] (stable-fixes).
- clk: visconti: Add bounds-checking coverage for struct
  visconti_pll_provider (stable-fixes).
- hwmon: (ltc2992) Avoid division by zero (stable-fixes).
- commit 1b92ddd
* Thu Aug 29 2024 petr.pavlu@suse.com
- jump_label: Fix the fix, brown paper bags galore (git-fixes).
- commit 89b2827
* Thu Aug 29 2024 petr.pavlu@suse.com
- jump_label: Simplify and clarify
  static_key_fast_inc_cpus_locked() (git-fixes).
- commit 954eaa3
* Thu Aug 29 2024 petr.pavlu@suse.com
- jump_label: Clarify condition in
  static_key_fast_inc_not_disabled() (git-fixes).
- commit eb457dc
* Thu Aug 29 2024 petr.pavlu@suse.com
- jump_label: Fix concurrency issues in static_key_slow_dec()
  (git-fixes).
- commit 6e92a06
* Thu Aug 29 2024 petr.pavlu@suse.com
- tracing: Return from tracing_buffers_read() if the file has
  been closed (bsc#1229136 git-fixes).
- commit 8dc8510
* Thu Aug 29 2024 petr.pavlu@suse.com
- kprobes: Fix to check symbol prefixes correctly (git-fixes).
- commit e8b168b
* Thu Aug 29 2024 petr.pavlu@suse.com
- kprobes: Prohibit probing on CFI preamble symbol (git-fixes).
- commit 2f9e2b1
* Thu Aug 29 2024 petr.pavlu@suse.com
- bpf: kprobe: remove unused declaring of bpf_kprobe_override
  (git-fixes).
- commit 4045c94
* Thu Aug 29 2024 tiwai@suse.de
- Update patch reference for wireless fix (CVE-2024-43911 bsc#1229827)
- commit c8f695c
* Thu Aug 29 2024 tiwai@suse.de
- wifi: mac80211: fix NULL dereference at band check in starting
  tx ba session (CVE-2024-43911 bsc#1229827).
- commit 0892b94
* Thu Aug 29 2024 tiwai@suse.de
- Correct patches.suse/wifi-mac80211-reset-negotiated-TTLM-on-disconnect.patch (jsc#PED-10412)
- commit 7377f47
* Thu Aug 29 2024 tiwai@suse.de
- blacklist.conf: add superfluous iwlwifi entry (jsc#PED-10412)
- commit 3939f4b
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: always unblock EMLSR on ROC end
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: separate non-BSS/ROC EMLSR blocking
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: fix re-enabling EMLSR (jsc#PED-10412).
- wifi: mac80211: cancel TTLM teardown work earlier
  (jsc#PED-10412).
- wifi: mac80211: fix TTLM teardown work (jsc#PED-10412).
- wifi: iwlwifi: mvm: don't skip link selection (jsc#PED-10412).
- commit da7fdb7
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: check vif for NULL/ERR_PTR before
  dereference (jsc#PED-10412).
- wifi: iwlwifi: mvm: avoid link lookup in statistics
  (jsc#PED-10412).
- wifi: iwlwifi: scan: correctly check if PSC listen period is
  needed (jsc#PED-10412).
- wifi: iwlwifi: mvm: unlock mvm mutex (jsc#PED-10412).
- wifi: iwlwifi: mvm: always set the TWT IE offset
  (jsc#PED-10412).
- wifi: iwlwifi: Ensure prph_mac dump includes all addresses
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: don't request statistics in restart
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: exit EMLSR if secondary link is not used
  (jsc#PED-10412).
- commit 1f0b706
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: align UATS naming with firmware
  (jsc#PED-10412).
- Refresh
  patches.suse/wifi-iwlwifi-mvm-don-t-limit-VLP-AFC-to-UATS-enabled.patch.
- commit 1753282
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: add beacon template version 14
  (jsc#PED-10412).
- wifi: iwlwifi: Force SCU_ACTIVE for specific platforms
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: record and return channel survey information
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: add the firmware API for channel survey
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: Fix race in scan completion (jsc#PED-10412).
- wifi: iwlwifi: mvm: Add a print for invalid link pair due to
  bandwidth (jsc#PED-10412).
- wifi: iwlwifi: mvm: add a debugfs for reading EMLSR blocking
  reasons (jsc#PED-10412).
- wifi: iwlwifi: mvm: Add active EMLSR blocking reasons prints
  (jsc#PED-10412).
- wifi: iwlwifi: bump FW API to 90 for BZ/SC devices
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: fix primary link setting (jsc#PED-10412).
- commit df80d8b
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: use already determined cmd_id
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: don't reset link selection during restart
  (jsc#PED-10412).
- wifi: iwlwifi: Print EMLSR states name (jsc#PED-10412).
- wifi: iwlwifi: mvm: Block EMLSR when a p2p/softAP vif is active
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: fix typo in debug print (jsc#PED-10412).
- wifi: iwlwifi: mvm: exit EMLSR when CSA happens (jsc#PED-10412).
- wifi: iwlwifi: mvm: Disable/enable EMLSR due to link's
  bandwidth/band (jsc#PED-10412).
- wifi: iwlwifi: mvm: avoid always prefering single-link
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: trigger link selection upon TTLM start/end
  (jsc#PED-10412).
- commit 2ffd281
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: consider FWs recommendation for EMLSR
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: Activate EMLSR based on traffic volume
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: don't always unblock EMLSR (jsc#PED-10412).
- wifi: iwlwifi: mvm: Always allow entering EMLSR from debugfs
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: add a debugfs for (un)blocking EMLSR
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: trigger link selection after exiting EMLSR
  (jsc#PED-10412).
- wifi: iwlwifi: cleanup EMLSR when BT is active handling
  (jsc#PED-10412).
- wifi: mac80211: handle color change per link (jsc#PED-10412).
- wifi: cfg80211: handle color change per link (jsc#PED-10412).
- wifi: cfg80211: Clear mlo_links info when STA disconnects
  (jsc#PED-10412).
- wifi: iwlwifi: pcie: allocate dummy net_device dynamically
  (jsc#PED-10412).
- wifi: mac80211: handle link ID during management Tx
  (jsc#PED-10412).
- wifi: mac80211: handle sdata->u.ap.active flag with MLO
  (jsc#PED-10412).
- wifi: cfg80211: add return docs for regulatory functions
  (jsc#PED-10412).
- wifi: cfg80211: make some regulatory functions void
  (jsc#PED-10412).
- wifi: mac80211: add return docs for sta_info_flush()
  (jsc#PED-10412).
- wifi: mac80211: keep mac80211 consistent on link activation
  failure (jsc#PED-10412).
- wifi: mac80211: simplify ieee80211_assign_link_chanctx()
  (jsc#PED-10412).
- wifi: mac80211: reserve chanctx during find (jsc#PED-10412).
- wifi: iwlwifi: mvm: Don't allow EMLSR when the RSSI is low
  (jsc#PED-10412).
- net: create a dummy net_device allocator (jsc#PED-10412).
- net: Do not return value from init_dummy_netdev()
  (jsc#PED-10412).
- commit 8be7f22
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: disable EMLSR when we suspend with wowlan
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: get periodic statistics in EMLSR
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: don't recompute EMLSR mode in
  can_activate_links (jsc#PED-10412).
- wifi: iwlwifi: mvm: implement EMLSR prevention mechanism
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: exit EMLSR upon missed beacon
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: Add helper functions to update EMLSR status
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: Implement new link selection algorithm
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: move EMLSR/links code (jsc#PED-10412).
- wifi: iwlwifi: mvm: check if EMLSR is allowed before selecting
  links (jsc#PED-10412).
- wifi: iwlwifi: mvm: implement link grading (jsc#PED-10412).
- commit 19d9522
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: send ap_tx_power_constraints cmd to FW in
  AP mode (jsc#PED-10412).
- wifi: iwlwifi: Add support for LARI_CONFIG_CHANGE_CMD v10
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: Add support for PPAG cmd v6 (jsc#PED-10412).
- wifi: iwlwifi: move lari_config handlig to regulatory
  (jsc#PED-10412).
- wifi: iwlwifi: add a device ID for BZ-W (jsc#PED-10412).
- wifi: iwlwifi: move WTAS macro to api file (jsc#PED-10412).
- wifi: iwlwifi: mvm: extend STEP URM workaround for new devices
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: move phy band to nl80211 band helper
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: Refactor tracking of scan UIDs
  (jsc#PED-10412).
- wifi: mac80211: defer link switch work in reconfig
  (jsc#PED-10412).
- commit b72dfce
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: set wider BW OFDMA ignore correctly
  (jsc#PED-10412).
- commit 95cf0f9
* Thu Aug 29 2024 tiwai@suse.de
- wifi: mac80211: extend IEEE80211_KEY_FLAG_GENERATE_MMIE to
  other ciphers (jsc#PED-10412).
- wifi: mac80211: correctly document struct mesh_table
  (jsc#PED-10412).
- wifi: mac80211: use kvcalloc() for codel vars (jsc#PED-10412).
- wifi: iwlwifi: mvm: don't change BA sessions during restart
  (jsc#PED-10412).
- wifi: iwlwifi: Add support for LARI_CONFIG_CHANGE_CMD cmd v9
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: Declare HE/EHT capabilities support for
  P2P interfaces (jsc#PED-10412).
- wifi: iwlwifi: mvm: Remove outdated comment (jsc#PED-10412).
- wifi: iwlwifi: add support for BZ_W (jsc#PED-10412).
- wifi: iwlwifi: Print a specific device name (jsc#PED-10412).
- commit 5b94c91
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: remove wrong CRF_IDs (jsc#PED-10412).
- wifi: iwlwifi: remove devices that never came out
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: mark EMLSR disabled in cleanup iterator
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: assign link STA ID lookups during restart
  (jsc#PED-10412).
- wifi: mac80211: reactivate multi-link later in restart
  (jsc#PED-10412).
- wifi: mac80211: improve drop for action frame return
  (jsc#PED-10412).
- wifi: mac80211: don't ask driver about no-op link changes
  (jsc#PED-10412).
- wifi: mac80211: clarify IEEE80211_STATUS_SUBDATA_MASK
  (jsc#PED-10412).
- wifi: mac80211: don't enter idle during link switch
  (jsc#PED-10412).
- wifi: iwlwifi: enable monitor on passive/inactive channels
  (jsc#PED-10412).
- commit e223e3a
* Thu Aug 29 2024 andrea.porta@suse.com
- syscalls: fix compat_sys_io_pgetevents_time64 usage (git-fixes).
- commit b90dd07
* Thu Aug 29 2024 tiwai@suse.de
- wifi: mac80211: add support for tearing down negotiated TTLM
  (jsc#PED-10412).
- Refresh
  patches.suse/wifi-mac80211-cancel-multi-link-reconf-work-on-disco.patch.
- commit c7ae2fe
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: remove 6 GHz NVM override (jsc#PED-10412).
- wifi: iwlwifi: mvm: don't support puncturing in 5 GHz
  (jsc#PED-10412).
- wifi: iwlwifi: fw: add clarifying comments about
  iwl_fwrt_dump_data (jsc#PED-10412).
- wifi: iwlwifi: mvm: always apply 6 GHz probe limitations
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: add debugfs for forcing unprotected ranging
  request (jsc#PED-10412).
- wifi: iwlwifi: mvm: Add debugfs entry for triggering internal
  MLO scan (jsc#PED-10412).
- wifi: iwlwifi: mvm: Introduce internal MLO passive scan
  (jsc#PED-10412).
- wifi: cfg80211: check BSSID Index against MaxBSSID
  (jsc#PED-10412).
- commit cee31f5
* Thu Aug 29 2024 tiwai@suse.de
- wifi: mac80211: handle indoor AFC/LPI AP on assoc success
  (jsc#PED-10412).
- commit ae296f4
* Thu Aug 29 2024 tiwai@suse.de
- wifi: mac80211: improve association error reporting slightly
  (jsc#PED-10412).
- wifi: mac80211: add flag to disallow puncturing in 5 GHz
  (jsc#PED-10412).
- wifi: cfg80211: handle indoor AFC/LPI AP in probe response
  and beacon (jsc#PED-10412).
- wifi: nl80211: cleanup nl80211.h kernel-doc (jsc#PED-10412).
- wifi: nl80211: fix nl80211 uapi comment style issues
  (jsc#PED-10412).
- wifi: nl80211: rename enum plink_actions (jsc#PED-10412).
- wifi: mac80211: spectmgmt: simplify 6 GHz HE/EHT handling
  (jsc#PED-10412).
- wifi: mac80211: supplement parsing of puncturing bitmap
  (jsc#PED-10412).
- wifi: iwlwifi: pcie: remove duplicate PCI IDs entry
  (jsc#PED-10412).
- commit ac19b77
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: Move beacon filtering to be per link
  (jsc#PED-10412).
- Refresh
  patches.suse/wifi-iwlwifi-mvm-introduce-esr_disable_reason.patch.
- commit 1805226
* Thu Aug 29 2024 tiwai@suse.de
- wifi: iwlwifi: mvm: Refactor scan start (jsc#PED-10412).
- wifi: iwlwifi: mvm: advertise IEEE80211_HW_HANDLES_QUIET_CSA
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: fix flushing during quiet CSA
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: support wowlan notif version 4
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: skip keys of other links (jsc#PED-10412).
- wifi: iwlwifi: mvm: stop assuming sta id 0 in d3
  (jsc#PED-10412).
- wifi: iwlwifi: mvm: fix the sta id in offload (jsc#PED-10412).
- wifi: iwlwifi: fix firmware API kernel doc (jsc#PED-10412).
- commit b395b4f
* Thu Aug 29 2024 vkarasulli@suse.de
- iommu: sprd: Avoid NULL deref in sprd_iommu_hw_en
  (CVE-2024-42277 bsc#1229409).
- commit ede2511
* Thu Aug 29 2024 iivanov@suse.de
- blacklist.conf: Silence git-fixes in dts files
  We do not provide device trees with SUSE products.
- commit 19456ba
* Thu Aug 29 2024 iivanov@suse.de
- blacklist.conf: Documentation/devicetree/bindings are ignored globally
  No need to blacklist individual patches. Drop them.
- commit 0192d23
* Thu Aug 29 2024 cfamullaconrad@suse.com
- tools/power turbostat: Add ARL-H support (jsc#PED-10187
  jsc#PED-10184).
- tools/power turbostat: Enhance ARL/LNL support (jsc#PED-10187
  jsc#PED-10184).
- x86/cpu: Add model number for another Intel Arrow Lake mobile
  processor (jsc#PED-10187 jsc#PED-10184).
- commit 8795977
* Thu Aug 29 2024 oneukum@suse.com
- usb: typec: altmodes: add svdm version info for typec cables
  (git-fixes).
- Refresh patches.suse/paddings-add-paddings-to-TypeC-stuff.patch.
- commit 8701cb3
* Thu Aug 29 2024 oneukum@suse.com
- usb: typec: altmodes: add typec_cable_ops to typec_altmode
  (jsc#PED-10361).
- Refresh patches.suse/0001-typeC-add-kABI-padding.patch.
- commit 3bb5e68
* Thu Aug 29 2024 ptesarik@suse.com
- udp: fix receiving fraglist GSO packets (git-fixes).
- commit ca0aa59
* Thu Aug 29 2024 tiwai@suse.de
- wifi: cfg80211: correct S1G beacon length calculation
  (git-fixes).
- wifi: mac80211: fix NULL dereference at band check in starting
  tx ba session (stable-fixes).
- commit 49b630f
* Wed Aug 28 2024 dsterba@suse.com
- Update references patches.suse/drm-amd-display-Add-null-checks-for-stream-and-plane.patch (CVE-2024-43904 bsc#1229768 stable-fixes)
- commit aaa26ef
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: enforce ready state when queueing alt mode
  vdm (jsc#PED-10361).
- blacklist.conf: kABI can be changed in SP7
- commit b770f6a
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: avoid sink goto SNK_UNATTACHED state if not
  received source capability message (jsc#PED-10361).
- commit 84a9aee
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: use 'time_left' variable with
  wait_for_completion_timeout() (jsc#PED-10361).
- commit 25ac51e
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: avoid resets for missing source capability
  messages (jsc#PED-10361).
- commit 5b06c56
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: queue correct sop type in
  tcpm_queue_vdm_unlocked (jsc#PED-10361).
- commit 5fe4ad1
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: add support to set tcpc connector
  orientatition (jsc#PED-10361).
- commit f3c3fa9
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: fix SOP' sequences in tcpm_pd_svdm
  (jsc#PED-10361).
- commit 7e73e2e
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: add alt mode enter/exit/vdm support for sop'
  (jsc#PED-10361).
- commit 9843cc4
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: add discover svids and discover modes support
  for sop' (jsc#PED-10361).
- commit b68da06
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: add state machine support for
  SRC_VDM_IDENTITY_REQUEST (jsc#PED-10361).
- commit e394650
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: add discover identity support for SOP'
  (jsc#PED-10361).
- Refresh
  patches.suse/usb-typec-tcpm-Check-for-port-partner-validity-befor.patch.
- commit b4cdeb1
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpci: add attempt_vconn_swap_discovery callback
  (git-fixes).
- commit ae3572f
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: add control message support to sop'
  (jsc#PED-10361).
- commit bf9c1bb
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: process receive and transmission of sop'
  messages (jsc-PED#10361).
- commit 7562c40
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpci: add tcpm_transmit_type to tcpm_pd_receive
  (jsc#PED-10361).
- commit dbb7c7e
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpci: add cable_comm_capable attribute (jsc#PED-10361).
- commit dcc9131
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpm: Query Source partner for FRS capability only
  if it is DRP (jsc#PED-10361).
- commit 97ffb7c
* Wed Aug 28 2024 tbogendoerfer@suse.de
- kabi: lib: objagg: Put back removed metod in struct objagg_ops
  (CVE-2024-43880 bsc#1229481).
- commit 9566f2d
* Wed Aug 28 2024 oneukum@suse.com
- usb: typec: tcpci: add vconn over current fault handling to
  maxim_core (jsc#PED-10361).
- commit a172726
* Wed Aug 28 2024 tiwai@suse.de
- wifi: nl80211: expose can-monitor channel property
  (jsc#PED-10412).
- wifi: rtw89: fw: remove unnecessary rcu_read_unlock() for
  punctured (jsc#PED-10412).
- commit 66467ac
* Wed Aug 28 2024 tiwai@suse.de
- Refresh patches.suse/wifi-mac80211-Add-getter-functions-for-vif-MLD-state.patch (jsc#PED-10412)
- commit 179a2e0
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: fix Spatial Reuse element size check
  (jsc#PED-10412).
- wifi: mac80211: pass proper link id for channel switch started
  notification (jsc#PED-10412).
- wifi: mac80211: transmit deauth only if link is available
  (jsc#PED-10412).
- commit bedfacb
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: ignore non-TX BSSs in per-STA profile
  (jsc#PED-10412).
- commit f263864
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: mlme: re-parse if AP mode is less than client
  (jsc#PED-10412).
- wifi: mac80211: mlme: fix memory leak (jsc#PED-10412).
- wifi: mac80211: mlme: re-parse with correct mode
  (jsc#PED-10412).
- wifi: mac80211: fix idle calculation with multi-link
  (jsc#PED-10412).
- wifi: mac80211: split mesh fast tx cache into
  local/proxied/forwarded (jsc#PED-10412).
- wifi: mac80211: fix mlme_link_id_dbg() (jsc#PED-10412).
- wifi: mac80211: remove TDLS peers on link deactivation
  (jsc#PED-10412).
- wifi: mac80211: remove TDLS peers only on affected link
  (jsc#PED-10412).
- commit dc5a961
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: mlme: unify CSA handling (jsc#PED-10412).
- wifi: mac80211: introduce a feature flag for quiet in CSA
  (jsc#PED-10412).
- wifi: mac80211: pass link conf to abort_channel_switch
  (jsc#PED-10412).
- wifi: mac80211: pass link_id to channel switch ops
  (jsc#PED-10412).
- wifi: cfg80211: allow cfg80211_defragment_element() without
  output (jsc#PED-10412).
- wifi: cfg80211: expose cfg80211_iter_rnr() to drivers
  (jsc#PED-10412).
- wifi: mac80211: hide element parsing internals (jsc#PED-10412).
- wifi: mac80211: remove unneeded scratch_len subtraction
  (jsc#PED-10412).
- wifi: mac80211: defragment reconfiguration MLE when parsing
  (jsc#PED-10412).
- wifi: mac80211: simplify multi-link element parsing
  (jsc#PED-10412).
- commit 913685d
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: remove unnecessary ML element checks
  (jsc#PED-10412).
- wifi: mac80211: add ieee80211_vif_link_active() helper
  (jsc#PED-10412).
- wifi: mac80211: remove unnecessary ML element type check
  (jsc#PED-10412).
- wifi: mac80211: Adjust CQM handling for MLO (jsc#PED-10412).
- wifi: mac80211: Allow beacons to update BSS table regardless
  of scan (jsc#PED-10412).
- wifi: cfg80211: print flags in tracing in hex (jsc#PED-10412).
- wifi: mac80211: obtain AP HT/VHT data for assoc request
  (jsc#PED-10412).
- wifi: mac80211: don't add VHT capa on links without them
  (jsc#PED-10412).
- wifi: mac80211: handle netif carrier up/down with link AP
  during MLO (jsc#PED-10412).
- wifi: mac80211: remove only link keys during stopping link AP
  (jsc#PED-10412).
- commit f5583c0
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: fix supported rate masking in scan
  (jsc#PED-10412).
- wifi: mac80211: check link exists before use (jsc#PED-10412).
- wifi: mac80211: always initialize match_auth (jsc#PED-10412).
- wifi: nl80211: refactor parsing CSA offsets (jsc#PED-10412).
- wifi: nl80211: force WLAN_AKM_SUITE_SAE in big endian in
  NL80211_CMD_EXTERNAL_AUTH (jsc#PED-10412).
- wifi: cfg80211: use ML element parsing helpers (jsc#PED-10412).
- wifi: mac80211: align ieee80211_mle_get_bss_param_ch_cnt()
  (jsc#PED-10412).
- commit d200d4e
* Wed Aug 28 2024 denis.kirjanov@suse.com
- net/sched: initialize noop_qdisc owner (git-fixes).
- commit 66e8d18
* Wed Aug 28 2024 iivanov@suse.de
- blacklist.conf: Drop e2768b798a19 ("arm64/mm: Modify range-based tlbi to decrement scale")
- commit 6f8618a
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: refactor RNR parsing (jsc#PED-10412).
- commit c8b0e9e
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: clean up cfg80211_inform_bss_frame_data()
  (jsc#PED-10412).
- commit 47b22b0
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: remove cfg80211_inform_single_bss_frame_data()
  (jsc#PED-10412).
- commit f728fce
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: Add KHZ_PER_GHZ to units.h and reuse
  (jsc#PED-10412).
- wifi: mac80211: make associated BSS pointer visible to the
  driver (jsc#PED-10412).
- wifi: mac80211: check beacon countdown is complete on per link
  basis (jsc#PED-10412).
- wifi: cfg80211: use IEEE80211_MAX_MESH_ID_LEN appropriately
  (jsc#PED-10412).
- wifi: mac80211: drop injection on disabled-chan monitor
  (jsc#PED-10412).
- wifi: cfg80211: optionally support monitor on disabled channels
  (jsc#PED-10412).
- wifi: mac80211: remove only own link stations during stop_ap
  (jsc#PED-10412).
- wifi: mac80211: flush only stations using requests links
  (jsc#PED-10412).
- wifi: cfg80211: add support for link id attribute in
  NL80211_CMD_DEL_STATION (jsc#PED-10412).
- wifi: mac80211: remove gfp parameter from
  ieee80211_obss_color_collision_notify (jsc#PED-10412).
- commit af927ab
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: fix kernel-doc for cfg80211_chandef_primary
  (jsc#PED-10412).
- wifi: mac80211: add support to call csa_finish on a link
  (jsc#PED-10412).
- wifi: mac80211: start and finalize channel switch on link basis
  (jsc#PED-10412).
- wifi: mac80211: handle set csa/after_csa beacon on per link
  basis (jsc#PED-10412).
- wifi: cfg80211: send link id in channel_switch ops
  (jsc#PED-10412).
- wifi: mac80211: refactor STA CSA parsing flows (jsc#PED-10412).
- wifi: cfg80211: Add utility for converting op_class into chandef
  (jsc#PED-10412).
- wifi: mac80211: don't use sband->band early (jsc#PED-10412).
- wifi: mac80211: add missing kernel-doc for fast_tx_check
  (jsc#PED-10412).
- wifi: mac80211: clarify vif handling in TX dequeue
  (jsc#PED-10412).
- commit 2d6daca
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: move element parsing to a new file
  (jsc#PED-10412).
- Refresh
  patches.suse/wifi-mac80211-update-scratch_pos-after-defrag.patch.
- commit bf13760
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: allow CSA to same channel (jsc#PED-10412).
- wifi: mac80211: convert ieee80211_ie_build_eht_cap() to SKB use
  (jsc#PED-10412).
- wifi: mac80211: convert ieee80211_ie_build_he_cap() to SKB use
  (jsc#PED-10412).
- wifi: mac80211: start building elements in SKBs (jsc#PED-10412).
- wifi: mac80211: simplify adding supported rates (jsc#PED-10412).
- wifi: mac80211: tdls: use ieee80211_put_he_6ghz_cap()
  (jsc#PED-10412).
- wifi: mac80211: rename ieee80211_ie_build_he_6ghz_cap()
  (jsc#PED-10412).
- wifi: mac80211: limit HE RU capabilities when limiting bandwidth
  (jsc#PED-10412).
- wifi: mac80211: adjust EHT capa when lowering bandwidth
  (jsc#PED-10412).
- commit a166a82
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: implement MLO multicast deduplication
  (jsc#PED-10412).
- Refresh
  patches.suse/wifi-mac80211-cancel-multi-link-reconf-work-on-disco.patch.
- commit ed289f4
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: simplify HE/EHT element length functions
  (jsc#PED-10412).
- wifi: mac80211: disallow basic multi-link element in per-STA
  profile (jsc#PED-10412).
- wifi: mac80211: disambiguate element parsing errors
  (jsc#PED-10412).
- wifi: mac80211: add/use ieee80211_get_sn() (jsc#PED-10412).
- commit 892692a
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211/mac80211: move puncturing into chandef
  (jsc#PED-10412).
- Refresh
  patches.suse/wifi-ath12k-enable-802.11-power-save-mode-in-station.patch.
- Refresh
  patches.suse/wifi-mac80211-fix-BSS_CHANGED_UNSOL_BCAST_PROBE_RESP.patch.
- commit 148c5a2
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: use cfg80211_chandef_primary_freq()
  (jsc#PED-10412).
- wifi: cfg80211: simplify cfg80211_chandef_compatible()
  (jsc#PED-10412).
- wifi: wireless: declare different S1G chandefs incompatible
  (jsc#PED-10412).
- wifi: mac80211: refactor puncturing bitmap extraction
  (jsc#PED-10412).
- commit 4421602
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: move puncturing validation code (jsc#PED-10412).
- wifi: mac80211: validate assoc response channel config
  (jsc#PED-10412).
- commit 5a45b69
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: support wider bandwidth OFDMA config
  (jsc#PED-10412).
- Refresh
  patches.suse/wifi-mac80211-correcty-limit-wider-BW-TDLS-STAs.patch.
- commit 2bbf3ce
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: add and use a link iteration macro
  (jsc#PED-10412).
- Refresh
  patches.suse/wifi-mac80211-correcty-limit-wider-BW-TDLS-STAs.patch.
- commit d5712ca
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: introduce 'channel request' (jsc#PED-10412).
- Refresh
  patches.suse/wifi-iwlwifi-mvm-calculate-EMLSR-mode-after-connecti.patch.
- Refresh
  patches.suse/wifi-iwlwifi-mvm-don-t-always-disable-EMLSR-due-to-B.patch.
- Refresh
  patches.suse/wifi-mac80211-correcty-limit-wider-BW-TDLS-STAs.patch.
- commit af16a83
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: chan: chandef is non-NULL for reserved
  (jsc#PED-10412).
- wifi: mac80211: clean up HE 6 GHz and EHT chandef parsing
  (jsc#PED-10412).
- commit cb58526
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: clean up connection process (jsc#PED-10412).
- commit 732cff2
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: clean up band switch in duration
  (jsc#PED-10412).
- wifi: mac80211: remove extra shadowing variable (jsc#PED-10412).
- commit 4194ddc
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: remove unused MAX_MSG_LEN define
  (jsc#PED-10412).
- wifi: mac80211: don't allow deactivation of all links
  (jsc#PED-10412).
- wifi: nl80211: move WPA version validation to policy
  (jsc#PED-10412).
- wifi: mac80211: clean up FILS discovery change flags handling
  (jsc#PED-10412).
- wifi: mac80211: trace SMPS requests from driver (jsc#PED-10412).
- Revert "nl80211/cfg80211: Specify band specific min RSSI
  thresholds with sched scan" (jsc#PED-10412).
- wifi: mac80211: Drop WBRF debugging statements (jsc#PED-10412).
- commit c53e5bb
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: take EML/MLD capa from assoc response
  (jsc#PED-10412).
- Refresh
  patches.suse/wifi-mac80211-cancel-multi-link-reconf-work-on-disco.patch.
- commit de97fb2
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: apply duration for SW scan (jsc#PED-10412).
- wifi: mac80211: don't set bss_conf in parsing (jsc#PED-10412).
- wifi: mac80211: disallow drivers with HT wider than HE
  (jsc#PED-10412).
- wifi: mac80211: simplify HE capability access (jsc#PED-10412).
- wifi: mac80211: remove extra element parsing (jsc#PED-10412).
- wifi: mac80211: simplify ieee80211_config_bw() prototype
  (jsc#PED-10412).
- wifi: cfg80211: validate MLO connections better (jsc#PED-10412).
- commit c34e2bb
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: add support for negotiated TTLM request
  (jsc#PED-10412).
- Refresh
  patches.suse/wifi-mac80211-cancel-multi-link-reconf-work-on-disco.patch.
- Refresh
  patches.suse/wifi-mac80211-reset-negotiated-TTLM-on-disconnect.patch.
- commit ddf627d
* Wed Aug 28 2024 tiwai@suse.de
- wifi: wireless: avoid strlen() in cfg80211_michael_mic_failure()
  (jsc#PED-10412).
- commit d116332
* Wed Aug 28 2024 tiwai@suse.de
- wifi: nl80211: fix grammar & spellos (jsc#PED-10412).
- commit aee3bd5
* Wed Aug 28 2024 tiwai@suse.de
- wifi: mac80211: Add support for WBRF features (jsc#PED-10412).
- Refresh
  patches.suse/wifi-mac80211-process-and-save-negotiated-TID-to-Lin.patch.
- Refresh
  patches.suse/wifi-mac80211-simplify-non-chanctx-drivers.patch.
- Refresh patches.suse/wireless-suse-kabi-padding.patch.
- commit b2b30d5
* Wed Aug 28 2024 oneukum@suse.com
- ubsan: fix unused variable warning in test module (git fix
  rejected for SP6).
- blacklist.conf: kABI can be changed in SP7
- commit dd9615e
* Wed Aug 28 2024 tiwai@suse.de
- Update config files: CONFIG_AMD_WBRF=y (jsc#PED-10412)
- commit 3705dfc
* Wed Aug 28 2024 tiwai@suse.de
- platform/x86/amd: Add support for AMD ACPI based Wifi band
  RFI mitigation feature (jsc#PED-10412).
- commit 1be0c01
* Wed Aug 28 2024 tiwai@suse.de
- Update config files: CONFIG_BT_HS is obsoleted
- commit 4b9af5d
* Wed Aug 28 2024 oneukum@suse.com
- xfrm: Correct spelling mistake in xfrm.h comment (git fix
  rejected for SP6).
- blacklist.conf: kABI can be changed in SP7
- commit 071ae18
* Wed Aug 28 2024 tiwai@suse.de
- wifi: nl80211: Documentation update for
  NL80211_CMD_PORT_AUTHORIZED event (jsc#PED-10412).
- wifi: nl80211: fix doc typos (jsc#PED-10412).
- commit a6bc697
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: add ieee80211_fragment_element to public API
  (jsc#PED-10412).
- commit 2f3d9f2
* Wed Aug 28 2024 oneukum@suse.com
- uapi: in6: replace temporary label with rfc9486 (git fix
  rejected for SP6).
- blacklist.conf: kABI can be changed in SP7
- commit 625f7f3
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: Annotate struct cfg80211_scan_request with
  __counted_by (jsc#PED-10412).
- Refresh
  patches.suse/wifi-cfg80211-Extend-support-for-scanning-while-MLO-.patch.
- commit 1acc433
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: Annotate struct cfg80211_cqm_config with
  __counted_by (jsc#PED-10412).
- Refresh
  patches.suse/wifi-cfg80211-fix-CQM-for-non-range-use.patch.
- Refresh
  patches.suse/wifi-cfg80211-fix-cqm_config-access-race.patch.
- commit 8590584
* Wed Aug 28 2024 tiwai@suse.de
- wifi: cfg80211: Annotate struct cfg80211_tid_config with
  __counted_by (jsc#PED-10412).
- wifi: cfg80211: Annotate struct cfg80211_rnr_elems with
  __counted_by (jsc#PED-10412).
- wifi: cfg80211: Annotate struct cfg80211_pmsr_request with
  __counted_by (jsc#PED-10412).
- wifi: cfg80211: Annotate struct cfg80211_mbssid_elems with
  __counted_by (jsc#PED-10412).
- wifi: cfg80211: Annotate struct cfg80211_acl_data with
  __counted_by (jsc#PED-10412).
- commit 6628583
* Wed Aug 28 2024 oneukum@suse.com
- sysctl: remove struct ctl_path (git fix rejected for SP6).
- blacklist.conf: kABI can be changed in SP7
- commit 7a7014b
* Wed Aug 28 2024 iivanov@suse.de
- config/arm64: Enable Qualcomm Centriq PMU drivers (jsc#PED-10480)
- commit 8ecc2c0
* Wed Aug 28 2024 oneukum@suse.com
- sysctl: Add ctl_table_size to ctl_table_header (git-fixes).
- commit 4ff2f74
* Wed Aug 28 2024 oneukum@suse.com
- usb: new quirk to reduce the SET_ADDRESS request timeout
  (git fix rejected for SP6).
- blacklist.conf: kABI can be changed in SP7
- Refresh
  patches.suse/usb-hub-Add-quirk-to-decrease-IN-ep-poll-interval-fo.patch.
- commit ae2f991
* Wed Aug 28 2024 pjakobsson@suse.de
- drm/amd/display: Fix null pointer deref in dcn20_resource.c (CVE-2024-43899 bsc#1229754).
- commit 1811990
* Wed Aug 28 2024 oneukum@suse.com
- usb: xhci: Add timeout argument in address_device USB HCD
  callback (git fix rejected in SP6).
- blacklist.conf: kABI can be changed in SP7
- Refresh patches.suse/padding-XHCI-additional-padding.patch.
- commit 27787c3
* Wed Aug 28 2024 oneukum@suse.com
- usb: dwc3: dwc3-octeon: Verify clock divider (git fixes not
  applicable in SP6).
- blacklist.conf: reason for blacklisting applied only in SP6, removing
  for SP7
- commit ed55fa9
* Wed Aug 28 2024 oneukum@suse.com
- usb: dwc3: dwc3-octeon: Add SPDX header and copyright (git
  fix rejected for SP6).
- usb: dwc3: dwc3-octeon: Dump control register on clock init
  failure (git fix rejected for SP6).
- usb: dwc3: dwc3-octeon: Move node parsing into driver probe
  (git fix rejected for SP6).
- usb: dwc3: dwc3-octeon: Avoid half-initialized controller state
  (git fix rejected for SP6).
- commit e3ee233
* Wed Aug 28 2024 oneukum@suse.com
- usb: dwc3: dwc3-octeon: Pass dwc3_octeon to setup functions
  (git fix rejected for SP6).
- commit 036ff34
* Wed Aug 28 2024 oneukum@suse.com
- usb: dwc3: dwc3-octeon: Use _ULL bitfields defines (git fix
  rejected for SP6).
- commit 45a1718
* Wed Aug 28 2024 oneukum@suse.com
- usb: dwc3: dwc3-octeon: Convert to glue driver (git fix rejected
  for SP6).
- commit e8830f6
* Wed Aug 28 2024 oneukum@suse.com
- MIPS: OCTEON: octeon-usb: cleanup divider calculation (git
  fix rejected for SP6).
- MIPS: OCTEON: octeon-usb: introduce dwc3_octeon_{read,write}q
  (git fix rejected for SP6).
- MIPS: OCTEON: octeon-usb: move gpio config to separate function
  (git fix rejected for SP6).
- commit 6b04497
* Wed Aug 28 2024 oneukum@suse.com
- MIPS: OCTEON: octeon-usb: use bitfields for shim register
  (git fix rejected for SP6).
- MIPS: OCTEON: octeon-usb: use bitfields for host config register
  (git fix rejected in SP6).
- MIPS: OCTEON: octeon-usb: use bitfields for control register
  (git fix rejected for SP6).
- MIPS: OCTEON: octeon-usb: add all register offsets (git fix
  rejected for SP6).
- commit f7e9da5
* Wed Aug 28 2024 tiwai@suse.de
- Bluetooth: fix connection setup in l2cap_connect (git-fixes).
- commit 04dfce2
* Wed Aug 28 2024 tiwai@suse.de
- Bluetooth: HCI: Remove HCI_AMP support (git-fixes).
- Refresh
  patches.suse/Bluetooth-L2CAP-Fix-slab-use-after-free-in-l2cap_con.patch.
- commit 8b94a6b
* Wed Aug 28 2024 tiwai@suse.de
- Bluetooth: Remove BT_HS (git-fixes).
- blacklist.conf: drop the backported entry
- Refresh
  patches.suse/Bluetooth-L2CAP-Fix-not-validating-setsockopt-user-i.patch.
- commit 34ffe69
* Wed Aug 28 2024 andrea.porta@suse.com
- blacklist.conf: add 56769ba4b297a629148eb24d554aef72d1ddfd9e
- commit e1cb2aa
* Wed Aug 28 2024 iivanov@suse.de
- config/arm64: Disable drivers used by Spreadtrum platform (jsc#PED-10480)
- commit ceb08e9
* Wed Aug 28 2024 iivanov@suse.de
- config/arm64: Disable drivers used by Amlogic Meson platform (jsc#PED-10480)
- commit c463397
* Wed Aug 28 2024 iivanov@suse.de
- config/arm64: Disable drivers used by Samsung Exynos platform (jsc#PED-10480)
- commit 917f646
* Wed Aug 28 2024 mhocko@suse.com
- exec: Fix ToCToU between perm check and set-uid/gid usage
  (CVE-2024-43882 bsc#1229503).
- commit 7a21b9d
* Wed Aug 28 2024 iivanov@suse.de
- config/arm64: Disable drivers used by MediaTek embedded platforms (jsc#PED-10480)
- commit 63132c8
* Wed Aug 28 2024 iivanov@suse.de
- config/arm64: Disable drivers used by Qualcomm embedded platforms (jsc#PED-10480)
- commit 363a810
* Wed Aug 28 2024 tiwai@suse.de
- ALSA: hda/realtek: support HP Pavilion Aero 13-bg0xxx Mute LED
  (stable-fixes).
- ALSA: hda/realtek: Fix the speaker output on Samsung Galaxy
  Book3 Ultra (stable-fixes).
- ASoC: allow module autoloading for table board_ids
  (stable-fixes).
- ASoC: allow module autoloading for table db1200_pids
  (stable-fixes).
- ASoC: mediatek: mt8188: Mark AFE_DAC_CON0 register as volatile
  (stable-fixes).
- ASoC: SOF: mediatek: Add missing board compatible
  (stable-fixes).
- ALSA: hda/realtek - FIxed ALC285 headphone no sound
  (stable-fixes).
- ALSA: hda/realtek - Fixed ALC256 headphone no sound
  (stable-fixes).
- ALSA: hda/realtek: Enable mute/micmute LEDs on HP Laptop
  14-ey0xxx (stable-fixes).
- ALSA: hda/realtek: Implement sound init sequence for Samsung
  Galaxy Book3 Pro 360 (stable-fixes).
- commit 97adcb2
* Wed Aug 28 2024 tbogendoerfer@suse.de
- ip6_tunnel: Fix broken GRO (bsc#1229444).
- net/mlx5: Always drain health in shutdown callback
  (CVE-2024-43866 bsc#1229495).
- mlxsw: spectrum_acl_erp: Fix object nesting warning
  (CVE-2024-43880 bsc#1229481).
- commit d9a404d
* Wed Aug 28 2024 tiwai@suse.de
- pinctrl: rockchip: correct RK3328 iomux width flag for GPIO2-B
  pins (git-fixes).
- pinctrl: starfive: jh7110: Correct the level trigger
  configuration of iev register (git-fixes).
- pinctrl: mediatek: common-v2: Fix broken bias-disable for
  PULL_PU_PD_RSEL_TYPE (git-fixes).
- pinctrl: single: fix potential NULL dereference in
  pcs_get_function() (git-fixes).
- ASoC: SOF: amd: Fix for acp init sequence (git-fixes).
- ASoC: amd: acp: fix module autoloading (git-fixes).
- ALSA: seq: Skip event type filtering for UMP events (git-fixes).
- commit 3fa4a0b
* Tue Aug 27 2024 tbogendoerfer@suse.de
- ice: Fix NULL pointer access, if PF doesn't support SRIOV_LAG
  (bsc#1228737).
- commit f1a9730
* Tue Aug 27 2024 vkarasulli@suse.de
- kABI: vfio: struct virqfd kABI workaround (CVE-2024-26812
  bsc#1222808).
- commit ae735c0
* Tue Aug 27 2024 denis.kirjanov@suse.com
- net/sched: Fix mirred deadlock on device recursion
  (CVE-2024-27010 bsc#1223720).
- commit 8c34ee8
* Tue Aug 27 2024 dsterba@suse.com
- Fix reference in patches.suse/netfilter-tproxy-bail-out-if-IP-has-been-disabled-on.patch (CVE-2024-36270 bsc#1226798)
- commit 052d917
* Tue Aug 27 2024 denis.kirjanov@suse.com
- net: qdisc: preserve kabi for struct QDisc (CVE-2024-27010 bsc#1223720).
- commit e31d466
* Tue Aug 27 2024 vbabka@suse.cz
- mm/userfaultfd: reset ptes when close() for wr-protected ones
  (CVE-2024-36881 bsc#1225718).
- commit 2267d46
* Tue Aug 27 2024 vbabka@suse.cz
- mm/mglru: fix div-by-zero in vmpressure_calc_level()
  (CVE-2024-42316 bsc#1229353).
- commit ba00671
* Tue Aug 27 2024 colyli@suse.de
- md/raid1: set max_sectors during early return from
  choose_slow_rdev() (git-fixes).
- md/raid5: recheck if reshape has finished with device_lock held
  (git-fixes).
- md: Don't wait for MD_RECOVERY_NEEDED for HOT_REMOVE_DISK ioctl
  (git-fixes).
- md/raid5: fix spares errors about rcu usage (git-fixes).
- md/md-bitmap: fix writing non bitmap pages (git-fixes).
- md: fix deadlock between mddev_suspend and flush bio
  (bsc#1229342, CVE-2024-43855).
- md: change the return value type of md_write_start to void
  (git-fixes).
- md: do not delete safemode_timer in mddev_suspend (git-fixes).
- md: don't account sync_io if iostats of the disk is disabled
  (git-fixes).
- md: add check for sleepers in md_wakeup_thread() (git-fixes).
- md/raid5: fix deadlock that raid5d() wait for itself to clear
  MD_SB_CHANGE_PENDING (git-fixes).
- md: add a mddev_add_trace_msg helper (git-fixes).
- Revert "Revert "md/raid5: Wait for MD_SB_CHANGE_PENDING in
  raid5d"" (git-fixes).
- md: fix a suspicious RCU usage warning (git-fixes).
- md/raid1: support read error check (git-fixes).
- commit f1ec0d4
* Tue Aug 27 2024 colyli@suse.de
- md: factor out a helper exceed_read_errors() to check
  read_errors (git-fixes).
- Refresh for the above change,
  patches.suse/md-display-timeout-error.patch.
  patches.suse/md-raid1-10-add-a-helper-raid1_check_read_range-f298.patch.
- commit 035e3f0
* Tue Aug 27 2024 colyli@suse.de
- Revert "md/raid5: Wait for MD_SB_CHANGE_PENDING in raid5d"
  (git-fixes).
- commit 5cc0fdd
* Mon Aug 26 2024 dsterba@suse.com
- net/mlx5e: Fix CT entry update leaks of modify header context (CVE-2024-43864 bsc#1229496)
- commit 316a4fe
* Mon Aug 26 2024 msuchanek@suse.de
- rpm/check-for-config-changes: Exclude ARCH_USING_PATCHABLE_FUNCTION_ENTRY
  gcc version dependent, at least on ppc
- commit 16da158
* Mon Aug 26 2024 mkoutny@suse.com
- af_unix: Fix data races in unix_release_sock/unix_stream_sendmsg
  (bsc#1226846 CVE-2024-38596).
- Update
  patches.suse/af_unix-Fix-data-races-around-sk-sk_shutdown.patch
  (git-fixes bsc#1226846).
- commit 7ceb0cd
* Mon Aug 26 2024 tiwai@suse.de
- platform/x86/intel/pmc: Improve PKGC residency counters debug
  (jsc#PED-10411).
- platform/x86/intel/pmc/arl: Put GNA device in D3
  (jsc#PED-10411).
- platform/x86/intel/pmc/lnl: Remove SSRAM support
  (jsc#PED-10411).
- platform/x86/intel/pmc: Add missing extern (jsc#PED-10411).
- platform/x86/intel/pmc/lnl: Add GBE LTR ignore during suspend
  (jsc#PED-10411).
- platform/x86/intel/pmc/arl: Add GBE LTR ignore during suspend
  (jsc#PED-10411).
- platform/x86/intel/pmc: Add Lunar Lake M support to
  intel_pmc_core driver (jsc#PED-10411).
- platform/x86/intel/pmc: Add Arrow Lake S support to
  intel_pmc_core driver (jsc#PED-10411).
- commit 70a33f0
* Mon Aug 26 2024 tiwai@suse.de
- platform/x86/intel/pmc: Add ssram_init flag in PMC discovery
  in Meteor Lake (jsc#PED-10411).
- platform/x86/intel/pmc: Move common code to core.c
  (jsc#PED-10411).
- platform/x86/intel/pmc: Add PSON residency counter for Alder
  Lake (jsc#PED-10411).
- platform/x86/intel/pmc: Add regmap for Tiger Lake H PCH
  (jsc#PED-10411).
- platform/x86/intel/pmc: Add PSON residency counter
  (jsc#PED-10411).
- platform/x86/intel/pmc: Fix in mtl_punit_pmt_init()
  (jsc#PED-10411).
- platform/x86/intel/pmc: Fix in pmc_core_ssram_get_pmc()
  (jsc#PED-10411).
- platform/x86/intel/pmc: Show Die C6 counter on Meteor Lake
  (jsc#PED-10411).
- platform/x86/intel/pmc: Add debug attribute for Die C6 counter
  (jsc#PED-10411).
- platform/x86/intel/pmc: Read low power mode requirements for
  MTL-M and MTL-P (jsc#PED-10411).
- commit 0f7c762
* Mon Aug 26 2024 tiwai@suse.de
- platform/x86/intel/pmc: Retrieve LPM information using Intel
  PMT (jsc#PED-10411).
- platform/x86/intel/pmc: Display LPM requirements for multiple
  PMCs (jsc#PED-10411).
- platform/x86/intel/pmc: Find and register PMC telemetry entries
  (jsc#PED-10411).
- platform/x86/intel/pmc/mtl: Use return value from
  pmc_core_ssram_init() (jsc#PED-10411).
- platform/x86/intel/pmc: Cleanup SSRAM discovery (jsc#PED-10411).
- platform/x86/intel/pmc: Allow pmc_core_ssram_init to fail
  (jsc#PED-10411).
- platform/x86/intel/pmt: telemetry: Export API to read telemetry
  (jsc#PED-10411).
- platform/x86/intel/pmt: Add header to struct intel_pmt_entry
  (jsc#PED-10411).
- commit ed73596
* Mon Aug 26 2024 tiwai@suse.de
- platform/x86:intel/pmc: Call pmc_get_low_power_modes from
  platform init (jsc#PED-10411).
- commit 777c985
* Mon Aug 26 2024 ptesarik@suse.com
- string: Allow 2-argument strscpy() (bsc#1229741).
- commit d3b7527
* Mon Aug 26 2024 tiwai@suse.de
- Enable pinctrl-intel-platform driver (jsc#PED-10210)
- Update config files: CONFIG_PINCTRL_INTEL_PLATFORM=m
- supported.conf: add pinctrl-intel-platform
- commit 7cad154
* Mon Aug 26 2024 tiwai@suse.de
- pinctrl: intel: Add a generic Intel pin control platform driver
  (jsc#PED-10210).
- devres: Provide krealloc_array (jsc#PED-10210).
- commit d328690
* Mon Aug 26 2024 sjaeckel@suse.de
- ipv6: mcast: fix data-race in ipv6_mc_down / mld_ifc_work
  (CVE-2024-26631 bsc#1221630).
- commit 317a097
* Mon Aug 26 2024 tiwai@suse.de
- tools/arch/x86/intel_sdsi: Add current meter support
  (jsc#PED-10384).
- tools/arch/x86/intel_sdsi: Simplify ascii printing
  (jsc#PED-10384).
- commit 3f1383e
* Mon Aug 26 2024 tiwai@suse.de
- platform/x86/intel/sdsi: Add attribute to read the current
  meter state (jsc#PED-10384).
- platform/x86/intel/sdsi: Add in-band BIOS lock support
  (jsc#PED-10384).
- platform/x86/intel/sdsi: Combine read and write mailbox flows
  (jsc#PED-10384).
- platform/x86/intel/sdsi: Set message size during writes
  (jsc#PED-10384).
- commit e23f4a7
* Mon Aug 26 2024 dsterba@suse.com
- netfilter: nf_tables: unconditionally flush pending work before notifier (CVE-2024-42109 bsc#1228505)
- commit 7a6a06c
* Mon Aug 26 2024 dsterba@suse.com
- cxl/region: Avoid null pointer dereference in region lookup (CVE-2024-41084 bsc#1228472)
- commit fc1408b
* Mon Aug 26 2024 dsterba@suse.com
- cxl/region: Move cxl_dpa_to_region() work to the region driver (bsc#1228472)
- commit ac0e984
* Mon Aug 26 2024 dsterba@suse.com
- ipv6: fix possible race in __fib6_drop_pcpu_from() (CVE-2024-40905 bsc#1227761)
- commit 6fcd399
* Mon Aug 26 2024 dsterba@suse.com
- ipv6: sr: fix memleak in seg6_hmac_init_algo (CVE-2024-39489 bsc#1227623)
- commit c55beb2
* Mon Aug 26 2024 ptesarik@suse.com
- swiotlb: do not set total_used to 0 in
  swiotlb_create_debugfs_files() (git-fixes).
- swiotlb: fix swiotlb_bounce() to do partial sync's correctly
  (git-fixes).
- commit 99fe6bb
* Mon Aug 26 2024 ptesarik@suse.com
- blacklist.conf: add console_replay_all() rename
- commit afd359c
* Mon Aug 26 2024 ptesarik@suse.com
- Documentation: kernel-parameters: Add DEVNAME:0.0 format for
  serial ports (bsc#1229741).
- serial: core: Add
  serial_base_match_and_update_preferred_console() (bsc#1229741).
- printk: Add match_devname_and_update_preferred_console()
  (bsc#1229741).
- commit 9c7a804
* Mon Aug 26 2024 ptesarik@suse.com
- printk: cleanup deprecated uses of strncpy/strcpy (bsc#1229741).
- Revert "printk: Save console options for
  add_preferred_console_match()" (git-fixes).
- Revert "printk: Don't try to parse DEVNAME:0.0 console options"
  (git-fixes).
- Revert "printk: Flag register_console() if console is set on
  command line" (git-fixes).
- commit 46921ce
* Mon Aug 26 2024 ptesarik@suse.com
- serial: core: Fix serial core port id, including multiport
  devices (git-fixes).
- serial: port: Don't block system suspend even if bytes are
  left to xmit (git-fixes).
- serial: core: Clearing the circular buffer before NULLifying it
  (git-fixes).
- serial: core: Fix regression when runtime PM is not enabled
  (git-fixes).
- serial: core: Fix serial_base_match() after fixing controller
  port name (git-fixes).
- serial: core: Fix missing shutdown and startup for serial base
  port (git-fixes).
- commit e8f48ae
* Mon Aug 26 2024 ptesarik@suse.com
- serial: port: Don't suspend if the port is still busy
  (git-fixes).
- serial: core: Revert checks for tx runtime PM state (git-fixes).
- serial: 8250: drop lockdep annotation from
  serial8250_clear_IER() (git-fixes).
- serial: core: Revert port_id use (git-fixes).
- serial: 8250: Reinit port_id when adding back
  serial8250_isa_devs (git-fixes).
- commit 1776421
* Mon Aug 26 2024 ptesarik@suse.com
- serial: core: Fix kmemleak issue for serial core device remove
  (git-fixes).
- serial: core: Fix serial core controller port name to show
  controller id (git-fixes).
- 8250_men_mcb: remove unnecessary cast when reading register
  (git-fixes).
- 8250_men_mcb: Fix unsigned expression compared with zero
  (git-fixes).
- ARM: 9352/1: iwmmxt: Remove support for PJ4/PJ4B cores
  (git-fixes).
- commit 424f391
* Mon Aug 26 2024 ptesarik@suse.com
- arm64/arch_timer: Fix MMIO byteswap (git-fixes).
- tty/sysrq: Replay kernel log messages on consoles via sysrq
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: Add function to replay kernel log on consoles
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: Flag register_console() if console is set on command
  line (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: Don't try to parse DEVNAME:0.0 console options
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit a8a4b7e
* Mon Aug 26 2024 ptesarik@suse.com
- printk: Save console options for add_preferred_console_match()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- net: Remove conditional threaded-NAPI wakeup based on task state
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- cxgb4: Properly lock TX queue for the selftest (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- btrfs: qgroup: fix qgroup prealloc rsv leak in subvolume
  operations (CVE-2024-35956 bsc#1224674).
- blacklist.conf: Remove the above commit.
- serial: port: Introduce a common helper to read properties
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 8dcc4c4
* Mon Aug 26 2024 ptesarik@suse.com
- serial: core: Add UPIO_UNKNOWN constant for unknown port type
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: core: Move struct uart_port::quirks closer to possible
  values (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: pch: Don't initialize uart_port's spin_lock (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: pch: Don't disable interrupts while acquiring lock in
  ISR (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: pch: Make push_rx() return void (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- commit 3993c78
* Mon Aug 26 2024 ptesarik@suse.com
- serial: pch: Invoke handle_rx_to() directly (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- panic: add option to dump blocked tasks in panic_print
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- panic: suppress gnu_printf warning (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- panic: Flush kernel log buffer at the end (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- blacklist.conf: Remove the above commit.
- serial: stm32: do not always set SER_RS485_RX_DURING_TX if RS485
  is enabled (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- xsk: Add truesize to skb_add_rx_frag() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- commit add956c
* Mon Aug 26 2024 ptesarik@suse.com
- usb: cdc-acm: return correct error code on unsupported break
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: Do not hold the port lock when setting rx-during-tx GPIO
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: core: Update uart_poll_timeout() function to return
  unsigned long (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- device property: Add fwnode_property_match_property_string()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- ARM: 9327/1: vfp: Add missing VFP instructions to
  neon_support_hook (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- commit cf7a873
* Mon Aug 26 2024 ptesarik@suse.com
- device property: Add fwnode_name_eq() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- device property: Implement device_is_big_endian() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- device property: Add SOFTWARE_NODE() macro for defining software
  nodes (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: core: Fix runtime PM handling for pending tx
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 064ade2
* Mon Aug 26 2024 ptesarik@suse.com
- printk: Constify name for add_preferred_console() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- printk: Check valid console index for preferred console
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: exar: Add RS-485 support for Sealevel XR17V35X based
  cards (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: use 'if' in send_break() instead of 'goto' (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty: don't check for signal_pending() in send_break()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 7496c73
* Mon Aug 26 2024 ptesarik@suse.com
- tty: early return from send_break() on TTY_DRIVER_HARDWARE_BREAK
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: core: Use port lock wrappers (git-fixes).
- Refresh
  patches.suse/serial-core-Fix-atomicity-violation-in-uart_tiocmget.patch.
- serial: core: Use lock wrappers (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- printk: fix illegal pbufs access for !CONFIG_PRINTK (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/printk-Avoid-non-panic-CPUs-writing-to-ringbuffer.patch.
- printk: nbcon: Allow drivers to mark unsafe regions and check
  state (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: nbcon: Add emit function and callback function
  for atomic printing (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- Refresh
  patches.suse/dump_stack-Do-not-get-cpu_sync-for-panic-CPU.patch.
- Refresh patches.suse/printk-Add-this_cpu_in_panic.patch.
- Refresh
  patches.suse/printk-Avoid-non-panic-CPUs-writing-to-ringbuffer.patch.
- commit 66aa9f0
* Mon Aug 26 2024 ptesarik@suse.com
- printk: nbcon: Add sequence handling (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- printk: nbcon: Add ownership state functions (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- printk: nbcon: Add buffer management (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- printk: Make static printk buffers available to nbcon
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: nbcon: Add acquire/release logic (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit d4c512c
* Mon Aug 26 2024 ptesarik@suse.com
- printk: Add non-BKL (nbcon) console basic infrastructure
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: Reduce pr_flush() pooling time (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- =?UTF-8?q?printk:=20printk:=20Remove=20unnecessary=20stat?=
  =?UTF-8?q?ements=EF=BC=87len=20=3D=200;=EF=BC=87?= (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- bpf: Remove xdp_do_flush_map() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- signal: Don't disable preemption in ptrace_stop() on PREEMPT_RT
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 4bad803
* Mon Aug 26 2024 ptesarik@suse.com
- signal: Add a proper comment about preempt_disable() in
  ptrace_stop() (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- sched/debug: Update stale reference to sched_debug.c
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: core: Fix checks for tx runtime PM state (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- printk: flush consoles before checking progress (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/printk-Wait-for-all-reserved-records-with-pr_flush.patch.
- selftests: hsr: Extend the testsuite to also cover HSRv1
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 272e73e
* Mon Aug 26 2024 ptesarik@suse.com
- selftests: hsr: Reorder the testsuite (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- selftests: hsr: Use `let' properly (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- printk: Add per-console suspended state (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- kdb: Do not assume write() callback available (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- Revert "tty: serial: meson: Add a earlycon for the T7 SoC"
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 62a3bb8
* Mon Aug 26 2024 ptesarik@suse.com
- serial: 8250_bcm7271: improve bcm7271 8250 port (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: sifive: Add suspend and resume operations (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty: serial: meson: Add a earlycon for the T7 SoC (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: stm32: synchronize RX DMA channel in shutdown
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: stm32: replace access to DMAR bit by
  dmaengine_pause/resume (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- commit 5173642
* Mon Aug 26 2024 ptesarik@suse.com
- serial: stm32: group dma pause/resume error handling into single
  function (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: stm32: modify parameter and rename
  stm32_usart_rx_dma_enabled (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- serial: stm32: use DMAT as a configuration bit (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: stm32: avoid clearing DMAT bit during transfer
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: use min() for size computation in iterate_tty_read()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit bc6a9a2
* Mon Aug 26 2024 ptesarik@suse.com
- tty: switch size and count types in iterate_tty_read() to size_t
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: use ssize_t for iterate_tty_read() returned type
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: use min() in iterate_tty_write() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- tty: rename and de-inline do_tty_write() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty: don't pass write() to do_tty_write() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit 7377b6a
* Mon Aug 26 2024 ptesarik@suse.com
- tty: change tty_write_lock()'s ndelay parameter to bool
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: sifive: Remove redundant of_match_ptr() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty: serial: samsung: Set missing PM ops for hibernation support
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: serial: xilinx_uartps: Do not check for 0 return after
  calling platform_get_irq() (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- tty: serial: meson: refactor objects definition for different
  devnames (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit e959e86
* Mon Aug 26 2024 ptesarik@suse.com
- 8250_men_mcb: fix error handling in
  read_uarts_available_from_reg() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- serial: st-asc: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: imx: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: sifive: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit d103400
* Mon Aug 26 2024 ptesarik@suse.com
- serial: mvebu-uart: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: sccnxp: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: sprd: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: mps2-uart: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: vt8500: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: fsl_lpuart: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit fe3c157
* Mon Aug 26 2024 ptesarik@suse.com
- serial: omap: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: tegra: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: linflexuart: Use
  devm_platform_get_and_ioremap_resource() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: clps711x: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: bcm63xx-uart: Use
  devm_platform_get_and_ioremap_resource() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit 442a43a
* Mon Aug 26 2024 ptesarik@suse.com
- serial: ar933x: Use devm_platform_get_and_ioremap_resource()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: qcom-geni: clean up clock-rate debug printk (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty: serial: fsl_lpuart: add IDLE interrupt support for
  rx_dma on imx7ulp/imx8ulp/imx8qxp (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- tty: serial: fsl_lpuart: move the lpuart32_int() below
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: serial: 8250: Define earlycon for mrvl,mmp-uart
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 048ed41
* Mon Aug 26 2024 ptesarik@suse.com
- tty: serial: meson: add independent uart_data for A1 SoC family
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: serial: meson: introduce separate uart_data for S4 SoC
  family (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: serial: meson: apply ttyS devname instead of ttyAML for
  new SoCs (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: serial: meson: redesign the module to platform_driver
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: serial: meson: use dev_err_probe (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- Refresh
  patches.suse/tty-serial-meson-fix-hard-LOCKUP-on-crtscts-mode.patch.
- commit 81dc1c3
* Mon Aug 26 2024 ptesarik@suse.com
- 8250_men_mcb: Make UART config auto configurable (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- 8250_men_mcb: Read num ports from register data (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- 8250_men_mcb: Add clockrate speed for G215/F215 boards
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: tegra: Don't print error on probe deferral (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty: Explicitly include correct DT includes (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/serial-imx-Introduce-timeout-when-waiting-on-transmi.patch.
- commit 3f8d73f
* Mon Aug 26 2024 ptesarik@suse.com
- serial: qcom-geni: use icc tag defines (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- serial: drivers: switch ch and flag to u8 (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/serial-max3100-Lock-port-lock-when-calling-uart_hand.patch.
- serial: omap-serial: remove flag from serial_omap_rdi()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: arc_uart: simplify flags handling in
  arc_serial_rx_chars() (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- serial: make uart_insert_char() accept u8s (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit bfcf125
* Mon Aug 26 2024 ptesarik@suse.com
- serial: convert uart sysrq handling to u8 (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty: make check_tty_count() void (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- ARM: entry: Make asm coproc dispatch code NWFPE only
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- ARM: iwmmxt: Use undef hook to enable coprocessor for task
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- ARM: entry: Disregard Thumb undef exception in coproc dispatch
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit b8595f0
* Mon Aug 26 2024 ptesarik@suse.com
- ARM: vfp: Use undef hook for handling VFP exceptions
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- ARM: kernel: Get rid of thread_info::used_cp[] array
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- ARM: vfp: Reimplement VFP exception entry in C code (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- ARM: vfp: Remove workaround for Feroceon CPUs (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- ARM: vfp: Record VFP bounces as perf emulation faults
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 8dc51a0
* Mon Aug 26 2024 ptesarik@suse.com
- kill do_each_thread() (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- sched: avoid false lockdep splat in put_task_struct()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: core: Fix serial core port id to not use port->line
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: core: Controller id cannot be negative (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- ARM: mm: Make virt_to_pfn() a static inline (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit 898f0c4
* Mon Aug 26 2024 ptesarik@suse.com
- tty_audit: make data of tty_audit_log() const (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty_audit: make icanon a bool (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- tty_audit: invert the condition in tty_audit_log() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty_audit: use kzalloc() in tty_audit_buf_alloc() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty_audit: use TASK_COMM_LEN for task comm (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit 497271a
* Mon Aug 26 2024 ptesarik@suse.com
- tty: tty_io: update timestamps on all device nodes (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: core: fix -EPROBE_DEFER handling in init (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- tty: serial: samsung_tty: Use abs() to simplify some code
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250: Apply FSL workarounds also without
  SERIAL_8250_CONSOLE (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- commit ad55bc8
* Mon Aug 26 2024 ptesarik@suse.com
- serial: core: don't kfree device managed data (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: 8250_mtk: Simplify clock sequencing and runtime PM
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: core: Fix error handling for
  serial_core_ctrl_device_add() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- serial: core: Fix probing serial_base_bus devices (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: core: Don't drop port_mutex in
  serial_core_remove_one_port (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- commit 54dc43c
* Mon Aug 26 2024 ptesarik@suse.com
- serial: core: Start managing serial controllers to enable
  runtime PM (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/serial-8250-Fix-oops-for-port-pm-on-uart_chang.patch.
- serial: 8250: omap: convert to modern PM ops (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/serial-8250_omap-Use-force_suspend-and-resume-f.patch.
- serial: 8250: omap: Move uart_write() inside PM section
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250-fsl: Expand description of the MPC83xx UART's
  misbehaviour (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: Indicate fintek option may also be required for RS232
  support (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 4b15607
* Mon Aug 26 2024 ptesarik@suse.com
- tty: serial: fsl_lpuart: Check the return value of
  dmaengine_tx_status (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- serial: Switch i2c drivers back to use .probe() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: 8250: synchronize and annotate UART_IER access
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250: lock port for omap8250_restore_regs() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: 8250: lock port for rx_dma() callback (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit e0ca1a8
* Mon Aug 26 2024 ptesarik@suse.com
- serial: 8250: lock port in startup() callbacks (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: Make uart_remove_one_port() return void (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: 8250_rt288x: Remove unnecessary UART_REG_UNMAPPED
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250_rt288x: Name non-standard divisor latch reg
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250: RT288x/Au1xxx code away from core (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/serial-8250_omap-Add-earlycon-support-for-the-AM654-.patch.
- commit a2895ad
* Mon Aug 26 2024 ptesarik@suse.com
- serial: 8250: Add dl_read/write, bugs and mapsize into
  plat_serial8250_port (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- Refresh
  patches.suse/Revert-8250-add-support-for-ASIX-devices-with-a.patch.
- serial: 8250: Document uart_8250_port's ->dl_read/write()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250: Change dl_read/write to handle value as u32
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250: Allow using ports higher than
  SERIAL_8250_RUNTIME_UARTS (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- serial: 8250: omap: Shut down on remove for console uart
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/serial-8250-omap-Don-t-skip-resource-freeing-if-pm_r.patch.
- commit d44d1c4
* Mon Aug 26 2024 ptesarik@suse.com
- serial: 8250: omap: Fix life cycle issues for interrupt handlers
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250: omap: Fix imprecise external abort for
  omap_8250_pm() (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- Refresh
  patches.suse/serial-8250-omap-Don-t-skip-resource-freeing-if-pm_r.patch.
- Refresh
  patches.suse/serial-8250_omap-Fix-errors-with-no_console_suspend.patch.
- Refresh
  patches.suse/serial-8250_omap-Implementation-of-Errata-i2310.patch.
- serial: pl011: set UART011_CR_RXE in pl011_set_termios after
  port shutdown (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: serial: fsl_lpuart: optimize the timer based EOP logic
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- device property: Implement device_is_compatible() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit f402fd9
* Mon Aug 26 2024 ptesarik@suse.com
- serial: qcom_geni: Comment use of devm_krealloc rather than
  devm_krealloc_array (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- panic: hide unused global functions (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- lockdep: Add lock_set_cmp_fn() annotation (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- cpuidle: Use local_clock_noinstr() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- sched/clock: Provide local_clock_noinstr() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- x86/tsc: Provide sched_clock_noinstr() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- commit d6687b5
* Mon Aug 26 2024 ptesarik@suse.com
- math64: Always inline u128 version of mul_u64_u64_shr()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- s390/time: Provide sched_clock_noinstr() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- arm64/arch_timer: Provide noinstr sched_clock_read() functions
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- arm64/io: Always inline all of __raw_{read,write}[bwlq]()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- time/sched_clock: Provide sched_clock_noinstr() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit b0e396c
* Mon Aug 26 2024 ptesarik@suse.com
- seqlock/latch: Provide raw_read_seqcount_latch_retry()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- arm: update in-source documentation references (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- ARM: 9312/1: vfp: include asm/neon.h in vfpmodule.c (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- commit 5988720
* Mon Aug 26 2024 bdas@suse.de
- x86/kaslr: Expose and use the end of the physical memory
  address space (bsc#1229443).
- commit 5b98c4e
* Mon Aug 26 2024 dsterba@suse.com
- tls: fix missing memory barrier in tls_init (CVE-2024-36489 bsc#1226874)
- commit 67db543
* Mon Aug 26 2024 tiwai@suse.de
- thermal: intel: int340x: Free MSI IRQ vectors on module exit
  (jsc#PED-10407).
- thermal: intel: int340x: Allow limited thermal MSI support
  (jsc#PED-10407).
- thermal: intel: int340x: Fix kernel warning during MSI cleanup
  (jsc#PED-10407).
- thermal: intel: int340x: Enable WLT and power floor support
  for Lunar Lake (jsc#PED-10407).
- thermal: intel: int340x: Support MSI interrupt for Lunar Lake
  (jsc#PED-10407).
- thermal: intel: int340x: Remove unnecessary calls to free irq
  (jsc#PED-10407).
- thermal: intel: intel_pch: Improve cooling log (jsc#PED-10407).
- thermal: int3403: remove unused struct
  'int3403_performance_state' (jsc#PED-10407).
- thermal: int3400: Use sizeof(*pointer) instead of sizeof(type)
  (jsc#PED-10407).
- ACPI: DPTF: Add Lunar Lake support (jsc#PED-10407).
- thermal: intel: hfi: Increase the number of CPU capabilities
  per netlink event (jsc#PED-10407).
- thermal: intel: hfi: Rename HFI_MAX_THERM_NOTIFY_COUNT
  (jsc#PED-10407).
- thermal: intel: hfi: Shorten the thermal netlink event delay
  to 100ms (jsc#PED-10407).
- thermal: intel: hfi: Rename HFI_UPDATE_INTERVAL (jsc#PED-10407).
- thermal: intel: Add missing module description (jsc#PED-10407).
- thermal: intel: int340x_thermal: replace deprecated strncpy()
  with strscpy() (jsc#PED-10407).
- commit c4c5001
* Mon Aug 26 2024 tiwai@suse.de
- thermal: intel: int340x: Add DLVR support for Lunar Lake
  (jsc#PED-10407).
- thermal: intel: int340x: Capability to map user space to
  firmware values (jsc#PED-10407).
- thermal: intel: int340x: Cleanup of DLVR sysfs on driver remove
  (jsc#PED-10407).
- commit 40be547
* Mon Aug 26 2024 tiwai@suse.de
- Update patch reference for intel thermal driver (jsc#PED-10201)
- commit 586e143
* Mon Aug 26 2024 vkarasulli@suse.de
- iommu: Add kABI workaround patch (bsc#1223742
  CVE-2024-27079).
- commit c4ebc76
* Mon Aug 26 2024 wqu@suse.com
- btrfs: copy dir permission and time when creating a stub
  subvolume (bsc#1228321).
- commit 46e95d1
* Sun Aug 25 2024 tiwai@suse.de
- Refresh patches.suse/0006-KVM-guest_memfd-extract-__kvm_gmem_get_pfn.patch
  Fix a wrong return for the merge-conflict fix.
  The current SLE15-SP7 code is slightly different from the latest upstream.
- commit 8c9c102
* Sat Aug 24 2024 tiwai@suse.de
- nouveau/firmware: use dma non-coherent allocator (git-fixes).
- drm/amdgpu/sdma5.2: limit wptr workaround to sdma 5.2.1
  (git-fixes).
- drm/msm/dpu: cleanup FB if dpu_format_populate_layout fails
  (git-fixes).
- drm/msm/dp: reset the link phy params before link training
  (git-fixes).
- drm/msm/dp: fix the max supported bpp logic (git-fixes).
- drm/msm/dpu: don't play tricks with debug macros (git-fixes).
- mmc: mmc_test: Fix NULL dereference on allocation failure
  (git-fixes).
- mmc: dw_mmc: allow biu and ciu clocks to defer (git-fixes).
- mmc: mtk-sd: receive cmd8 data when hs400 tuning fail
  (git-fixes).
- commit ec72baf
* Fri Aug 23 2024 krisman@suse.de
- filelock: Fix fcntl/close race recovery compat path (bsc#1228427
  CVE-2024-41020).
- commit 2c615e8
* Fri Aug 23 2024 vkarasulli@suse.de
- vfio/pci: fix potential memory leak in vfio_intx_enable()
  (git-fixes).
- commit 45c2786
* Fri Aug 23 2024 vkarasulli@suse.de
- vfio: Introduce interface to flush virqfd inject workqueue
  (CVE-2024-26812 bsc#1222808).
- commit 0704da7
* Fri Aug 23 2024 jgross@suse.com
- KVM: x86: Disallow read-only memslots for SEV-ES and SEV-SNP
  (and TDX) (git-fixes).
- commit a269b15
* Fri Aug 23 2024 jgross@suse.com
- KVM: SEV: Implement gmem hook for invalidating private pages
  (jsc#PED-5122).
- Update config files.
- commit 48cc52c
* Fri Aug 23 2024 jgross@suse.com
- KVM: SEV: Implement gmem hook for initializing private pages
  (jsc#PED-5122).
- Update config files.
- commit 2610bc7
* Fri Aug 23 2024 vkarasulli@suse.de
- vfio/pci: Create persistent INTx handler (CVE-2024-26812
  bsc#1222808).
- commit c0eeff7
* Fri Aug 23 2024 mgorman@suse.de
- README.BRANCH: Add Petr Tesarik as branch maintainer
- commit e83c39e
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Fix incorrect error code printout in fred_bad_type() (git-fixes).
- commit 6f369a8
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Fix typo in Kconfig description (git-fixes).
- commit a3839d4
* Fri Aug 23 2024 mkubecek@suse.cz
- netfilter: nf_tables: discard table flag update with pending
  basechain deletion (CVE-2024-35897 bsc#1224510).
- netfilter: nf_tables: reject table flag and netdev basechain
  updates (CVE-2024-35897 bsc#1224510).
- commit bc3bca5
* Fri Aug 23 2024 nik.borisov@suse.com
- MAINTAINERS: Add a maintainer entry for FRED (jsc#PED-10236).
- commit 1d1fb28
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Fix init_task thread stack pointer initialization (jsc#PED-10236).
- commit dac8439
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Fix a build warning with allmodconfig due to 'inline' failing to inline properly (jsc#PED-10236).
- commit 5323d23
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Invoke FRED initialization code to enable FRED (jsc#PED-10236).
- commit 1cea8b4
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Add FRED initialization functions (jsc#PED-10236).
- commit 9bacc0b
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/syscall: Split IDT syscall setup code into idt_syscall_init() (jsc#PED-10236).
- commit 78d6cf9
* Fri Aug 23 2024 nik.borisov@suse.com
- KVM: VMX: Call fred_entry_from_kvm() for IRQ/NMI handling (jsc#PED-10236).
- commit 286c6b4
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/entry: Add fred_entry_from_kvm() for VMX to handle IRQ/NMI (jsc#PED-10236).
- commit e91f47f
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/entry/calling: Allow PUSH_AND_CLEAR_REGS being used beyond actual  entry code (jsc#PED-10236).
- commit fa70b45
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Fixup fault on ERETU by jumping to fred_entrypoint_user (jsc#PED-10236).
- commit b838b91
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Let ret_from_fork_asm() jmp to asm_fred_exit_user when FRED is enabled (jsc#PED-10236).
- commit d6f6547
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/traps: Add sysvec_install() to install a system interrupt handler (jsc#PED-10236).
- commit 24f4cd0
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: FRED entry/exit and dispatch code (jsc#PED-10236).
- Refresh
  patches.suse/x86-bugs-Fix-the-SRSO-mitigation-on-Zen3-4.patch.
- commit 09e49bb
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Add a machine check entry stub for FRED (jsc#PED-10236).
- commit 1c5b1a1
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Add a NMI entry stub for FRED (jsc#PED-10236).
- commit 7b999cb
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Add a debug fault entry stub for FRED (jsc#PED-10236).
- commit 706f1aa
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/idtentry: Incorporate definitions/declarations of the FRED entries (jsc#PED-10236).
- commit e0c3e0b
* Fri Aug 23 2024 mkubecek@suse.cz
- kabi: restore const specifier in flow_offload_route_init()
  (CVE-2024-27403 bsc#1224415).
- netfilter: nft_flow_offload: reset dst in route object after
  setting up flow (CVE-2024-27403 bsc#1224415).
- commit f1d28bc
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Make exc_page_fault() work for FRED (jsc#PED-10236).
- Refresh patches.suse/x86-fault-Dump-RMP-table-information-when-RMP-page-faults-occur.
- commit 1e78b66
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Allow single-step trap and NMI when starting a new task (jsc#PED-10236).
- commit e51fa23
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: No ESPFIX needed when FRED is enabled (jsc#PED-10236).
- commit 3a2e473
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Disallow the swapgs instruction when FRED is enabled (jsc#PED-10236).
- commit 86c14bd
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Update MSR_IA32_FRED_RSP0 during task switch (jsc#PED-10236).
- commit 98b02ab
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Reserve space for the FRED stack frame (jsc#PED-10236).
- commit 20c25f5
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Add a new header file for FRED definitions (jsc#PED-10236).
- commit d7b2831
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/ptrace: Add FRED additional information to the pt_regs structure (jsc#PED-10236).
- commit 9e63d83
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/ptrace: Cleanup the definition of the pt_regs structure (jsc#PED-10236).
- commit 5ec5fb8
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/cpu: Add MSR numbers for FRED configuration (jsc#PED-10236).
- commit 04bffbb
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/cpu: Add X86_CR4_FRED macro (jsc#PED-10236).
- commit 69782a8
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/objtool: Teach objtool about ERET (jsc#PED-10236).
- commit 8992f34
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/opcode: Add ERET instructions to the x86 opcode map (jsc#PED-10236).
- commit 1fcadbc
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Add a fred= cmdline param (jsc#PED-10236).
- commit b3f1806
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Disable FRED support if CONFIG_X86_FRED is disabled  (jsc#PED-10236).
- Refresh patches.suse/x86-cpufeatures-Add-SEV-SNP-CPU-feature.
- Refresh patches.suse/x86-cpufeatures-Enable-unmask-SEV-SNP-CPU-feature.
- commit 1f8603b
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/cpufeatures: Add the CPU feature bit for FRED (jsc#PED-10236).
- commit 3c372ca
* Fri Aug 23 2024 tiwai@suse.de
- Bluetooth: MGMT: Add error handling to pair_device()
  (git-fixes).
- Bluetooth: SMP: Fix assumption of Central always being Initiator
  (git-fixes).
- Bluetooth: hci_core: Fix LE quote calculation (git-fixes).
- commit 82ede4a
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/fred: Add Kconfig option for FRED (CONFIG_X86_FRED) (jsc#PED-10236).
- commit 798e495
* Fri Aug 23 2024 nik.borisov@suse.com
- Documentation/x86/64: Add documentation for FRED (jsc#PED-10236).
- commit 6e88ec9
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/trapnr: Add event type macros to <asm/trapnr.h> (jsc#PED-10236).
- commit fecd499
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/entry: Remove idtentry_sysvec from entry_{32,64}.S (jsc#PED-10236).
- commit 01e57c3
* Fri Aug 23 2024 nik.borisov@suse.com
- x86/cpufeatures,opcode,msr: Add the WRMSRNS instruction support (jsc#PED-10236).
- commit 87094b3
* Fri Aug 23 2024 sjaeckel@suse.de
- netfilter: nf_tables: fix memleak in map from abort path
  (CVE-2024-27011 bsc#1223803).
- commit df3e052
* Fri Aug 23 2024 tiwai@suse.de
- README.BRANCH: update maintainers
- commit 167e5e2
* Fri Aug 23 2024 tiwai@suse.de
- Update intel thermal patch reference (jsc#PED-10222)
- commit dfc5e63
* Fri Aug 23 2024 jgross@suse.com
- KVM: Reject overly excessive IDs in KVM_CREATE_VCPU (git-fixes).
- commit acfc6dd
* Fri Aug 23 2024 jgross@suse.com
- KVM: arm64: Fix __pkvm_init_switch_pgd call ABI (git-fixes).
- commit ca5dde8
* Fri Aug 23 2024 jgross@suse.com
- KVM: Stop processing *all* memslots when "null" mmu_notifier
  handler is found (git-fixes).
- commit edcaf30
* Fri Aug 23 2024 jgross@suse.com
- virt: guest_memfd: fix reference leak on hwpoisoned page
  (git-fixes).
- commit 7ac89c3
* Fri Aug 23 2024 jgross@suse.com
- KVM: arm64: AArch32: Fix spurious trapping of conditional
  instructions (git-fixes).
- commit 6b4a32b
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: Allow AArch32 PSTATE.M to be restored as System mode
  (git-fixes).
- commit d2c979d
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: Fix AArch32 register narrowing on userspace write
  (git-fixes).
- commit c002253
* Thu Aug 22 2024 jgross@suse.com
- KVM: fix kvm_mmu_memory_cache allocation warning (git-fixes).
- commit 9570c83
* Thu Aug 22 2024 jgross@suse.com
- KVM: Always flush async #PF workqueue when vCPU is being
  destroyed (git-fixes).
- commit bbeeae4
* Thu Aug 22 2024 vkarasulli@suse.de
- iommu: Add static iommu_ops->release_domain (bsc#1223742
  CVE-2024-27079).
- iommu/vt-d: Fix NULL domain on device release (bsc#1223742
  CVE-2024-27079).
- Refresh
  patches.suse/iommu-vt-d-Fix-WARN_ON-in-iommu-probe-path.patch.
- commit 5ddde3c
* Thu Aug 22 2024 jgross@suse.com
- KVM: Make KVM_MEM_GUEST_MEMFD mutually exclusive with
  KVM_MEM_READONLY (git-fixes).
- commit 7a71a2a
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: vgic-its: Test for valid IRQ in MOVALL handler
  (git-fixes).
- commit ebc54df
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: vgic-its: Test for valid IRQ in
  its_sync_lpi_pending_table() (git-fixes).
- commit 989930f
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: Add missing memory barriers when switching to
  pKVM's hyp pgd (git-fixes).
- commit 5599b84
* Thu Aug 22 2024 tiwai@suse.de
- supported.conf: update for intel thermal drivers (jsc#PED-10050)
- commit 6bd53ef
* Thu Aug 22 2024 tiwai@suse.de
- Update config files: delete obsoleted lines
- commit 7be65b7
* Thu Aug 22 2024 tiwai@suse.de
- Update config files: CONFIG_ACPI_THERMAL_LIB=y autoselect (jsc#PED-10050)
- commit b3c562f
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: vgic-v4: Restore pending state on host userspace
  write (git-fixes).
- commit ba9826d
* Thu Aug 22 2024 tiwai@suse.de
- thermal: core: Add governor callback for thermal zone change
  (jsc#PED-10050).
- commit 2bdc0ae
* Thu Aug 22 2024 tiwai@suse.de
- thermal/core: Check get_temp ops is present when registering
  a tz (jsc#PED-10050).
- Refresh
  patches.suse/thermal-core-Fix-thermal-zone-suspend-resume-synchro.patch.
- commit b80bc9a
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: vgic: Force vcpu vgic teardown on vcpu destroy
  (git-fixes).
- commit 26e04aa
* Thu Aug 22 2024 tiwai@suse.de
- thermal: int340x: processor_thermal: Support shared interrupts
  (jsc#PED-10050).
- commit 46f9c76
* Thu Aug 22 2024 tiwai@suse.de
- thermal: ACPI: Invalidate trip points with temperature of 0
  or below (jsc#PED-10050).
- commit 9575253
* Thu Aug 22 2024 tiwai@suse.de
- thermal: Drop spaces before TABs (jsc#PED-10050).
- thermal: intel: int340x_thermal: Use thermal zone accessor
  functions (jsc#PED-10050).
- thermal: int340x: processor_thermal: Add Lunar Lake-M PCI ID
  (jsc#PED-10050).
- thermal: core: remove unnecessary check in
  trip_point_hyst_store() (jsc#PED-10050).
- thermal: core: Remove excess empty line from a comment
  (jsc#PED-10050).
- thermal: sysfs: Fix up white space in trip_point_temp_store()
  (jsc#PED-10050).
- thermal: intel: powerclamp: Remove dead code for target mwait
  value (jsc#PED-10050).
- thermal: core: Use kstrdup_const() during cooling device
  registration (jsc#PED-10050).
- thermal: intel: hfi: Enable an HFI instance from its first
  online CPU (jsc#PED-10050).
- thermal: trip: Constify thermal zone argument of
  thermal_zone_trip_id() (jsc#PED-10050).
- commit dc6622c
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: vgic: Add a non-locking primitive for
  kvm_vgic_vcpu_destroy() (git-fixes).
- commit 686bc1c
* Thu Aug 22 2024 tiwai@suse.de
- thermal: core: Initialize poll_queue in
  thermal_zone_device_init() (jsc#PED-10050).
- commit edf3158
* Thu Aug 22 2024 tiwai@suse.de
- thermal/sysfs: Update governors when the 'weight' has changed
  (jsc#PED-10050).
- thermal/sysfs: Update instance->weight under tz lock
  (jsc#PED-10050).
- thermal: netlink: Add thermal_group_has_listeners() helper
  (jsc#PED-10050).
- thermal: netlink: Add enum for mutlicast groups indexes
  (jsc#PED-10050).
- thermal: cpuidle_cooling: fix kernel-doc warning and a spello
  (jsc#PED-10050).
- commit b6af56d
* Thu Aug 22 2024 mkubecek@suse.cz
- netfilter: nft_limit: reject configurations that cause integer
  overflow (CVE-2024-26668 bsc#1222335).
- commit 8ea214b
* Thu Aug 22 2024 tiwai@suse.de
- thermal: helpers: Use for_each_trip() in
  __thermal_zone_get_temp() (jsc#PED-10050).
- thermal: trip: Drop redundant __thermal_zone_get_trip() header
  (jsc#PED-10050).
- thermal: core: Rework thermal zone availability check
  (jsc#PED-10050).
- thermal: Drop redundant and confusing device_is_registered()
  checks (jsc#PED-10050).
- thermal: core: Make thermal_zone_device_unregister() return
  after freeing the zone (jsc#PED-10050).
- thermal: sysfs: Rework the reading of trip point attributes
  (jsc#PED-10050).
- commit fb69e60
* Thu Aug 22 2024 tiwai@suse.de
- overflow: Change DEFINE_FLEX to take __counted_by member
  (jsc#PED-10288).
- commit 45b4eb7
* Thu Aug 22 2024 mkubecek@suse.cz
- netfilter: nf_tables: set dormant flag on hook register failure
  (CVE-2024-26835 bsc#1222967).
- commit 8f4d028
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: vgic: Simplify kvm_vgic_destroy() (git-fixes).
- commit 3a96863
* Thu Aug 22 2024 jgross@suse.com
- Revert "KVM: Prevent module exit until all VMs are freed"
  (git-fixes).
- commit c075225
* Thu Aug 22 2024 tiwai@suse.de
- thermal: sysfs: Rework the handling of trip point updates
  (jsc#PED-10050).
- thermal: trip: Drop a redundant check from
  thermal_zone_set_trip() (jsc#PED-10050).
- thermal: ACPI: Move the ACPI thermal library to drivers/acpi/
  (jsc#PED-10050).
- thermal: int340x: processor_thermal: Handle power floor
  interrupts (jsc#PED-10050).
- thermal: int340x: processor_thermal: Support power floor
  notifications (jsc#PED-10050).
- thermal: int340x: processor_thermal: Set feature mask before
  proc_thermal_add (jsc#PED-10050).
- thermal: int340x: processor_thermal: Common function to clear
  SOC interrupt (jsc#PED-10050).
- thermal: int340x: processor_thermal: Move interrupt status
  MMIO offset to common header (jsc#PED-10050).
- thermal: int340x: Use thermal_zone_for_each_trip()
  (jsc#PED-10050).
- thermal: int340x: processor_thermal: Ack all PCI interrupts
  (jsc#PED-10050).
- thermal: int340x: Add ArrowLake-S PCI ID (jsc#PED-10050).
- thermal: int340x: Handle workload hint interrupts
  (jsc#PED-10050).
- thermal: int340x: processor_thermal: Add workload type hint
  interface (jsc#PED-10050).
- commit 6478189
* Thu Aug 22 2024 tiwai@suse.de
- thermal: int340x: Remove PROC_THERMAL_FEATURE_WLT_REQ for
  Meteor Lake (jsc#PED-10050).
- thermal: int340x: processor_thermal: Use non MSI interrupts
  by default (jsc#PED-10050).
- thermal: int340x: processor_thermal: Add interrupt configuration
  function (jsc#PED-10050).
- thermal: int340x: processor_thermal: Move mailbox code to
  common module (jsc#PED-10050).
- thermal: trip: Define for_each_trip() macro (jsc#PED-10050).
- thermal: trip: Simplify computing trip indices (jsc#PED-10050).
- commit 472c7a3
* Thu Aug 22 2024 tiwai@suse.de
- thermal: trip: Remove lockdep assertion from
  for_each_thermal_trip() (jsc#PED-10050).
- thermal: int3406: Convert to platform remove callback returning
  void (jsc#PED-10050).
- thermal: int3403: Convert to platform remove callback returning
  void (jsc#PED-10050).
- thermal: int3402: Convert to platform remove callback returning
  void (jsc#PED-10050).
- thermal: int3401: Convert to platform remove callback returning
  void (jsc#PED-10050).
- thermal: int3400: Convert to platform remove callback returning
  void (jsc#PED-10050).
- thermal: core: Add function to walk trips under zone lock
  (jsc#PED-10050).
- thermal: core: Allow trip pointers to be used for cooling
  device binding (jsc#PED-10050).
- thermal: core: Drop trips_disabled bitmask (jsc#PED-10050).
- thermal: core: Fix disabled trip point check in
  handle_thermal_trip() (jsc#PED-10050).
- thermal: core: Drop thermal_zone_device_register()
  (jsc#PED-10050).
- thermal: Use thermal_tripless_zone_device_register()
  (jsc#PED-10050).
- thermal: core: Add function for registering tripless thermal
  zones (jsc#PED-10050).
- thermal: core: Clean up headers of thermal zone registration
  functions (jsc#PED-10050).
- commit 9b8c3a1
* Thu Aug 22 2024 mkubecek@suse.cz
- netfilter: nft_chain_filter: handle NETDEV_UNREGISTER for
  inet/ingress basechain (CVE-2024-26808 bsc#1222634).
- commit 7f0379b
* Thu Aug 22 2024 tiwai@suse.de
- thermal: core: Drop unused .get_trip_*() callbacks
  (jsc#PED-10050).
- thermal: intel: intel_soc_dts_iosf: Remove redundant check
  (jsc#PED-10050).
- thermal: intel: int340x: simplify the code with
  module_platform_driver() (jsc#PED-10050).
- thermal: intel: intel_soc_dts_iosf: Use struct thermal_trip
  (jsc#PED-10050).
- thermal: intel: intel_soc_dts_iosf: Rework critical trip setup
  (jsc#PED-10050).
- thermal: intel: intel_soc_dts_iosf: Add helper for resetting
  trip points (jsc#PED-10050).
- thermal: intel: intel_soc_dts_iosf: Change initialization
  ordering (jsc#PED-10050).
- thermal: intel: intel_soc_dts_iosf: Pass sensors to
  update_trip_temp() (jsc#PED-10050).
- thermal: intel: intel_soc_dts_iosf: Untangle update_trip_temp()
  (jsc#PED-10050).
- thermal: intel: intel_soc_dts_iosf: Always assume notification
  support (jsc#PED-10050).
- thermal: intel: intel_soc_dts_iosf: Drop redundant symbol
  definition (jsc#PED-10050).
- thermal: intel: intel_soc_dts_iosf: Always use 2 trips
  (jsc#PED-10050).
- thermal/drivers/int340x: Do not check the thermal zone state
  (jsc#PED-10050).
- thermal/drivers/int3400: Use thermal zone device wrappers
  (jsc#PED-10050).
- thermal: core: Do not handle trip points with invalid
  temperature (jsc#PED-10050).
- powercap: intel_rapl: Fix a sparse warning in TPMI interface
  (jsc#PED-10050).
- thermal: intel: int340x_thermal: New IOCTLs for Passive v2 table
  (jsc#PED-10050).
- commit b0aa59d
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: GICv4: Do not perform a map to a mapped vLPI
  (git-fixes).
- commit 919175d
* Thu Aug 22 2024 tiwai@suse.de
- supported.conf: mark intel-ishtp-loader as supported (jsc#PED-10288)
- commit 4bf2362
* Thu Aug 22 2024 tiwai@suse.de
- HID: intel-ish-hid: add MODULE_DESCRIPTION() (jsc#PED-10288).
- HID: intel-ish-hid: fix ishtp_wait_resume() kernel-doc
  (jsc#PED-10288).
- HID: intel-ish-hid: fix endian-conversion (jsc#PED-10288).
- HID: intel-ish-hid: Fix build error for COMPILE_TEST
  (jsc#PED-10288).
- HID: intel-ish-hid: handler multiple MNG_RESET_NOTIFY messages
  (jsc#PED-10288).
- HID: intel-ish-hid: Implement loading firmware from host feature
  (jsc#PED-10288).
- HID: intel-ish-hid: Add driver_data for specifying the firmware
  filename (jsc#PED-10288).
- HID: intel-ish-hid: ipc: Add Lunar Lake-M PCI device ID
  (jsc#PED-10288).
- HID: intel-ish-hid: Use PCI_VDEVICE() and rename device ID
  macros (jsc#PED-10288).
- HID: intel-ish-hid: ipc: Add Arrow Lake PCI device ID
  (jsc#PED-10288).
- HID: Intel-ish-hid: Ishtp: Fix sensor reads after ACPI S3
  suspend (jsc#PED-10288 jsc#PED-10032).
- HID: intel-ish-hid: ipc: Rework EHL OOB wakeup (jsc#PED-10288).
- HID: intel-ish-hid: ishtp-fw-loader: use helper functions for
  connection (jsc#PED-10288).
- HID: intel-ish-hid: ishtp-hid-client: use helper functions
  for connection (jsc#PED-10288).
- HID: Intel-ish-hid: Ishtp: Add helper functions for client
  connection (jsc#PED-10288).
- HID: make ishtp_cl_bus_type const (jsc#PED-10288).
- commit dffbc3a
* Thu Aug 22 2024 mkubecek@suse.cz
- netfilter: nft_set_pipapo: release elements in clone only from
  destroy path (CVE-2024-26809 bsc#1222633).
- commit d3a3287
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: vgic-v2: Use cpuid from userspace as vcpu_id
  (git-fixes).
- commit 7b3deae
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: timers: Correctly handle TGE flip with CNTPOFF_EL2
  (git-fixes).
- commit 48c0cad
* Thu Aug 22 2024 mkubecek@suse.cz
- netfilter: nf_tables: fix memleak when more than 255 elements
  expired (CVE-2023-52581 bsc#1220877).
- commit 26441fd
* Thu Aug 22 2024 jgross@suse.com
- KVM: Protect vcpu->pid dereference via debugfs with RCU
  (git-fixes).
- commit 55ae2a6
* Thu Aug 22 2024 jgross@suse.com
- KVM: arm64: timers: Fix resource leaks in kvm_timer_hyp_init()
  (git-fixes).
- commit f80cefe
* Thu Aug 22 2024 tiwai@suse.de
- Update config files: enable CONFIG_PINCTRL_METEORPOINT (jsc#PED-10341)
- commit e5276ac
* Thu Aug 22 2024 tiwai@suse.de
- blacklist.conf: Add pinctrl blacklist (jsc#PED-10341)
  The commit is rather useless for SLE kernel, and the backport for the
  missing macro would need too much unnecessary changes
- commit 5b7a034
* Thu Aug 22 2024 shung-hsi.yu@suse.com
- bpf: Fix updating attached freplace prog in prog_array map
  (bsc#1229297 CVE-2024-43837).
- commit a9d7d77
* Thu Aug 22 2024 tiwai@suse.de
- supported.conf: Add pinctrl-meteorpoint (jsc#PED-10341)
- commit 0ed135b
* Thu Aug 22 2024 tiwai@suse.de
- pinctrl: intel: Add Intel Meteor Point pin controller and GPIO
  support (jsc#PED-10341).
- pinctrl: intel: Make PM ops functions static (jsc#PED-10341).
- pinctrl: tigerlake: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: sunrisepoint: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: meteorlake: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: lewisburg: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: lakefield: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: jasperlake: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: icelake: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: geminilake: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: emmitsburg: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: elkhartlake: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: denverton: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: cedarfork: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: cannonlake: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: broxton: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: alderlake: Switch to use Intel pin control PM ops
  (jsc#PED-10341).
- pinctrl: intel: Provide Intel pin control wide PM ops structure
  (jsc#PED-10341).
- pinctrl: lynxpoint: drop runtime PM support (jsc#PED-10341).
- pinctrl: baytrail: drop runtime PM support (jsc#PED-10341).
- pinctrl: intel: consolidate ACPI dependency (jsc#PED-10341).
- pinctrl: cherryview: Switch to use DEFINE_NOIRQ_DEV_PM_OPS()
  helper (jsc#PED-10341).
- pinctrl: lynxpoint: Make use of pm_ptr() (jsc#PED-10341).
- pinctrl: baytrail: Make use of pm_ptr() (jsc#PED-10341).
- pinctrl: intel: Switch to use exported namespace
  (jsc#PED-10341).
- pinctrl: lynxpoint: reuse common functions from pinctrl-intel
  (jsc#PED-10341).
- pinctrl: cherryview: reuse common functions from pinctrl-intel
  (jsc#PED-10341).
- pinctrl: baytrail: reuse common functions from pinctrl-intel
  (jsc#PED-10341).
- pinctrl: intel: export common pinctrl functions (jsc#PED-10341).
- commit 22148aa
* Thu Aug 22 2024 nik.borisov@suse.com
- dma-direct: Leak pages on dma_set_decrypted() failure (bsc#1224535 CVE-2024-35939).
- commit 7de8166
* Thu Aug 22 2024 tiwai@suse.de
- scsi: ufs: ufs-pci: Add support for Intel Arrow Lake
  (jsc#PED-10352).
- commit 1634314
* Thu Aug 22 2024 tbogendoerfer@suse.de
- ice: Add a per-VF limit on number of FDIR filters
  (CVE-2024-42291 bsc#1229374).
- commit ee2b93b
* Thu Aug 22 2024 tbogendoerfer@suse.de
- net/mlx5: Fix missing lock on sync reset reload (CVE-2024-42268
  bsc#1229391).
- commit 268cdf6
* Thu Aug 22 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add a test to verify previous stacksafe() fix
  (bsc#1225903).
- bpf: Fix a kernel verifier crash in stacksafe() (bsc#1225903).
- commit dab2844
* Thu Aug 22 2024 dsterba@suse.com
- xdp: fix invalid wait context of page_pool_destroy() (CVE-2024-43834 bsc#1229314)
- commit 6348ec4
* Thu Aug 22 2024 jlee@suse.com
- clk: mediatek: mt7622-apmixedsys: Fix an error handling path
  in clk_mt8135_apmixed_probe() (bsc#1224711 CVE-2024-27433).
- commit 30e1ef1
* Thu Aug 22 2024 dsterba@suse.com
- netfilter: nfnetlink_queue: acquire rcu_read_lock() in instance_destroy_rcu() (CVE-2024-36286 bsc#1226801)
- commit 3278d5d
* Thu Aug 22 2024 dsterba@suse.com
- netfilter: tproxy: bail out if IP has been disabled on the device (CVE-2024-36270 1226798)
- commit 26814d6
* Thu Aug 22 2024 dsterba@suse.com
- netfilter: nf_conntrack_h323: Add protection for bmp length out of range (CVE-2024-26851 bsc#1223074)
- commit 6ad2cbe
* Wed Aug 21 2024 sjaeckel@suse.de
- net: bridge: mst: fix suspicious rcu usage in br_mst_set_state
  (CVE-2024-40920 bsc#1227781).
- net: bridge: mst: pass vlan group directly to
  br_mst_vlan_set_state (CVE-2024-40921 bsc#1227784).
- net: bridge: mst: fix vlan use-after-free (CVE-2024-36979
  bsc#1226604).
- commit 7beae73
* Wed Aug 21 2024 andrea.porta@suse.com
- blacklist.conf: git-fixes f2eaed1565acc2bdeb5c433f5f6c7bd7a0d62db1
  blacklisted since it involves backporting many other commits not
  that are relevnat only to gdb debug scripts and whose dependent
  commits may break kABI.
- commit 323e420
* Wed Aug 21 2024 rgoldwyn@suse.com
- erofs: fix inconsistent per-file compression format (bsc#1220252, CVE-2024-26590).
- commit 4f99bd1
* Wed Aug 21 2024 jlee@suse.com
- perf: hisi: Fix use-after-free when register pmu fails
  (bsc#1225582 CVE-2023-52859).
- commit a50ce06
* Wed Aug 21 2024 pmladek@suse.com
- printk/panic: Allow cpu backtraces to be written into ringbuffer
  during panic (bsc#1225607).
- commit 1ebfff4
* Wed Aug 21 2024 nik.borisov@suse.com
- platform/x86/intel/vsec: Remove nuisance message (jsc#PED-10233).
- commit f5f412a
* Wed Aug 21 2024 nik.borisov@suse.com
- platform/x86/intel/vsec: Add support for Lunar Lake M (jsc#PED-10233).
- commit 55567dd
* Wed Aug 21 2024 nik.borisov@suse.com
- platform/x86/intel/vsec: Add base address field (jsc#PED-10233).
- commit aed1815
* Wed Aug 21 2024 nik.borisov@suse.com
- platform/x86/intel/vsec: Add intel_vsec_register (jsc#PED-10233).
- commit cb022f6
* Wed Aug 21 2024 nik.borisov@suse.com
- platform/x86/intel/vsec: Assign auxdev parent by argument (jsc#PED-10233).
- commit e99c08a
* Wed Aug 21 2024 nik.borisov@suse.com
- platform/x86/intel/vsec: Use cleanup.h (jsc#PED-10233).
- commit df6c0e7
* Wed Aug 21 2024 nik.borisov@suse.com
- platform/x86/intel/vsec: remove platform_info from vsec device structure (jsc#PED-10233).
- commit 1d42e14
* Wed Aug 21 2024 nik.borisov@suse.com
- platform/x86/intel/vsec: Move structures to header (jsc#PED-10233).
- commit b6f6174
* Wed Aug 21 2024 nik.borisov@suse.com
- platform/x86/intel/vsec: Remove unnecessary return (jsc#PED-10233).
- commit de6ea1c
* Wed Aug 21 2024 jgross@suse.com
- net: drop bad gso csum_start and offset in virtio_net_hdr
  (git-fixes).
- commit 6d27b13
* Wed Aug 21 2024 shung-hsi.yu@suse.com
- selftests/bpf: Test for null-pointer-deref bugfix in
  resolve_prog_type() (bsc#1229297 CVE-2024-43837).
- bpf: Fix null pointer dereference in resolve_prog_type()
  for BPF_PROG_TYPE_EXT (bsc#1229297 CVE-2024-43837).
- commit 37e60d8
* Wed Aug 21 2024 shung-hsi.yu@suse.com
- bpf: simplify btf_get_prog_ctx_type() into
  btf_is_prog_ctx_type() (git-fixes).
- Refresh patches.suse/bpf-don-t-infer-PTR_TO_CTX-for-programs-with-unnamed.patch
- Refresh patches.suse/bpf-handle-bpf_user_pt_regs_t-typedef-explicitly-for.patch
- bpf: extract bpf_ctx_convert_map logic and make it more reusable
  (git-fixes).
- Refresh patches.suse/bpf-handle-bpf_user_pt_regs_t-typedef-explicitly-for.patch
- commit a1a0c24
* Wed Aug 21 2024 jgross@suse.com
- vhost: Release worker mutex during flushes (git-fixes).
- commit be0d4d9
* Wed Aug 21 2024 jgross@suse.com
- virtio: reenable config if freezing device failed (git-fixes).
- commit d96d64e
* Wed Aug 21 2024 neilb@suse.de
- kabi fix for SUNRPC: add a missing rpc_stat for TCP TLS
  (git-fixes).
- SUNRPC: add a missing rpc_stat for TCP TLS (git-fixes).
- commit 4fa6f6d
* Tue Aug 20 2024 dsterba@suse.com
- netfilter: iptables: Fix null-ptr-deref in iptable_nat_table_init() (CVE-2024-42270 bsc#1229404)
- commit eb407e1
* Tue Aug 20 2024 dsterba@suse.com
- netfilter: iptables: Fix potential null-ptr-deref in ip6table_nat_table_init() (CVE-2024-42269 bsc#1229402)
- commit 6f31e8c
* Tue Aug 20 2024 dsterba@suse.com
- tipc: Return non-zero value from tipc_udp_addr2str() on error (CVE-2024-42284 bsc#1229382)
- commit 003e7ab
* Tue Aug 20 2024 dsterba@suse.com
- net: nexthop: Initialize all fields in dumped nexthops (CVE-2024-42283 bsc#1229383)
- commit dd830eb
* Tue Aug 20 2024 dsterba@suse.com
- sysctl: always initialize i_uid/i_gid (CVE-2024-42312 bsc#1229357)
- commit 683a109
* Tue Aug 20 2024 dsterba@suse.com
- block: initialize integrity buffer to zero before writing it to media (CVE-2024-43854 bsc#1229345)
- commit bc065ac
* Tue Aug 20 2024 dsterba@suse.com
- ipvs: properly dereference pe in ip_vs_add_service (CVE-2024-42322 bsc#1229347)
- commit 5abcd51
* Tue Aug 20 2024 jgross@suse.com
- vhost-vdpa: switch to use vmf_insert_pfn() in the fault handler
  (git-fixes).
- commit efaee02
* Tue Aug 20 2024 jgross@suse.com
- net: missing check virtio (git-fixes).
- commit 547a4d8
* Tue Aug 20 2024 jgross@suse.com
- vhost/vsock: always initialize seqpacket_allow (git-fixes).
- commit 1501797
* Tue Aug 20 2024 jgross@suse.com
- vhost: Use virtqueue mutex for swapping worker (git-fixes).
- commit ee31e9d
* Tue Aug 20 2024 dwagner@suse.de
- nvme-sysfs: add 'tls_keyring' attribute (bsc#1221857).
- nvme-sysfs: add 'tls_configured_key' sysfs attribute
  (bsc#1221857).
- nvme: split off TLS sysfs attributes into a separate group
  (bsc#1221857).
- nvme: add a newline to the 'tls_key' sysfs attribute
  (bsc#1221857).
- nvme-tcp: check for invalidated or revoked key (bsc#1221857).
- nvme-tcp: sanitize TLS key handling (bsc#1221857).
- nvme: tcp: remove unnecessary goto statement (bsc#1221857).
- commit 95902b1
* Tue Aug 20 2024 dwagner@suse.de
- Refresh patches.suse/nvme-fabrics-typo-in-nvmf_parse_key.patch.
  Move into sorted section.
- commit 24e43c3
* Tue Aug 20 2024 jgross@suse.com
- vhost-scsi: Handle vhost_vq_work_queue failures for events
  (git-fixes).
- commit bb54ef9
* Tue Aug 20 2024 tiwai@suse.de
- Update DRM patch reference (CVE-2024-42308 bsc#1229411)
- commit ddc1933
* Tue Aug 20 2024 dwagner@suse.de
- Update
  patches.suse/nvme-tcp-fix-compile-time-checks-for-TLS-mode.patch
  (jsc#PED-6252 jsc#PED-5728 jsc#PED-5062 jsc#PED-3535
  bsc#1221857).
  Fix backporting error.
- commit 35c7df3
* Tue Aug 20 2024 tiwai@suse.de
- Update parport patch reference (CVE-2024-42301 bsc#1229407)
- commit 6707829
* Tue Aug 20 2024 dwagner@suse.de
- Refresh
  patches.suse/nvme-tcp-strict-pdu-pacing-to-avoid-send-stalls-on-T.patch.
  Use the version which got upload upstream.
- commit 4896f98
* Tue Aug 20 2024 jgross@suse.com
- blacklist.conf: add ffe6176b7f53 ("virtio: store owner from modules
  with register_virtio_driver()")
- commit 08df841
* Tue Aug 20 2024 jgross@suse.com
- virtio_net: use u64_stats_t infra to avoid data-races
  (git-fixes).
- commit 1825530
* Tue Aug 20 2024 oneukum@suse.com
- usb: typec: fsa4480: Check if the chip is really there
  (git-fixes).
- commit 771af75
* Tue Aug 20 2024 oneukum@suse.com
- usb: typec: fsa4480: Add support to swap SBU orientation
  (git-fixes).
- commit b744e01
* Tue Aug 20 2024 oneukum@suse.com
- usb: typec: fsa4480: add support for Audio Accessory Mode
  (git-fixes).
- commit 471d14e
* Tue Aug 20 2024 oneukum@suse.com
- usb: typec: fsa4480: rework mux & switch setup to handle more
  states (git-fixes).
- commit dc03605
* Tue Aug 20 2024 tiwai@suse.de
- irqchip/imx-irqsteer: Handle runtime power management correctly
  (CVE-2024-42290 bsc#1229379).
- commit a3bbc63
* Tue Aug 20 2024 ailiop@suse.com
- landlock: Don't lose track of restrictions on cred_transfer
  (bsc#1229351 CVE-2024-42318).
- commit e161e74
* Tue Aug 20 2024 rgoldwyn@suse.com
- apparmor: Fix null pointer deref when receiving skb during sock creation (bsc#1229287, CVE-2023-52889).
- commit 7a47d08
* Tue Aug 20 2024 jgross@suse.com
- kABI fix of: virtio-crypto: handle config changed by work queue
  (git-fixes).
- commit 2e4646f
* Tue Aug 20 2024 dwagner@suse.de
- nvme-multipath: implement "queue-depth" iopolicy (bsc#1227706).
- nvme-multipath: prepare for "queue-depth" iopolicy
  (bsc#1227706).
- commit 796fd31
* Tue Aug 20 2024 ailiop@suse.com
- nilfs2: handle inconsistent state in nilfs_btnode_create_block()
  (bsc#1229370 CVE-2024-42295).
- commit 34231c4
* Tue Aug 20 2024 iivanov@suse.de
- arm64: dts: imx8mp: Fix pgc vpu locations (git-fixes)
- commit 6f29859
* Tue Aug 20 2024 iivanov@suse.de
- arm64: dts: imx8mp: Fix pgc_mlmix location (git-fixes)
- commit 6b6ab8a
* Tue Aug 20 2024 tiwai@suse.de
- soc: qcom: icc-bwmon: Fix refcount imbalance seen during
  bwmon_remove (CVE-2024-43850 bsc#1229316).
- soc: qcom: icc-bwmon: Set default thresholds dynamically
  (CVE-2024-43850 bsc#1229316).
- commit e842a77
* Tue Aug 20 2024 iivanov@suse.de
- arm64: dts: imx8mp: add HDMI power-domains (git-fixes)
- commit 88b7cca
* Tue Aug 20 2024 iivanov@suse.de
- arm64: dts: imx8mp: Add NPU Node (git-fixes)
- commit 55a2e84
* Tue Aug 20 2024 tiwai@suse.de
- media: mediatek: vcodec: Handle invalid decoder vsi
  (CVE-2024-43831 bsc#1229309).
- commit a7b1ec0
* Tue Aug 20 2024 tbogendoerfer@suse.de
- bna: adjust 'name' buf size of bna_tcb and bna_ccb structures
  (CVE-2024-43839 bsc#1229301).
- net: mana: Add support for page sizes other than 4KB on ARM64
  (jsc#PED-8491 bsc#1226530).
- commit 24750b5
* Tue Aug 20 2024 ailiop@suse.com
- Squashfs: fix variable overflow triggered by sysbot (git-fixes).
- commit 90b77e5
* Tue Aug 20 2024 ailiop@suse.com
- squashfs: squashfs_read_data need to check if the length is 0
  (git-fixes).
- commit 1ab3d64
* Tue Aug 20 2024 ailiop@suse.com
- jfs: Fix shift-out-of-bounds in dbDiscardAG (git-fixes).
- commit f862c1b
* Tue Aug 20 2024 ailiop@suse.com
- jfs: fix null ptr deref in dtInsertEntry (git-fixes).
- commit 72d65ab
* Tue Aug 20 2024 ailiop@suse.com
- reiserfs: fix uninit-value in comp_keys (git-fixes).
- commit aeea4b8
* Tue Aug 20 2024 sjaeckel@suse.de
- Update
  patches.suse/0001-netlink-add-nla-be16-32-types-to-minlen-array.patch
  (CVE-2024-26849 bsc#1223053).
  Fixes: 2747893c94d9b55340403026d9430f2f93947449
- commit 4cf09d7
* Tue Aug 20 2024 jgross@suse.com
- virtio-crypto: handle config changed by work queue (git-fixes).
- Refresh
  patches.suse/crypto-virtio-Wait-for-tasklet-to-complete-on-device.patch.
- commit 3719b45
* Tue Aug 20 2024 lhenriques@suse.de
- fuse: Initialize beyond-EOF page contents before setting
  uptodate (bsc#1229456).
- fs/netfs/fscache_cookie: add missing "n_accesses" check
  (bsc#1229455).
- commit 1ffdccd
* Tue Aug 20 2024 mfranc@suse.cz
- s390/dasd: fix error recovery leading to data corruption on
  ESE devices (git-fixes bsc#1229452).
- commit 421d882
* Tue Aug 20 2024 pjakobsson@suse.de
- blacklist.conf: Change entry to alt-commit
- Refresh patches.suse/tools-Disable-__packed-attribute-compiler-warning-due-to-Werror-attributes.patch.
- commit a7c7d40
* Tue Aug 20 2024 mfranc@suse.cz
- net/iucv: fix the allocation size of iucv_path_table array
  (git-fixes bsc#1229451).
- commit 4e0b259
* Tue Aug 20 2024 mfranc@suse.cz
- blacklist.conf: we don't enable CONFIG_CPUMASK_OFFSTACK on s390
- commit 8a36035
* Tue Aug 20 2024 pjakobsson@suse.de
- Refresh patches.suse/0001-drm-mst-Fix-NULL-pointer-dereference-at-drm_dp_add_p.patch (git-fixes)
  Alt-commit
- commit 98e41cf
* Tue Aug 20 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-i915-vma-Fix-UAF-on-destroy-against-retire-race.patch (git-fixes)
  Alt-commit
- commit 11ef901
* Tue Aug 20 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Send-DTBCLK-disable-message-on-first.patch (git-fixes)
  Alt-commit
- commit 6d9aa0a
* Tue Aug 20 2024 pjakobsson@suse.de
- Refresh patches.suse/drm-amd-display-Fix-DPSTREAM-CLK-on-and-off-sequence.patch (git-fixes)
  Alt-commit
- commit 24768b9
* Tue Aug 20 2024 sjaeckel@suse.de
- tcp: use signed arithmetic in tcp_rtx_probe0_timed_out()
  (CVE-2024-41007 bsc#1227863).
- commit 35aaaf5
* Tue Aug 20 2024 tiwai@suse.de
- HID: wacom: Defer calculation of resolution until
  resolution_code is known (git-fixes).
- ALSA: usb: Fix UBSAN warning in parse_audio_unit()
  (stable-fixes).
- commit a485c9b
* Tue Aug 20 2024 tiwai@suse.de
- blacklist.conf: Add libata upstream revert entry (bsc#1229054)
- commit 5ded40a
* Tue Aug 20 2024 shung-hsi.yu@suse.com
- bpf: Fix a segment issue when downgrading gso_size (bsc#1229386
  CVE-2024-42281).
- commit f593f1f
* Mon Aug 19 2024 sjaeckel@suse.de
- kABI fix for net/sched: flower: Fix chain template offload
  (CVE-2024-26669 bsc#1222350).
- net/sched: flower: Fix chain template offload (CVE-2024-26669
  bsc#1222350).
- commit 43f1cd6
* Mon Aug 19 2024 sjaeckel@suse.de
- kABI fix for rxrpc: Fix delayed ACKs to not set the reference
  serial number (CVE-2024-26677 bsc#1222387).
- rxrpc: Fix delayed ACKs to not set the reference serial number
  (CVE-2024-26677 bsc#1222387).
- commit c3c3a27
* Mon Aug 19 2024 msuchanek@suse.de
- Update patches.suse/cpu-SMT-Enable-SMT-only-if-a-core-is-online.patch
  (bsc#1214285 bsc#1205462 ltc#200161 ltc#200588 git-fixes
  bsc#1229327 ltc#206365).
- Update patches.suse/powerpc-topology-Check-if-a-core-is-online.patch
  (bsc#1214285 bsc#1205462 ltc#200161 ltc#200588 git-fixes
  bsc#1229327 ltc#206365).
- commit fd7ec4b
* Mon Aug 19 2024 neilb@suse.de
- xprtrdma: Fix rpcrdma_reqs_reset() (git-fixes).
- gss_krb5: Fix the error handling path for
  crypto_sync_skcipher_setkey (git-fixes).
- commit c717fae
* Mon Aug 19 2024 neilb@suse.de
- SUNRPC: Fix a race to wake a sync task (git-fixes).
- nfs: pass explicit offset/count to trace events (git-fixes).
- commit 6f41a0a
* Mon Aug 19 2024 neilb@suse.de
- NFSv4.1 another fix for EXCHGID4_FLAG_USE_PNFS_DS for DS server
  (git-fixes).
- NFSD: Support write delegations in LAYOUTGET (git-fixes).
- nfs: don't invalidate dentries on transient errors (git-fixes).
- nfs: propagate readlink errors in nfs_symlink_filler
  (git-fixes).
- nfs: make the rpc_stat per net namespace (git-fixes).
- nfs: expose /proc/net/sunrpc/nfs in net namespaces (git-fixes).
- sunrpc: add a struct rpc_stats arg to rpc_create_args
  (git-fixes).
- commit 6ab4001
* Mon Aug 19 2024 jlee@suse.com
- Update
  patches.suse/ata-libata-core-Fix-double-free-on-error.patch
  (git-fixes CVE-2024-41087 bsc#1228740 bsc#1228466).
- Update
  patches.suse/cachefiles-add-missing-lock-protection-when-polling.patch
  (bsc#1229256 CVE-2024-42250 bsc#1228977).
- Update
  patches.suse/cachefiles-defer-exposing-anon_fd-until-after-copy_to.patch
  (bsc#1229251 CVE-2024-40913 bsc#1227839).
- Update
  patches.suse/cachefiles-fix-slab-use-after-free-in-cachefiles_onde.patch
  (bsc#1229247 CVE-2024-39510 bsc#1227734).
- Update
  patches.suse/cachefiles-fix-slab-use-after-free-in-cachefiles_ondemand_daemon_read.patch
  (bsc#1229246 CVE-2024-40899 bsc#1227758).
- Update
  patches.suse/drm-i915-gem-Fix-Virtual-Memory-mapping-boundaries-c.patch
  (git-fixes CVE-2024-42259 bsc#1229156).
- Update
  patches.suse/powerpc-pseries-Whitelist-dtl-slub-object-for-copyin.patch
  (bsc#1194869 CVE-2024-41065 bsc#1228636).
- commit 3fec826
* Mon Aug 19 2024 tiwai@suse.de
- char: xillybus: Check USB endpoints when probing device
  (git-fixes).
- Revert "misc: fastrpc: Restrict untrusted app to attach to
  privileged PD" (git-fixes).
- tty: atmel_serial: use the correct RTS flag (git-fixes).
- tty: serial: fsl_lpuart: mark last busy before uart_add_one_port
  (git-fixes).
- xhci: Fix Panther point NULL pointer deref at full-speed
  re-enumeration (git-fixes).
- Revert "usb: typec: tcpm: clear pd_event queue in PORT_RESET"
  (git-fixes).
- commit e3fe681
* Mon Aug 19 2024 neilb@suse.de
- blacklist.conf: add unwanted nfs/sunrpc patch
- commit 405ec89
* Mon Aug 19 2024 neilb@suse.de
- Refresh patches.suse/SUNRPC-avoid-soft-lockup-when-transmitting-UDP-to-re.patch.
  Add git-commit
- commit 7a1e763
* Sun Aug 18 2024 ailiop@suse.com
- xfs: attr forks require attr, not attr2 (git-fixes).
- commit d1644af
* Sun Aug 18 2024 tiwai@suse.de
- i2c: qcom-geni: Add missing geni_icc_disable in
  geni_i2c_runtime_resume (git-fixes).
- i2c: Use IS_REACHABLE() for substituting empty ACPI functions
  (git-fixes).
- commit 37fcb0e
* Sun Aug 18 2024 tiwai@suse.de
- Move upstreamed powerpc patches into sorted section
- commit 7bdd775
* Sun Aug 18 2024 ailiop@suse.com
- xfs: journal geometry is not properly bounds checked
  (git-fixes).
- commit 7680aeb
* Sat Aug 17 2024 svarbanov@suse.de
- arm64: Fix KASAN random tag seed initialization (git-fixes)
- commit a300263
* Sat Aug 17 2024 svarbanov@suse.de
- arm64: ACPI: NUMA: initialize all values of acpi_early_node_map to (git-fixes)
- commit a089c62
* Sat Aug 17 2024 tiwai@suse.de
- spi: Add empty versions of ACPI functions (stable-fixes).
- i2c: Fix conditional for substituting empty ACPI functions
  (stable-fixes).
- commit 3dc083c
* Sat Aug 17 2024 tiwai@suse.de
- gpio: mlxbf3: Support shutdown() function (git-fixes).
- ALSA: hda/tas2781: Use correct endian conversion (git-fixes).
- ALSA: usb-audio: Support Yamaha P-125 quirk entry
  (stable-fixes).
- ALSA: hda/tas2781: fix wrong calibrated data order (git-fixes).
- ALSA: usb-audio: Add delay quirk for VIVO USB-C-XE710 HEADSET
  (stable-fixes).
- ALSA: hda/realtek: Add support for new HP G12 laptops
  (stable-fixes).
- ALSA: hda/realtek: Fix noise from speakers on Lenovo IdeaPad
  3 15IAU7 (git-fixes).
- ALSA: timer: Relax start tick time check for slave timer
  elements (git-fixes).
- drm/amd/display: Adjust cursor position (git-fixes).
- drm/amd/display: fix cursor offset on rotation 180 (git-fixes).
- device property: Add cleanup.h based fwnode_handle_put()
  scope based cleanup (stable-fixes).
- commit 51be9a0
* Fri Aug 16 2024 ailiop@suse.com
- xfs: allow cross-linking special files without project quota
  (git-fixes).
- commit 8d26aca
* Fri Aug 16 2024 jgross@suse.com
- KVM: nVMX: Check for pending posted interrupts when looking
  for nested events (git-fixes).
- commit 0b1027c
* Fri Aug 16 2024 jgross@suse.com
- KVM: VMX: Split out the non-virtualization part of
  vmx_interrupt_blocked() (git-fixes).
- commit 47fc351
* Fri Aug 16 2024 ailiop@suse.com
- xfs: use consistent uid/gid when grabbing dquots for inodes
  (git-fixes).
- commit c1c88ce
* Fri Aug 16 2024 ailiop@suse.com
- xfs: honor init_xattrs in xfs_init_new_inode for !ATTR fs
  (git-fixes).
- commit fae2711
* Fri Aug 16 2024 ailiop@suse.com
- xfs: allow unlinked symlinks and dirs with zero size
  (git-fixes).
- commit 184b713
* Fri Aug 16 2024 jgross@suse.com
- blacklist.conf: add f99b052256f1 ("KVM: SNP: Fix LBR Virtualization for SNP guest")
- commit c9ad47e
* Fri Aug 16 2024 jgross@suse.com
- KVM: x86/mmu: Bug the VM if KVM tries to split a !hugepage SPTE
  (git-fixes).
- commit 96acab8
* Fri Aug 16 2024 ailiop@suse.com
- xfs: fix unlink vs cluster buffer instantiation race
  (git-fixes).
- commit 0ae592b
* Fri Aug 16 2024 ailiop@suse.com
- xfs: upgrade the extent counters in xfs_reflink_end_cow_extent
  later (git-fixes).
- commit 730a4f0
* Fri Aug 16 2024 ailiop@suse.com
- xfs: match lock mode in xfs_buffered_write_iomap_begin()
  (git-fixes).
- commit e70a195
* Fri Aug 16 2024 ailiop@suse.com
- xfs: require XFS_SB_FEAT_INCOMPAT_LOG_XATTRS for attr log
  intent item recovery (git-fixes).
- commit 85919a1
* Fri Aug 16 2024 ailiop@suse.com
- xfs: don't use current->journal_info (git-fixes).
- commit d96f684
* Fri Aug 16 2024 jgross@suse.com
- KVM: nVMX: Request immediate exit iff pending nested event
  needs injection (git-fixes).
- commit 9d306b8
* Fri Aug 16 2024 lhenriques@suse.de
- cachefiles: add missing lock protection when polling
  (bsc#1229256).
- cachefiles: cyclic allocation of msg_id to avoid reuse
  (bsc#1228499 CVE-2024-41050).
- cachefiles: wait for ondemand_object_worker to finish when
  dropping  object (bsc#1228468 CVE-2024-41051).
- cachefiles: cancel all requests for the object that is being
  dropped (bsc#1229255).
- cachefiles: stop sending new request when dropping object
  (bsc#1229254).
- cachefiles: propagate errors from vfs_getxattr() to avoid
  infinite  loop (bsc#1229253).
- cachefiles: make on-demand read killable (bsc#1229252).
- cachefiles: Set object to close if ondemand_id < 0 in copen
  (bsc#1228643 CVE-2024-41074).
- cachefiles: defer exposing anon_fd until after copy_to_user()
  succeeds (bsc#1229251).
- cachefiles: never get a new anonymous fd if ondemand_id is valid
  (bsc#1229250).
- cachefiles: add spin_lock for cachefiles_ondemand_info
  (bsc#1229249).
- cachefiles: add consistency check for copen/cread (bsc#1228646
  CVE-2024-41075).
- cachefiles: remove err_put_fd label in
  cachefiles_ondemand_daemon_read() (bsc#1229248).
- cachefiles: fix slab-use-after-free in
  cachefiles_ondemand_daemon_read() (bsc#1229247).
- cachefiles: fix slab-use-after-free in
  cachefiles_ondemand_get_fd() (bsc#1229246).
- cachefiles, erofs: Fix NULL deref in when cachefiles is not
  doing  ondemand-mode (bsc#1229245).
- cachefiles: add restore command to recover inflight ondemand
  read  requests (bsc#1229244).
- cachefiles: narrow the scope of triggering EPOLLIN events in
  ondemand  mode (bsc#1229243).
- cachefiles: resend an open request if the read request's object
  is  closed (bsc#1229241).
- cachefiles: extract ondemand info field from cachefiles_object
  (bsc#1229240).
- cachefiles: introduce object ondemand state (bsc#1229239).
- commit 3d893c5
* Fri Aug 16 2024 jgross@suse.com
- KVM: nVMX: Add a helper to get highest pending from Posted
  Interrupt vector (git-fixes).
- commit ebf04ff
* Fri Aug 16 2024 jgross@suse.com
- KVM: VMX: Switch __vmx_exit() and kvm_x86_vendor_exit() in
  vmx_exit() (git-fixes).
- commit 8ef91ee
* Fri Aug 16 2024 jgross@suse.com
- KVM: x86: Limit check IDs for KVM_SET_BOOT_CPU_ID (git-fixes).
- commit 395837f
* Fri Aug 16 2024 jgross@suse.com
- KVM: VMX: Move posted interrupt descriptor out of VMX code
  (git-fixes).
- commit feb966b
* Fri Aug 16 2024 ailiop@suse.com
- xfs: allow symlinks with short remote targets (bsc#1229160).
- commit e82d4ad
* Fri Aug 16 2024 jgross@suse.com
- blacklist.conf: add 1c682593096a ("xen: privcmd: Switch from mutex to spinlock for irqfds")
- commit 46d4480
* Fri Aug 16 2024 jgross@suse.com
- x86/xen: Convert comma to semicolon (git-fixes).
- commit c8d2d16
* Fri Aug 16 2024 tiwai@suse.de
- Update config files: disable ChromeOS support (jsc#PED-10476)
  As Leap 15.7 won't be built, all ChromeOS features become superfluous.
  Let's drop all ChromeOS-specific kernel configs for simplification.
- commit b58fc8c
* Fri Aug 16 2024 tiwai@suse.de
- Drop armv7hl builds (bsc#1229434)
  There will be no Leap 15.7, hence no 32bit Arm port
- commit 09ee386
* Fri Aug 16 2024 lhenriques@suse.de
- supported.conf: mark ceph-related modules as unsupported
  CephFS is not supported anymore, as well as the ceph-based block device
  rbd.  Also remove the LIO rbd backend from the supported.conf file as we
  are not forward-porting this code anymore.
- commit 10c2293
* Fri Aug 16 2024 tbogendoerfer@suse.de
- net: mana: Fix doorbell out of order violation and avoid
  unnecessary doorbell rings (bsc#1229154).
- net: mana: Fix RX buf alloc_size alignment and atomic op panic
  (bsc#1229086).
- commit 59cb1c7
* Fri Aug 16 2024 jgross@suse.com
- KVM: Make KVM_MEM_GUEST_MEMFD mutually exclusive with
  KVM_MEM_READONLY (git-fixes).
- commit 4020b4e
* Fri Aug 16 2024 jgross@suse.com
- KVM: SVM: Fix uninitialized variable bug (git-fixes).
- commit 385a593
* Fri Aug 16 2024 tiwai@suse.de
- wifi: brcmfmac: cfg80211: Handle SSID based pmksa deletion
  (git-fixes).
- net: ethernet: mtk_wed: fix use-after-free panic in
  mtk_wed_setup_tc_block_cb() (git-fixes).
- media: Revert "media: dvb-usb: Fix unexpected infinite loop
  in dvb_usb_read_remote_control()" (git-fixes).
- commit daf04e2
* Fri Aug 16 2024 jgross@suse.com
- KVM: SVM: Fix an error code in sev_gmem_post_populate()
  (git-fixes).
- commit db95276
* Thu Aug 15 2024 krisman@suse.de
- filelock: Remove locks reliably when fcntl/close race is
  detected (CVE-2024-41012 bsc#1228247).
- commit a736b9b
* Thu Aug 15 2024 krisman@suse.de
- io_uring: fix possible deadlock in
  io_register_iowq_max_workers() (bsc#1228616 CVE-2024-41080).
- commit eae6448
* Thu Aug 15 2024 krisman@suse.de
- io_uring: fix io_match_task must_hold (git-fixes).
- io_uring: tighten task exit cancellations (git-fixes).
- commit f9ce2d8
* Thu Aug 15 2024 krisman@suse.de
- io_uring: Fix probe of disabled operations (git-fixes).
- io_uring/advise: support 64-bit lengths (git-fixes).
- commit 7566a8d
* Thu Aug 15 2024 krisman@suse.de
- io_uring: Drop per-ctx dummy_ubuf (git-fixes).
- commit 2717cc1
* Thu Aug 15 2024 msuchanek@suse.de
- Refresh patches.suse/powerpc-pseries-Add-failure-related-checks-for-h_get.patch.
  Changing hte return value to long breaks ABI which makes the upstream
  version unsuitable for SP6.
- commit 3034e83
* Thu Aug 15 2024 msuchanek@suse.de
- powerpc/kexec_file: fix cpus node update to FDT (bsc#1194869).
- powerpc/pseries: Whitelist dtl slub object for copying to
  userspace (bsc#1194869).
- powerpc/kexec: make the update_cpus_node() function public
  (bsc#1194869).
- powerpc/xmon: Check cpu id in commands "c#", "dp#" and "dx#"
  (bsc#1194869).
- powerpc/64: Set _IO_BASE to POISON_POINTER_DELTA not 0 for
  CONFIG_PCI=n (bsc#1194869).
- powerpc/io: Avoid clang null pointer arithmetic warnings
  (bsc#1194869).
- powerpc/pseries: Add failure related checks for h_get_mpp and
  h_get_ppp (bsc#1194869).
- powerpc/kexec: split CONFIG_KEXEC_FILE and CONFIG_CRASH_DUMP
  (bsc#1194869).
- powerpc: xor_vmx: Add '-mhard-float' to CFLAGS (bsc#1194869).
- powerpc/radix: Move some functions into #ifdef
  CONFIG_KVM_BOOK3S_HV_POSSIBLE (bsc#1194869).
- commit 4e7f0fe
* Thu Aug 15 2024 msuchanek@suse.de
- blacklist.conf: Add a bunch of superfluous ppc changes reported by
  git-fixes.
- commit 7c2a851
* Thu Aug 15 2024 msuchanek@suse.de
- blacklist.conf: Add ppc more ppc unsupported arch paths and commits.
- commit 66e06b4
* Thu Aug 15 2024 ptesarik@suse.com
- Restore patches inadvertently lost during a previous merge:
  - bsc#1193454:
    patches.suse/workqueue-wq_watchdog_touch-is-always-called-with-valid-CPU.patch
    patches.suse/workqueue-Improve-scalability-of-workqueue-watchdog-touch.patch
  - bsc#1222254:
    patches.suse/cgroup-Remove-unnecessary-list_empty.patch
    patches.suse/cgroup-Make-operations-on-the-cgroup-root_list-RCU-safe.patch
    patches.suse/cgroup-Eliminate-the-need-for-cgroup_mutex-in-proc_cgroup_show.patch
    patches.suse/cgroup-Add-annotation-for-holding-namespace_sem-in-current_cgns_cgroup_from_root.patch
  - bsc#1222625 CVE-2024-27437:
    patches.suse/vfio-pci-Disable-auto-enable-of-exclusive-INTx-IRQ.patch
  - bsc#1224700 CVE-2024-35949:
    patches.suse/btrfs-make-sure-that-WRITTEN-is-set-on-all-metadata-.patch
  - bsc#1227798 CVE-2024-40909:
    patches.suse/bpf-Fix-a-potential-use-after-free-in-bpf_link_free.patch
  - bsc#1227808 CVE-2024-40954:
    patches.suse/net-do-not-leave-a-dangling-sk-pointer-when-socket-c.patch
  - bsc#1227811 CVE-2024-40957:
    patches.suse/seg6-fix-parameter-passing-when-calling-NF_HOOK-in-E.patch
  - bsc#1227823 CVE-2024-40989:
    patches.suse/KVM-arm64-Disassociate-vcpus-from-redistributor-regi.patch
  - bsc#1228020 CVE-2024-41009:
    patches.suse/selftests-bpf-Add-more-ring-buffer-test-coverage.patch
  - bsc#1228409 CVE-2024-41015:
    patches.suse/ocfs2-add-bounds-checking-to-ocfs2_check_dir_entry.patch
  - bsc#1228410 CVE-2024-41016:
    patches.suse/ocfs2-add-bounds-checking-to-ocfs2_xattr_find_entry.patch
    patches.suse/ocfs2-strict-bound-check-before-memcmp-in-ocfs2_xatt.patch
  - bsc#1228581 CVE-2024-41070:
    patches.suse/KVM-PPC-Book3S-HV-Prevent-UAF-in-kvm_spapr_tce_attac.patch
  - bsc#1228591 CVE-2024-42122:
    patches.suse/0001-drm-amd-display-Add-NULL-pointer-check-for-kzalloc.patch
  - bsc#1228617 CVE-2024-41081:
    patches.suse/ila-block-BH-in-ila_output.patch
  - bsc#1228672 CVE-2024-42079:
    patches.suse/gfs2-Fix-NULL-pointer-dereference-in-gfs2_log_flush.patch
  - bsc#1228680 CVE-2024-42093:
    patches.suse/net-dpaa2-Avoid-explicit-cpumask-var-allocation-on-s.patch
- commit 4d8a2f8
* Thu Aug 15 2024 msuchanek@suse.de
- blacklist.conf: Add more ppc 32bit paths.
- commit 013a9db
* Thu Aug 15 2024 iivanov@suse.de
- arm64: errata: Expand speculative SSBS workaround (again) (git-fixes)
- commit e589bbc
* Thu Aug 15 2024 iivanov@suse.de
- arm64: cputype: Add Cortex-A725 definitions (git-fixes)
- commit 0d04176
* Thu Aug 15 2024 iivanov@suse.de
- arm64: cputype: Add Cortex-X1C definitions (git-fixes)
- commit 6a5ea61
* Thu Aug 15 2024 iivanov@suse.de
- arm64: errata: Expand speculative SSBS workaround (git-fixes)
- commit f75d6ba
* Thu Aug 15 2024 iivanov@suse.de
- arm64: errata: Unify speculative SSBS errata logic (git-fixes).
  Update config files.
- commit ffaab08
* Thu Aug 15 2024 iivanov@suse.de
- arm64: cputype: Add Cortex-X925 definitions (git-fixes)
- commit 3c8ddb7
* Thu Aug 15 2024 iivanov@suse.de
- arm64: cputype: Add Cortex-A720 definitions (git-fixes)
- commit f5fd7c6
* Thu Aug 15 2024 iivanov@suse.de
- arm64: cputype: Add Cortex-X3 definitions (git-fixes)
- commit d87d988
* Thu Aug 15 2024 iivanov@suse.de
- arm64: errata: Add workaround for Arm errata 3194386 and 3312417 (git-fixes)
  Refresh patches.suse/kabi-arm64-reserve-space-in-cpu_hwcaps-and-cpu_hwcap.patch
  and enable around.
- commit b3747ef
* Thu Aug 15 2024 iivanov@suse.de
- arm64: cputype: Add Neoverse-V3 definitions (git-fixes)
- commit 78aeee9
* Thu Aug 15 2024 iivanov@suse.de
- arm64: cputype: Add Cortex-X4 definitions (git-fixes)
- commit 2841965
* Thu Aug 15 2024 iivanov@suse.de
- arm64: barrier: Restore spec_bar() macro (git-fixes)
- commit 5c935b6
* Thu Aug 15 2024 iivanov@suse.de
- arm64: Add Neoverse-V2 part (git-fixes)
- commit 0f9f30b
* Thu Aug 15 2024 tiwai@suse.de
- rpm/kernel-source.changes.old: Re-add the lost CVE and XSA references
  Some references have been lost at smashing since they were in lower
  letters ("cve-*").  Also one CVE entry was incorrect, but keep here
  for reference.
- commit 50b21fe
* Thu Aug 15 2024 tiwai@suse.de
- Update config files: drop configs for *-optional (jsc#PED-10475)
  As we won't have openSUSE Leap 15.7, most of drivers that are shipped
  only for kernel-*-optional can be disabled gracefully.
  There are still a few left due to the dependency issues.
- commit fb5a4a5
* Thu Aug 15 2024 sjaeckel@suse.de
- net/rds: fix possible cp null dereference (git-fixes).
- commit cac3126
* Thu Aug 15 2024 mfranc@suse.cz
- s390/pci: Add missing virt_to_phys() for directed DIBV
  (git-fixes bsc#1229174).
- commit ea8e3e7
* Thu Aug 15 2024 mfranc@suse.cz
- s390/dasd: fix error checks in dasd_copy_pair_store()
  (git-fixes bsc#1229173).
- commit f5c4fe8
* Thu Aug 15 2024 mfranc@suse.cz
- s390/pci: Allow allocation of more than 1 MSI interrupt
  (git-fixes bsc#1229172).
- s390/pci: Refactor arch_setup_msi_irqs() (git-fixes
  bsc#1229172).
- commit ad8c54b
* Thu Aug 15 2024 mfranc@suse.cz
- s390/cpum_cf: Fix endless loop in CF_DIAG event stop (git-fixes
  bsc#1229171).
- commit 94c7469
* Thu Aug 15 2024 mfranc@suse.cz
- s390/uv: Panic for set and remove shared access UVC errors
  (git-fixes bsc#1229170).
- commit 447c271
* Thu Aug 15 2024 mfranc@suse.cz
- s390/sclp: Prevent release of buffer in I/O (git-fixes
  bsc#1229169).
- commit 9daf007
* Thu Aug 15 2024 mfranc@suse.cz
- kvm: s390: Reject memory region operations for ucontrol VMs
  (git-fixes bsc#1229168).
- commit 14a9742
* Thu Aug 15 2024 mfranc@suse.cz
- KVM: s390: fix validity interception issue when gisa is switched
  off (git-fixes bsc#1229167).
- commit 5c4e348
* Thu Aug 15 2024 kbuild@suse.de
- Delete patches.kabi/* workarounds
- commit 72e8d5f
* Thu Aug 15 2024 tiwai@suse.de
- Update patch reference of USB patch (jsc#PED-10108)
- commit edfa08b
* Thu Aug 15 2024 tiwai@suse.de
- USB: serial: debug: do not echo input by default (stable-fixes).
- usb: vhci-hcd: Do not drop references before new references
  are gained (stable-fixes).
- serial: core: check uartclk for zero to avoid divide by zero
  (stable-fixes).
- media: xc2028: avoid use-after-free in load_firmware_cb()
  (stable-fixes).
- media: uvcvideo: Fix the bandwdith quirk on USB 3.x
  (stable-fixes).
- media: uvcvideo: Ignore empty TS packets (stable-fixes).
- media: amphion: Remove lock in s_ctrl callback (stable-fixes).
- wifi: nl80211: don't give key data to userspace (stable-fixes).
- PCI: Add Edimax Vendor ID to pci_ids.h (stable-fixes).
- wifi: ath12k: fix memory leak in ath12k_dp_rx_peer_frag_setup()
  (stable-fixes).
- wifi: nl80211: disallow setting special AP channel widths
  (stable-fixes).
- gpio: prevent potential speculation leaks in
  gpio_device_get_desc() (stable-fixes).
- commit 2335bf9
* Thu Aug 15 2024 tiwai@suse.de
- docs: KVM: Fix register ID of SPSR_FIQ (git-fixes).
- drm/i915/gem: Adjust vma offset for framebuffer mmap offset
  (stable-fixes).
- drm/amd/display: Skip Recompute DSC Params if no Stream on Link
  (stable-fixes).
- drm/amdgpu: Forward soft recovery errors to userspace
  (stable-fixes).
- drm/dp_mst: Skip CSN if topology probing is not done yet
  (stable-fixes).
- drm/mediatek/dp: Fix spurious kfree() (git-fixes).
- drm/amd/display: Add null checker before passing variables
  (stable-fixes).
- Revert "drm/amd/display: Add NULL check for 'afb' before
  dereferencing in amdgpu_dm_plane_handle_cursor_update"
  (stable-fixes).
- drm/amd/display: Add NULL check for 'afb' before dereferencing
  in amdgpu_dm_plane_handle_cursor_update (stable-fixes).
- drm/bridge: analogix_dp: properly handle zero sized AUX
  transactions (stable-fixes).
- drm/amd/pm: Fix the null pointer dereference for vega10_hwmgr
  (stable-fixes).
- drm/radeon: Remove __counted_by from StateArray.states[]
  (git-fixes).
- drm/amdgpu: Add lock around VF RLCG interface (stable-fixes).
- drm/admgpu: fix dereferencing null pointer context
  (stable-fixes).
- drm/amdgpu/pm: Fix the null pointer dereference in
  apply_state_adjust_rules (stable-fixes).
- drm/amdgpu: Fix the null pointer dereference to ras_manager
  (stable-fixes).
- drm/amdgpu/pm: Fix the null pointer dereference for smu7
  (stable-fixes).
- drm/amdgpu/pm: Fix the param type of set_power_profile_mode
  (stable-fixes).
- drm/amdgpu: fix potential resource leak warning (stable-fixes).
- drm/amd/display: Add delay to improve LTTPR UHBR interop
  (stable-fixes).
- Bluetooth: btnxpuart: Shutdown timer and prevent rearming when
  driver unloading (stable-fixes).
- can: mcp251xfd: tef: update workaround for erratum DS80000789E
  6 of mcp2518fd (stable-fixes).
- can: mcp251xfd: tef: prepare to workaround broken TEF FIFO
  tail index erratum (stable-fixes).
- ACPI: SBS: manage alarm sysfs attribute through psy core
  (stable-fixes).
- ACPI: battery: create alarm sysfs attribute atomically
  (stable-fixes).
- clocksource/drivers/sh_cmt: Address race condition for clock
  events (stable-fixes).
- commit 2a8ca72
* Wed Aug 14 2024 tiwai@suse.de
- Update patch reference for SPI patch (jsc#PED-10105)
- commit a896d55
* Wed Aug 14 2024 tiwai@suse.de
- rpm/config.sh: Update for SLE15-SP7
- commit b69d639
* Wed Aug 14 2024 mfranc@suse.cz
- kabi fix for KVM: s390: fix LPSWEY handling (bsc#1227634
  git-fixes).
- KVM: s390: fix LPSWEY handling (bsc#1227634 git-fixes).
- commit 576de67
* Wed Aug 14 2024 mkoutny@suse.com
- kernfs: Convert kernfs_path_from_node_locked() from strlcpy()
  to strscpy() (bsc#1229134).
- Refresh
  patches.suse/cgroup-cpuset-Prevent-UAF-in-proc_cpuset_show.patch.
- commit bc8376b
* Wed Aug 14 2024 tiwai@suse.de
- i2c: designware: Add ACPI ID for Granite Rapids-D I2C controller
  (jsc#PED-10047).
- i2c: smbus: Support up to 8 SPD EEPROMs (jsc#PED-10046).
- commit 938da33
* Wed Aug 14 2024 tiwai@suse.de
- Update patch reference for iwlwifi fix (jsc#PED-10055)
- commit 73fda85
* Wed Aug 14 2024 tiwai@suse.de
- Input: i8042 - add Fujitsu Lifebook E756 to i8042 quirk table
  (bsc#1229056).
- commit 0ae7f4e
* Wed Aug 14 2024 jlee@suse.com
- bpf: hardcode BPF_PROG_PACK_SIZE to 2MB * num_possible_nodes()
  (git-fixes).
- bpf: don't infer PTR_TO_CTX for programs with unnamed context
  type (git-fixes).
- bpf: handle bpf_user_pt_regs_t typedef explicitly for PTR_TO_CTX
  global arg (git-fixes).
- bpf: Mark bpf_spin_{lock,unlock}() helpers with notrace
  correctly (git-fixes).
- commit dd0591b
* Wed Aug 14 2024 neilb@suse.de
- net, sunrpc: Remap EPERM in case of connection failure in
  xs_tcp_setup_socket (CVE-2024-42246 bsc#1228989).
- commit 12865c8
* Wed Aug 14 2024 jlee@suse.com
- tools/resolve_btfids: Fix comparison of distinct pointer types
  warning in resolve_btfids (git-fixes).
- tools/resolve_btfids: fix build with musl libc (git-fixes).
- commit f42b517
* Tue Aug 13 2024 fdmanana@suse.com
- btrfs: fix leak of qgroup extent records after transaction abort
  (git-fixes).
- btrfs: fix ordered extent split error handling in
  btrfs_dio_submit_io (git-fixes).
- btrfs: use irq safe locking when running and adding delayed
  iputs (git-fixes).
- commit 59b18df
* Tue Aug 13 2024 fdmanana@suse.com
- btrfs: fix extent map use-after-free when adding pages to
  compressed bio (git-fixes).
- commit b3e7c96
* Tue Aug 13 2024 tiwai@suse.de
- Drop libata patch that caused a regression (bsc#1229054)
- commit 3d5faca
* Tue Aug 13 2024 fdmanana@suse.com
- btrfs: fix double inode unlock for direct IO sync writes
  (git-fixes).
- btrfs: fix corruption after buffer fault in during direct IO
  append write (git-fixes).
- btrfs: use a btrfs_inode local variable at btrfs_sync_file()
  (git-fixes).
- btrfs: pass a btrfs_inode to btrfs_wait_ordered_range()
  (git-fixes).
- btrfs: pass a btrfs_inode to btrfs_fdatawrite_range()
  (git-fixes).
- btrfs: use a btrfs_inode in the log context (struct
  btrfs_log_ctx) (git-fixes).
- btrfs: make btrfs_finish_ordered_extent() return void
  (git-fixes).
- btrfs: ensure fast fsync waits for ordered extents after a
  write failure (git-fixes).
- btrfs: rename err to ret in btrfs_direct_write() (git-fixes).
- btrfs: uninline some static inline helpers from tree-log.h
  (git-fixes).
- btrfs: use btrfs_finish_ordered_extent to complete buffered
  writes (git-fixes).
- btrfs: use btrfs_finish_ordered_extent to complete direct writes
  (git-fixes).
- btrfs: use btrfs_finish_ordered_extent to complete compressed
  writes (git-fixes).
- btrfs: open code end_extent_writepage in
  end_bio_extent_writepage (git-fixes).
- btrfs: add a btrfs_finish_ordered_extent helper (git-fixes).
- btrfs: factor out a btrfs_queue_ordered_fn helper (git-fixes).
- btrfs: factor out a can_finish_ordered_extent helper
  (git-fixes).
- btrfs: use bbio->ordered in btrfs_csum_one_bio (git-fixes).
- btrfs: add an ordered_extent pointer to struct btrfs_bio
  (git-fixes).
- btrfs: open code btrfs_bio_end_io in btrfs_dio_submit_io
  (git-fixes).
- btrfs: add a is_data_bbio helper (git-fixes).
- btrfs: remove btrfs_add_ordered_extent (git-fixes).
- btrfs: pass an ordered_extent to btrfs_submit_compressed_write
  (git-fixes).
- btrfs: pass an ordered_extent to btrfs_reloc_clone_csums
  (git-fixes).
- btrfs: merge the two calls to btrfs_add_ordered_extent in
  run_delalloc_nocow (git-fixes).
- btrfs: limit write bios to a single ordered extent (git-fixes).
- commit 90ea198
* Tue Aug 13 2024 msuchanek@suse.de
- powerpc/topology: Check if a core is online (bsc#1214285
  bsc#1205462 ltc#200161 ltc#200588 git-fixes).
- cpu/SMT: Enable SMT only if a core is online (bsc#1214285
  bsc#1205462 ltc#200161 ltc#200588 git-fixes).
- commit 3d340df
* Tue Aug 13 2024 tiwai@suse.de
- Update patch reference for MD patch (jsc#PED-10029 jsc#PED-10045)
- commit 1bf8fd1
* Tue Aug 13 2024 tiwai@suse.de
- Update patch refefernce for MFD patch (jsc#PED-10029)
- commit f36d989
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Check HSMP support on AMD family of processors (jsc#PED-8779).
- commit c606582
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: switch to use device_add_groups() (jsc#PED-8779).
- commit 4007799
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Change devm_kzalloc() to devm_kcalloc() (jsc#PED-8779).
- commit 9854658
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Remove extra parenthesis and add a space (jsc#PED-8779).
- commit 0a84b39
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Check num_sockets against MAX_AMD_SOCKETS (jsc#PED-8779).
- commit 85ba4b7
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Non-ACPI support for AMD F1A_M00~0Fh (jsc#PED-8779).
- commit 1b89039
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Add support for ACPI based probing (jsc#PED-8779).
- commit 73c2646
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Restructure sysfs group creation (jsc#PED-8779).
- commit 9e31807
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Move dev from platdev to hsmp_socket (jsc#PED-8779).
- commit f6baa58
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Define a struct to hold mailbox regs (jsc#PED-8779).
- commit 07f864e
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Create static func to handle platdev (jsc#PED-8779).
- commit d5ea9be
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Cache pci_dev in struct hsmp_socket (jsc#PED-8779).
- commit d314cb6
* Tue Aug 13 2024 nik.borisov@suse.com
- platform/x86/amd/hsmp: Move hsmp_test to probe (jsc#PED-8779).
- commit b00829d
* Tue Aug 13 2024 jlee@suse.com
- tools/resolve_btfids: Fix cross-compilation to non-host
  endianness (git-fixes).
- tools/resolve_btfids: Refactor set sorting with types from
  btf_ids.h (git-fixes).
- libbpf: Use OPTS_SET() macro in bpf_xdp_query() (git-fixes).
- commit 6fc7b9e
* Tue Aug 13 2024 jlee@suse.com
- libbpf: Add missing LIBBPF_API annotation to
  libbpf_set_memlock_rlim API (git-fixes).
- selftests/bpf: Disable IPv6 for lwt_redirect test (git-fixes).
- libbpf: Fix faccessat() usage on Android (git-fixes).
- selftests/bpf: Wait for the netstamp_needed_key static key to
  be turned on (git-fixes).
- commit 89d6f3b
* Tue Aug 13 2024 jlee@suse.com
- selftests/bpf: Fix the flaky tc_redirect_dtime test (git-fixes).
- selftest/bpf: Add map_in_maps with BPF_MAP_TYPE_PERF_EVENT_ARRAY
  values (git-fixes).
- libbpf: Apply map_set_def_max_entries() for inner_maps on
  creation (git-fixes).
- selftests/bpf: Fix potential premature unload in bpf_testmod
  (git-fixes).
- bpftool: Silence build warning about calloc() (git-fixes).
- commit 7aaf2fc
* Tue Aug 13 2024 nik.borisov@suse.com
- x86/asm: Use %%c/%%n instead of %%P operand modifier in asm  templates (git-fixes).
- Refresh
  patches.suse/x86-uaccess-Fix-missed-zeroing-of-ia32-u64-get_user-range-.patch.
- commit 97ffc68
* Tue Aug 13 2024 jlee@suse.com
- selftests/bpf: Fix up xdp bonding test wrt feature flags
  (git-fixes).
- selftests/bpf: fix compiler warnings in RELEASE=1 mode
  (git-fixes).
- selftests/bpf: Relax time_tai test for equal timestamps in
  tai_forward (git-fixes).
- bpf: Set uattr->batch.count as zero before batched update or
  deletion (git-fixes).
- bpf: Remove unnecessary wait from bpf_map_copy_value()
  (git-fixes).
- commit 19ebfe6
* Tue Aug 13 2024 jlee@suse.com
- bpf: enforce precision of R0 on callback return (git-fixes).
- selftests/bpf: Fix erroneous bitmask operation (git-fixes).
- bpf/tests: Remove duplicate JSGT tests (git-fixes).
- bpftool: mark orphaned programs during prog show (git-fixes).
- commit 2b6a18e
* Tue Aug 13 2024 jlee@suse.com
- bpf: Fix a few selftest failures due to llvm18 change
  (git-fixes).
- selftests/bpf: Fix issues in setup_classid_environment()
  (git-fixes).
- selftests/bpf: Add assert for user stacks in test_task_stack
  (git-fixes).
- selftests/bpf: Fix pyperf180 compilation failure with clang18
  (git-fixes).
- bpf: Add crosstask check to __bpf_get_stack (git-fixes).
- commit fce00e9
* Tue Aug 13 2024 jlee@suse.com
- bpf, lpm: Fix check prefixlen before walking trie (git-fixes).
- selftests/bpf: satisfy compiler by having explicit return in
  btf test (git-fixes).
- selftests/bpf: fix RELEASE=1 build for tc_opts (git-fixes).
- bpf: Fix prog_array_map_poke_run map poke update (git-fixes).
- commit ca200c8
* Mon Aug 12 2024 lduncan@suse.com
- scsi: mpi3mr: Use proper format specifier in
  mpi3mr_sas_port_add() (bsc#1228754 CVE-2024-42159 git-fixes).
- scsi: mpi3mr: Sanitise num_phys (bsc#1228754 CVE-2024-42159).
- commit e024eb0
* Mon Aug 12 2024 davide.benini@suse.com
- tcp_metrics: validate source addr length
  (CVE-2024-42154 bsc#1228507).
- commit a83d949
* Mon Aug 12 2024 lduncan@suse.com
- scsi: mpi3mr: Use proper format specifier in
  mpi3mr_sas_port_add() (bsc#1228754 CVE-2024-42159 git-fixes).
- scsi: mpi3mr: Sanitise num_phys (bsc#1228754 CVE-2024-42159).
- commit bc5cb15
* Mon Aug 12 2024 jlee@suse.com
- selftests/bpf: check if max number of bpf_loop iterations is
  tracked (git-fixes).
  Refresh
  patches.suse/selftests-bpf-test-case-for-callback_depth-states-pr.patch.
- selftests/bpf: fix bpf_loop_bench for new callback verification
  scheme (git-fixes).
- selftests/bpf: Add netkit to tc_redirect selftest (git-fixes).
- selftests/bpf: De-veth-ize the tc_redirect test case
  (git-fixes).
- bpf: fix control-flow graph checking in privileged mode
  (git-fixes).
- commit 27db2c6
* Mon Aug 12 2024 jlee@suse.com
- bpf: Fix check_stack_write_fixed_off() to correctly spill imm
  (git-fixes).
- bpf: Fix unnecessary -EBUSY from htab_lock_bucket (git-fixes).
- commit b5c430e
* Mon Aug 12 2024 mhocko@suse.com
- mm/shmem: disable PMD-sized page cache if needed (CVE-2024-42241
  bsc#1228986).
- commit 8ecdd91
* Mon Aug 12 2024 nik.borisov@suse.com
- x86/mm: Fix pti_clone_pgtable() alignment assumption (git-fixes).
- commit 1d041a1
* Mon Aug 12 2024 nik.borisov@suse.com
- x86/mm: Fix pti_clone_entry_text() for i386 (git-fixes).
- commit 5407674
* Mon Aug 12 2024 nik.borisov@suse.com
- x86/pci: Skip early E820 check for ECAM region (git-fixes).
- commit 7ac1bfc
* Mon Aug 12 2024 nik.borisov@suse.com
- x86/mtrr: Check if fixed MTRRs exist before saving them (git-fixes).
- commit 03de6ee
* Mon Aug 12 2024 nik.borisov@suse.com
- x86/entry/64: Remove obsolete comment on tracing vs. SYSRET (git-fixes).
- commit 41708c1
* Mon Aug 12 2024 mhocko@suse.com
- memcg: protect concurrent access to mem_cgroup_idr (git-fixes).
- commit e9979b2
* Mon Aug 12 2024 rhopkins@suse.de
- Revert "sched/fair: Make sure to try to detach at least one
  movable task" (CVE-2024-42245 bsc#1228978).
- commit bff0dc0
* Mon Aug 12 2024 jlee@suse.com
- selftests/bpf: Make linked_list failure test more robust
  (git-fixes).
- bpf: Ensure proper register state printing for cond jumps
  (git-fixes).
- commit 2ec4f49
* Mon Aug 12 2024 denis.kirjanov@suse.com
- ipv6: sr: fix incorrect unregister order (git-fixes).
- commit f975fdd
* Mon Aug 12 2024 denis.kirjanov@suse.com
- ipv6: sr: fix possible use-after-free and null-ptr-deref
  (CVE-2024-26735 bsc#1222372).
- commit 75aaed9
* Mon Aug 12 2024 jlee@suse.com
- bpftool: Align output skeleton ELF code (git-fixes).
- samples/bpf: syscall_tp_user: Fix array out-of-bound access
  (git-fixes).
- samples/bpf: syscall_tp_user: Rename num_progs into nr_tests
  (git-fixes).
- bpf: Fix kfunc callback register type handling (git-fixes).
- commit ee3cca0
* Mon Aug 12 2024 jlee@suse.com
- bpf: Detect IP == ksym.end as part of BPF program (git-fixes).
- commit b5b57d0
* Mon Aug 12 2024 jlee@suse.com
- selftests/bpf: Skip module_fentry_shadow test when bpf_testmod
  is not available (git-fixes).
- commit 85b5d5e
* Mon Aug 12 2024 jlee@suse.com
- bpftool: Fix -Wcast-qual warning (git-fixes).
- commit 0417873
* Mon Aug 12 2024 sjaeckel@suse.de
- net: bridge: switchdev: Skip MDB replays of deferred events
  on offload (CVE-2024-26837 bsc#1222973).
- commit 2f55c98
* Mon Aug 12 2024 mfranc@suse.cz
- s390/pkey: Wipe copies of protected- and secure-keys
  (CVE-2024-42155 bsc#1228733).
- s390/pkey: Wipe copies of clear-key structures on failure
  (CVE-2024-42156 bsc#1228722).
- s390/pkey: Wipe sensitive data on failure (CVE-2024-42157
  bsc#1228727).
- s390/pkey: Use kfree_sensitive() to fix Coccinelle warnings
  (CVE-2024-42158 bsc#1228720).
- s390/pkey: introduce dynamic debugging for pkey (bsc#1228720).
- s390/pkey: harmonize pkey s390 debug feature calls
  (bsc#1228720).
- commit 72f0617
* Mon Aug 12 2024 tiwai@suse.de
- usb: gadget: u_serial: Set start_delayed during suspend
  (git-fixes).
- usb: gadget: core: Check for unset descriptor (git-fixes).
- usb: gadget: u_audio: Check return codes from usb_ep_enable
  and config_ep_by_speed (git-fixes).
- driver core: Fix uevent_show() vs driver detach race
  (git-fixes).
- thermal/drivers/broadcom: Fix race between removal and clock
  disable (git-fixes).
- thermal: bcm2835: Convert to platform remove callback returning
  void (stable-fixes).
- commit 9bfd8af
* Mon Aug 12 2024 shung-hsi.yu@suse.com
- selftests/bpf: Cover verifier checks for mutating
  sockmap/sockhash (bsc#1226885 CVE-2024-38662).
- Revert "bpf, sockmap: Prevent lock inversion deadlock in map
  delete elem" (bsc#1226885 CVE-2024-38662).
- bpf: Allow delete from sockmap/sockhash only if update is
  allowed (bsc#1226885 CVE-2024-38662).
- commit 7f528cf
* Mon Aug 12 2024 jslaby@suse.cz
- rpm/kernel-binary.spec.in: fix klp_symbols macro
  The commit below removed openSUSE filter from %%ifs of the klp_symbols
  definition. But it removed -c of grep too and that causes:
  error: syntax error in expression:  01 && (  || 1 )
  error:                                        ^
  error: unmatched (:  01 && (  || 1 )
  error:                     ^
  error: kernel-default.spec:137: bad %%if condition:  01 && (  || 1 )
  So reintroduce -c to the PTF's grep.
  Fixes: fd0b293bebaf (kernel-binary.spec.in: Enable klp_symbols on openSUSE Tumbleweed (boo#1229042).)
- commit 4a36fe3
* Sun Aug 11 2024 tiwai@suse.de
- i2c: qcom-geni: Add missing geni_icc_disable in
  geni_i2c_runtime_resume (git-fixes).
- i2c: qcom-geni: Add missing clk_disable_unprepare in
  geni_i2c_runtime_resume (git-fixes).
- i2c: smbus: Send alert notifications to all devices if source
  not found (git-fixes).
- i2c: smbus: Improve handling of stuck alerts (git-fixes).
- spi: spi-fsl-lpspi: Fix scldiv calculation (git-fixes).
- spi: spidev: Add missing spi_device_id for bh2228fv (git-fixes).
- drm/i915/gem: Fix Virtual Memory mapping boundaries calculation
  (git-fixes).
- drm/client: fix null pointer dereference in
  drm_client_modeset_probe (git-fixes).
- commit e093c66
* Sat Aug 10 2024 tiwai@suse.de
- Update patch references for ASoC regression fixes (bsc#1229045 bsc#1229046)
- commit 4e3f007
* Sat Aug 10 2024 tiwai@suse.de
- rpm/kernel-binary.spec.in: Fix build regression
  The previous fix forgot to take over grep -c option that broke the
  conditional expression
- commit d29edf2
* Sat Aug 10 2024 tiwai@suse.de
- Moved upstreamed ASoC patch into sorted section
- commit 3058bc3
* Sat Aug 10 2024 tiwai@suse.de
- ASoC: cs35l56: Patch CS35L56_IRQ1_MASK_18 to the default value
  (stable-fixes).
- ASoC: amd: yc: Support mic on Lenovo Thinkpad E14 Gen 6
  (stable-fixes).
- ASoC: cs35l56: Handle OTP read latency over SoundWire
  (stable-fixes).
- ASoC: nau8822: Lower debug print priority (stable-fixes).
- ASoC: fsl_micfil: Expand the range of FIFO watermark mask
  (stable-fixes).
- ASoC: amd: yc: Support mic on HP 14-em0002la (stable-fixes).
- ALSA: hda/realtek: Add Framework Laptop 13 (Intel Core Ultra)
  to quirks (stable-fixes).
- ALSA: hda/hdmi: Yet more pin fix for HP EliteDesk 800 G4
  (stable-fixes).
- ALSA: hda: Add HP MP9 G4 Retail System AMS to force connect list
  (stable-fixes).
- ALSA: line6: Fix racy access to midibuf (stable-fixes).
- ASoC: cs35l56: Patch CS35L56_IRQ1_MASK_18 to the default value
  (stable-fixes).
- ASoC: amd: yc: Support mic on Lenovo Thinkpad E14 Gen 6
  (stable-fixes).
- ASoC: cs35l56: Handle OTP read latency over SoundWire
  (stable-fixes).
- ASoC: nau8822: Lower debug print priority (stable-fixes).
- ASoC: fsl_micfil: Expand the range of FIFO watermark mask
  (stable-fixes).
- ASoC: amd: yc: Support mic on HP 14-em0002la (stable-fixes).
- ALSA: hda/realtek: Add Framework Laptop 13 (Intel Core Ultra)
  to quirks (stable-fixes).
- ALSA: hda/hdmi: Yet more pin fix for HP EliteDesk 800 G4
  (stable-fixes).
- ALSA: hda: Add HP MP9 G4 Retail System AMS to force connect list
  (stable-fixes).
- ALSA: line6: Fix racy access to midibuf (stable-fixes).
- commit a8c8868
* Sat Aug 10 2024 tiwai@suse.de
- ASoC: meson: axg-fifo: fix irq scheduling issue with PREEMPT_RT
  (git-fixes).
- ASoC: SOF: Remove libraries from topology lookups (git-fixes).
- ASoC: codecs: wsa884x: Correct Soundwire ports mask (git-fixes).
- ASoC: codecs: wsa883x: Correct Soundwire ports mask (git-fixes).
- ASoC: codecs: wsa881x: Correct Soundwire ports mask (git-fixes).
- ASoC: codecs: wcd938x-sdw: Correct Soundwire ports mask
  (git-fixes).
- ALSA: usb-audio: Re-add ScratchAmp quirk entries (git-fixes).
- ASoC: meson: axg-fifo: fix irq scheduling issue with PREEMPT_RT
  (git-fixes).
- ASoC: SOF: Remove libraries from topology lookups (git-fixes).
- ASoC: codecs: wsa884x: Correct Soundwire ports mask (git-fixes).
- ASoC: codecs: wsa883x: Correct Soundwire ports mask (git-fixes).
- ASoC: codecs: wsa881x: Correct Soundwire ports mask (git-fixes).
- ASoC: codecs: wcd938x-sdw: Correct Soundwire ports mask
  (git-fixes).
- ALSA: usb-audio: Re-add ScratchAmp quirk entries (git-fixes).
- commit cdc2939
* Fri Aug  9 2024 mpdesouza@suse.com
- kernel-binary.spec.in: Enable klp_symbols on openSUSE Tumbleweed (boo#1229042).
  After the Jump project the kernel used by SLE and openSUSE Leap are the
  same. As consequence the klp_symbols variable is set, enabling
  kernel-default-livepatch-devel on both SLE and openSUSE.
  The current rules to avoid enabling the package exclude openSUSE
  Tumbleweed alone, which doesn't makes sense for now. Enabling
  kernel-default-livepatch-devel on TW makes it easier to test the
  creation of kernel livepatches of the next SLE versions.
- commit fd0b293
* Fri Aug  9 2024 tiwai@suse.de
- Split kABI workaround of recent hyperv fixes (bsc#1229040, bsc#1225745, CVE-2024-36911, bsc#1225717, CVE-2024-36910, bsc#1225744, CVE-2024-36909)
- commit 3639306
* Fri Aug  9 2024 tiwai@suse.de
- Yet more build fix without patches.kabi (bsc#1226502)
- commit 6bc3429
* Fri Aug  9 2024 tiwai@suse.de
- Fix build errors without patches.kabi (bsc#1226502)
  Now patches.suse/x86-Stop-using-weak-symbols-for-__iowrite32_copy.patch
  has a full backport and later partially reverted via
  patches.kabi/kabi-partial-revert-commit-20516d6e51dd.patch
- commit 44c5e90
* Fri Aug  9 2024 mfranc@suse.cz
- landlock: Fix d_parent walk (CVE-2024-40938 bsc#1227840).
- commit 36de641
* Fri Aug  9 2024 tiwai@suse.de
- Drop kABI symbols and patches.kabi/* for SLE15-SP7
- commit 4244494
* Fri Aug  9 2024 tiwai@suse.de
- Fork SLE15-SP7: reduce the old changelog
  Only the old references are kept, the old entries are saved in
  old_changelog.txt
- commit 2db23fb
* Fri Aug  9 2024 pmladek@suse.com
- blacklist.conf: printk/sysctl: breaks kernel without pre-requisite
  patches (bsc#1229025)
- Delete
  patches.suse/printk-Remove-the-now-superfluous-sentinel-elements-from-ctl_table-array.patch.
- commit db77a25
* Fri Aug  9 2024 mfranc@suse.cz
- net: fix sk_memory_allocated_{add|sub} vs softirqs
  (bsc#1228757).
- commit a963c0f
* Fri Aug  9 2024 msuchanek@suse.de
- minmax: fix up min3() and max3() too (bsc#1229024).
- minmax: improve macro expansion and type checking (bsc#1229024).
- minmax: simplify min()/max()/clamp() implementation
  (bsc#1229024).
- minmax: don't use max() in situations that want a C constant
  expression (bsc#1229024).
- minmax: make generic MIN() and MAX() macros available everywhere
  (bsc#1229024).
- minmax: simplify and clarify min_t()/max_t() implementation
  (bsc#1229024).
- minmax: add a few more MIN_T/MAX_T users (bsc#1229024).
- minmax: avoid overly complicated constant expressions in VM code
  (bsc#1229024).
- drm/radeon/evergreen_cs: Clean up errors in evergreen_cs.c
  (bsc#1229024).
- commit c64c296
* Fri Aug  9 2024 jslaby@suse.cz
- Update
  patches.suse/ALSA-emux-improve-patch-ioctl-data-validation.patch
  (stable-fixes CVE-2024-42097 bsc#1228766).
- Update
  patches.suse/ASoC-SOF-Intel-hda-fix-null-deref-on-system-suspend-.patch
  (git-fixes CVE-2024-41037 bsc#1228508).
- Update
  patches.suse/ASoC-amd-acp-add-a-null-check-for-chip_pdev-structur.patch
  (git-fixes CVE-2024-42074 bsc#1228481).
- Update
  patches.suse/ASoC-fsl-asoc-card-set-priv-pdev-before-using-it.patch
  (git-fixes CVE-2024-42089 bsc#1228450).
- Update
  patches.suse/Bluetooth-ISO-Check-socket-flag-instead-of-hcon.patch
  (git-fixes CVE-2024-42141 bsc#1228502).
- Update
  patches.suse/Bluetooth-Ignore-too-large-handle-values-in-BIG.patch
  (git-fixes CVE-2024-42133 bsc#1228511).
- Update
  patches.suse/Bluetooth-hci_core-cancel-all-works-upon-hci_unregis.patch
  (stable-fixes CVE-2024-41063 bsc#1228580).
- Update
  patches.suse/Bluetooth-qca-Fix-BT-enable-failure-again-for-QCA639.patch
  (git-fixes CVE-2024-42137 bsc#1228563).
- Update patches.suse/PCI-MSI-Fix-UAF-in-msi_capability_init.patch
  (git-fixes CVE-2024-41096 bsc#1228479).
- Update
  patches.suse/RDMA-restrack-Fix-potential-invalid-address-access.patch
  (git-fixes CVE-2024-42080 bsc#1228673).
- Update
  patches.suse/USB-core-Fix-duplicate-endpoint-bug-by-clearing-rese.patch
  (git-fixes CVE-2024-41035 bsc#1228485).
- Update patches.suse/USB-serial-mos7840-fix-crash-on-resume.patch
  (git-fixes CVE-2024-42244 bsc#1228967).
- Update
  patches.suse/ata-libata-core-Fix-null-pointer-dereference-on-erro.patch
  (git-fixes CVE-2024-41098 bsc#1228467).
- Update
  patches.suse/bluetooth-hci-disallow-setting-handle-bigger-than-HC.patch
  (git-fixes CVE-2024-42132 bsc#1228492).
- Update
  patches.suse/bpf-Fail-bpf_timer_cancel-when-callback-is-being-can.patch
  (bsc#1228531 CVE-2024-41045 CVE-2024-42239 bsc#1228979).
- Update
  patches.suse/can-mcp251xfd-fix-infinite-loop-when-xmit-fails.patch
  (git-fixes CVE-2024-41088 bsc#1228469).
- Update
  patches.suse/cdrom-rearrange-last_media_change-check-to-avoid-uni.patch
  (stable-fixes CVE-2024-42136 bsc#1228758).
- Update
  patches.suse/crypto-aead-cipher-zeroize-key-buffer-after-use.patch
  (stable-fixes CVE-2024-42229 bsc#1228708).
- Update
  patches.suse/crypto-ecdh-explicitly-zeroize-private_key.patch
  (stable-fixes CVE-2024-42098 bsc#1228779).
- Update
  patches.suse/drm-amd-display-ASSERT-when-failing-to-find-index-by.patch
  (stable-fixes CVE-2024-42117 bsc#1228582).
- Update
  patches.suse/drm-amd-display-Check-index-msg_id-before-read-or-wr.patch
  (stable-fixes CVE-2024-42121 bsc#1228590).
- Update
  patches.suse/drm-amd-display-Check-pipe-offset-before-setting-vbl.patch
  (stable-fixes CVE-2024-42120 bsc#1228588).
- Update
  patches.suse/drm-amd-display-Fix-array-index-out-of-bounds-in-dml.patch
  (stable-fixes CVE-2024-41061 bsc#1228572).
- Update
  patches.suse/drm-amd-display-Fix-overlapping-copy-within-dml_core.patch
  (stable-fixes CVE-2024-42227 bsc#1228707).
- Update
  patches.suse/drm-amd-display-Skip-finding-free-audio-for-unknown-.patch
  (stable-fixes CVE-2024-42119 bsc#1228584).
- Update
  patches.suse/drm-amd-display-Skip-pipe-if-the-pipe-idx-not-set-pr.patch
  (stable-fixes CVE-2024-42064 bsc#1228586).
- Update
  patches.suse/drm-amdgpu-Fix-signedness-bug-in-sdma_v4_0_process_t.patch
  (git-fixes CVE-2024-41022 bsc#1228429).
- Update
  patches.suse/drm-amdgpu-Using-uninitialized-value-size-when-calli.patch
  (stable-fixes CVE-2024-42228 bsc#1228667).
- Update
  patches.suse/drm-amdgpu-avoid-using-null-object-of-framebuffer.patch
  (stable-fixes CVE-2024-41093 bsc#1228660).
- Update
  patches.suse/drm-fbdev-dma-Only-set-smem_start-is-enable-per-modu.patch
  (git-fixes CVE-2024-41094 bsc#1228458).
- Update
  patches.suse/drm-i915-gt-Fix-potential-UAF-by-revoke-of-fence-reg.patch
  (git-fixes CVE-2024-41092 bsc#1228483).
- Update
  patches.suse/drm-lima-fix-shared-irq-handling-on-driver-remove.patch
  (stable-fixes CVE-2024-42127 bsc#1228721).
- Update
  patches.suse/drm-nouveau-dispnv04-fix-null-pointer-dereference-in-66edf3f.patch
  (stable-fixes CVE-2024-41095 bsc#1228662).
- Update
  patches.suse/drm-nouveau-dispnv04-fix-null-pointer-dereference-in.patch
  (stable-fixes CVE-2024-41089 bsc#1228658).
- Update
  patches.suse/drm-nouveau-fix-null-pointer-dereference-in-nouveau_.patch
  (git-fixes CVE-2024-42101 bsc#1228495).
- Update
  patches.suse/drm-panel-ilitek-ili9881c-Fix-warning-with-GPIO-cont.patch
  (stable-fixes CVE-2024-42087 bsc#1228677).
- Update
  patches.suse/drm-radeon-check-bo_va-bo-is-non-NULL-before-using-i.patch
  (stable-fixes CVE-2024-41060 bsc#1228567).
- Update
  patches.suse/filelock-fix-potential-use-after-free-in-posix_lock_inode.patch
  (git-fixes CVE-2024-41049 bsc#1228486).
- Update
  patches.suse/firmware-cs_dsp-Fix-overflow-checking-of-wmfw-header.patch
  (git-fixes CVE-2024-41039 bsc#1228515).
- Update
  patches.suse/firmware-cs_dsp-Prevent-buffer-overrun-when-processi.patch
  (git-fixes CVE-2024-41038 bsc#1228509).
- Update
  patches.suse/firmware-cs_dsp-Return-error-if-block-header-overflo.patch
  (git-fixes CVE-2024-42238 bsc#1228991).
- Update
  patches.suse/firmware-cs_dsp-Use-strnlen-on-name-fields-in-V1-wmf.patch
  (git-fixes CVE-2024-41056 bsc#1228480).
- Update
  patches.suse/firmware-cs_dsp-Validate-payload-length-before-proce.patch
  (git-fixes CVE-2024-42237 bsc#1228992).
- Update
  patches.suse/genirq-cpuhotplug-x86-vector-Prevent-vector-leak-dur.patch
  (git-fixes CVE-2024-31076 bsc#1226765).
- Update
  patches.suse/gpio-davinci-Validate-the-obtained-number-of-IRQs.patch
  (git-fixes CVE-2024-42092 bsc#1228447).
- Update
  patches.suse/gpio-pca953x-fix-pca953x_irq_bus_sync_unlock-race.patch
  (stable-fixes CVE-2024-42253 bsc#1229005).
- Update
  patches.suse/i2c-pnx-Fix-potential-deadlock-warning-from-del_time.patch
  (git-fixes CVE-2024-42153 bsc#1228510).
- Update
  patches.suse/iio-chemical-bme680-Fix-overflows-in-compensate-func.patch
  (git-fixes CVE-2024-42086 bsc#1228452).
- Update
  patches.suse/jffs2-Fix-potential-illegal-address-access-in-jffs2_free_inode.patch
  (git-fixes CVE-2024-42115 bsc#1228656).
- Update
  patches.suse/libceph-fix-race-between-delayed_work-and-ceph_monc_s.patch
  (bsc#1228192 CVE-2024-42232 bsc#1228959).
- Update
  patches.suse/media-dvb-frontends-tda10048-Fix-integer-overflow.patch
  (stable-fixes CVE-2024-42223 bsc#1228726).
- Update
  patches.suse/misc-fastrpc-Fix-memory-leak-in-audio-daemon-attach-.patch
  (git-fixes CVE-2024-41025 bsc#1228527).
- Update
  patches.suse/misc-fastrpc-Restrict-untrusted-app-to-attach-to-pri.patch
  (git-fixes CVE-2024-41024 bsc#1228525).
- Update
  patches.suse/mm-Avoid-overflows-in-dirty-throttling-logic.patch
  (bsc#1222364 CVE-2024-26720 CVE-2024-42131 bsc#1228650).
- Update
  patches.suse/msft-hv-3022-net-mana-Fix-possible-double-free-in-error-handling-.patch
  (git-fixes CVE-2024-42069 bsc#1228463).
- Update
  patches.suse/net-can-j1939-Initialize-unused-data-in-j1939_send_o.patch
  (git-fixes CVE-2024-42076 bsc#1228484).
- Update
  patches.suse/net-can-j1939-enhanced-error-handling-for-tightly-re.patch
  (git-fixes CVE-2023-52887 bsc#1228426).
- Update
  patches.suse/nfc-nci-Add-the-inconsistency-check-between-the-inpu.patch
  (stable-fixes CVE-2024-42130 bsc#1228687).
- Update
  patches.suse/nilfs2-add-missing-check-for-inode-numbers-on-direct.patch
  (stable-fixes CVE-2024-42104 bsc#1228654).
- Update patches.suse/nvme-avoid-double-free-special-payload.patch
  (git-fixes CVE-2024-41073 bsc#1228635).
- Update patches.suse/nvmet-always-initialize-cqe.result.patch
  (git-fixes CVE-2024-41079 bsc#1228615).
- Update
  patches.suse/nvmet-fix-a-possible-leak-when-destroy-a-ctrl-during.patch
  (git-fixes CVE-2024-42152 bsc#1228724).
- Update
  patches.suse/ocfs2-fix-DIO-failure-due-to-insufficient-transaction-credits.patch
  (git-fixes CVE-2024-42077 bsc#1228516).
- Update
  patches.suse/ocfs2-strict-bound-check-before-memcmp-in-ocfs2_xatt.patch
  (bsc#1228410 CVE-2024-41016).
- Update patches.suse/orangefs-fix-out-of-bounds-fsid-access.patch
  (git-fixes CVE-2024-42143 bsc#1228748).
- Update
  patches.suse/pinctrl-fix-deadlock-in-create_pinctrl-when-handling.patch
  (git-fixes CVE-2024-42090 bsc#1228449).
- Update
  patches.suse/platform-x86-toshiba_acpi-Fix-array-out-of-bounds-ac.patch
  (git-fixes CVE-2024-41028 bsc#1228539).
- Update
  patches.suse/powerpc-Avoid-nmi_enter-nmi_exit-in-real-mode-interr.patch
  (bsc#1221645 ltc#205739 bsc#1223191 CVE-2024-42126 bsc#1228718).
- Update
  patches.suse/powerpc-pseries-Fix-scv-instruction-crash-with-kexec.patch
  (bsc#1194869 CVE-2024-42230 bsc#1228489).
- Update
  patches.suse/thermal-drivers-mediatek-lvts_thermal-Check-NULL-ptr.patch
  (stable-fixes CVE-2024-42144 bsc#1228666).
- Update
  patches.suse/usb-atm-cxacru-fix-endpoint-checking-in-cxacru_bind.patch
  (git-fixes CVE-2024-41097 bsc#1228513).
- Update
  patches.suse/usb-dwc3-core-remove-lock-of-otg-mode-during-gadget-.patch
  (git-fixes CVE-2024-42085 bsc#1228456).
- Update
  patches.suse/usb-gadget-configfs-Prevent-OOB-read-write-in-usb_st.patch
  (stable-fixes CVE-2024-42236 bsc#1228964).
- Update
  patches.suse/usb-xhci-prevent-potential-failure-in-handle_tx_even.patch
  (stable-fixes CVE-2024-42226 bsc#1228709).
- Update
  patches.suse/wifi-cfg80211-restrict-NL80211_ATTR_TXQ_QUANTUM-valu.patch
  (git-fixes CVE-2024-42114 bsc#1228564).
- Update
  patches.suse/wifi-cfg80211-wext-add-extra-SIOCSIWSCAN-data-check.patch
  (stable-fixes CVE-2024-41072 bsc#1228626).
- Update
  patches.suse/wifi-mac80211-Avoid-address-calculations-via-out-of-.patch
  (stable-fixes CVE-2024-41071 bsc#1228625).
- Update
  patches.suse/wifi-mt76-replace-skb_put-with-skb_put_zero.patch
  (stable-fixes CVE-2024-42225 bsc#1228710).
- Update
  patches.suse/wifi-rtw89-fw-scan-offload-prohibit-all-6-GHz-channe.patch
  (bsc#1227149 CVE-2024-42125 bsc#1228674).
- Update
  patches.suse/x86-bhi-Avoid-warning-in-DB-handler-due-to-BHI-mitigation
  (git-fixes CVE-2024-42240 bsc#1228966).
  Add CVE references.
- commit dfa8582
* Fri Aug  9 2024 tbogendoerfer@suse.de
- wireguard: allowedips: avoid unaligned 64-bit memory accesses
  (CVE-2024-42247 bsc#1228988).
- commit 12abe6d
* Fri Aug  9 2024 shung-hsi.yu@suse.com
- selftests/bpf: Add netlink helper library (bsc#1228021
  CVE-2024-41010).
- Fix BPF selftest build failure
- commit c3e9de4
* Fri Aug  9 2024 jlee@suse.com
- x86/numa: Fix the sort compare func used in numa_fill_memblks()
  (git-fixes).
- x86/numa: Fix the address overlap check in numa_fill_memblks()
  (git-fixes).
- commit b42baa2
* Thu Aug  8 2024 davide.benini@suse.com
- inet_diag: Initialize pad field in struct inet_diag_req_v2
  (CVE-2024-42106 bsc#1228493).
- commit 87d015b
* Thu Aug  8 2024 jlee@suse.com
- x86/numa: Fix SRAT lookup of CFMWS ranges with
  numa_fill_memblks() (git-fixes).
- ACPI/NUMA: Apply SRAT proximity domain to entire CFMWS window
  (git-fixes).
- x86/numa: Introduce numa_fill_memblks() (git-fixes).
- commit 7f40727
* Thu Aug  8 2024 jlee@suse.com
- ACPI: processor_idle: use raw_safe_halt() in
  acpi_idle_play_dead() (git-fixes).
- perf/smmuv3: Enable HiSilicon Erratum 162001900 quirk for
  HIP08/09 (git-fixes).
- commit 23f94eb
* Thu Aug  8 2024 tiwai@suse.de
- Fork SLE15-SP7 branch, the changelog entries until the commit
  104de54ef80a are truncated in order to save space.
  Bugzilla/CVE/Jira references from the deleted changelog entries are
  included below. The full text for these removed entries can be found in
    /usr/share/doc/packages/kernel-docs/old_changelog.txt
  from the kernel-docs package:
  bac#1214529 bnc#804482 boo#1193472 boo#1211226 boo#1221077 bsc#1012628
  bsc#1023051 bsc#1065729 bsc#1108281 bsc#1120059 bsc#1141539 bsc#1148712
  bsc#1177090 bsc#1177719 bsc#1180336 bsc#1181674 bsc#1183045 bsc#1184587
  bsc#1186716 bsc#1187236 bsc#1187716 bsc#1187829 bsc#1189965 bsc#1191396
  bsc#1192327 bsc#1193201 bsc#1193203 bsc#1193454 bsc#1193599 bsc#1193629
  bsc#1194869 bsc#1195774 bsc#1195775 bsc#1198276 bsc#1201284 bsc#1204315
  bsc#1204562 bsc#1205316 bsc#1205462 bsc#1206453 bsc#1206578 bsc#1207948
  bsc#1208410 bsc#1208593 bsc#1208724 bsc#1208783 bsc#1208788 bsc#1208995
  bsc#1209006 bsc#1209284 bsc#1209657 bsc#1209834 bsc#1210335 bsc#1210421
  bsc#1210658 bsc#1210690 bsc#1210778 bsc#1211307 bsc#1211346 bsc#1211732
  bsc#1211847 bsc#1211852 bsc#1211960 bsc#1212091 bsc#1212301 bsc#1212395
  bsc#1212405 bsc#1212445 bsc#1212471 bsc#1212505 bsc#1212514 bsc#1212533
  bsc#1212639 bsc#1212649 bsc#1212703 bsc#1212741 bsc#1212773 bsc#1212775
  bsc#1212808 bsc#1212835 bsc#1212857 bsc#1212873 bsc#1212874 bsc#1212886
  bsc#1212887 bsc#1213026 bsc#1213059 bsc#1213061 bsc#1213123 bsc#1213179
  bsc#1213270 bsc#1213287 bsc#1213456 bsc#1213491 bsc#1213534 bsc#1213545
  bsc#1213546 bsc#1213573 bsc#1213583 bsc#1213585 bsc#1213588 bsc#1213592
  bsc#1213645 bsc#1213666 bsc#1213667 bsc#1213693 bsc#1213705 bsc#1213745
  bsc#1213747 bsc#1213756 bsc#1213779 bsc#1213787 bsc#1213812 bsc#1213916
  bsc#1213968 bsc#1213971 bsc#1213972 bsc#1213978 bsc#1214022 bsc#1214073
  bsc#1214120 bsc#1214133 bsc#1214149 bsc#1214193 bsc#1214212 bsc#1214233
  bsc#1214285 bsc#1214297 bsc#1214304 bsc#1214371 bsc#1214377 bsc#1214380
  bsc#1214385 bsc#1214386 bsc#1214397 bsc#1214428 bsc#1214479 bsc#1214635
  bsc#1214683 bsc#1214700 bsc#1214727 bsc#1214746 bsc#1214747 bsc#1214754
  bsc#1214772 bsc#1214773 bsc#1214842 bsc#1214847 bsc#1214852 bsc#1214883
  bsc#1214891 bsc#1214928 bsc#1214931 bsc#1214934 bsc#1214939 bsc#1214951
  bsc#1214952 bsc#1214953 bsc#1214955 bsc#1214963 bsc#1214993 bsc#1214995
  bsc#1214997 bsc#1214998 bsc#1215115 bsc#1215117 bsc#1215124 bsc#1215143
  bsc#1215146 bsc#1215150 bsc#1215155 bsc#1215199 bsc#1215211 bsc#1215221
  bsc#1215234 bsc#1215237 bsc#1215252 bsc#1215253 bsc#1215275 bsc#1215284
  bsc#1215291 bsc#1215322 bsc#1215344 bsc#1215345 bsc#1215420 bsc#1215467
  bsc#1215528 bsc#1215529 bsc#1215530 bsc#1215541 bsc#1215587 bsc#1215612
  bsc#1215613 bsc#1215696 bsc#1215710 bsc#1215745 bsc#1215767 bsc#1215768
  bsc#1215858 bsc#1215860 bsc#1215875 bsc#1215880 bsc#1215885 bsc#1215899
  bsc#1215921 bsc#1215931 bsc#1215938 bsc#1216004 bsc#1216015 bsc#1216033
  bsc#1216046 bsc#1216062 bsc#1216196 bsc#1216213 bsc#1216214 bsc#1216215
  bsc#1216259 bsc#1216325 bsc#1216326 bsc#1216327 bsc#1216331 bsc#1216358
  bsc#1216396 bsc#1216435 bsc#1216436 bsc#1216505 bsc#1216507 bsc#1216523
  bsc#1216527 bsc#1216584 bsc#1216611 bsc#1216621 bsc#1216687 bsc#1216693
  bsc#1216702 bsc#1216759 bsc#1216760 bsc#1216761 bsc#1216776 bsc#1216837
  bsc#1216838 bsc#1216861 bsc#1216864 bsc#1216929 bsc#1216954 bsc#1216965
  bsc#1216976 bsc#1217030 bsc#1217036 bsc#1217068 bsc#1217090 bsc#1217124
  bsc#1217132 bsc#1217140 bsc#1217169 bsc#1217250 bsc#1217282 bsc#1217313
  bsc#1217344 bsc#1217362 bsc#1217382 bsc#1217384 bsc#1217408 bsc#1217410
  bsc#1217412 bsc#1217417 bsc#1217473 bsc#1217481 bsc#1217489 bsc#1217510
  bsc#1217591 bsc#1217602 bsc#1217686 bsc#1217698 bsc#1217731 bsc#1217750
  bsc#1217756 bsc#1217780 bsc#1217801 bsc#1217818 bsc#1217908 bsc#1217912
  bsc#1217927 bsc#1217930 bsc#1217931 bsc#1217938 bsc#1217944 bsc#1217946
  bsc#1217947 bsc#1217958 bsc#1217959 bsc#1217987 bsc#1217988 bsc#1217989
  bsc#1218003 bsc#1218054 bsc#1218085 bsc#1218139 bsc#1218177 bsc#1218180
  bsc#1218184 bsc#1218195 bsc#1218205 bsc#1218216 bsc#1218245 bsc#1218253
  bsc#1218258 bsc#1218272 bsc#1218286 bsc#1218335 bsc#1218336 bsc#1218359
  bsc#1218397 bsc#1218442 bsc#1218447 bsc#1218495 bsc#1218515 bsc#1218554
  bsc#1218555 bsc#1218556 bsc#1218559 bsc#1218562 bsc#1218624 bsc#1218634
  bsc#1218636 bsc#1218644 bsc#1218709 bsc#1218713 bsc#1218720 bsc#1218721
  bsc#1218726 bsc#1218727 bsc#1218730 bsc#1218753 bsc#1218757 bsc#1218768
  bsc#1218777 bsc#1218779 bsc#1218785 bsc#1218804 bsc#1218820 bsc#1218829
  bsc#1218830 bsc#1218832 bsc#1218836 bsc#1218855 bsc#1218869 bsc#1218870
  bsc#1218893 bsc#1218915 bsc#1218916 bsc#1218917 bsc#1218934 bsc#1218941
  bsc#1218948 bsc#1218958 bsc#1218960 bsc#1218968 bsc#1218986 bsc#1218987
  bsc#1218988 bsc#1218989 bsc#1218991 bsc#1218992 bsc#1218993 bsc#1218996
  bsc#1219077 bsc#1219104 bsc#1219120 bsc#1219126 bsc#1219127 bsc#1219128
  bsc#1219141 bsc#1219146 bsc#1219163 bsc#1219165 bsc#1219169 bsc#1219170
  bsc#1219216 bsc#1219222 bsc#1219224 bsc#1219246 bsc#1219247 bsc#1219254
  bsc#1219261 bsc#1219264 bsc#1219285 bsc#1219286 bsc#1219315 bsc#1219338
  bsc#1219404 bsc#1219429 bsc#1219434 bsc#1219440 bsc#1219443 bsc#1219451
  bsc#1219470 bsc#1219473 bsc#1219475 bsc#1219478 bsc#1219485 bsc#1219496
  bsc#1219497 bsc#1219509 bsc#1219510 bsc#1219551 bsc#1219558 bsc#1219566
  bsc#1219567 bsc#1219582 bsc#1219596 bsc#1219608 bsc#1219617 bsc#1219623
  bsc#1219631 bsc#1219633 bsc#1219653 bsc#1219670 bsc#1219692 bsc#1219731
  bsc#1219732 bsc#1219789 bsc#1219808 bsc#1219809 bsc#1219810 bsc#1219811
  bsc#1219812 bsc#1219814 bsc#1219815 bsc#1219816 bsc#1219825 bsc#1219827
  bsc#1219832 bsc#1219834 bsc#1219835 bsc#1219847 bsc#1219889 bsc#1219953
  bsc#1219987 bsc#1220009 bsc#1220021 bsc#1220030 bsc#1220045 bsc#1220066
  bsc#1220089 bsc#1220106 bsc#1220120 bsc#1220129 bsc#1220137 bsc#1220138
  bsc#1220140 bsc#1220144 bsc#1220148 bsc#1220154 bsc#1220174 bsc#1220182
  bsc#1220185 bsc#1220186 bsc#1220187 bsc#1220214 bsc#1220218 bsc#1220237
  bsc#1220238 bsc#1220240 bsc#1220241 bsc#1220243 bsc#1220247 bsc#1220250
  bsc#1220251 bsc#1220253 bsc#1220254 bsc#1220255 bsc#1220257 bsc#1220265
  bsc#1220277 bsc#1220287 bsc#1220319 bsc#1220320 bsc#1220322 bsc#1220325
  bsc#1220326 bsc#1220328 bsc#1220330 bsc#1220331 bsc#1220332 bsc#1220335
  bsc#1220336 bsc#1220337 bsc#1220340 bsc#1220342 bsc#1220344 bsc#1220348
  bsc#1220350 bsc#1220359 bsc#1220360 bsc#1220363 bsc#1220364 bsc#1220365
  bsc#1220369 bsc#1220398 bsc#1220411 bsc#1220413 bsc#1220419 bsc#1220424
  bsc#1220427 bsc#1220428 bsc#1220430 bsc#1220431 bsc#1220433 bsc#1220451
  bsc#1220452 bsc#1220453 bsc#1220454 bsc#1220492 bsc#1220502 bsc#1220507
  bsc#1220569 bsc#1220587 bsc#1220649 bsc#1220682 bsc#1220684 bsc#1220703
  bsc#1220709 bsc#1220735 bsc#1220736 bsc#1220738 bsc#1220783 bsc#1220790
  bsc#1220796 bsc#1220797 bsc#1220825 bsc#1220827 bsc#1220830 bsc#1220831
  bsc#1220833 bsc#1220835 bsc#1220836 bsc#1220839 bsc#1220840 bsc#1220843
  bsc#1220848 bsc#1220869 bsc#1220870 bsc#1220871 bsc#1220872 bsc#1220873
  bsc#1220874 bsc#1220876 bsc#1220878 bsc#1220879 bsc#1220883 bsc#1220885
  bsc#1220887 bsc#1220897 bsc#1220898 bsc#1220901 bsc#1220914 bsc#1220915
  bsc#1220918 bsc#1220920 bsc#1220921 bsc#1220924 bsc#1220925 bsc#1220926
  bsc#1220927 bsc#1220928 bsc#1220929 bsc#1220930 bsc#1220931 bsc#1220932
  bsc#1220933 bsc#1220935 bsc#1220936 bsc#1220937 bsc#1220938 bsc#1220939
  bsc#1220940 bsc#1220941 bsc#1220942 bsc#1220943 bsc#1220945 bsc#1220946
  bsc#1221012 bsc#1221015 bsc#1221021 bsc#1221022 bsc#1221032 bsc#1221040
  bsc#1221042 bsc#1221044 bsc#1221045 bsc#1221046 bsc#1221048 bsc#1221055
  bsc#1221056 bsc#1221057 bsc#1221058 bsc#1221060 bsc#1221061 bsc#1221062
  bsc#1221066 bsc#1221067 bsc#1221068 bsc#1221069 bsc#1221070 bsc#1221071
  bsc#1221079 bsc#1221080 bsc#1221081 bsc#1221082 bsc#1221084 bsc#1221086
  bsc#1221088 bsc#1221090 bsc#1221097 bsc#1221114 bsc#1221156 bsc#1221157
  bsc#1221161 bsc#1221162 bsc#1221261 bsc#1221269 bsc#1221271 bsc#1221273
  bsc#1221274 bsc#1221276 bsc#1221277 bsc#1221281 bsc#1221282 bsc#1221291
  bsc#1221293 bsc#1221295 bsc#1221298 bsc#1221299 bsc#1221303 bsc#1221305
  bsc#1221325 bsc#1221330 bsc#1221337 bsc#1221339 bsc#1221341 bsc#1221375
  bsc#1221379 bsc#1221388 bsc#1221389 bsc#1221390 bsc#1221391 bsc#1221392
  bsc#1221393 bsc#1221428 bsc#1221491 bsc#1221504 bsc#1221553 bsc#1221611
  bsc#1221612 bsc#1221613 bsc#1221614 bsc#1221615 bsc#1221616 bsc#1221617
  bsc#1221618 bsc#1221620 bsc#1221623 bsc#1221625 bsc#1221626 bsc#1221635
  bsc#1221645 bsc#1221647 bsc#1221649 bsc#1221652 bsc#1221654 bsc#1221656
  bsc#1221659 bsc#1221765 bsc#1221777 bsc#1221783 bsc#1221814 bsc#1221816
  bsc#1221829 bsc#1221830 bsc#1221858 bsc#1221958 bsc#1222011 bsc#1222015
  bsc#1222048 bsc#1222051 bsc#1222054 bsc#1222055 bsc#1222056 bsc#1222060
  bsc#1222066 bsc#1222067 bsc#1222070 bsc#1222072 bsc#1222073 bsc#1222080
  bsc#1222083 bsc#1222085 bsc#1222115 bsc#1222117 bsc#1222173 bsc#1222230
  bsc#1222241 bsc#1222247 bsc#1222254 bsc#1222264 bsc#1222266 bsc#1222273
  bsc#1222274 bsc#1222278 bsc#1222291 bsc#1222293 bsc#1222294 bsc#1222299
  bsc#1222300 bsc#1222301 bsc#1222303 bsc#1222304 bsc#1222307 bsc#1222317
  bsc#1222323 bsc#1222324 bsc#1222326 bsc#1222328 bsc#1222331 bsc#1222355
  bsc#1222356 bsc#1222357 bsc#1222358 bsc#1222359 bsc#1222360 bsc#1222364
  bsc#1222365 bsc#1222366 bsc#1222367 bsc#1222368 bsc#1222369 bsc#1222370
  bsc#1222371 bsc#1222373 bsc#1222374 bsc#1222378 bsc#1222379 bsc#1222380
  bsc#1222385 bsc#1222413 bsc#1222415 bsc#1222416 bsc#1222418 bsc#1222419
  bsc#1222420 bsc#1222422 bsc#1222424 bsc#1222425 bsc#1222426 bsc#1222427
  bsc#1222428 bsc#1222430 bsc#1222431 bsc#1222433 bsc#1222434 bsc#1222435
  bsc#1222437 bsc#1222438 bsc#1222444 bsc#1222445 bsc#1222449 bsc#1222451
  bsc#1222459 bsc#1222463 bsc#1222464 bsc#1222466 bsc#1222482 bsc#1222489
  bsc#1222503 bsc#1222513 bsc#1222520 bsc#1222522 bsc#1222523 bsc#1222525
  bsc#1222527 bsc#1222529 bsc#1222531 bsc#1222532 bsc#1222536 bsc#1222549
  bsc#1222550 bsc#1222552 bsc#1222557 bsc#1222559 bsc#1222561 bsc#1222563
  bsc#1222585 bsc#1222586 bsc#1222588 bsc#1222596 bsc#1222601 bsc#1222602
  bsc#1222606 bsc#1222607 bsc#1222608 bsc#1222609 bsc#1222610 bsc#1222613
  bsc#1222615 bsc#1222617 bsc#1222618 bsc#1222619 bsc#1222622 bsc#1222624
  bsc#1222625 bsc#1222626 bsc#1222627 bsc#1222630 bsc#1222632 bsc#1222635
  bsc#1222654 bsc#1222656 bsc#1222667 bsc#1222677 bsc#1222678 bsc#1222680
  bsc#1222720 bsc#1222721 bsc#1222724 bsc#1222726 bsc#1222727 bsc#1222728
  bsc#1222742 bsc#1222764 bsc#1222765 bsc#1222768 bsc#1222769 bsc#1222770
  bsc#1222771 bsc#1222772 bsc#1222775 bsc#1222777 bsc#1222779 bsc#1222780
  bsc#1222781 bsc#1222782 bsc#1222783 bsc#1222784 bsc#1222788 bsc#1222793
  bsc#1222798 bsc#1222799 bsc#1222801 bsc#1222809 bsc#1222810 bsc#1222823
  bsc#1222870 bsc#1222893 bsc#1222960 bsc#1222961 bsc#1222968 bsc#1222974
  bsc#1222975 bsc#1222976 bsc#1223007 bsc#1223010 bsc#1223011 bsc#1223012
  bsc#1223013 bsc#1223014 bsc#1223015 bsc#1223016 bsc#1223018 bsc#1223020
  bsc#1223021 bsc#1223023 bsc#1223024 bsc#1223026 bsc#1223027 bsc#1223030
  bsc#1223031 bsc#1223033 bsc#1223034 bsc#1223035 bsc#1223036 bsc#1223037
  bsc#1223038 bsc#1223039 bsc#1223041 bsc#1223042 bsc#1223043 bsc#1223044
  bsc#1223045 bsc#1223046 bsc#1223048 bsc#1223049 bsc#1223051 bsc#1223052
  bsc#1223055 bsc#1223056 bsc#1223057 bsc#1223058 bsc#1223060 bsc#1223061
  bsc#1223062 bsc#1223064 bsc#1223065 bsc#1223066 bsc#1223076 bsc#1223077
  bsc#1223078 bsc#1223081 bsc#1223084 bsc#1223111 bsc#1223113 bsc#1223115
  bsc#1223118 bsc#1223119 bsc#1223137 bsc#1223138 bsc#1223140 bsc#1223143
  bsc#1223187 bsc#1223188 bsc#1223189 bsc#1223190 bsc#1223191 bsc#1223192
  bsc#1223195 bsc#1223196 bsc#1223197 bsc#1223198 bsc#1223202 bsc#1223203
  bsc#1223204 bsc#1223205 bsc#1223207 bsc#1223265 bsc#1223285 bsc#1223315
  bsc#1223323 bsc#1223338 bsc#1223369 bsc#1223380 bsc#1223384 bsc#1223390
  bsc#1223395 bsc#1223415 bsc#1223439 bsc#1223462 bsc#1223525 bsc#1223532
  bsc#1223539 bsc#1223570 bsc#1223575 bsc#1223590 bsc#1223591 bsc#1223592
  bsc#1223593 bsc#1223625 bsc#1223626 bsc#1223627 bsc#1223628 bsc#1223629
  bsc#1223631 bsc#1223632 bsc#1223633 bsc#1223634 bsc#1223637 bsc#1223638
  bsc#1223641 bsc#1223642 bsc#1223643 bsc#1223644 bsc#1223645 bsc#1223646
  bsc#1223648 bsc#1223649 bsc#1223650 bsc#1223651 bsc#1223652 bsc#1223653
  bsc#1223654 bsc#1223655 bsc#1223657 bsc#1223660 bsc#1223661 bsc#1223663
  bsc#1223664 bsc#1223665 bsc#1223666 bsc#1223667 bsc#1223668 bsc#1223669
  bsc#1223670 bsc#1223671 bsc#1223675 bsc#1223677 bsc#1223678 bsc#1223679
  bsc#1223686 bsc#1223692 bsc#1223693 bsc#1223695 bsc#1223696 bsc#1223698
  bsc#1223699 bsc#1223705 bsc#1223709 bsc#1223711 bsc#1223712 bsc#1223714
  bsc#1223715 bsc#1223717 bsc#1223718 bsc#1223723 bsc#1223725 bsc#1223728
  bsc#1223731 bsc#1223732 bsc#1223734 bsc#1223735 bsc#1223737 bsc#1223738
  bsc#1223739 bsc#1223740 bsc#1223741 bsc#1223744 bsc#1223745 bsc#1223747
  bsc#1223748 bsc#1223749 bsc#1223750 bsc#1223752 bsc#1223754 bsc#1223756
  bsc#1223757 bsc#1223759 bsc#1223760 bsc#1223761 bsc#1223762 bsc#1223763
  bsc#1223764 bsc#1223765 bsc#1223768 bsc#1223769 bsc#1223770 bsc#1223774
  bsc#1223776 bsc#1223778 bsc#1223779 bsc#1223780 bsc#1223781 bsc#1223782
  bsc#1223787 bsc#1223788 bsc#1223789 bsc#1223790 bsc#1223802 bsc#1223804
  bsc#1223805 bsc#1223806 bsc#1223807 bsc#1223808 bsc#1223810 bsc#1223813
  bsc#1223815 bsc#1223816 bsc#1223819 bsc#1223821 bsc#1223822 bsc#1223823
  bsc#1223824 bsc#1223826 bsc#1223827 bsc#1223828 bsc#1223829 bsc#1223831
  bsc#1223834 bsc#1223836 bsc#1223837 bsc#1223838 bsc#1223842 bsc#1223843
  bsc#1223844 bsc#1223847 bsc#1223863 bsc#1223869 bsc#1223870 bsc#1223871
  bsc#1223872 bsc#1223874 bsc#1223944 bsc#1223945 bsc#1223946 bsc#1223991
  bsc#1224049 bsc#1224076 bsc#1224096 bsc#1224098 bsc#1224099 bsc#1224137
  bsc#1224166 bsc#1224174 bsc#1224177 bsc#1224180 bsc#1224181 bsc#1224187
  bsc#1224331 bsc#1224348 bsc#1224414 bsc#1224422 bsc#1224423 bsc#1224429
  bsc#1224430 bsc#1224432 bsc#1224433 bsc#1224437 bsc#1224438 bsc#1224439
  bsc#1224442 bsc#1224443 bsc#1224445 bsc#1224449 bsc#1224477 bsc#1224479
  bsc#1224480 bsc#1224481 bsc#1224482 bsc#1224485 bsc#1224486 bsc#1224487
  bsc#1224488 bsc#1224490 bsc#1224491 bsc#1224492 bsc#1224493 bsc#1224494
  bsc#1224495 bsc#1224497 bsc#1224498 bsc#1224499 bsc#1224500 bsc#1224501
  bsc#1224502 bsc#1224504 bsc#1224505 bsc#1224506 bsc#1224507 bsc#1224508
  bsc#1224509 bsc#1224511 bsc#1224512 bsc#1224513 bsc#1224515 bsc#1224516
  bsc#1224517 bsc#1224519 bsc#1224520 bsc#1224521 bsc#1224523 bsc#1224524
  bsc#1224525 bsc#1224526 bsc#1224530 bsc#1224531 bsc#1224534 bsc#1224537
  bsc#1224539 bsc#1224540 bsc#1224541 bsc#1224542 bsc#1224543 bsc#1224544
  bsc#1224545 bsc#1224546 bsc#1224549 bsc#1224550 bsc#1224552 bsc#1224553
  bsc#1224555 bsc#1224557 bsc#1224558 bsc#1224559 bsc#1224562 bsc#1224565
  bsc#1224566 bsc#1224567 bsc#1224568 bsc#1224569 bsc#1224571 bsc#1224572
  bsc#1224573 bsc#1224575 bsc#1224576 bsc#1224577 bsc#1224578 bsc#1224579
  bsc#1224580 bsc#1224581 bsc#1224582 bsc#1224583 bsc#1224584 bsc#1224585
  bsc#1224586 bsc#1224587 bsc#1224588 bsc#1224589 bsc#1224592 bsc#1224596
  bsc#1224598 bsc#1224600 bsc#1224601 bsc#1224602 bsc#1224603 bsc#1224604
  bsc#1224605 bsc#1224606 bsc#1224607 bsc#1224608 bsc#1224609 bsc#1224611
  bsc#1224612 bsc#1224613 bsc#1224614 bsc#1224615 bsc#1224617 bsc#1224618
  bsc#1224619 bsc#1224620 bsc#1224621 bsc#1224622 bsc#1224623 bsc#1224624
  bsc#1224626 bsc#1224627 bsc#1224628 bsc#1224629 bsc#1224630 bsc#1224631
  bsc#1224632 bsc#1224633 bsc#1224634 bsc#1224636 bsc#1224637 bsc#1224638
  bsc#1224639 bsc#1224640 bsc#1224641 bsc#1224643 bsc#1224644 bsc#1224645
  bsc#1224646 bsc#1224647 bsc#1224648 bsc#1224649 bsc#1224650 bsc#1224651
  bsc#1224652 bsc#1224653 bsc#1224654 bsc#1224655 bsc#1224657 bsc#1224659
  bsc#1224660 bsc#1224661 bsc#1224662 bsc#1224663 bsc#1224664 bsc#1224665
  bsc#1224666 bsc#1224667 bsc#1224668 bsc#1224670 bsc#1224671 bsc#1224672
  bsc#1224673 bsc#1224674 bsc#1224675 bsc#1224676 bsc#1224677 bsc#1224678
  bsc#1224679 bsc#1224680 bsc#1224681 bsc#1224682 bsc#1224683 bsc#1224685
  bsc#1224686 bsc#1224687 bsc#1224688 bsc#1224690 bsc#1224692 bsc#1224694
  bsc#1224696 bsc#1224697 bsc#1224698 bsc#1224699 bsc#1224700 bsc#1224701
  bsc#1224703 bsc#1224704 bsc#1224705 bsc#1224706 bsc#1224707 bsc#1224709
  bsc#1224710 bsc#1224712 bsc#1224714 bsc#1224716 bsc#1224717 bsc#1224718
  bsc#1224719 bsc#1224720 bsc#1224721 bsc#1224722 bsc#1224723 bsc#1224725
  bsc#1224727 bsc#1224728 bsc#1224729 bsc#1224730 bsc#1224731 bsc#1224732
  bsc#1224733 bsc#1224735 bsc#1224736 bsc#1224738 bsc#1224739 bsc#1224740
  bsc#1224741 bsc#1224742 bsc#1224743 bsc#1224747 bsc#1224749 bsc#1224751
  bsc#1224759 bsc#1224763 bsc#1224764 bsc#1224765 bsc#1224766 bsc#1224767
  bsc#1224790 bsc#1224792 bsc#1224793 bsc#1224803 bsc#1224804 bsc#1224866
  bsc#1224928 bsc#1224930 bsc#1224932 bsc#1224933 bsc#1224935 bsc#1224936
  bsc#1224937 bsc#1224939 bsc#1224941 bsc#1224944 bsc#1224946 bsc#1224947
  bsc#1224949 bsc#1224951 bsc#1224988 bsc#1224989 bsc#1224992 bsc#1224998
  bsc#1225000 bsc#1225001 bsc#1225004 bsc#1225006 bsc#1225007 bsc#1225008
  bsc#1225009 bsc#1225014 bsc#1225015 bsc#1225022 bsc#1225025 bsc#1225028
  bsc#1225029 bsc#1225031 bsc#1225036 bsc#1225041 bsc#1225044 bsc#1225049
  bsc#1225050 bsc#1225053 bsc#1225076 bsc#1225077 bsc#1225078 bsc#1225081
  bsc#1225085 bsc#1225086 bsc#1225088 bsc#1225090 bsc#1225092 bsc#1225096
  bsc#1225097 bsc#1225098 bsc#1225101 bsc#1225103 bsc#1225104 bsc#1225105
  bsc#1225106 bsc#1225108 bsc#1225120 bsc#1225132 bsc#1225133 bsc#1225134
  bsc#1225136 bsc#1225172 bsc#1225180 bsc#1225272 bsc#1225300 bsc#1225391
  bsc#1225472 bsc#1225475 bsc#1225476 bsc#1225477 bsc#1225478 bsc#1225485
  bsc#1225489 bsc#1225490 bsc#1225502 bsc#1225527 bsc#1225529 bsc#1225530
  bsc#1225532 bsc#1225534 bsc#1225548 bsc#1225550 bsc#1225553 bsc#1225554
  bsc#1225555 bsc#1225556 bsc#1225557 bsc#1225559 bsc#1225560 bsc#1225564
  bsc#1225565 bsc#1225566 bsc#1225568 bsc#1225569 bsc#1225570 bsc#1225571
  bsc#1225572 bsc#1225573 bsc#1225577 bsc#1225578 bsc#1225579 bsc#1225580
  bsc#1225581 bsc#1225583 bsc#1225584 bsc#1225585 bsc#1225586 bsc#1225587
  bsc#1225588 bsc#1225589 bsc#1225590 bsc#1225591 bsc#1225592 bsc#1225593
  bsc#1225594 bsc#1225595 bsc#1225599 bsc#1225600 bsc#1225601 bsc#1225602
  bsc#1225605 bsc#1225607 bsc#1225609 bsc#1225610 bsc#1225611 bsc#1225616
  bsc#1225618 bsc#1225640 bsc#1225642 bsc#1225681 bsc#1225692 bsc#1225694
  bsc#1225695 bsc#1225696 bsc#1225698 bsc#1225699 bsc#1225702 bsc#1225704
  bsc#1225705 bsc#1225708 bsc#1225710 bsc#1225711 bsc#1225712 bsc#1225714
  bsc#1225715 bsc#1225717 bsc#1225719 bsc#1225720 bsc#1225722 bsc#1225723
  bsc#1225726 bsc#1225728 bsc#1225731 bsc#1225732 bsc#1225734 bsc#1225735
  bsc#1225736 bsc#1225737 bsc#1225741 bsc#1225744 bsc#1225745 bsc#1225746
  bsc#1225747 bsc#1225748 bsc#1225749 bsc#1225750 bsc#1225752 bsc#1225753
  bsc#1225756 bsc#1225757 bsc#1225758 bsc#1225759 bsc#1225760 bsc#1225761
  bsc#1225762 bsc#1225763 bsc#1225765 bsc#1225766 bsc#1225767 bsc#1225769
  bsc#1225770 bsc#1225773 bsc#1225775 bsc#1225805 bsc#1225810 bsc#1225815
  bsc#1225820 bsc#1225823 bsc#1225827 bsc#1225829 bsc#1225830 bsc#1225834
  bsc#1225835 bsc#1225838 bsc#1225839 bsc#1225840 bsc#1225842 bsc#1225843
  bsc#1225847 bsc#1225851 bsc#1225856 bsc#1225866 bsc#1225872 bsc#1225894
  bsc#1225895 bsc#1225896 bsc#1225898 bsc#1225903 bsc#1225945 bsc#1226022
  bsc#1226031 bsc#1226127 bsc#1226131 bsc#1226145 bsc#1226149 bsc#1226155
  bsc#1226158 bsc#1226163 bsc#1226202 bsc#1226211 bsc#1226212 bsc#1226213
  bsc#1226226 bsc#1226457 bsc#1226502 bsc#1226503 bsc#1226513 bsc#1226514
  bsc#1226519 bsc#1226520 bsc#1226547 bsc#1226582 bsc#1226587 bsc#1226588
  bsc#1226592 bsc#1226593 bsc#1226594 bsc#1226595 bsc#1226597 bsc#1226607
  bsc#1226608 bsc#1226610 bsc#1226612 bsc#1226613 bsc#1226630 bsc#1226632
  bsc#1226633 bsc#1226634 bsc#1226637 bsc#1226657 bsc#1226658 bsc#1226734
  bsc#1226735 bsc#1226737 bsc#1226738 bsc#1226739 bsc#1226740 bsc#1226741
  bsc#1226742 bsc#1226743 bsc#1226744 bsc#1226746 bsc#1226747 bsc#1226749
  bsc#1226750 bsc#1226751 bsc#1226754 bsc#1226757 bsc#1226758 bsc#1226760
  bsc#1226761 bsc#1226764 bsc#1226767 bsc#1226768 bsc#1226769 bsc#1226771
  bsc#1226772 bsc#1226774 bsc#1226775 bsc#1226776 bsc#1226777 bsc#1226780
  bsc#1226781 bsc#1226783 bsc#1226785 bsc#1226786 bsc#1226788 bsc#1226789
  bsc#1226790 bsc#1226791 bsc#1226796 bsc#1226799 bsc#1226834 bsc#1226837
  bsc#1226839 bsc#1226840 bsc#1226841 bsc#1226842 bsc#1226844 bsc#1226848
  bsc#1226852 bsc#1226856 bsc#1226857 bsc#1226859 bsc#1226861 bsc#1226863
  bsc#1226864 bsc#1226866 bsc#1226867 bsc#1226868 bsc#1226875 bsc#1226876
  bsc#1226878 bsc#1226879 bsc#1226883 bsc#1226886 bsc#1226890 bsc#1226891
  bsc#1226894 bsc#1226895 bsc#1226905 bsc#1226908 bsc#1226909 bsc#1226911
  bsc#1226915 bsc#1226920 bsc#1226928 bsc#1226934 bsc#1226938 bsc#1226939
  bsc#1226941 bsc#1226948 bsc#1226949 bsc#1226950 bsc#1226962 bsc#1226976
  bsc#1226989 bsc#1226990 bsc#1226992 bsc#1226993 bsc#1226994 bsc#1226995
  bsc#1226996 bsc#1227066 bsc#1227072 bsc#1227085 bsc#1227089 bsc#1227090
  bsc#1227096 bsc#1227101 bsc#1227103 bsc#1227149 bsc#1227149# bsc#1227182
  bsc#1227190 bsc#1227282 bsc#1227362 bsc#1227363 bsc#1227383 bsc#1227432
  bsc#1227433 bsc#1227434 bsc#1227435 bsc#1227443 bsc#1227446 bsc#1227447
  bsc#1227487 bsc#1227492 bsc#1227493 bsc#1227494 bsc#1227573 bsc#1227618
  bsc#1227620 bsc#1227626 bsc#1227627 bsc#1227716 bsc#1227719 bsc#1227722
  bsc#1227723 bsc#1227724 bsc#1227725 bsc#1227728 bsc#1227729 bsc#1227730
  bsc#1227732 bsc#1227733 bsc#1227736 bsc#1227747 bsc#1227750 bsc#1227754
  bsc#1227755 bsc#1227757 bsc#1227760 bsc#1227762 bsc#1227763 bsc#1227764
  bsc#1227766 bsc#1227770 bsc#1227771 bsc#1227772 bsc#1227774 bsc#1227779
  bsc#1227780 bsc#1227783 bsc#1227785 bsc#1227786 bsc#1227787 bsc#1227788
  bsc#1227789 bsc#1227790 bsc#1227791 bsc#1227792 bsc#1227796 bsc#1227797
  bsc#1227798 bsc#1227800 bsc#1227801 bsc#1227802 bsc#1227803 bsc#1227806
  bsc#1227808 bsc#1227810 bsc#1227811 bsc#1227812 bsc#1227813 bsc#1227814
  bsc#1227815 bsc#1227816 bsc#1227818 bsc#1227820 bsc#1227823 bsc#1227824
  bsc#1227826 bsc#1227828 bsc#1227829 bsc#1227830 bsc#1227832 bsc#1227833
  bsc#1227834 bsc#1227836 bsc#1227846 bsc#1227849 bsc#1227851 bsc#1227853
  bsc#1227855 bsc#1227862 bsc#1227864 bsc#1227865 bsc#1227866 bsc#1227867
  bsc#1227869 bsc#1227870 bsc#1227883 bsc#1227884 bsc#1227886 bsc#1227891
  bsc#1227893 bsc#1227899 bsc#1227910 bsc#1227913 bsc#1227926 bsc#1227929
  bsc#1227950 bsc#1227957 bsc#1227981 bsc#1228020 bsc#1228021 bsc#1228090
  bsc#1228114 bsc#1228115 bsc#1228192 bsc#1228193 bsc#1228195 bsc#1228202
  bsc#1228211 bsc#1228235 bsc#1228236 bsc#1228237 bsc#1228269 bsc#1228289
  bsc#1228327 bsc#1228328 bsc#1228403 bsc#1228405 bsc#1228408 bsc#1228409
  bsc#1228410 bsc#1228417 bsc#1228446 bsc#1228457 bsc#1228459 bsc#1228460
  bsc#1228462 bsc#1228470 bsc#1228482 bsc#1228487 bsc#1228491 bsc#1228494
  bsc#1228496 bsc#1228500 bsc#1228501 bsc#1228503 bsc#1228518 bsc#1228520
  bsc#1228530 bsc#1228531 bsc#1228561 bsc#1228565 bsc#1228568 bsc#1228579
  bsc#1228581 bsc#1228591 bsc#1228599 bsc#1228617 bsc#1228633 bsc#1228640
  bsc#1228644 bsc#1228649 bsc#1228655 bsc#1228665 bsc#1228672 bsc#1228680
  bsc#1228705 bsc#1228706 bsc#1228723 bsc#1228740 bsc#1228743 bsc#1228756
  bsc#1228764 bsc#1228801 bsc#1228849 bsc#1228850 bsc#1228857 bsc#1228973
  CVE-2016-3695 CVE-2020-26555 CVE-2021-47432 CVE-2022-48628 CVE-2022-48669
  CVE-2022-48772 CVE-2023-0160 CVE-2023-1192 CVE-2023-1206 CVE-2023-20569
  CVE-2023-25775 CVE-2023-28746 CVE-2023-31085 CVE-2023-31248 CVE-2023-3269
  CVE-2023-34319 CVE-2023-35001 CVE-2023-35826 CVE-2023-35827 CVE-2023-3611
  CVE-2023-37453 CVE-2023-3772 CVE-2023-3773 CVE-2023-3776 CVE-2023-38417
  CVE-2023-39189 CVE-2023-39192 CVE-2023-39193 CVE-2023-39197 CVE-2023-39198
  CVE-2023-4004 CVE-2023-40283 CVE-2023-4128 CVE-2023-4134 CVE-2023-4147
  CVE-2023-4155 CVE-2023-4244 CVE-2023-4273 CVE-2023-42752 CVE-2023-42753
  CVE-2023-42754 CVE-2023-42756 CVE-2023-4563 CVE-2023-45871 CVE-2023-4611
  CVE-2023-4622 CVE-2023-4623 CVE-2023-46813 CVE-2023-46838 CVE-2023-46862
  CVE-2023-47210 CVE-2023-47233 CVE-2023-4881 CVE-2023-4921 CVE-2023-50431
  CVE-2023-51042 CVE-2023-51043 CVE-2023-5158 CVE-2023-51779 CVE-2023-5178
  CVE-2023-51780 CVE-2023-51782 CVE-2023-5197 CVE-2023-52429 CVE-2023-52433
  CVE-2023-52434 CVE-2023-52435 CVE-2023-52437 CVE-2023-52439 CVE-2023-52440
  CVE-2023-52443 CVE-2023-52445 CVE-2023-52446 CVE-2023-52447 CVE-2023-52448
  CVE-2023-52449 CVE-2023-52450 CVE-2023-52451 CVE-2023-52452 CVE-2023-52453
  CVE-2023-52454 CVE-2023-52455 CVE-2023-52456 CVE-2023-52457 CVE-2023-52458
  CVE-2023-52460 CVE-2023-52461 CVE-2023-52462 CVE-2023-52463 CVE-2023-52464
  CVE-2023-52467 CVE-2023-52468 CVE-2023-52469 CVE-2023-52470 CVE-2023-52471
  CVE-2023-52472 CVE-2023-52473 CVE-2023-52475 CVE-2023-52476 CVE-2023-52477
  CVE-2023-52478 CVE-2023-52481 CVE-2023-52482 CVE-2023-52483 CVE-2023-52484
  CVE-2023-52485 CVE-2023-52486 CVE-2023-52487 CVE-2023-52488 CVE-2023-52490
  CVE-2023-52491 CVE-2023-52492 CVE-2023-52493 CVE-2023-52494 CVE-2023-52495
  CVE-2023-52497 CVE-2023-52498 CVE-2023-52500 CVE-2023-52501 CVE-2023-52502
  CVE-2023-52503 CVE-2023-52504 CVE-2023-52505 CVE-2023-52507 CVE-2023-52508
  CVE-2023-52509 CVE-2023-52510 CVE-2023-52511 CVE-2023-52512 CVE-2023-52513
  CVE-2023-52515 CVE-2023-52517 CVE-2023-52518 CVE-2023-52519 CVE-2023-52520
  CVE-2023-52522 CVE-2023-52523 CVE-2023-52524 CVE-2023-52525 CVE-2023-52526
  CVE-2023-52527 CVE-2023-52528 CVE-2023-52529 CVE-2023-52530 CVE-2023-52531
  CVE-2023-52532 CVE-2023-52559 CVE-2023-52561 CVE-2023-52562 CVE-2023-52563
  CVE-2023-52564 CVE-2023-52565 CVE-2023-52566 CVE-2023-52567 CVE-2023-52568
  CVE-2023-52569 CVE-2023-52570 CVE-2023-52571 CVE-2023-52572 CVE-2023-52573
  CVE-2023-52574 CVE-2023-52575 CVE-2023-52576 CVE-2023-52577 CVE-2023-52578
  CVE-2023-52580 CVE-2023-52582 CVE-2023-52583 CVE-2023-52584 CVE-2023-52585
  CVE-2023-52586 CVE-2023-52587 CVE-2023-52589 CVE-2023-52590 CVE-2023-52591
  CVE-2023-52593 CVE-2023-52594 CVE-2023-52595 CVE-2023-52597 CVE-2023-52598
  CVE-2023-52599 CVE-2023-52600 CVE-2023-52601 CVE-2023-52602 CVE-2023-52603
  CVE-2023-52604 CVE-2023-52606 CVE-2023-52607 CVE-2023-52608 CVE-2023-52611
  CVE-2023-52612 CVE-2023-52614 CVE-2023-52615 CVE-2023-52616 CVE-2023-52617
  CVE-2023-52618 CVE-2023-52619 CVE-2023-52621 CVE-2023-52622 CVE-2023-52623
  CVE-2023-52624 CVE-2023-52625 CVE-2023-52626 CVE-2023-52627 CVE-2023-52628
  CVE-2023-52631 CVE-2023-52632 CVE-2023-52634 CVE-2023-52635 CVE-2023-52636
  CVE-2023-52637 CVE-2023-52638 CVE-2023-52639 CVE-2023-52640 CVE-2023-52641
  CVE-2023-52642 CVE-2023-52643 CVE-2023-52644 CVE-2023-52645 CVE-2023-52647
  CVE-2023-52648 CVE-2023-52649 CVE-2023-52650 CVE-2023-52652 CVE-2023-52653
  CVE-2023-52654 CVE-2023-52655 CVE-2023-52656 CVE-2023-52657 CVE-2023-52658
  CVE-2023-52659 CVE-2023-52660 CVE-2023-52661 CVE-2023-52662 CVE-2023-52663
  CVE-2023-52664 CVE-2023-52667 CVE-2023-52668 CVE-2023-52669 CVE-2023-52670
  CVE-2023-52671 CVE-2023-52672 CVE-2023-52673 CVE-2023-52674 CVE-2023-52675
  CVE-2023-52676 CVE-2023-52678 CVE-2023-52679 CVE-2023-52680 CVE-2023-52681
  CVE-2023-52683 CVE-2023-52685 CVE-2023-52686 CVE-2023-52687 CVE-2023-52688
  CVE-2023-52690 CVE-2023-52691 CVE-2023-52692 CVE-2023-52693 CVE-2023-52694
  CVE-2023-52695 CVE-2023-52696 CVE-2023-52697 CVE-2023-52698 CVE-2023-52699
  CVE-2023-52735 CVE-2023-52749 CVE-2023-52750 CVE-2023-52751 CVE-2023-52753
  CVE-2023-52754 CVE-2023-52757 CVE-2023-52759 CVE-2023-52762 CVE-2023-52763
  CVE-2023-52764 CVE-2023-52765 CVE-2023-52766 CVE-2023-52767 CVE-2023-52768
  CVE-2023-52769 CVE-2023-52771 CVE-2023-52772 CVE-2023-52773 CVE-2023-52774
  CVE-2023-52775 CVE-2023-52776 CVE-2023-52777 CVE-2023-52780 CVE-2023-52781
  CVE-2023-52782 CVE-2023-52783 CVE-2023-52784 CVE-2023-52786 CVE-2023-52787
  CVE-2023-52788 CVE-2023-52789 CVE-2023-52791 CVE-2023-52792 CVE-2023-52794
  CVE-2023-52795 CVE-2023-52796 CVE-2023-52798 CVE-2023-52799 CVE-2023-52800
  CVE-2023-52801 CVE-2023-52803 CVE-2023-52804 CVE-2023-52805 CVE-2023-52806
  CVE-2023-52807 CVE-2023-52808 CVE-2023-52809 CVE-2023-52810 CVE-2023-52811
  CVE-2023-52812 CVE-2023-52813 CVE-2023-52814 CVE-2023-52815 CVE-2023-52816
  CVE-2023-52817 CVE-2023-52818 CVE-2023-52819 CVE-2023-52821 CVE-2023-52825
  CVE-2023-52826 CVE-2023-52827 CVE-2023-52829 CVE-2023-52832 CVE-2023-52833
  CVE-2023-52834 CVE-2023-52835 CVE-2023-52836 CVE-2023-52837 CVE-2023-52838
  CVE-2023-52840 CVE-2023-52841 CVE-2023-52842 CVE-2023-52843 CVE-2023-52844
  CVE-2023-52845 CVE-2023-52846 CVE-2023-52847 CVE-2023-52849 CVE-2023-52850
  CVE-2023-52851 CVE-2023-52853 CVE-2023-52854 CVE-2023-52855 CVE-2023-52856
  CVE-2023-52857 CVE-2023-52858 CVE-2023-52860 CVE-2023-52861 CVE-2023-52862
  CVE-2023-52863 CVE-2023-52864 CVE-2023-52865 CVE-2023-52866 CVE-2023-52867
  CVE-2023-52868 CVE-2023-52869 CVE-2023-52870 CVE-2023-52871 CVE-2023-52872
  CVE-2023-52873 CVE-2023-52874 CVE-2023-52875 CVE-2023-52876 CVE-2023-52877
  CVE-2023-52878 CVE-2023-52879 CVE-2023-52880 CVE-2023-52881 CVE-2023-52882
  CVE-2023-52883 CVE-2023-52884 CVE-2023-52885 CVE-2023-52886 CVE-2023-5345
  CVE-2023-5633 CVE-2023-5717 CVE-2023-5972 CVE-2023-6039 CVE-2023-6121
  CVE-2023-6238 CVE-2023-6270 CVE-2023-6356 CVE-2023-6531 CVE-2023-6535
  CVE-2023-6536 CVE-2023-6546 CVE-2023-6606 CVE-2023-6610 CVE-2023-6622
  CVE-2023-6679 CVE-2023-6817 CVE-2023-6915 CVE-2023-6931 CVE-2023-6932
  CVE-2023-7042 CVE-2024-0193 CVE-2024-0565 CVE-2024-0607 CVE-2024-0639
  CVE-2024-0641 CVE-2024-0646 CVE-2024-0841 CVE-2024-1085 CVE-2024-1086
  CVE-2024-1151 CVE-2024-1312 CVE-2024-21823 CVE-2024-22099 CVE-2024-23307
  CVE-2024-23848 CVE-2024-23849 CVE-2024-23850 CVE-2024-23851 CVE-2024-24860
  CVE-2024-24861 CVE-2024-25739 CVE-2024-25741 CVE-2024-25744 CVE-2024-26482
  CVE-2024-26581 CVE-2024-26582 CVE-2024-26583 CVE-2024-26584 CVE-2024-26585
  CVE-2024-26586 CVE-2024-26589 CVE-2024-26591 CVE-2024-26593 CVE-2024-26595
  CVE-2024-26597 CVE-2024-26598 CVE-2024-26599 CVE-2024-26600 CVE-2024-26601
  CVE-2024-26602 CVE-2024-26603 CVE-2024-26605 CVE-2024-26607 CVE-2024-26610
  CVE-2024-26611 CVE-2024-26612 CVE-2024-26614 CVE-2024-26615 CVE-2024-26616
  CVE-2024-26618 CVE-2024-26620 CVE-2024-26622 CVE-2024-26623 CVE-2024-26625
  CVE-2024-26627 CVE-2024-26629 CVE-2024-26632 CVE-2024-26633 CVE-2024-26635
  CVE-2024-26636 CVE-2024-26637 CVE-2024-26638 CVE-2024-26641 CVE-2024-26642
  CVE-2024-26643 CVE-2024-26644 CVE-2024-26645 CVE-2024-26646 CVE-2024-26647
  CVE-2024-26648 CVE-2024-26649 CVE-2024-26650 CVE-2024-26651 CVE-2024-26652
  CVE-2024-26654 CVE-2024-26656 CVE-2024-26657 CVE-2024-26659 CVE-2024-26660
  CVE-2024-26661 CVE-2024-26662 CVE-2024-26663 CVE-2024-26664 CVE-2024-26665
  CVE-2024-26666 CVE-2024-26667 CVE-2024-26670 CVE-2024-26671 CVE-2024-26672
  CVE-2024-26673 CVE-2024-26674 CVE-2024-26675 CVE-2024-26676 CVE-2024-26679
  CVE-2024-26680 CVE-2024-26681 CVE-2024-26682 CVE-2024-26683 CVE-2024-26684
  CVE-2024-26685 CVE-2024-26687 CVE-2024-26688 CVE-2024-26689 CVE-2024-26691
  CVE-2024-26692 CVE-2024-26693 CVE-2024-26694 CVE-2024-26695 CVE-2024-26696
  CVE-2024-26697 CVE-2024-26698 CVE-2024-26699 CVE-2024-26700 CVE-2024-26702
  CVE-2024-26704 CVE-2024-26709 CVE-2024-26710 CVE-2024-26711 CVE-2024-26714
  CVE-2024-26715 CVE-2024-26716 CVE-2024-26717 CVE-2024-26718 CVE-2024-26720
  CVE-2024-26721 CVE-2024-26722 CVE-2024-26723 CVE-2024-26724 CVE-2024-26725
  CVE-2024-26726 CVE-2024-26727 CVE-2024-26728 CVE-2024-26729 CVE-2024-26731
  CVE-2024-26733 CVE-2024-26734 CVE-2024-26736 CVE-2024-26737 CVE-2024-26738
  CVE-2024-26739 CVE-2024-26740 CVE-2024-26742 CVE-2024-26743 CVE-2024-26744
  CVE-2024-26745 CVE-2024-26746 CVE-2024-26747 CVE-2024-26748 CVE-2024-26749
  CVE-2024-26750 CVE-2024-26751 CVE-2024-26752 CVE-2024-26753 CVE-2024-26754
  CVE-2024-26755 CVE-2024-26756 CVE-2024-26757 CVE-2024-26758 CVE-2024-26761
  CVE-2024-26763 CVE-2024-26764 CVE-2024-26766 CVE-2024-26767 CVE-2024-26769
  CVE-2024-26771 CVE-2024-26772 CVE-2024-26773 CVE-2024-26774 CVE-2024-26775
  CVE-2024-26776 CVE-2024-26777 CVE-2024-26778 CVE-2024-26779 CVE-2024-26780
  CVE-2024-26783 CVE-2024-26785 CVE-2024-26786 CVE-2024-26787 CVE-2024-26788
  CVE-2024-26789 CVE-2024-26790 CVE-2024-26791 CVE-2024-26792 CVE-2024-26793
  CVE-2024-26794 CVE-2024-26797 CVE-2024-26798 CVE-2024-26799 CVE-2024-26800
  CVE-2024-26801 CVE-2024-26802 CVE-2024-26803 CVE-2024-26805 CVE-2024-26807
  CVE-2024-26813 CVE-2024-26814 CVE-2024-26815 CVE-2024-26816 CVE-2024-26820
  CVE-2024-26822 CVE-2024-26824 CVE-2024-26825 CVE-2024-26826 CVE-2024-26828
  CVE-2024-26829 CVE-2024-26830 CVE-2024-26832 CVE-2024-26833 CVE-2024-26836
  CVE-2024-26838 CVE-2024-26839 CVE-2024-26840 CVE-2024-26843 CVE-2024-26844
  CVE-2024-26845 CVE-2024-26846 CVE-2024-26847 CVE-2024-26848 CVE-2024-26852
  CVE-2024-26853 CVE-2024-26854 CVE-2024-26855 CVE-2024-26856 CVE-2024-26857
  CVE-2024-26858 CVE-2024-26859 CVE-2024-26860 CVE-2024-26861 CVE-2024-26862
  CVE-2024-26863 CVE-2024-26865 CVE-2024-26866 CVE-2024-26868 CVE-2024-26870
  CVE-2024-26872 CVE-2024-26874 CVE-2024-26875 CVE-2024-26876 CVE-2024-26877
  CVE-2024-26878 CVE-2024-26879 CVE-2024-26880 CVE-2024-26881 CVE-2024-26882
  CVE-2024-26883 CVE-2024-26884 CVE-2024-26885 CVE-2024-26886 CVE-2024-26889
  CVE-2024-26890 CVE-2024-26891 CVE-2024-26892 CVE-2024-26893 CVE-2024-26894
  CVE-2024-26895 CVE-2024-26896 CVE-2024-26897 CVE-2024-26898 CVE-2024-26899
  CVE-2024-26900 CVE-2024-26901 CVE-2024-26903 CVE-2024-26906 CVE-2024-26907
  CVE-2024-26909 CVE-2024-26911 CVE-2024-26912 CVE-2024-26913 CVE-2024-26914
  CVE-2024-26915 CVE-2024-26916 CVE-2024-26917 CVE-2024-26919 CVE-2024-26920
  CVE-2024-26921 CVE-2024-26922 CVE-2024-26923 CVE-2024-26925 CVE-2024-26927
  CVE-2024-26928 CVE-2024-26929 CVE-2024-26930 CVE-2024-26931 CVE-2024-26932
  CVE-2024-26933 CVE-2024-26934 CVE-2024-26935 CVE-2024-26937 CVE-2024-26938
  CVE-2024-26939 CVE-2024-26940 CVE-2024-26943 CVE-2024-26944 CVE-2024-26945
  CVE-2024-26946 CVE-2024-26948 CVE-2024-26949 CVE-2024-26950 CVE-2024-26951
  CVE-2024-26955 CVE-2024-26956 CVE-2024-26957 CVE-2024-26958 CVE-2024-26959
  CVE-2024-26960 CVE-2024-26961 CVE-2024-26962 CVE-2024-26963 CVE-2024-26964
  CVE-2024-26965 CVE-2024-26966 CVE-2024-26968 CVE-2024-26969 CVE-2024-26970
  CVE-2024-26972 CVE-2024-26973 CVE-2024-26974 CVE-2024-26975 CVE-2024-26977
  CVE-2024-26978 CVE-2024-26979 CVE-2024-26981 CVE-2024-26982 CVE-2024-26983
  CVE-2024-26984 CVE-2024-26986 CVE-2024-26988 CVE-2024-26989 CVE-2024-26990
  CVE-2024-26991 CVE-2024-26992 CVE-2024-26993 CVE-2024-26994 CVE-2024-26995
  CVE-2024-26996 CVE-2024-26997 CVE-2024-26999 CVE-2024-27000 CVE-2024-27001
  CVE-2024-27002 CVE-2024-27003 CVE-2024-27004 CVE-2024-27008 CVE-2024-27009
  CVE-2024-27012 CVE-2024-27013 CVE-2024-27014 CVE-2024-27015 CVE-2024-27016
  CVE-2024-27019 CVE-2024-27020 CVE-2024-27022 CVE-2024-27023 CVE-2024-27025
  CVE-2024-27027 CVE-2024-27028 CVE-2024-27029 CVE-2024-27030 CVE-2024-27031
  CVE-2024-27036 CVE-2024-27037 CVE-2024-27038 CVE-2024-27039 CVE-2024-27040
  CVE-2024-27041 CVE-2024-27042 CVE-2024-27043 CVE-2024-27044 CVE-2024-27045
  CVE-2024-27046 CVE-2024-27047 CVE-2024-27048 CVE-2024-27049 CVE-2024-27051
  CVE-2024-27052 CVE-2024-27053 CVE-2024-27054 CVE-2024-27056 CVE-2024-27057
  CVE-2024-27059 CVE-2024-27060 CVE-2024-27062 CVE-2024-27064 CVE-2024-27065
  CVE-2024-27067 CVE-2024-27068 CVE-2024-27071 CVE-2024-27072 CVE-2024-27073
  CVE-2024-27074 CVE-2024-27075 CVE-2024-27076 CVE-2024-27077 CVE-2024-27078
  CVE-2024-27080 CVE-2024-27388 CVE-2024-27389 CVE-2024-27391 CVE-2024-27393
  CVE-2024-27395 CVE-2024-27396 CVE-2024-27398 CVE-2024-27399 CVE-2024-27400
  CVE-2024-27401 CVE-2024-27402 CVE-2024-27404 CVE-2024-27405 CVE-2024-27408
  CVE-2024-27410 CVE-2024-27411 CVE-2024-27412 CVE-2024-27413 CVE-2024-27414
  CVE-2024-27416 CVE-2024-27417 CVE-2024-27418 CVE-2024-27419 CVE-2024-27431
  CVE-2024-27432 CVE-2024-27434 CVE-2024-27435 CVE-2024-27436 CVE-2024-27437
  CVE-2024-33619 CVE-2024-34777 CVE-2024-35247 CVE-2024-35784 CVE-2024-35786
  CVE-2024-35788 CVE-2024-35789 CVE-2024-35790 CVE-2024-35791 CVE-2024-35794
  CVE-2024-35795 CVE-2024-35796 CVE-2024-35799 CVE-2024-35800 CVE-2024-35801
  CVE-2024-35803 CVE-2024-35804 CVE-2024-35805 CVE-2024-35806 CVE-2024-35807
  CVE-2024-35808 CVE-2024-35809 CVE-2024-35810 CVE-2024-35811 CVE-2024-35812
  CVE-2024-35813 CVE-2024-35814 CVE-2024-35815 CVE-2024-35817 CVE-2024-35819
  CVE-2024-35821 CVE-2024-35822 CVE-2024-35823 CVE-2024-35824 CVE-2024-35825
  CVE-2024-35827 CVE-2024-35828 CVE-2024-35829 CVE-2024-35830 CVE-2024-35831
  CVE-2024-35833 CVE-2024-35834 CVE-2024-35835 CVE-2024-35836 CVE-2024-35837
  CVE-2024-35838 CVE-2024-35841 CVE-2024-35842 CVE-2024-35843 CVE-2024-35845
  CVE-2024-35847 CVE-2024-35848 CVE-2024-35849 CVE-2024-35850 CVE-2024-35851
  CVE-2024-35852 CVE-2024-35853 CVE-2024-35854 CVE-2024-35855 CVE-2024-35857
  CVE-2024-35860 CVE-2024-35861 CVE-2024-35862 CVE-2024-35863 CVE-2024-35864
  CVE-2024-35865 CVE-2024-35866 CVE-2024-35867 CVE-2024-35868 CVE-2024-35869
  CVE-2024-35870 CVE-2024-35872 CVE-2024-35875 CVE-2024-35877 CVE-2024-35878
  CVE-2024-35879 CVE-2024-35880 CVE-2024-35883 CVE-2024-35884 CVE-2024-35885
  CVE-2024-35886 CVE-2024-35887 CVE-2024-35889 CVE-2024-35890 CVE-2024-35891
  CVE-2024-35892 CVE-2024-35893 CVE-2024-35895 CVE-2024-35896 CVE-2024-35898
  CVE-2024-35899 CVE-2024-35900 CVE-2024-35901 CVE-2024-35903 CVE-2024-35904
  CVE-2024-35905 CVE-2024-35907 CVE-2024-35908 CVE-2024-35909 CVE-2024-35911
  CVE-2024-35912 CVE-2024-35913 CVE-2024-35914 CVE-2024-35915 CVE-2024-35916
  CVE-2024-35917 CVE-2024-35921 CVE-2024-35922 CVE-2024-35924 CVE-2024-35925
  CVE-2024-35926 CVE-2024-35927 CVE-2024-35928 CVE-2024-35930 CVE-2024-35931
  CVE-2024-35932 CVE-2024-35933 CVE-2024-35934 CVE-2024-35935 CVE-2024-35936
  CVE-2024-35937 CVE-2024-35938 CVE-2024-35940 CVE-2024-35942 CVE-2024-35943
  CVE-2024-35944 CVE-2024-35945 CVE-2024-35946 CVE-2024-35947 CVE-2024-35949
  CVE-2024-35950 CVE-2024-35951 CVE-2024-35952 CVE-2024-35953 CVE-2024-35954
  CVE-2024-35955 CVE-2024-35956 CVE-2024-35957 CVE-2024-35958 CVE-2024-35959
  CVE-2024-35960 CVE-2024-35961 CVE-2024-35962 CVE-2024-35963 CVE-2024-35964
  CVE-2024-35965 CVE-2024-35966 CVE-2024-35967 CVE-2024-35969 CVE-2024-35970
  CVE-2024-35971 CVE-2024-35972 CVE-2024-35973 CVE-2024-35974 CVE-2024-35975
  CVE-2024-35976 CVE-2024-35977 CVE-2024-35978 CVE-2024-35979 CVE-2024-35981
  CVE-2024-35982 CVE-2024-35984 CVE-2024-35986 CVE-2024-35989 CVE-2024-35990
  CVE-2024-35991 CVE-2024-35992 CVE-2024-35995 CVE-2024-35997 CVE-2024-35998
  CVE-2024-35999 CVE-2024-36002 CVE-2024-36003 CVE-2024-36004 CVE-2024-36005
  CVE-2024-36006 CVE-2024-36007 CVE-2024-36008 CVE-2024-36009 CVE-2024-36010
  CVE-2024-36011 CVE-2024-36012 CVE-2024-36013 CVE-2024-36014 CVE-2024-36015
  CVE-2024-36016 CVE-2024-36017 CVE-2024-36018 CVE-2024-36019 CVE-2024-36020
  CVE-2024-36021 CVE-2024-36024 CVE-2024-36025 CVE-2024-36026 CVE-2024-36029
  CVE-2024-36030 CVE-2024-36032 CVE-2024-36281 CVE-2024-36288 CVE-2024-36477
  CVE-2024-36478 CVE-2024-36479 CVE-2024-36880 CVE-2024-36882 CVE-2024-36885
  CVE-2024-36887 CVE-2024-36889 CVE-2024-36890 CVE-2024-36891 CVE-2024-36893
  CVE-2024-36894 CVE-2024-36895 CVE-2024-36896 CVE-2024-36897 CVE-2024-36898
  CVE-2024-36899 CVE-2024-36900 CVE-2024-36901 CVE-2024-36902 CVE-2024-36903
  CVE-2024-36904 CVE-2024-36906 CVE-2024-36909 CVE-2024-36910 CVE-2024-36911
  CVE-2024-36912 CVE-2024-36913 CVE-2024-36914 CVE-2024-36915 CVE-2024-36916
  CVE-2024-36917 CVE-2024-36918 CVE-2024-36919 CVE-2024-36921 CVE-2024-36922
  CVE-2024-36923 CVE-2024-36924 CVE-2024-36926 CVE-2024-36928 CVE-2024-36930
  CVE-2024-36931 CVE-2024-36934 CVE-2024-36935 CVE-2024-36936 CVE-2024-36937
  CVE-2024-36938 CVE-2024-36939 CVE-2024-36940 CVE-2024-36941 CVE-2024-36942
  CVE-2024-36944 CVE-2024-36945 CVE-2024-36946 CVE-2024-36947 CVE-2024-36949
  CVE-2024-36950 CVE-2024-36951 CVE-2024-36952 CVE-2024-36955 CVE-2024-36957
  CVE-2024-36959 CVE-2024-36960 CVE-2024-36962 CVE-2024-36964 CVE-2024-36965
  CVE-2024-36967 CVE-2024-36969 CVE-2024-36970 CVE-2024-36971 CVE-2024-36972
  CVE-2024-36973 CVE-2024-36974 CVE-2024-36975 CVE-2024-36977 CVE-2024-36978
  CVE-2024-37021 CVE-2024-37078 CVE-2024-37353 CVE-2024-37354 CVE-2024-38381
  CVE-2024-38384 CVE-2024-38385 CVE-2024-38388 CVE-2024-38390 CVE-2024-38391
  CVE-2024-38539 CVE-2024-38540 CVE-2024-38541 CVE-2024-38543 CVE-2024-38544
  CVE-2024-38545 CVE-2024-38546 CVE-2024-38547 CVE-2024-38548 CVE-2024-38549
  CVE-2024-38550 CVE-2024-38551 CVE-2024-38552 CVE-2024-38553 CVE-2024-38554
  CVE-2024-38555 CVE-2024-38556 CVE-2024-38557 CVE-2024-38558 CVE-2024-38559
  CVE-2024-38560 CVE-2024-38562 CVE-2024-38563 CVE-2024-38564 CVE-2024-38565
  CVE-2024-38566 CVE-2024-38567 CVE-2024-38568 CVE-2024-38569 CVE-2024-38570
  CVE-2024-38571 CVE-2024-38572 CVE-2024-38573 CVE-2024-38575 CVE-2024-38578
  CVE-2024-38579 CVE-2024-38580 CVE-2024-38581 CVE-2024-38582 CVE-2024-38583
  CVE-2024-38586 CVE-2024-38587 CVE-2024-38588 CVE-2024-38590 CVE-2024-38591
  CVE-2024-38592 CVE-2024-38594 CVE-2024-38595 CVE-2024-38597 CVE-2024-38598
  CVE-2024-38599 CVE-2024-38600 CVE-2024-38601 CVE-2024-38602 CVE-2024-38603
  CVE-2024-38604 CVE-2024-38605 CVE-2024-38608 CVE-2024-38609 CVE-2024-38610
  CVE-2024-38611 CVE-2024-38615 CVE-2024-38616 CVE-2024-38617 CVE-2024-38618
  CVE-2024-38619 CVE-2024-38621 CVE-2024-38622 CVE-2024-38627 CVE-2024-38628
  CVE-2024-38629 CVE-2024-38630 CVE-2024-38633 CVE-2024-38634 CVE-2024-38635
  CVE-2024-38636 CVE-2024-38659 CVE-2024-38661 CVE-2024-38663 CVE-2024-38664
  CVE-2024-38780 CVE-2024-39276 CVE-2024-39277 CVE-2024-39291 CVE-2024-39296
  CVE-2024-39301 CVE-2024-39362 CVE-2024-39371 CVE-2024-39463 CVE-2024-39466
  CVE-2024-39468 CVE-2024-39469 CVE-2024-39471 CVE-2024-39472 CVE-2024-39473
  CVE-2024-39474 CVE-2024-39475 CVE-2024-39479 CVE-2024-39481 CVE-2024-39482
  CVE-2024-39483 CVE-2024-39484 CVE-2024-39486 CVE-2024-39487 CVE-2024-39488
  CVE-2024-39490 CVE-2024-39491 CVE-2024-39493 CVE-2024-39494 CVE-2024-39496
  CVE-2024-39497 CVE-2024-39498 CVE-2024-39499 CVE-2024-39500 CVE-2024-39501
  CVE-2024-39502 CVE-2024-39504 CVE-2024-39505 CVE-2024-39506 CVE-2024-39507
  CVE-2024-39508 CVE-2024-39509 CVE-2024-40900 CVE-2024-40901 CVE-2024-40902
  CVE-2024-40903 CVE-2024-40904 CVE-2024-40906 CVE-2024-40908 CVE-2024-40909
  CVE-2024-40910 CVE-2024-40911 CVE-2024-40912 CVE-2024-40916 CVE-2024-40919
  CVE-2024-40922 CVE-2024-40923 CVE-2024-40924 CVE-2024-40925 CVE-2024-40926
  CVE-2024-40927 CVE-2024-40928 CVE-2024-40929 CVE-2024-40930 CVE-2024-40931
  CVE-2024-40932 CVE-2024-40934 CVE-2024-40935 CVE-2024-40936 CVE-2024-40937
  CVE-2024-40940 CVE-2024-40941 CVE-2024-40942 CVE-2024-40943 CVE-2024-40944
  CVE-2024-40945 CVE-2024-40947 CVE-2024-40948 CVE-2024-40953 CVE-2024-40954
  CVE-2024-40956 CVE-2024-40957 CVE-2024-40958 CVE-2024-40959 CVE-2024-40960
  CVE-2024-40961 CVE-2024-40962 CVE-2024-40964 CVE-2024-40966 CVE-2024-40967
  CVE-2024-40970 CVE-2024-40972 CVE-2024-40975 CVE-2024-40976 CVE-2024-40977
  CVE-2024-40978 CVE-2024-40979 CVE-2024-40981 CVE-2024-40982 CVE-2024-40984
  CVE-2024-40987 CVE-2024-40988 CVE-2024-40989 CVE-2024-40990 CVE-2024-40992
  CVE-2024-40994 CVE-2024-40995 CVE-2024-40997 CVE-2024-40998 CVE-2024-40999
  CVE-2024-41000 CVE-2024-41001 CVE-2024-41002 CVE-2024-41004 CVE-2024-41006
  CVE-2024-41009 CVE-2024-41010 CVE-2024-41011 CVE-2024-41013 CVE-2024-41014
  CVE-2024-41015 CVE-2024-41016 CVE-2024-41017 CVE-2024-41032 CVE-2024-41036
  CVE-2024-41040 CVE-2024-41041 CVE-2024-41044 CVE-2024-41045 CVE-2024-41048
  CVE-2024-41057 CVE-2024-41058 CVE-2024-41059 CVE-2024-41064 CVE-2024-41066
  CVE-2024-41068 CVE-2024-41069 CVE-2024-41070 CVE-2024-41076 CVE-2024-41078
  CVE-2024-41081 CVE-2024-41087 CVE-2024-41090 CVE-2024-41091 CVE-2024-42070
  CVE-2024-42073 CVE-2024-42079 CVE-2024-42082 CVE-2024-42093 CVE-2024-42095
  CVE-2024-42096 CVE-2024-42105 CVE-2024-42107 CVE-2024-42110 CVE-2024-42113
  CVE-2024-42122 CVE-2024-42124 CVE-2024-42138 CVE-2024-42139 CVE-2024-42142
  CVE-2024-42145 CVE-2024-42147 CVE-2024-42148 CVE-2024-42161 CVE-2024-42162
  CVE-2024-42224 CVE-2023-34324 CVE-2024-26760
  jsc#PED-1117 jsc#PED-2006 jsc#PED-3039 jsc#PED-3184
  jsc#PED-3186 jsc#PED-3289 jsc#PED-3309 jsc#PED-3311 jsc#PED-3317 jsc#PED-3526
  jsc#PED-3527 jsc#PED-3535 jsc#PED-3545 jsc#PED-3594 jsc#PED-3616 jsc#PED-3637
  jsc#PED-3750 jsc#PED-4075 jsc#PED-4082 jsc#PED-4102 jsc#PED-4114 jsc#PED-4126
  jsc#PED-4296 jsc#PED-4486 jsc#PED-4593 jsc#PED-4647 jsc#PED-4696 jsc#PED-4698
  jsc#PED-4733 jsc#PED-4736 jsc#PED-4747 jsc#PED-4860 jsc#PED-4862 jsc#PED-4866
  jsc#PED-4868 jsc#PED-4872 jsc#PED-4874 jsc#PED-4876 jsc#PED-4897 jsc#PED-4901
  jsc#PED-4927 jsc#PED-4929 jsc#PED-4937 jsc#PED-4961 jsc#PED-5021 jsc#PED-5057
  jsc#PED-5059 jsc#PED-5062 jsc#PED-5063 jsc#PED-5064 jsc#PED-5065 jsc#PED-5067
  jsc#PED-5077 jsc#PED-5083 jsc#PED-5085 jsc#PED-5089 jsc#PED-5091 jsc#PED-5122
  jsc#PED-5174 jsc#PED-5417 jsc#PED-542 jsc#PED-5433 jsc#PED-5436 jsc#PED-5439
  jsc#PED-5441 jsc#PED-5452 jsc#PED-5453 jsc#PED-5458 jsc#PED-5460 jsc#PED-5475
  jsc#PED-5477 jsc#PED-5484 jsc#PED-5505 jsc#PED-5511 jsc#PED-5524 jsc#PED-5525
  jsc#PED-5555 jsc#PED-5557 jsc#PED-5728 jsc#PED5728 jsc#PED-5734 jsc#PED-5736
  jsc#PED-5742 jsc#PED-5759 jsc#PED-5816 jsc#PED-5824 jsc#PED-5853 jsc#PED-5859
  jsc#PED-5861 jsc#PED-5873 jsc#PED-6007 jsc#PED-6008 jsc#PED-6010 jsc#PED-6012
  jsc#PED-6014 jsc#PED-6016 jsc#PED-6018 jsc#PED-6023 jsc#PED-6028 jsc#PED-6036
  jsc#PED-6037 jsc#PED-6040 jsc#PED-6041 jsc#PED-6045 jsc#PED-6048 jsc#PED-6054
  jsc#PED-6055 jsc#PED-6056 jsc#PED-6057 jsc#PED-6061 jsc#PED-6065 jsc#PED-6067
  jsc#PED-6068 jsc#PED-6069 jsc#PED-6070 jsc#PED-6071 jsc#PED-6079 jsc#PED-6081
  jsc#PED-6090 jsc#PED-6091 jsc#PED-6104 jsc#PED-6105 jsc#PED-6106 jsc#PED-6107
  jsc#PED-6113 jsc#PED-6114 jsc#PED-6116 jsc#PED-6118 jsc#PED-6120 jsc#PED-6121
  jsc#PED-6123 jsc#PED-6124 jsc#PED-6127 jsc#PED-6130 jsc#PED-6143 jsc#PED-6156
  jsc#PED-6252 jsc#PED-6254 jsc#PED-6316 jsc#PED-6319 jsc#PED-6371 jsc#PED-6375
  jsc#PED-6384 jsc#PED-6469 jsc#PED-6528 jsc#PED-6716 jsc#PED-6719 jsc#PED-6721
  jsc#PED-6741 jsc#PED-6747 jsc#PED-6811 jsc#PED-6831 jsc#PED-6833 jsc#PED-6835
  jsc#PED-6864 jsc#PED-6866 jsc#PED-6874 jsc#PED-6875 jsc#PED-6876 jsc#PED-6878
  jsc#PED-6881 jsc#PED-6884 jsc#PED-6886 jsc#PED-6887 jsc#PED-6894 jsc#PED-6930
  jsc#PED-6931 jsc#PED-6936 jsc#PED-6937 jsc#PED-6951 jsc#PED-6953 jsc#PED-6954
  jsc#PED-7009 jsc#PED-7167 jsc#PED-7238 jsc#PED-7249 jsc#PED-7322 jsc#PED-7377
  jsc#PED-7382 jsc#PED-7477 jsc#PED-7513 jsc#PED-7514 jsc#PED-7520 jsc#PED-7542
  jsc#PED-7574 jsc#PED-7581 jsc#PED-7600 jsc#PED-7618 jsc#PED-7619 jsc#PED-7622
  jsc#PED-7623 jsc#PED-7689 jsc#PED-7779 jsc#PED-7780 jsc#PED-7785 jsc#PED-7786
  jsc#PED-7789 jsc#PED-7793 jsc#PED-7859 jsc#PED-7888 jsc#PED-7970 jsc#PED-8032
  jsc#PED-8065 jsc#PED-8111 jsc#PED-8240 jsc#PED-8491 jsc#PED-8570 jsc#PED-8644
  jsc#PED-8688 jsc#PED-8701 jsc#PED-8954 jsc#PED-949 jsc#PED-962 jsc#SES-1880
  jsc#SLE-12908 ltc#189159 ltc#193451 ltc#197503 ltc#199106 ltc#200161
  ltc#200588 ltc#202097 ltc#202582 ltc#202733 ltc#203238 LTC#203629 ltc#203927
  LTC#203998 ltc#204476 ltc#204477 ltc#204519 ltc#204523 ltc#204570 ltc#205270
  ltc#205305 ltc#205683 ltc#205739 ltc#205740 ltc#205770 ltc#205888 ltc#205900
  XSA-432 XSA-441, XSA-448
  The old log contained also an incorrect reference, CVE-2024-267600
* Thu Aug  8 2024 mvetter@suse.com
- config.sh: generate and install compile_commands.json (bsc#1228971)
  This file contains the command line options used to compile every C file.
  It's useful for the livepatching team.
- kernel-binary: generate and install compile_commands.json (bsc#1228971)
  This file contains the command line options used to compile every C file.
  It's useful for the livepatching team.
- commit 15eff3e
* Wed Aug  7 2024 sjaeckel@suse.de
- tcp: avoid too many retransmit packets (CVE-2024-41007
  bsc#1227863).
- commit 8f47fe6
* Tue Aug  6 2024 davide.benini@suse.com
- tipc: force a dst refcount before doing decryption (CVE-2024-40983 bsc#1227819).
- commit cee1bad
* Tue Aug  6 2024 jgross@suse.com
- KVM: x86/mmu: fix determination of max NPT mapping level for
  private pages (git-fixes).
- commit cc71c2c
* Mon Aug  5 2024 dwagner@suse.de
- kabi/severity: add nvme common code
  The nvme common code is also allowed to change the data structures, there
  are only internal users.
- commit 3abdbd5
* Fri Aug  2 2024 dbond@suse.com
- nvme_core: scan namespaces asynchronously (bsc#1224105).
- commit e6f41be
* Fri Aug  2 2024 sjaeckel@suse.de
- net: wwan: iosm: Fix tainted pointer delete is case of region
  creation fail (CVE-2024-40939 bsc#1227799).
- commit 0b93a9f
* Fri Aug  2 2024 sjaeckel@suse.de
- nsh: Restore skb->{protocol,data,mac_header} for outer header
  in nsh_gso_segment() (CVE-2024-36933 bsc#1225832).
- commit 6740d82
* Fri Aug  2 2024 sjaeckel@suse.de
- net: core: reject skb_copy(_expand) for fraglist GSO skbs
  (CVE-2024-36929 bsc#1225814).
- commit e49ed10
* Mon Jul 29 2024 sjaeckel@suse.de
- netlink: add nla be16/32 types to minlen array (CVE-2024-26849
  bsc#1223053).
- commit 2747893
* Fri Jul 26 2024 jroedel@suse.de
- blacklist.conf: Add "mm, virt: merge AS_UNMOVABLE and AS_INACCESSIBLE"
- commit 9155db2
* Fri Jul 26 2024 jroedel@suse.de
- KVM: interrupt kvm_gmem_populate() on signals (jsc#PED-5122).
- KVM: SEV: Don't WARN() if RMP lookup fails when invalidating
  gmem pages (jsc#PED-5122).
- commit 83c7177
* Fri Jul 26 2024 jroedel@suse.de
- KVM: x86/mmu: check for invalid async page faults involving
  private memory (jsc#PED-5122).
- Refresh
  patches.suse/kabi-placeholders-for-coco-host-support.patch.
- commit 8ffcad3
* Fri Jul 26 2024 jroedel@suse.de
- KVM: x86: Fully re-initialize supported_vm_types on vendor
  module load (jsc#PED-5122).
- Refresh
  patches.suse/KVM-x86-Fully-re-initialize-supported_mce_cap-on-ven.patch.
- commit 928d5b0
* Fri Jul 26 2024 jroedel@suse.de
- KVM: SEV: sync FPU and AVX state at LAUNCH_UPDATE_VMSA time
  (jsc#PED-5122).
- Refresh
  patches.suse/KVM-SEV-ES-Delegate-LBR-virtualization-to-the-proces.patch.
- commit f5d649f
* Fri Jul 26 2024 jroedel@suse.de
- KVM: x86: Add supported_vm_types to kvm_caps (jsc#PED-5122).
- Refresh
  patches.suse/KVM-x86-Fully-re-initialize-supported_mce_cap-on-ven.patch.
- commit 8e54974
* Fri Jul 26 2024 jroedel@suse.de
- crypto: ccp: Add the SNP_VLEK_LOAD command (jsc#PED-5122).
- KVM: SEV: Provide support for SNP_EXTENDED_GUEST_REQUEST NAE
  event (jsc#PED-5122).
- KVM: SEV: Provide support for SNP_GUEST_REQUEST NAE event
  (jsc#PED-5122).
- KVM: SNP: Fix LBR Virtualization for SNP guest (jsc#PED-5122).
- KVM: SVM: Add module parameter to enable SEV-SNP (jsc#PED-5122).
- KVM: SEV: Avoid WBINVD for HVA-based MMU notifications for SNP
  (jsc#PED-5122).
- KVM: x86: Implement hook for determining max NPT mapping level
  (jsc#PED-5122).
- KVM: SEV: Support SEV-SNP AP Creation NAE event (jsc#PED-5122).
- KVM: SEV: Add support to handle RMP nested page faults
  (jsc#PED-5122).
- KVM: SEV: Add support to handle Page State Change VMGEXIT
  (jsc#PED-5122).
- KVM: SEV: Add support to handle MSR based Page State Change
  VMGEXIT (jsc#PED-5122).
- KVM: SEV: Add support to handle GHCB GPA register VMGEXIT
  (jsc#PED-5122).
- KVM: SEV: Add KVM_SEV_SNP_LAUNCH_FINISH command (jsc#PED-5122).
- KVM: SEV: Add KVM_SEV_SNP_LAUNCH_UPDATE command (jsc#PED-5122).
- KVM: SEV: Add KVM_SEV_SNP_LAUNCH_START command (jsc#PED-5122).
- KVM: SEV: Add initial SEV-SNP support (jsc#PED-5122).
- KVM: SEV: Select KVM_GENERIC_PRIVATE_MEM when
  CONFIG_KVM_AMD_SEV=y (jsc#PED-5122).
- KVM: MMU: Disable fast path if KVM_EXIT_MEMORY_FAULT is needed
  (jsc#PED-5122).
- KVM: x86: Add hook for determining max NPT mapping level
  (jsc#PED-5122).
- KVM: guest_memfd: Add hook for invalidating memory
  (jsc#PED-5122).
- KVM: guest_memfd: Add interface for populating gmem pages with
  user data (jsc#PED-5122).
- KVM: guest_memfd: extract __kvm_gmem_get_pfn() (jsc#PED-5122).
- KVM: guest_memfd: Add hook for initializing memory
  (jsc#PED-5122).
- KVM: guest_memfd: limit overzealous WARN (jsc#PED-5122).
- KVM: guest_memfd: pass error up from filemap_grab_folio
  (jsc#PED-5122).
- KVM: guest_memfd: Use AS_INACCESSIBLE when creating guest_memfd
  inode (jsc#PED-5122).
- mm: Introduce AS_INACCESSIBLE for encrypted/confidential memory
  (jsc#PED-5122).
- KVM: x86/mmu: Don't save mmu_invalidate_seq after checking
  private attr (jsc#PED-5122).
- KVM: SEV: Allow per-guest configuration of GHCB protocol version
  (jsc#PED-5122).
- KVM: SEV: Add GHCB handling for termination requests
  (jsc#PED-5122).
- KVM: SEV: Add GHCB handling for Hypervisor Feature Support
  requests (jsc#PED-5122).
- KVM: SEV: Add support to handle AP reset MSR protocol
  (jsc#PED-5122).
- KVM: x86/mmu: Sanity check that __kvm_faultin_pfn() doesn't
  create noslot pfns (jsc#PED-5122).
- KVM: x86/mmu: Initialize kvm_page_fault's pfn and hva to error
  values (jsc#PED-5122).
- KVM: x86/mmu: Set kvm_page_fault.hva to KVM_HVA_ERR_BAD for
  "no slot" faults (jsc#PED-5122).
- KVM: x86/mmu: Handle no-slot faults at the beginning of
  kvm_faultin_pfn() (jsc#PED-5122).
- KVM: x86/mmu: Move slot checks from __kvm_faultin_pfn() to
  kvm_faultin_pfn() (jsc#PED-5122).
- KVM: x86/mmu: Explicitly disallow private accesses to emulated
  MMIO (jsc#PED-5122).
- KVM: x86/mmu: WARN and skip MMIO cache on private, reserved
  page faults (jsc#PED-5122).
- KVM: x86/mmu: Use synthetic page fault error code to indicate
  private faults (jsc#PED-5122).
- KVM: x86/mmu: WARN if upper 32 bits of legacy #PF error code
  are non-zero (jsc#PED-5122).
- KVM: x86/mmu: Pass full 64-bit error code when handling page
  faults (jsc#PED-5122).
- KVM: x86: Move synthetic PFERR_* sanity checks to SVM's #NPF
  handler (jsc#PED-5122).
- KVM: x86: Define more SEV+ page fault error bits/flags for #NPF
  (jsc#PED-5122).
- KVM: x86: Remove separate "bit" defines for page fault error
  code masks (jsc#PED-5122).
- KVM: x86/mmu: Exit to userspace with -EFAULT if private fault
  hits emulation (jsc#PED-5122).
- KVM: SEV: introduce KVM_SEV_INIT2 operation (jsc#PED-5122).
- KVM: SEV: define VM types for SEV and SEV-ES (jsc#PED-5122).
- KVM: SEV: introduce to_kvm_sev_info (jsc#PED-5122).
- KVM: x86: add fields to struct kvm_arch for CoCo features
  (jsc#PED-5122).
- KVM: SEV: store VMSA features in kvm_sev_info (jsc#PED-5122).
- KVM: SEV: publish supported VMSA features (jsc#PED-5122).
- KVM: introduce new vendor op for KVM_GET_DEVICE_ATTR
  (jsc#PED-5122).
- KVM: x86: use u64_to_user_ptr() (jsc#PED-5122).
- KVM: SVM: Compile sev.c if and only if CONFIG_KVM_AMD_SEV=y
  (jsc#PED-5122).
- KVM: SVM: Invert handling of SEV and SEV_ES feature flags
  (jsc#PED-5122).
- x86/CPU/AMD: Track SNP host status with cc_platform_*()
  (jsc#PED-5122).
- x86/cc: Add cc_platform_set/_clear() helpers (jsc#PED-5122).
- commit 8b9927e
* Wed Jul 24 2024 sjaeckel@suse.de
- net/rds: fix WARNING in rds_conn_connect_if_down (CVE-2024-27024
  bsc#1223777).
- commit 466c800
* Tue Jul 23 2024 jslaby@suse.cz
- PCI: Extend ACS configurability (bsc#1228090).
- commit 3be1ce1
* Mon Jul  8 2024 lduncan@suse.com
- Update
  patches.suse/scsi-qedf-Ensure-the-copied-buf-is-NUL-terminated.patch
  (bsc#1226785 CVE-2024-38559).
  fix incorrect bug number reference
- commit e17e7ff
* Mon Jul  8 2024 nik.borisov@suse.com
- wifi: nl80211: don't free NULL coalescing rule (bsc#1225835 CVE-2024-36941).
- commit d308879
* Tue Jul  2 2024 rhopkins@suse.de
- hsr: Prevent use after free in prp_create_tagged_frame()
  (CVE-2023-52846 bsc#1225098).
- commit 4f322b5
* Tue Jul  2 2024 dwagner@suse.de
- blk-mq: add helper for checking if one CPU is mapped to
  specified hctx (bsc#1223600).
- blk-mq: don't schedule block kworker on isolated CPUs
  (bsc#1223600).
- commit 2b67848
* Fri Jun 28 2024 mgorman@suse.de
- Update -rt config files.
- commit 1b276ca
* Fri Jun 28 2024 tiwai@suse.de
- drm/drm_file: Fix pid refcounting race (git-fixes).
- commit 7060e1c
* Wed Jun 26 2024 lduncan@suse.com
- scsi: qedf: Ensure the copied buf is NUL terminated (bsc#1226758
  CVE-2024-38559).
- scsi: bfa: Ensure the copied buf is NUL terminated (bsc#1226786
  CVE-2024-38560).
- commit 4fb286d
* Tue Jun 25 2024 davide.benini@suse.com
- net/sched: taprio: always validate TCA_TAPRIO_ATTR_PRIOMAP
  (CVE-2024-36974 bsc#1226519).
- commit e84ced3
* Mon Jun 24 2024 nmorey@suse.com
- RDMA/hns: Fix UAF for cq async event (bsc#1226595 CVE-2024-38545)
- commit 3456e75
* Tue Jun 18 2024 mgorman@suse.de
- series.conf: Consolidate RT history
- commit 4cf8ef0
* Tue Jun 18 2024 mgorman@suse.de
- Update
  patches.suse/sched-rt-Don-t-try-push-tasks-if-there-are-none.patch
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 46250cc
* Tue Jun 18 2024 mgorman@suse.de
- perf: Split __perf_pending_irq() out of perf_pending_irq()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- perf: Remove perf_swevent_get_recursion_context() from
  perf_pending_task() (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- perf: Enqueue SIGTRAP always via task_work (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- perf: Move irq_work_queue() where the event is prepared
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit cc5598f
* Tue Jun 18 2024 tzimmermann@suse.com
- drm/amdgpu: fix mmhub client id out-of-bounds access (bsc#1223789 CVE-2024-27029)
- commit 4d36c27
* Mon Jun 17 2024 mgorman@suse.de
- series.conf: Clarification
- commit c4ef68a
* Mon Jun 17 2024 mgorman@suse.de
- Refresh patches.suse/arm-Disable-jump-label-on-PREEMPT_RT.patch.
- commit 5b97e47
* Mon Jun 17 2024 mgorman@suse.de
- Replace with mainline and sort
  Update
  - patches.suse/kdb-Do-not-assume-write-callback-available.patch.
- commit 7d612cd
* Mon Jun 17 2024 mgorman@suse.de
- Refresh ARM (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- Mainline
  ARM: 9312/1: vfp: include asm/neon.h in vfpmodule.c
  ARM: 9327/1: vfp: Add missing VFP instructions to neon_support_hook backports.
  ARM: entry: Disregard Thumb undef exception in coproc dispatch
  ARM: entry: Make asm coproc dispatch code NWFPE only
  ARM: iwmmxt: Use undef hook to enable coprocessor for task
  ARM: kernel: Get rid of thread_info::used_cp[] array
  ARM: mm: Make virt_to_pfn() a static inline
  ARM: vfp: Move sending signals outside of vfp_lock()ed section
  ARM: vfp: Record VFP bounces as perf emulation faults
  ARM: vfp: Reimplement VFP exception entry in C code
  ARM: vfp: Remove workaround for Feroceon CPUs
  ARM: vfp: Use undef hook for handling VFP exceptions
  ARM: vfp: Use vfp_lock() in vfp_support_entry()
  arm: update in-source documentation references
- Refresh
  patches.suse/ARM-Allow-to-enable-RT.patch.
  patches.suse/ARM64-Allow-to-enable-RT.patch.
- Update
  patches.suse/ARM-enable-irq-in-translation-section-permission-fault-handlers.patch
  patches.suse/ARM-vfp-Provide-vfp_lock-for-VFP-locking.patch
  patches.suse/ARM-vfp-Use-vfp_lock-in-vfp_sync_hwstate.patch
- Delete
  patches.suse/ARM-vfp-Use-vfp_lock-in-vfp_entry.patch.
- commit d866c69
* Sun Jun 16 2024 mgorman@suse.de
- Replace with mainline and sort
- Update
  patches.suse/signal-Don-t-disable-preemption-in-ptrace_stop-on-PREEMPT_RT.patch
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- Rename to
  patches.suse/signal-Add-a-proper-comment-about-preempt_disable-in-ptrace_stop.patch.
- Delete patches.suse/signal-Update-the-comment-ptrace_stop.patch.
- commit d335161
* Sun Jun 16 2024 mgorman@suse.de
- Replace with mainline and sort
  patches.suse/sched-avoid-false-lockdep-splat-in-put_task_struct.patch
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit 455749f
* Sun Jun 16 2024 mgorman@suse.de
- net: Remove conditional threaded-NAPI wakeup based on task state
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- cxgb4: Properly lock TX queue for the selftest (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: pch: Don't initialize uart_port's spin_lock (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: pch: Don't disable interrupts while acquiring lock in
  ISR (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: pch: Make push_rx() return void (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- serial: pch: Invoke handle_rx_to() directly (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- xsk: Add truesize to skb_add_rx_frag() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- bpf: Remove xdp_do_flush_map() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- sched/debug: Update stale reference to sched_debug.c
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- selftests: hsr: Extend the testsuite to also cover HSRv1
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- selftests: hsr: Reorder the testsuite (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- selftests: hsr: Use `let' properly (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- commit 0f7dfa4
* Fri Jun 14 2024 ematsumiya@suse.de
- smb: client: fix use-after-free bug in
  cifs_debug_data_proc_show() (bsc#1225487, CVE-2023-52752).
- commit c4e1b53
* Fri Jun 14 2024 mgorman@suse.de
- Move/Refresh PREEMPT_RT upstream prerequisites to sorted section
  patches.suse/Revert-8250-add-support-for-ASIX-devices-with-a.patch.
  patches.suse/serial-8250-Add-dl_read-write-bugs-and-mapsize-into-plat_serial8250_port.patch.
  patches.suse/serial-8250-Fix-oops-for-port-pm-on-uart_chang.patch.
  patches.suse/serial-8250-RT288x-Au1xxx-code-away-from-core.patch.
  patches.suse/serial-8250-omap-Don-t-skip-resource-freeing-if-pm_r.patch.
  patches.suse/serial-8250-omap-Fix-imprecise-external-abort-for-omap_8250_pm.patch.
  patches.suse/serial-8250-omap-Shut-down-on-remove-for-console-uart.patch.
  patches.suse/serial-8250-omap-convert-to-modern-PM-ops.patch.
  patches.suse/serial-8250_omap-Add-earlycon-support-for-the-AM654-.patch.
  patches.suse/serial-8250_omap-Fix-errors-with-no_console_suspend.patch.
  patches.suse/serial-8250_omap-Use-force_suspend-and-resume-f.patch.
  patches.suse/serial-core-Start-managing-serial-controllers-to-enable-runtime-PM.patch.
  patches.suse/serial-drivers-switch-ch-and-flag-to-u8.patch.
  patches.suse/serial-exar-Add-RS-485-support-for-Sealevel-XR17V35X-based-cards.patch.
  patches.suse/serial-max3100-Lock-port-lock-when-calling-uart_hand.patch.
  patches.suse/tty-serial-meson-fix-hard-LOCKUP-on-crtscts-mode.patch.
- patches.suse/tty-serial-meson-use-dev_err_probe.patch.
- commit 4714620
* Fri Jun 14 2024 mgorman@suse.de
- Refresh patch metadata
  patches.suse/ARM-Allow-to-enable-RT.patch.
  patches.suse/ARM-enable-irq-in-translation-section-permission-fault-handlers.patch.
  patches.suse/ARM-vfp-Provide-vfp_lock-for-VFP-locking.patch.
  patches.suse/ARM-vfp-Use-vfp_lock-in-vfp_entry.patch.
  patches.suse/ARM-vfp-Use-vfp_lock-in-vfp_sync_hwstate.patch.
  patches.suse/ARM64-Allow-to-enable-RT.patch.
  patches.suse/ASoC-mediatek-mt8186-Remove-unused-mutex.patch.
  patches.suse/POWERPC-Allow-to-enable-RT.patch.
  patches.suse/Revert-drm-i915-Depend-on-PREEMPT_RT.patch.
  patches.suse/arch-arm64-Add-lazy-preempt-support.patch.
  patches.suse/arm-Add-support-for-lazy-preemption.patch.
  patches.suse/arm-Disable-jump-label-on-PREEMPT_RT.patch.
  patches.suse/drm-i915-Disable-tracing-points-on-PREEMPT_RT.patch.
  patches.suse/drm-i915-Don-t-check-for-atomic-context-on-PREEMPT_RT.patch.
  patches.suse/drm-i915-Don-t-disable-interrupts-on-PREEMPT_RT-during-atomic-updates.patch.
  patches.suse/drm-i915-Drop-the-irqs_disabled-check.patch.
  patches.suse/drm-i915-Use-preempt_disable-enable_rt-where-recommended.patch.
  patches.suse/drm-i915-gt-Use-spin_lock_irq-instead-of-local_irq_disable-spin_lock.patch.
  patches.suse/drm-i915-skip-DRM_I915_LOW_LEVEL_TRACEPOINTS-with-NOTRACE.patch.
  patches.suse/entry-Fix-the-preempt-lazy-fallout.patch.
  patches.suse/kdb-do-not-assume-write-callback-available.patch.
  patches.suse/net-Avoid-the-IPI-to-free-the.patch.
  patches.suse/powerpc-Add-support-for-lazy-preemption.patch.
  patches.suse/powerpc-kvm-Disable-in-kernel-MPIC-emulation-for-PREEMPT_RT.patch.
  patches.suse/powerpc-pseries-Select-the-generic-memory-allocator.patch.
  patches.suse/powerpc-pseries-iommu-Use-a-locallock-instead-local_irq_save.patch.
  patches.suse/powerpc-stackprotector-work-around-stack-guard-init-from-atomic.patch.
  patches.suse/powerpc-traps-Use-PREEMPT_RT.patch.
  patches.suse/preempt-Put-preempt_enable-within-an-instrumentation-section.patch.
  patches.suse/rcutorture-Also-force-sched-priority-to-timersd-on-boosting-test.patch.
  patches.suse/sched-Add-support-for-lazy-preemption.patch.
  patches.suse/sched-avoid-false-lockdep-splat-in-put_task_struct.patch.
  patches.suse/sched-core-Provide-a-method-to-check-if-a-task-is-PI-boosted.patch.
  patches.suse/sched-rt-Don-t-try-push-tasks-if-there-are-none.patch.
  patches.suse/signal-Add-proper-comment-about-the-preempt-disable-in-ptrace_stop.patch.
  patches.suse/signal-Don-t-disable-preemption-in-ptrace_stop-on-PREEMPT_RT.patch.
  patches.suse/signal-Update-the-comment-ptrace_stop.patch.
  patches.suse/softirq-Add-function-to-preempt-serving-softirqs.patch.
  patches.suse/softirq-Use-a-dedicated-thread-for-timer-wakeups.patch.
  patches.suse/softirq-Wake-ktimers-thread-also-in-softirq.patch.
  patches.suse/sysfs-Add-sys-kernel-realtime-entry.patch.
  patches.suse/tick-Fix-timer-storm-since-introduction-of-timersd.patch.
  patches.suse/time-Allow-to-preempt-after-a-callback.patch.
  patches.suse/tty-serial-omap-Make-the-locking-RT-aware.patch.
  patches.suse/tty-serial-pl011-Make-the-locking-work-on-RT.patch.
  patches.suse/x86-Allow-to-enable-RT.patch.
  patches.suse/x86-Enable-RT-also-on-32bit.patch.
  patches.suse/x86-Support-for-lazy-preemption.patch.
  patches.suse/x86-entry-Use-should_resched-in-idtentry_exit_cond_resched.patch.
  patches.suse/x86-microcode-Remove-microcode_mutex.patch.
  patches.suse/zram-Replace-bit-spinlocks-with-spinlock_t-for-PREEMPT_RT.patch.
- commit 7b96be5
* Fri Jun 14 2024 mgorman@suse.de
- Preparation update to v6.10-rc3-rt5 ((bsc#1214683 (PREEMPT_RT prerequisite backports)).
- Add
  console: Improve console_srcu_read_flags() comments
  device property: Add SOFTWARE_NODE() macro for defining software nodes
  device property: Add fwnode_name_eq()
  device property: Add fwnode_property_match_property_string()
  device property: Implement device_is_big_endian()
  device property: Implement device_is_compatible()
  nbcon: Provide functions for drivers to acquire console for non-printing.
  panic: Flush kernel log buffer at the end
  panic: Mark emergency section in oops
  panic: Mark emergency section in warn
  panic: add option to dump blocked tasks in panic_print
  panic: suppress gnu_printf warning
  printk: Add @flags argument for console_is_usable()
  printk: Add function to replay kernel log on consoles
  printk: Add kthread for all legacy consoles
  printk: Add non-BKL (nbcon) console basic infrastructure
  printk: Add notation to console_srcu locking
  printk: Atomic print in printk context on shutdown
  printk: Avoid console_lock dance if no legacy or boot consoles
  printk: Avoid false positive lockdep report for legacy printing
  printk: Check printk_deferred_enter()/_exit() usage
  printk: Check valid console index for preferred console
  printk: Constify name for add_preferred_console()
  printk: Coordinate direct printing in panic
  printk: Don't try to parse DEVNAME:0.0 console options
  printk: Flag register_console() if console is set on command line.
  printk: Let console_is_usable() handle nbcon
  printk: Make console_is_usable() available to nbcon
  printk: Make static printk buffers available to nbcon
  printk: Properly deal with nbcon consoles on seq init
  printk: Provide helper for message prepending
  printk: Provide threadprintk boot argument
  printk: Reduce pr_flush() pooling time
  printk: Remove the now superfluous sentinel elements from ctl_table array
  printk: Save console options for add_preferred_console_match()
  printk: Track nbcon consoles
  printk: Track registered boot consoles
  printk: fix illegal pbufs access for !CONFIG_PRINTK
  printk: flush consoles before checking progress
  printk: nbcon: Add acquire/release logic
  printk: nbcon: Add buffer management
  printk: nbcon: Add callbacks to synchronize with driver
  printk: nbcon: Add context to console_is_usable()
  printk: nbcon: Add detailed doc for write_atomic()
  printk: nbcon: Add emit function and callback function for atomic printing
  printk: nbcon: Add helper to assign priority based on CPU state
  printk: nbcon: Add ownership state functions
  printk: nbcon: Add printer thread wakeups
  printk: nbcon: Add sequence handling
  printk: nbcon: Add unsafe flushing on panic
  printk: nbcon: Allow drivers to mark unsafe regions and check state.
  printk: nbcon: Do not rely on proxy headers
  printk: nbcon: Implement emergency sections
  printk: nbcon: Introduce printing kthreads
  printk: nbcon: Provide function to flush using write_atomic()
  printk: nbcon: Provide function to reacquire ownership
  printk: nbcon: Remove return value for write_atomic()
  printk: nbcon: Show replay message on takeover
  printk: nbcon: Start printing threads
  printk: nbcon: Use driver synchronization while (un)registering
  printk: nbcon: Use nbcon consoles in console_flush_all()
  serial: convert uart sysrq handling to u8
  serial: core: Add UPIO_UNKNOWN constant for unknown port type
  serial: core: Controller id cannot be negative
  serial: core: Fix serial core port id to not use port->line
  serial: core: Implement processing in port->lock wrapper
  serial: core: Introduce wrapper to set @uart_port->cons
  serial: core: Move struct uart_port::quirks closer to possible
  serial: core: Provide low-level functions to lock port
  serial: core: Update uart_poll_timeout() function to return unsigned long.
  serial: core: Use lock wrappers
  serial: core: don't kfree device managed data
  serial: core: fix -EPROBE_DEFER handling in init
  serial: make uart_insert_char() accept u8s
  serial: port: Introduce a common helper to read properties
  tty/sysrq: Replay kernel log messages on consoles via sysrq
- Update
  patches.suse/dump_stack-Do-not-get-cpu_sync-for-panic-CPU.patch
  patches.suse/printk-Add-this_cpu_in_panic.patch
  patches.suse/printk-Adjust-mapping-for-32bit-seq-macros.patch
  patches.suse/printk-Avoid-non-panic-CPUs-writing-to-ringbuffer.patch
  patches.suse/printk-Disable-passing-console-lock-owner-completely-during-panic.patch
  patches.suse/printk-For-suppress_panic_printk-check-for-other-CPU-in-panic.patch
  patches.suse/printk-Update-the-printk-series.patch.
  patches.suse/printk-Use-prb_first_seq-as-base-for-32bit-seq-macros.patch
  patches.suse/printk-Wait-for-all-reserved-records-with-pr_flush.patch
  patches.suse/printk-nbcon-Relocate-32bit-seq-macros.patch
  patches.suse/printk-ringbuffer-Clarify-special-lpos-values.patch
  patches.suse/printk-ringbuffer-Cleanup-reader-terminology.patch
  patches.suse/printk-ringbuffer-Do-not-skip-non-finalized-records-with-prb_next_seq.patch
  patches.suse/printk-ringbuffer-Skip-non-finalized-records-in-panic.patch
  patches.suse/printk-nbcon-Stop-threads-on-shutdown-reboot.patch.
- Delete
  patches.suse/kernel-panic-Add-atomic-write-enforcement-to-warn-panic.patch.
  patches.suse/printk-Add-non-BKL-console-basic-infrastructure.patch.
  patches.suse/printk-Add-threaded-printing-support-for-BKL-consoles.patch.
  patches.suse/printk-Perform-atomic-flush-in-console_flush_on_panic.patch.
  patches.suse/printk-nbcon-move-locked_port-flag-to-struct-uart_port.patch.
  patches.suse/printk-nobkl-Add-acquire-release-logic.patch.
  patches.suse/printk-nobkl-Add-buffer-management.patch.
  patches.suse/printk-nobkl-Add-emit-function-and-callback-functions-for-atomic-printing.patch.
  patches.suse/printk-nobkl-Add-print-state-functions.patch.
  patches.suse/printk-nobkl-Add-printer-thread-wakeups.patch.
  patches.suse/printk-nobkl-Add-sequence-handling.patch.
  patches.suse/printk-nobkl-Add-write-context-storage-for-atomic-writes.patch.
  patches.suse/printk-nobkl-Introduce-printer-threads.patch.
  patches.suse/printk-nobkl-Provide-functions-for-atomic-write-enforcement.patch.
  patches.suse/printk-only-disable-if-actually-unregistered.patch.
  patches.suse/printk-replace-local_irq_save-with-local_lock-for-safe-mode.patch.
  patches.suse/rcu-Add-atomic-write-enforcement-for-rcu-stalls.patch
- commit cb99469
* Tue Jun 11 2024 jlee@suse.com
- Bluetooth: Fix use-after-free bugs caused by sco_sock_timeout
  (bsc#1224174 CVE-2024-27398).
- commit 9beffd0
* Tue Jun  4 2024 mgorman@suse.de
- Merge branch 'SLE15-SP6' (7c8fc2c7cc52) into 'SLE15-SP6-RT'
- Refreshed -rt patches
  patches.suse/serial-drivers-switch-ch-and-flag-to-u8.patch
  patches.suse/printk-Update-the-printk-series.patch
- commit 6959d87
* Mon Jun  3 2024 ematsumiya@suse.de
- cifs: failure to add channel on iface should bump up weight
  (git-fixes, bsc#1225172).
- commit 01a0775
* Mon Jun  3 2024 ematsumiya@suse.de
- smb: client: fix parsing of SMB3.1.1 POSIX create context
  (git-fixes, bsc#1225172).
- commit 9762b3b
* Mon Jun  3 2024 ematsumiya@suse.de
- Revert "cifs: reconnect work should have reference on server
  struct" (git-fixes, bsc#1225172).
- commit 1ececaf
* Mon Jun  3 2024 ematsumiya@suse.de
- cifs: fix leak of iface for primary channel (git-fixes,
  bsc#1225172).
- commit e31ce8b
* Mon Jun  3 2024 ematsumiya@suse.de
- smb: client: fix mount when dns_resolver key is not available
  (git-fixes, bsc#1225172).
- commit 5435746
* Thu May 30 2024 ematsumiya@suse.de
- smb: client: fix potential OOBs in smb2_parse_contexts()
  (bsc#1220148, CVE-2023-52434).
- commit 5cdfe62
* Wed May 29 2024 nstange@suse.de
- Refresh
  patches.suse/0002-PKCS-7-Check-codeSigning-EKU-for-kernel-module-and-k.patch (bsc#1222771).
  In preparation of enabling CONFIG_FIPS_SIGNATURE_SELFTEST, amend the
  missing 'usage' argument in the pkcs7_validate_trust() invocation
  from  the PKCS#7 selftest.
- commit 1da6364
* Wed May 29 2024 nstange@suse.de
- certs: Add ECDSA signature verification self-test (bsc#1222777).
- Port "certs: Add ECDSA signature verification self-test".
- Enable new CONFIG_FIPS_SIGNATURE_SELFTEST_ECDSA.
- Refresh
  0002-PKCS-7-Check-codeSigning-EKU-for-kernel-module-and-k.patch:
  trivial context update to Kconfig
- commit c3fa331
* Wed May 29 2024 nstange@suse.de
- certs: Move RSA self-test data to separate file (bsc#1222777).
- Update config files.
- Refresh
  patches.suse/0002-PKCS-7-Check-codeSigning-EKU-for-kernel-module-and-k.patch.
- commit 595a21a
* Tue May 28 2024 ematsumiya@suse.de
- smb: client: guarantee refcounted children from parent session
  (bsc#1225172, bsc#1224679, CVE-2024-35869).
- commit 2a83172
* Tue May 28 2024 ematsumiya@suse.de
- smb: client: fix UAF in smb2_reconnect_server() (bsc#1225172,
  bsc#1224672, CVE-2024-35870).
- commit 1395031
* Tue May 28 2024 ematsumiya@suse.de
- smb: Fix regression in writes when non-standard maximum write
  size negotiated (bsc#1222464, CVE-2024-26692).
- commit 4c0a9d1
* Tue May 28 2024 ematsumiya@suse.de
- cifs: Fix writeback data corruption (bsc#1225172,
  bsc#1223810, CVE-2024-27036).
- commit 02d771d
* Tue May 28 2024 ematsumiya@suse.de
- cifs: Don't use certain unnecessary folio_*() functions
  (bsc#1225172).
- commit 2852616
* Mon May 27 2024 ematsumiya@suse.de
- cifs: fix charset issue in reconnection (bsc#1225172).
- commit e5797ff
* Sat May 25 2024 ematsumiya@suse.de
- cifs: handle cases where multiple sessions share connection
  (bsc#1225172).
- commit 614a973
* Sat May 25 2024 ematsumiya@suse.de
- smb3: show beginning time for per share stats (bsc#1225172).
- commit 7ed0a90
* Sat May 25 2024 ematsumiya@suse.de
- cifs: cifs_chan_is_iface_active should be called with chan_lock
  held (bsc#1225172).
- commit 2a1cfd7
* Sat May 25 2024 ematsumiya@suse.de
- cifs: do not pass cifs_sb when trying to add channels
  (bsc#1225172).
- commit 918135a
* Sat May 25 2024 ematsumiya@suse.de
- smb: client: remove extra @chan_count check in
  __cifs_put_smb_ses() (bsc#1225172).
- commit b3988e8
* Sat May 25 2024 ematsumiya@suse.de
- cifs: reconnect work should have reference on server struct
  (bsc#1225172).
- commit b671293
* Sat May 25 2024 ematsumiya@suse.de
- cifs: handle cases where a channel is closed (bsc#1225172).
- commit 48ef022
* Sat May 25 2024 ematsumiya@suse.de
- smb: client: reduce stack usage in cifs_try_adding_channels()
  (bsc#1225172).
- commit 7290ab8
* Sat May 25 2024 ematsumiya@suse.de
- smb: client: get rid of dfs code dep in namespace.c
  (bsc#1225172).
- commit 1de62b5
* Sat May 25 2024 ematsumiya@suse.de
- smb: client: get rid of dfs naming in automount code
  (bsc#1225172).
- commit 7c6dc40
* Sat May 25 2024 ematsumiya@suse.de
- smb: client: rename cifs_dfs_ref.c to namespace.c (bsc#1225172).
- commit 2752efd
* Sat May 25 2024 ematsumiya@suse.de
- smb: client: ensure to try all targets when finding nested links
  (bsc#1225172).
- commit 41c1456
* Sat May 25 2024 ematsumiya@suse.de
- smb: client: introduce DFS_CACHE_TGT_LIST() (bsc#1225172).
- commit 475c105
* Sat May 25 2024 ematsumiya@suse.de
- cifs: account for primary channel in the interface list
  (bsc#1225172).
- commit 1d6cc08
* Sat May 25 2024 ematsumiya@suse.de
- cifs: distribute channels across interfaces based on speed
  (bsc#1225172).
- commit 4fa68b8
* Fri May 10 2024 msuchanek@suse.de
- Update ppc64le config files (bsc#1223982).
  drop support for agpgart, there is no driver enabled
  drop support for pinctrl and backlight drivers, these are not used
  drop support for auxiliary display, none is exposed
  drop support for i2c leds, timers, multiplexors, watchdogs, displays, HID - these are not used
  drop support for PC CMOS rtc, there is rtc_opal and rtc_generic
  drop support for platform-specific DMA found on other platforms
  drop support for SoC-specific PWM, USB, PCI, gpio, and clk drivers
  drop support for DSA
- commit 1f4aae4
* Fri Mar 29 2024 mkoutny@suse.com
- README.BRANCH: Remove copy of branch name
- commit 01b2863
* Thu Mar 28 2024 mgorman@suse.de
- Rename and refresh
  patches.suse/sched-fair-Combine-EAS-check-with-root_domain-overutilized-access.patch.
- commit c443ee5
* Thu Mar 28 2024 mgorman@suse.de
- Break out portions of the monolithic printk patch
- Add
  Revert "tty: serial: meson: Add a earlycon for the T7 SoC"
  serial: Do not hold the port lock when setting rx-during-tx GPIO
  serial: ar933x: Use devm_platform_get_and_ioremap_resource()
  serial: bcm63xx-uart: Use devm_platform_get_and_ioremap_resource()
  serial: clps711x: Use devm_platform_get_and_ioremap_resource()
  serial: core: Fix checks for tx runtime PM state
  serial: core: Fix runtime PM handling for pending tx
  serial: fsl_lpuart: Use devm_platform_get_and_ioremap_resource()
  serial: imx: Use devm_platform_get_and_ioremap_resource()
  serial: linflexuart: Use devm_platform_get_and_ioremap_resource()
  serial: mps2-uart: Use devm_platform_get_and_ioremap_resource()
  serial: mvebu-uart: Use devm_platform_get_and_ioremap_resource()
  serial: omap: Use devm_platform_get_and_ioremap_resource()
  serial: qcom-geni: clean up clock-rate debug printk
  serial: qcom-geni: use icc tag defines
  serial: qcom_geni: Comment use of devm_krealloc rather than devm_krealloc_array
  serial: sccnxp: Use devm_platform_get_and_ioremap_resource()
  serial: sifive: Add suspend and resume operations
  serial: sifive: Remove redundant of_match_ptr()
  serial: sifive: Use devm_platform_get_and_ioremap_resource()
  serial: sprd: Use devm_platform_get_and_ioremap_resource()
  serial: st-asc: Use devm_platform_get_and_ioremap_resource()
  serial: stm32: avoid clearing DMAT bit during transfer
  serial: stm32: do not always set SER_RS485_RX_DURING_TX if RS485 is enabled
  serial: stm32: group dma pause/resume error handling into single function
  serial: stm32: modify parameter and rename stm32_usart_rx_dma_enabled
  serial: stm32: replace access to DMAR bit by dmaengine_pause/resume
  serial: stm32: synchronize RX DMA channel in shutdown
  serial: stm32: use DMAT as a configuration bit
  serial: tegra: Don't print error on probe deferral
  serial: tegra: Use devm_platform_get_and_ioremap_resource()
  serial: vt8500: Use devm_platform_get_and_ioremap_resource()
  tty: serial: fsl_lpuart: add IDLE interrupt support for rx_dma on imx7ulp/imx8ulp/imx8qxp
  tty: serial: fsl_lpuart: move the lpuart32_int() below
  tty: serial: meson: Add a earlycon for the T7 SoC
  tty: serial: meson: add independent uart_data for A1 SoC family
  tty: serial: meson: apply ttyS devname instead of ttyAML for new SoCs
  tty: serial: meson: introduce separate uart_data for S4 SoC family
  tty: serial: meson: redesign the module to platform_driver
  tty: serial: meson: refactor objects definition for different devnames
  tty: serial: meson: use dev_err_probe
  tty: serial: samsung: Set missing PM ops for hibernation support
  tty: serial: samsung_tty: Use abs() to simplify some code
  tty: serial: xilinx_uartps: Do not check for 0 return after calling platform_get_irq()
- Update
  patches.suse/drm-i915-guc-Consider-also-RCU-depth-in-busy-loop.patch
  patches.suse/printk-Update-the-printk-series.patch.
  patches.suse/printk-nbcon-move-locked_port-flag-to-struct-uart_port.patch
  patches.suse/rt-Add-documentation-describing-what-RT-kernel-config-changes-to-default.patch.
  patches.suse/rt-Add-documentation-describing-what-kernel-debug-options-to-add-for-testing.patch.
  patches.suse/rt-Add-helper-script-to-refresh-RT-configs-based-on-the-parent.patch.
  patches.suse/serial-8250-implement-non-BKL-console.patch.
  patches.suse/tty-don-t-check-for-signal_pending-in-send_break.patch.
  patches.suse/tty-use-if-in-send_break-instead-of-goto.patch.
  patches.suse/usb-cdc-acm-return-correct-error-code-on-unsupported-break.patch.
- commit eee7e3b
* Wed Mar 27 2024 mgorman@suse.de
- Delete config-test/arm64/rt.
  No plan to support arm64 on SLE15-SP6
- commit e5213ef
* Tue Mar 26 2024 mgorman@suse.de
- Refresh series
- patches.suse/sched-fair-Add-EAS-checks-before-updating-root_domain-overutilized.patch.
- patches.suse/sched-fair-Introduce-is_rd_overutilized-helper-function-to-access-root_domain-overutilized.patch.
- patches.suse/sched-fair-Combine-EAS-check-with-overutilized-access.patch.
- commit 54886a9
* Mon Mar 25 2024 mgorman@suse.de
- Break out portions of the monolithic printk patch
- Add
  lockdep: Add lock_set_cmp_fn() annotation (bsc#1214683
  tty: tty_io: update timestamps on all device nodes
  tty_audit: invert the condition in tty_audit_log() (bsc#1214683
  tty_audit: make data of tty_audit_log() const (bsc#1214683
  tty_audit: make icanon a bool (bsc#1214683 (PREEMPT_RT
  tty_audit: use TASK_COMM_LEN for task comm (bsc#1214683
  tty_audit: use kzalloc() in tty_audit_buf_alloc() (bsc#1214683
  kill do_each_thread()
  tty: change tty_write_lock()'s ndelay parameter to bool
  tty: don't check for signal_pending() in send_break()
  tty: don't pass write() to do_tty_write()
  tty: early return from send_break() on TTY_DRIVER_HARDWARE_BREAK
  tty: make check_tty_count() void
  tty: rename and de-inline do_tty_write()
  tty: switch size and count types in iterate_tty_read() to size_t
  tty: tty_io: update timestamps on all device nodes
  tty: use 'if' in send_break() instead of 'goto'
  tty: use min() for size computation in iterate_tty_read()
  tty: use min() in iterate_tty_write()
  tty: use ssize_t for iterate_tty_read() returned type
  usb: cdc-acm: return correct error code on unsupported break
- Update
  patches.suse/printk-Update-the-printk-series.patch.
  patches.suse/printk-nbcon-move-locked_port-flag-to-struct-uart_port.patch.
- commit ade5c78
* Mon Mar 25 2024 mgorman@suse.de
- series.conf: Sort PREEMPT_RT pre-requisites by upstream commit ID
- Refresh
  patches.suse/serial-8250-lock-port-for-omap8250_restore_regs.patch.
  patches.suse/serial-8250-lock-port-for-rx_dma-callback.patch.
- commit 7f67936
* Fri Mar 22 2024 mgorman@suse.de
- Refresh -rt configs.
- commit 314698d
* Fri Mar 22 2024 mgorman@suse.de
- printk: nbcon: move locked_port flag to struct uart_port
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- Refresh patches.suse/printk-Update-the-printk-series.patch.
- commit 649949f
* Thu Mar 21 2024 mgorman@suse.de
- Update printk to v6.6.20-rt25
- kernel/panic: Add atomic write enforcement to warn/panic (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- panic: hide unused global functions (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: Add non-BKL console basic infrastructure (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: Add threaded printing support for BKL consoles (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: Consolidate console deferred printing (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: Do not take console lock for console_flush_on_panic() (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: Perform atomic flush in console_flush_on_panic() (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: Rename abandon_console_lock_in_panic() to other_cpu_in_panic() (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: Update the printk series (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: nobkl: Add acquire/release logic (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: nobkl: Add buffer management (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: nobkl: Add emit function and callback functions for atomic printing (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: nobkl: Add print state functions (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: nobkl: Add printer thread wakeups (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: nobkl: Add sequence handling (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: nobkl: Add write context storage for atomic writes (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: nobkl: Introduce printer threads (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: nobkl: Provide functions for atomic write enforcement (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: nobkl: Stop threads on shutdown/reboot (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: only disable if actually unregistered (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- printk: replace local_irq_save with local_lock for safe mode (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- proc: consoles: Add support for non-BKL consoles (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- rcu: Add atomic write enforcement for rcu stalls (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250: implement non-BKL console
- serial: Make uart_remove_one_port() return void (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: Switch i2c drivers back to use .probe() (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: core: Don't drop port_mutex in serial_core_remove_one_port (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: core: Fix error handling for serial_core_ctrl_device_add() (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: core: Fix probing serial_base_bus devices (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: core: Start managing serial controllers to enable runtime PM (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: pl011: set UART011_CR_RXE in pl011_set_termios after port shutdown (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: serial: fsl_lpuart: Check the return value of dmaengine_tx_status (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: serial: fsl_lpuart: optimize the timer based EOP logic (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: tty_io: Show non-BKL consoles as active (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/printk-Add-per-console-suspended-state.patch.
  patches.suse/printk-Keep-non-panic-CPUs-out-of-console-lock.patch.
  patches.suse/printk-Reduce-console_unblank-usage-in-unsafe-scenarios.patch.
- Delete
  patches.suse/printk-Add-NMI-check-to-console_flush_on_panic-and-console_unblank.patch.
- commit 348ec5a
* Thu Mar 21 2024 mgorman@suse.de
- Revert v6.5-rt printk
- commit 39196a4
* Wed Mar 20 2024 mgorman@suse.de
- series.conf: Move v6.5-rc7-rt4 printk series to prepare for revert and refresh
- Update
  patches.suse/kernel-panic-Add-atomic-write-enforcement-to-warn-panic.patch.
  patches.suse/printk-Add-NMI-check-to-console_flush_on_panic-and-console_unblank.patch.
  patches.suse/printk-Add-non-BKL-console-basic-infrastructure.patch.
  patches.suse/printk-Add-per-console-suspended-state.patch.
  patches.suse/printk-Add-threaded-printing-support-for-BKL-consoles.patch.
  patches.suse/printk-Check-only-for-migration-in-printk_deferred_.patch.
  patches.suse/printk-Consolidate-console-deferred-printing.patch.
  patches.suse/printk-Keep-non-panic-CPUs-out-of-console-lock.patch.
  patches.suse/printk-Monolithic-bring-printk-up-to-date-with-v6.6-rt25.patch.
  patches.suse/printk-Perform-atomic-flush-in-console_flush_on_panic.patch.
  patches.suse/printk-Reduce-console_unblank-usage-in-unsafe-scenarios.patch.
  patches.suse/printk-nobkl-Add-acquire-release-logic.patch.
  patches.suse/printk-nobkl-Add-buffer-management.patch.
  patches.suse/printk-nobkl-Add-print-state-functions.patch.
  patches.suse/printk-nobkl-Add-printer-thread-wakeups.patch.
  patches.suse/printk-nobkl-Add-sequence-handling.patch.
  patches.suse/printk-nobkl-Add-write-context-storage-for-atomic-writes.patch.
  patches.suse/printk-nobkl-Introduce-printer-threads.patch.
  patches.suse/printk-nobkl-Provide-functions-for-atomic-write-enforcement.patch.
  patches.suse/printk-nobkl-Stop-threads-on-shutdown-reboot.patch.
  patches.suse/printk-only-disable-if-actually-unregistered.patch.
  patches.suse/printk-replace-local_irq_save-with-local_lock-for-safe-mode.patch.
  patches.suse/proc-consoles-Add-support-for-non-BKL-consoles.patch.
  patches.suse/rcu-Add-atomic-write-enforcement-for-rcu-stalls.patch.
  patches.suse/serial-8250-implement-non-BKL-console.patch.
  patches.suse/serial-8250-lock-port-for-omap8250_restore_regs.patch.
  patches.suse/serial-8250-lock-port-for-rx_dma-callback.patch.
  patches.suse/serial-8250-omap-convert-to-modern-PM-ops.patch.
  patches.suse/serial-8250_mtk-Simplify-clock-sequencing-and-runtime-PM.patch.
  patches.suse/serial-arc_uart-simplify-flags-handling-in-arc_serial_rx_chars.patch.
  patches.suse/serial-drivers-switch-ch-and-flag-to-u8.patch.
  patches.suse/serial-exar-Add-RS-485-support-for-Sealevel-XR17V35X-based-cards.patch.
  patches.suse/serial-omap-serial-remove-flag-from-serial_omap_rdi.patch.
  patches.suse/tty-Explicitly-include-correct-DT-includes.patch.
  patches.suse/tty-tty_io-Show-non-BKL-consoles-as-active.patch.
- commit 3eb390b
* Wed Mar 20 2024 mgorman@suse.de
- series.conf: Move v6.5-rc7-rt4 printk series to prepare for revert and refresh
- commit 87038dd
* Wed Mar 20 2024 mgorman@suse.de
- Break out patches from RT monolithic printk update
- serial: 8250: lock port for omap8250_restore_regs() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: 8250: lock port for rx_dma() callback (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: 8250: omap: convert to modern PM ops (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: 8250_mtk: Simplify clock sequencing and runtime PM
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: arc_uart: simplify flags handling in
  arc_serial_rx_chars() (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- serial: drivers: switch ch and flag to u8 (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: exar: Add RS-485 support for Sealevel XR17V35X based
  cards (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: omap-serial: remove flag from serial_omap_rdi()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- tty: Explicitly include correct DT includes (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- printk: Keep non-panic-CPUs out of console lock (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- printk: Reduce console_unblank() usage in unsafe scenarios
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- Refresh
  patches.suse/printk-Monolithic-bring-printk-up-to-date-with-v6.6-rt25.patch.
- commit cb95eee
* Fri Mar 15 2024 mgorman@suse.de
- printk: Monolithic bring printk up to date with v6.6-rt25
  (SLE Realtime Extension).
- serial: 8250_bcm7271: improve bcm7271 8250 port (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- 8250_men_mcb: fix error handling in
  read_uarts_available_from_reg() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- tty: serial: 8250: Define earlycon for mrvl,mmp-uart
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- 8250_men_mcb: Make UART config auto configurable (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- 8250_men_mcb: Read num ports from register data (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- 8250_men_mcb: Add clockrate speed for G215/F215 boards
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250_rt288x: Remove unnecessary UART_REG_UNMAPPED
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250_rt288x: Name non-standard divisor latch reg
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250: Allow using ports higher than
  SERIAL_8250_RUNTIME_UARTS (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- cpuidle: Use local_clock_noinstr() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- sched/clock: Provide local_clock_noinstr() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- x86/tsc: Provide sched_clock_noinstr() (bsc#1214683 (PREEMPT_RT
  prerequisite backports)).
- math64: Always inline u128 version of mul_u64_u64_shr()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- s390/time: Provide sched_clock_noinstr() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- arm64/arch_timer: Provide noinstr sched_clock_read() functions
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- arm64/io: Always inline all of __raw_{read,write}[bwlq]()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- time/sched_clock: Provide sched_clock_noinstr() (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- seqlock/latch: Provide raw_read_seqcount_latch_retry()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit bbc5d1a
* Wed Mar 13 2024 mgorman@suse.de
- drm/i915/guc: Consider also RCU depth in busy loop (SLE
  Realtime Extension).
- srcu: Use try-lock lockdep annotation for NMI-safe access
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- futex/pi: Fix recursive rt_mutex waiter state (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- srcu: Remove extraneous parentheses from srcu_read_lock() etc
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- commit fb0af0c
* Mon Feb 19 2024 lhruska@suse.cz
- rpm/scripts: Remove obsolete Symbols.list
  Symbols.list is not longer needed by the new klp-convert implementation. (bsc#1218644)
- commit 596cf9f
* Tue Nov 28 2023 mgorman@suse.de
- Refresh arm64 rt configs.
- commit 836dee6
* Tue Nov  7 2023 mgorman@suse.de
- Update -rt config files.
- commit b2029bb
* Tue Oct 24 2023 mgorman@suse.de
- Refresh -rt config files.
- commit e539d6b
* Thu Aug 31 2023 mgorman@suse.de
- Add prototype arm64 RT configuration.
- commit e1d88f5
* Thu Aug 31 2023 mgorman@suse.de
- Refresh
  patches.suse/rt-Add-helper-script-to-refresh-RT-configs-based-on-the-parent.patch.
- commit 8123171
* Thu Aug 31 2023 mgorman@suse.de
- rt: Add helper script to refresh RT configs based on the parent
  (SLE Realtime Extension).
- commit a1cc66d
* Mon Aug 28 2023 jack@suse.cz
- patches.suse/add-suse-supported-flag.patch: Add CONFIG_MODULES dependency
- commit cd84206
* Mon Aug 28 2023 mgorman@suse.de
- README.BRANCH: Add -rt branch maintainers
- commit e55c60f
* Mon Aug 28 2023 mgorman@suse.de
- Create initial -rt config files.
- commit 78ac3d9
* Mon Aug 28 2023 mgorman@suse.de
- config.conf: Remove unsupported architectures and enable rt configurations
- Delete config/arm64/64kb.
- Delete config/arm64/default.
- Delete config/arm64/kvmsmall.
- Delete config/armv7hl/default.
- Delete config/armv7hl/lpae.
- Delete config/ppc64le/debug.
- Delete config/ppc64le/default.
- Delete config/ppc64le/kvmsmall.
- Delete config/s390x/default.
- Delete config/s390x/zfcpdump.
- Delete config/x86_64/kvmsmall.
- commit 85816bc
* Mon Aug 28 2023 mgorman@suse.de
- rt: Add documentation describing what kernel debug options to
  add for testing (SLE Realtime Extension).
- rt: Add documentation describing what RT kernel config changes
  to default (SLE Realtime Extension).
- locking/rtmutex: Update the "flush I/O on schedule" series
  (SLE Realtime Extension).
- signal: Update the comment ptrace_stop() (SLE Realtime
  Extension).
- ASoC: mediatek: mt8186: Remove unused mutex (SLE Realtime
  Extension).
- x86/microcode: Remove microcode_mutex (SLE Realtime Extension).
- time: Allow to preempt after a callback (SLE Realtime
  Extension).
- softirq: Add function to preempt serving softirqs (SLE Realtime
  Extension).
- sched/core: Provide a method to check if a task is PI-boosted
  (SLE Realtime Extension).
- sched/rt: Don't try push tasks if there are none (SLE Realtime
  Extension).
- sysfs: Add /sys/kernel/realtime entry (SLE Realtime Extension).
- POWERPC: Allow to enable RT (SLE Realtime Extension).
- powerpc/stackprotector: work around stack-guard init from atomic
  (SLE Realtime Extension).
- powerpc/kvm: Disable in-kernel MPIC emulation for PREEMPT_RT
  (SLE Realtime Extension).
- powerpc/pseries: Select the generic memory allocator (SLE
  Realtime Extension).
- powerpc/imc-pmu: Use the correct spinlock initializer (SLE
  Realtime Extension).
- powerpc/pseries/iommu: Use a locallock instead local_irq_save()
  (SLE Realtime Extension).
- powerpc: traps: Use PREEMPT_RT (SLE Realtime Extension).
- ARM64: Allow to enable RT (SLE Realtime Extension).
- ARM: Allow to enable RT (SLE Realtime Extension).
- tty/serial/pl011: Make the locking work on RT (SLE Realtime
  Extension).
- tty/serial/omap: Make the locking RT aware (SLE Realtime
  Extension).
- ARM: enable irq in translation/section permission fault handlers
  (SLE Realtime Extension).
- arm: Disable jump-label on PREEMPT_RT (SLE Realtime Extension).
- arch/arm64: Add lazy preempt support (SLE Realtime Extension).
- powerpc: Add support for lazy preemption (SLE Realtime
  Extension).
- arm: Add support for lazy preemption (SLE Realtime Extension).
- entry: Fix the preempt lazy fallout (SLE Realtime Extension).
- x86: Support for lazy preemption (SLE Realtime Extension).
- x86/entry: Use should_resched() in idtentry_exit_cond_resched()
  (SLE Realtime Extension).
- sched: Add support for lazy preemption (SLE Realtime Extension).
- Revert "drm/i915: Depend on !PREEMPT_RT." (SLE Realtime
  Extension).
- drm/i915: Do not disable preemption for resets (SLE Realtime
  Extension).
- drm/i915: Drop the irqs_disabled() check (SLE Realtime
  Extension).
- drm/i915/gt: Use spin_lock_irq() instead of local_irq_disable()
  + spin_lock() (SLE Realtime Extension).
- drm/i915/gt: Queue and wait for the irq_work item (SLE Realtime
  Extension).
- drm/i915: skip DRM_I915_LOW_LEVEL_TRACEPOINTS with NOTRACE
  (SLE Realtime Extension).
- drm/i915: Disable tracing points on PREEMPT_RT (SLE Realtime
  Extension).
- drm/i915: Don't check for atomic context on PREEMPT_RT (SLE
  Realtime Extension).
- drm/i915: Don't disable interrupts on PREEMPT_RT during atomic
  updates (SLE Realtime Extension).
- drm/i915: Use preempt_disable/enable_rt() where recommended
  (SLE Realtime Extension).
- printk: Check only for migration in printk_deferred_*()
  (SLE Realtime Extension).
- serial: 8250: implement non-BKL console (SLE Realtime
  Extension).
- printk: replace local_irq_save with local_lock for safe mode
  (SLE Realtime Extension).
- printk: Add threaded printing support for BKL consoles (SLE
  Realtime Extension).
- printk: only disable if actually unregistered (SLE Realtime
  Extension).
- printk: Perform atomic flush in console_flush_on_panic()
  (SLE Realtime Extension).
- rcu: Add atomic write enforcement for rcu stalls (SLE Realtime
  Extension).
- kernel/panic: Add atomic write enforcement to warn/panic
  (SLE Realtime Extension).
- proc: consoles: Add support for non-BKL consoles (SLE Realtime
  Extension).
- tty: tty_io: Show non-BKL consoles as active (SLE Realtime
  Extension).
- printk: nobkl: Stop threads on shutdown/reboot (SLE Realtime
  Extension).
- printk: nobkl: Provide functions for atomic write enforcement
  (SLE Realtime Extension).
- printk: nobkl: Add write context storage for atomic writes
  (SLE Realtime Extension).
- printk: nobkl: Add printer thread wakeups (SLE Realtime
  Extension).
- printk: nobkl: Introduce printer threads (SLE Realtime
  Extension).
- printk: nobkl: Add emit function and callback functions for
  atomic printing (SLE Realtime Extension).
- printk: nobkl: Add print state functions (SLE Realtime
  Extension).
- printk: nobkl: Add sequence handling (SLE Realtime Extension).
- printk: nobkl: Add buffer management (SLE Realtime Extension).
- printk: nobkl: Add acquire/release logic (SLE Realtime
  Extension).
- printk: Add non-BKL console basic infrastructure (SLE Realtime
  Extension).
- printk: Add per-console suspended state (SLE Realtime
  Extension).
- printk: Consolidate console deferred printing (SLE Realtime
  Extension).
- printk: Add NMI check to console_flush_on_panic() and
  console_unblank() (SLE Realtime Extension).
- kdb: do not assume write() callback available (SLE Realtime
  Extension).
- preempt: Put preempt_enable() within an instrumentation*()
  section (SLE Realtime Extension).
- zram: Replace bit spinlocks with spinlock_t for PREEMPT_RT
  (SLE Realtime Extension).
- softirq: Wake ktimers thread also in softirq (SLE Realtime
  Extension).
- tick: Fix timer storm since introduction of timersd (SLE
  Realtime Extension).
- rcutorture: Also force sched priority to timersd on boosting
  test (SLE Realtime Extension).
- softirq: Use a dedicated thread for timer wakeups (SLE Realtime
  Extension).
- x86: Enable RT also on 32bit (SLE Realtime Extension).
- x86: Allow to enable RT (SLE Realtime Extension).
- net: Avoid the IPI to free the (SLE Realtime Extension).
- mm/page_alloc: Use write_seqlock_irqsave() instead
  write_seqlock() + local_irq_save() (SLE Realtime Extension).
- seqlock: Do the lockdep annotation before locking in
  do_write_seqcount_begin_nested() (SLE Realtime Extension).
- ARM: vfp: Use vfp_lock() in vfp_entry() (SLE Realtime
  Extension).
- ARM: vfp: Use vfp_lock() in vfp_sync_hwstate() (SLE Realtime
  Extension).
- ARM: vfp: Provide vfp_lock() for VFP locking (SLE Realtime
  Extension).
- signal: Don't disable preemption in ptrace_stop() on PREEMPT_RT
  (SLE Realtime Extension).
- signal: Add proper comment about the preempt-disable in
  ptrace_stop() (SLE Realtime Extension).
- locking/rtmutex: Add a lockdep assert to catch potential nested
  blocking (SLE Realtime Extension).
- locking/rtmutex: Avoid pointless blk_flush_plug() invocations
  (SLE Realtime Extension).
- locking/rtmutex: Submit/resume work explicitly before/after
  blocking (SLE Realtime Extension).
- sched/core: Provide sched_rtmutex() and expose sched work
  helpers (SLE Realtime Extension).
- sched: avoid false lockdep splat in put_task_struct() (SLE
  Realtime Extension).
- kernel/fork: beware of __put_task_struct calling context
  (SLE Realtime Extension).
- serial: 8250: Apply FSL workarounds also without
  SERIAL_8250_CONSOLE (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- serial: 8250: omap: Move uart_write() inside PM section
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250-fsl: Expand description of the MPC83xx UART's
  misbehaviour (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: Indicate fintek option may also be required for RS232
  support (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250: synchronize and annotate UART_IER access
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250: lock port in startup() callbacks (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: 8250: RT288x/Au1xxx code away from core (bsc#1214683
  (PREEMPT_RT prerequisite backports)).
- serial: 8250: Add dl_read/write, bugs and mapsize into
  plat_serial8250_port (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- serial: 8250: Document uart_8250_port's ->dl_read/write()
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250: Change dl_read/write to handle value as u32
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250: omap: Shut down on remove for console uart
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250: omap: Fix life cycle issues for interrupt handlers
  (bsc#1214683 (PREEMPT_RT prerequisite backports)).
- serial: 8250: omap: Fix imprecise external abort for
  omap_8250_pm() (bsc#1214683 (PREEMPT_RT prerequisite
  backports)).
- commit ad2dfb0
* Fri Jul 14 2023 tiwai@suse.de
- Please note: To save space, changelog entries from prior to the
  SLE15-SP6 kernel rebase (to v6.4) have been removed at the commit
  b35e0a62edf4. Listed below are the Bugzilla/CVE/Jira references
  from the deleted changelog entries (typos included).
  The full text for these removed entries can be found in
    /usr/share/doc/packages/kernel-docs/old_changelog.txt
  from the kernel-docs package:
  bsc#158563 boo#173030 bsc#178378 bsc#182715 bsc#182716 bsc#182717
  bsc#185032 bnc#464461 bsc#464461 bnc#754690 bnc#814005 bnc#854875
  bsc#865869 bsc#873195 bsc#927455 bsc#951844 bsc#954532 bsc#962720
  bsc#964063 bsc#974406 bnc#981838 bsc#981838 bnc#1012628 bsc#1012628
  bnc#1018348 bsc#1020657 bsc#1023051 bsc#1024015 bsc#1024412 boo#1027378
  boo#1029158 bsc#1032323 boo#1039806 bsc#1040020 bsc#1040364 bsc#1040855
  bsc#1043990 bsc#1044120 bsc#1044767 bsc#1047233 bsc#1048129 bsc#1048585
  bsc#1048934 bnc#1048935 bsc#1050582 bsc#1051510 bsc#1053501 bsc#1053802
  bsc#1054239 bsc#1054610 bsc#1055013 bsc#1055014 bsc#1055117 bsc#1055186
  bsc#1055817 bsc#1055826 bsc#1056427 bsc#1056588 bsc#1056686 bsc#1056979
  bsc#1057199 bnc#1057389 bnc#1058115 bsc#1058115 bsc#1058410 bsc#1059807
  bsc#1060333 bsc#1061593 bsc#1061840 bsc#1061843 boo#1062303 bsc#1062597
  bsc#1063667 bnc#1064414 bsc#1064414 bnc#1064590 boo#1065536 bsc#1065600
  bsc#1065729 bnc#1066110 bsc#1066369 bsc#1066382 bsc#1066573 bsc#1066606
  bnc#1066845 bsc#1067087 bsc#1067105 bsc#1067494 bsc#1067593 bnc#1068032
  bsc#1068032 boo#1068256 bsc#1068680 bnc#1068877 bnc#1069562 bnc#1069605
  boo#1069828 boo#1069830 bsc#1071995 boo#1072032 boo#1073193 bsc#1073579
  bsc#1073836 boo#1076393 bsc#1076905 bsc#1077428 bsc#1077692 bsc#1078019
  bsc#1078248 bsc#1078720 bsc#1078788 bsc#1079747 boo#1080250 boo#1080435
  bsc#1080449 bsc#1080813 bsc#1081134 boo#1081473 bsc#1082504 bsc#1082555
  bsc#1082635 bnc#1082905 bsc#1083215 bsc#1083527 bsc#1083694 bsc#1084332
  bsc#1084610 bsc#1084620 bsc#1085030 bsc#1085174 bsc#1085224 bsc#1085308
  bsc#1085996 bsc#1087082 bsc#1088640 bsc#1089086 bsc#1089644 bsc#1089764
  bsc#1090162 bsc#1090717 bsc#1091041 bsc#1091101 bsc#1092456 bnc#1092466
  bsc#1093118 bsc#1094244 bsc#1094840 bsc#1095042 boo#1095717 bsc#1097593
  boo#1098050 bnc#1098392 bsc#1098626 bsc#1098995 bsc#1099078 bsc#1099745
  bsc#1099924 bsc#1100944 bsc#1101465 bsc#1103269 bsc#1103636 boo#1104529
  bsc#1104708 boo#1104833 bsc#1105536 bsc#1105672 bsc#1106061 bsc#1106751
  bsc#1107829 bsc#1107870 bsc#1108281 bsc#1108533 bsc#1109137 bsc#1109158
  boo#1109665 bsc#1109695 bsc#1110716 bsc#1111183 bsc#1112504 bsc#1113295
  bsc#1113399 bsc#1114523 boo#1114846 bsc#1115431 bsc#1116448 bsc#1116724
  bsc#1117016 bsc#1117665 bsc#1118212 bsc#1118338 bsc#1119838 bsc#1119846
  bsc#1119861 bsc#1120163 bsc#1120853 bsc#1121726 bsc#1123015 bsc#1123317
  bsc#1123348 bsc#1123697 bsc#1124167 bsc#1124235 bsc#1124431 bsc#1125004
  bsc#1125580 bsc#1125907 bsc#1127155 boo#1127188 bsc#1127188 bsc#1127339
  bsc#1127552 bsc#1127650 bnc#1127808 bsc#1127808 bsc#1127886 bsc#1128045
  bnc#1128245 bsc#1128910 bsc#1129551 bsc#1129923 bsc#1130365 boo#1130448
  bsc#1131107 bsc#1131437 boo#1132154 bsc#1132477 bsc#1133021 bsc#1133147
  bsc#1133401 bsc#1133945 boo#1134303 bsc#1134760 bsc#1134906 bnc#1135217
  bsc#1135333 bsc#1135481 bnc#1135646 bsc#1135854 bnc#1135868 bsc#1135966
  bsc#1135967 bsc#1136157 bsc#1136666 bsc#1136922 bsc#1137325 bsc#1137361
  bsc#1137586 bsc#1137625 bnc#1137686 bsc#1137728 bsc#1138374 boo#1138496
  bsc#1138496 boo#1139244 bsc#1139944 bsc#1140025 bsc#1140221 bsc#1140494
  bsc#1141340 bsc#1141456 bsc#1141558 bsc#1141600 bsc#1142019 bsc#1142095
  bsc#1142685 bsc#1142701 bsc#1143706 bsc#1143841 bsc#1143959 bsc#1144123
  bsc#1144168 bnc#1144446 bsc#1144653 bsc#1144700 boo#1144723 bsc#1144903
  bnc#1144943 bsc#1144943 bsc#1145929 boo#1146026 bsc#1146352 bsc#1146368
  bsc#1146378 bsc#1146512 bsc#1146514 bsc#1146516 bsc#1146539 bsc#1146540
  bsc#1146543 bnc#1147116 bsc#1148030 bsc#1148712 bsc#1148868 bsc#1149032
  bsc#1149119 bsc#1149313 bsc#1149652 bsc#1149713 bsc#1149940 bsc#1150305
  bsc#1150423 bsc#1150452 bsc#1150457 bsc#1150465 bsc#1150466 bsc#1150577
  bsc#1150727 bsc#1150846 bsc#1150850 bnc#1150875 bsc#1151192 bsc#1151225
  bsc#1151508 bsc#1151674 bsc#1151675 bsc#1151676 bsc#1151677 bsc#1151678
  bsc#1151679 bsc#1151680 bsc#1151794 bnc#1151927 bsc#1151927 bsc#1152109
  bsc#1152148 bsc#1152161 bsc#1152187 bsc#1152243 bsc#1152457 bsc#1152472
  bsc#1152489 bsc#1152525 bsc#1152624 bsc#1152631 bsc#1152879 bsc#1152885
  bsc#1152932 bsc#1152972 bsc#1152973 bsc#1152974 bsc#1152975 bsc#1153013
  bsc#1153112 bsc#1153137 bsc#1153158 bsc#1153192 bsc#1153217 bsc#1153274
  bsc#1153275 bsc#1153535 bsc#1153713 bsc#1153917 bsc#1153954 bsc#1153955
  bsc#1153956 bsc#1153957 bsc#1153962 bsc#1153963 bsc#1153964 bsc#1153965
  bnc#1153969 bsc#1154010 bsc#1154043 bsc#1154208 bsc#1154242 bsc#1154268
  bsc#1154329 bsc#1154353 bsc#1154354 bsc#1154355 bsc#1154372 bsc#1154395
  bsc#1154488 bsc#1154492 bsc#1154536 boo#1154578 bsc#1154617 bsc#1154619
  bsc#1154624 bsc#1154625 bsc#1154626 bsc#1154627 bsc#1154628 bsc#1154629
  bsc#1154630 bsc#1154631 bsc#1154632 bsc#1154633 bsc#1154634 bsc#1154635
  bsc#1154636 bsc#1154637 bsc#1154772 bsc#1154776 bsc#1154824 bnc#1154866
  bsc#1155178 bsc#1155179 bsc#1155184 bsc#1155186 bsc#1155364 bsc#1155518
  bnc#1155628 bsc#1155689 bnc#1155756 bnc#1155780 bnc#1155798 bsc#1155798
  bsc#1155836 bsc#1155897 bnc#1155921 bsc#1156043 bsc#1156055 bsc#1156256
  bsc#1156258 bsc#1156259 bsc#1156277 bsc#1156278 bsc#1156315 bsc#1156395
  bsc#1156419 bsc#1156466 bsc#1156494 bsc#1156510 bnc#1156537 bsc#1156538
  bsc#1156561 bsc#1156632 bsc#1156700 bsc#1156773 bsc#1156782 bsc#1156882
  bsc#1156898 bsc#1156919 bsc#1156954 bsc#1157032 bsc#1157038 bsc#1157042
  bsc#1157044 bsc#1157045 bsc#1157046 bsc#1157049 bsc#1157064 bsc#1157067
  bsc#1157069 bsc#1157070 bsc#1157115 bsc#1157143 bsc#1157145 bsc#1157155
  bsc#1157157 bsc#1157158 bsc#1157160 bsc#1157162 bsc#1157169 bsc#1157171
  bsc#1157173 bsc#1157177 bsc#1157178 bsc#1157180 bsc#1157191 bsc#1157192
  bsc#1157193 bsc#1157197 bsc#1157294 bsc#1157298 bsc#1157300 bsc#1157303
  bsc#1157304 bsc#1157307 bsc#1157319 bsc#1157324 bsc#1157333 bsc#1157336
  bsc#1157424 bsc#1157480 bsc#1157698 bsc#1157715 bsc#1157717 bsc#1157720
  bsc#1157774 bsc#1157778 bnc#1157813 bsc#1157923 bsc#1157966 bsc#1158013
  bsc#1158050 bsc#1158055 bsc#1158071 bsc#1158107 bsc#1158193 bsc#1158210
  bsc#1158242 bsc#1158265 bsc#1158279 bsc#1158370 bsc#1158371 bsc#1158373
  bsc#1158374 bsc#1158376 bsc#1158378 bsc#1158380 bsc#1158381 bsc#1158383
  bsc#1158389 bsc#1158398 bsc#1158407 bsc#1158413 bsc#1158417 bsc#1158451
  bsc#1158454 bsc#1158455 bsc#1158456 bsc#1158457 bsc#1158458 bsc#1158459
  bsc#1158460 bsc#1158632 bsc#1158633 bsc#1158746 bnc#1158748 bsc#1158748
  bsc#1158749 bsc#1158751 bsc#1158753 bnc#1158765 bsc#1158765 bsc#1158775
  bsc#1158776 bsc#1158811 bsc#1158819 bsc#1158824 bsc#1158827 bsc#1158834
  bsc#1158887 bsc#1158893 bsc#1158954 bsc#1158962 bsc#1158983 bsc#1159024
  bsc#1159037 bsc#1159058 bsc#1159152 bsc#1159198 bsc#1159271 bsc#1159280
  bsc#1159281 bsc#1159285 bsc#1159297 bsc#1159370 bsc#1159374 bsc#1159375
  bsc#1159441 bsc#1159455 bsc#1159484 bsc#1159519 bsc#1159522 bsc#1159523
  bsc#1159535 bsc#1159537 bsc#1159555 bsc#1159588 bsc#1159592 bsc#1159594
  bsc#1159662 bsc#1159717 bnc#1159781 bsc#1159811 bsc#1159816 bsc#1159864
  bsc#1159867 bsc#1159886 bsc#1159889 bsc#1159911 bsc#1159929 bsc#1159949
  bsc#1159955 bsc#1159986 bsc#1160010 bsc#1160018 bsc#1160067 bsc#1160102
  bsc#1160135 bsc#1160136 bsc#1160137 bsc#1160138 bsc#1160139 bsc#1160140
  bsc#1160141 bsc#1160142 bsc#1160143 bsc#1160195 bsc#1160214 bsc#1160215
  bsc#1160218 bsc#1160227 bsc#1160228 bsc#1160229 bsc#1160231 bsc#1160310
  bsc#1160311 bsc#1160320 bsc#1160366 bsc#1160388 bsc#1160435 bsc#1160442
  bsc#1160461 bsc#1160508 bsc#1160561 bsc#1160609 bsc#1160632 bsc#1160634
  bsc#1160647 bsc#1160659 bsc#1160750 bsc#1160751 bsc#1160752 bsc#1160784
  bsc#1160787 bsc#1160794 bsc#1160803 bsc#1160804 bsc#1160831 bnc#1160896
  bsc#1160947 bsc#1160977 bsc#1160979 bsc#1161073 bsc#1161099 bsc#1161154
  bsc#1161207 bsc#1161291 boo#1161305 boo#1161360 bsc#1161428 bsc#1161495
  bsc#1161518 bsc#1161520 bsc#1161549 bnc#1161692 bsc#1161692 bsc#1161695
  bsc#1161720 bsc#1161726 bsc#1161731 bsc#1161785 bsc#1161889 bsc#1161907
  bsc#1161930 bsc#1161931 bsc#1161934 bsc#1161935 bsc#1161936 bsc#1161937
  bsc#1161943 bsc#1161948 bsc#1161951 bsc#1162002 bsc#1162028 bsc#1162063
  bsc#1162067 bsc#1162109 bsc#1162209 bsc#1162393 bsc#1162400 bsc#1162414
  bnc#1162503 bsc#1162557 bnc#1162576 bsc#1162583 bsc#1162590 bsc#1162684
  bsc#1162702 bsc#1162831 bnc#1162928 bsc#1162929 bsc#1162931 bsc#1162943
  bsc#1163036 bsc#1163206 bsc#1163335 bsc#1163383 bsc#1163384 bsc#1163388
  bsc#1163403 bsc#1163419 bsc#1163458 bsc#1163459 bsc#1163463 bsc#1163493
  bsc#1163496 bsc#1163521 bsc#1163524 bsc#1163560 bsc#1163592 bsc#1163617
  bsc#1163727 bsc#1163762 bsc#1163774 bsc#1163776 bsc#1163836 bsc#1163838
  bsc#1163843 bsc#1163850 bsc#1163852 bsc#1163853 bsc#1163855 bsc#1163856
  bsc#1163867 bsc#1163869 bsc#1163880 bsc#1163891 bsc#1163892 bsc#1163893
  bsc#1163894 bsc#1163896 bsc#1163897 bsc#1163898 bsc#1163899 bsc#1163901
  bsc#1163902 bsc#1163904 bsc#1163905 bsc#1163907 bsc#1163909 bsc#1163910
  bsc#1163911 bsc#1163912 bsc#1163913 bsc#1163915 bsc#1163916 bsc#1163917
  bsc#1163918 bsc#1163919 bsc#1163920 bsc#1163921 bsc#1163930 bsc#1163971
  bsc#1163984 bsc#1163988 bsc#1164051 bsc#1164069 bsc#1164094 bsc#1164095
  bsc#1164118 bsc#1164141 bsc#1164146 bsc#1164147 bsc#1164148 bsc#1164149
  bsc#1164150 bsc#1164151 bsc#1164152 bsc#1164153 bsc#1164154 bsc#1164155
  bsc#1164156 bsc#1164157 bsc#1164158 bsc#1164159 bsc#1164160 bsc#1164161
  bsc#1164162 bsc#1164163 bsc#1164164 bsc#1164165 bsc#1164166 bsc#1164167
  bsc#1164168 bsc#1164169 bsc#1164170 bsc#1164171 bsc#1164172 bsc#1164173
  bsc#1164174 bsc#1164175 bsc#1164176 bsc#1164177 bsc#1164178 bsc#1164179
  bsc#1164180 bsc#1164181 bsc#1164182 bsc#1164183 bsc#1164184 bsc#1164185
  bsc#1164186 bsc#1164194 bsc#1164195 bsc#1164196 bsc#1164197 bsc#1164198
  bsc#1164199 bsc#1164200 bsc#1164201 bsc#1164202 bsc#1164203 bsc#1164205
  bsc#1164206 bsc#1164208 bsc#1164209 bsc#1164210 bsc#1164211 bsc#1164212
  bsc#1164214 bsc#1164215 bsc#1164216 bsc#1164217 bsc#1164218 bsc#1164219
  bsc#1164220 bsc#1164221 bsc#1164254 bsc#1164268 bsc#1164272 bsc#1164276
  bsc#1164284 bsc#1164285 bsc#1164302 bsc#1164303 bsc#1164304 bsc#1164305
  bsc#1164306 bsc#1164307 bsc#1164308 bsc#1164328 bsc#1164329 bsc#1164330
  bsc#1164331 bsc#1164332 bsc#1164333 bsc#1164334 bsc#1164335 bsc#1164336
  bsc#1164337 bsc#1164338 bsc#1164339 bsc#1164340 bsc#1164342 bsc#1164343
  bsc#1164344 bsc#1164345 bsc#1164346 bsc#1164347 bsc#1164348 bsc#1164349
  bsc#1164350 bsc#1164351 bsc#1164352 bsc#1164353 bsc#1164354 bsc#1164355
  bsc#1164356 bsc#1164357 bsc#1164359 bsc#1164360 bsc#1164361 bsc#1164362
  bsc#1164363 bsc#1164364 bsc#1164365 bsc#1164366 bsc#1164367 bsc#1164368
  bsc#1164369 bsc#1164370 bsc#1164371 bsc#1164372 bsc#1164373 bsc#1164374
  bsc#1164375 bsc#1164376 bsc#1164377 bsc#1164378 bsc#1164379 bsc#1164380
  bsc#1164381 bsc#1164382 bsc#1164383 bsc#1164388 bsc#1164436 bsc#1164445
  bsc#1164446 bsc#1164461 bsc#1164471 bsc#1164482 bsc#1164514 bsc#1164534
  bsc#1164565 boo#1164632 bsc#1164648 bsc#1164711 bsc#1164722 bsc#1164777
  bsc#1164780 bsc#1164893 bsc#1164917 bsc#1164993 bsc#1165019 bsc#1165047
  bsc#1165102 bsc#1165111 bsc#1165167 bsc#1165181 bsc#1165187 bsc#1165211
  bsc#1165245 bsc#1165404 bsc#1165455 bsc#1165527 bsc#1165545 bsc#1165581
  bsc#1165618 bsc#1165629 bsc#1165692 bsc#1165741 bsc#1165806 bsc#1165807
  bsc#1165813 bsc#1165823 bsc#1165873 bsc#1165929 bsc#1165933 bsc#1165950
  bsc#1165954 bsc#1165975 bsc#1165980 bsc#1166003 bsc#1166091 bsc#1166132
  bsc#1166133 bsc#1166136 bsc#1166140 bsc#1166143 bsc#1166144 bsc#1166145
  bsc#1166146 bsc#1166147 bsc#1166149 bsc#1166152 bsc#1166153 bsc#1166154
  bsc#1166155 bsc#1166156 bsc#1166158 bsc#1166160 bsc#1166161 bsc#1166162
  bsc#1166164 bsc#1166166 bsc#1166226 bsc#1166323 bsc#1166340 bsc#1166486
  bsc#1166535 bsc#1166547 bsc#1166632 bsc#1166658 boo#1166664 bsc#1166685
  bsc#1166686 bsc#1166687 bsc#1166722 bsc#1166723 bsc#1166724 bsc#1166725
  bsc#1166726 bsc#1166727 bsc#1166728 bsc#1166729 bsc#1166769 bsc#1166772
  bsc#1166780 bsc#1166859 bsc#1166860 bsc#1166861 bsc#1166862 bsc#1166864
  bsc#1166866 bsc#1166867 bsc#1166868 bsc#1166870 bsc#1166871 bsc#1166872
  bsc#1166874 bsc#1166875 bsc#1166876 bsc#1166878 bsc#1166940 bsc#1166965
  bsc#1166969 bsc#1166982 bsc#1166985 bsc#1167030 bsc#1167032 bsc#1167104
  bsc#1167137 bsc#1167151 bsc#1167197 bsc#1167201 bsc#1167241 bsc#1167260
  bsc#1167288 bsc#1167338 bnc#1167384 bnc#1167415 bsc#1167421 bsc#1167423
  bsc#1167517 bsc#1167527 bsc#1167574 bsc#1167594 bsc#1167629 bsc#1167649
  bsc#1167650 bsc#1167651 bsc#1167657 bsc#1167722 bsc#1167765 bsc#1167769
  bsc#1167773 bsc#1167851 bsc#1167867 bsc#1167878 bsc#1167903 bsc#1168081
  bsc#1168202 bsc#1168230 bsc#1168236 bsc#1168297 bsc#1168354 bsc#1168423
  bsc#1168424 bsc#1168461 bsc#1168468 bsc#1168476 bsc#1168486 bsc#1168553
  bsc#1168575 bsc#1168596 bsc#1168670 bsc#1168760 bsc#1168761 bsc#1168762
  bsc#1168763 bsc#1168764 bsc#1168765 bsc#1168768 bsc#1168777 bsc#1168779
  bsc#1168829 bsc#1168838 bsc#1168847 bsc#1168854 bsc#1168888 bsc#1168952
  bsc#1168959 bsc#1168999 bsc#1169003 bsc#1169005 bsc#1169013 bsc#1169021
  bsc#1169045 bsc#1169048 bsc#1169049 bsc#1169050 bsc#1169051 bsc#1169052
  bsc#1169053 bsc#1169056 bsc#1169078 bsc#1169094 bsc#1169194 bsc#1169263
  bsc#1169493 bsc#1169514 bsc#1169518 bsc#1169524 bsc#1169625 bnc#1169681
  bsc#1169681 bsc#1169709 bsc#1169763 bsc#1169771 bsc#1169790 bsc#1169795
  bsc#1170011 bsc#1170030 bsc#1170056 bsc#1170139 boo#1170232 bsc#1170269
  bsc#1170284 bsc#1170415 bsc#1170442 bsc#1170511 bsc#1170522 bsc#1170617
  bsc#1170621 bsc#1170630 bsc#1170680 bsc#1170774 bsc#1170791 bsc#1170799
  bsc#1170828 bsc#1170879 bsc#1170891 bsc#1170895 bsc#1170901 bsc#1171000
  bsc#1171068 bsc#1171073 bsc#1171075 bsc#1171076 bsc#1171078 bsc#1171079
  bsc#1171080 bsc#1171081 bsc#1171082 bsc#1171083 bsc#1171084 bsc#1171117
  bsc#1171150 bsc#1171156 bsc#1171189 bsc#1171191 bsc#1171195 bsc#1171202
  bsc#1171205 bsc#1171214 bsc#1171217 bsc#1171218 bsc#1171219 bsc#1171220
  bsc#1171236 bsc#1171242 bsc#1171246 bsc#1171279 bsc#1171285 bsc#1171293
  bsc#1171295 bsc#1171374 bsc#1171390 bsc#1171391 bsc#1171392 bsc#1171417
  bsc#1171420 bsc#1171426 bsc#1171507 bsc#1171513 bsc#1171514 bsc#1171529
  bsc#1171530 bsc#1171558 bsc#1171634 bsc#1171644 bsc#1171662 bsc#1171675
  bsc#1171688 bsc#1171699 bsc#1171709 bsc#1171730 bsc#1171732 bsc#1171736
  bsc#1171739 bsc#1171742 bsc#1171743 bsc#1171759 bsc#1171773 bsc#1171774
  bsc#1171775 bsc#1171776 bsc#1171777 bsc#1171778 bsc#1171779 bsc#1171780
  bsc#1171781 bsc#1171782 bsc#1171783 bsc#1171784 bsc#1171785 bsc#1171786
  bsc#1171787 bsc#1171788 bsc#1171789 bsc#1171790 bsc#1171791 bsc#1171792
  bsc#1171793 bsc#1171794 bsc#1171795 bsc#1171796 bsc#1171797 bsc#1171798
  bsc#1171799 bsc#1171810 bsc#1171827 bsc#1171828 bsc#1171832 bsc#1171833
  bsc#1171834 bsc#1171835 bsc#1171839 bsc#1171840 bsc#1171841 bsc#1171842
  bsc#1171843 bsc#1171844 bsc#1171849 bsc#1171857 bsc#1171868 bsc#1171904
  bsc#1171915 bsc#1171982 bsc#1171983 bsc#1171988 bsc#1172017 bsc#1172046
  bsc#1172061 bsc#1172062 bsc#1172063 bsc#1172064 bsc#1172065 bsc#1172066
  bsc#1172067 bsc#1172068 bsc#1172069 boo#1172073 bsc#1172086 bsc#1172095
  bsc#1172108 bsc#1172145 bsc#1172169 bsc#1172170 bsc#1172197 bsc#1172201
  bsc#1172208 bsc#1172223 bsc#1172247 bsc#1172266 bsc#1172317 bsc#1172342
  bsc#1172343 bsc#1172344 bsc#1172355 bsc#1172365 bsc#1172366 bsc#1172374
  bsc#1172391 bsc#1172393 bsc#1172394 bsc#1172418 bsc#1172419 bsc#1172453
  bsc#1172458 bsc#1172467 bsc#1172484 bsc#1172537 bsc#1172543 bsc#1172687
  bsc#1172719 bsc#1172733 bsc#1172739 bsc#1172751 bsc#1172757 bsc#1172759
  bsc#1172775 bsc#1172781 bsc#1172782 bsc#1172783 bsc#1172814 bsc#1172823
  bsc#1172841 bsc#1172871 bsc#1172873 bsc#1172938 bsc#1172939 bsc#1172940
  boo#1172956 bsc#1172963 bsc#1172983 bsc#1172984 bsc#1172985 bsc#1172986
  bsc#1172987 bsc#1172988 bsc#1172989 bsc#1172990 bsc#1172999 bsc#1173017
  bsc#1173068 bsc#1173074 bsc#1173085 bsc#1173115 bsc#1173139 bsc#1173206
  bsc#1173267 bnc#1173271 bsc#1173280 bsc#1173284 bsc#1173428 bsc#1173438
  bsc#1173461 bsc#1173468 bsc#1173485 bsc#1173514 bsc#1173552 bsc#1173573
  bsc#1173625 bsc#1173746 bsc#1173776 bsc#1173798 boo#1173813 bsc#1173817
  bsc#1173818 bsc#1173820 bsc#1173822 bsc#1173823 bsc#1173824 bsc#1173825
  bsc#1173826 bsc#1173827 bsc#1173828 bsc#1173830 bsc#1173831 bsc#1173832
  bsc#1173833 bsc#1173834 bsc#1173836 bsc#1173837 bsc#1173838 bsc#1173839
  bsc#1173841 bsc#1173843 bsc#1173844 bsc#1173845 bsc#1173847 bsc#1173849
  bsc#1173860 bsc#1173894 bsc#1173941 bsc#1173954 bsc#1174002 bsc#1174003
  bsc#1174018 bsc#1174019 bsc#1174026 bsc#1174029 bsc#1174072 bsc#1174098
  bsc#1174110 bsc#1174111 bsc#1174116 bsc#1174126 bsc#1174127 bsc#1174128
  bsc#1174129 bsc#1174185 bsc#1174205 bsc#1174244 bsc#1174263 bsc#1174264
  bsc#1174331 bsc#1174332 bsc#1174333 bsc#1174345 bsc#1174356 bsc#1174358
  bsc#1174362 bsc#1174387 bsc#1174396 bsc#1174398 bsc#1174407 bsc#1174409
  bsc#1174411 bsc#1174416 bsc#1174426 bsc#1174438 bsc#1174462 bsc#1174484
  bsc#1174486 bsc#1174513 bsc#1174527 bsc#1174585 bsc#1174625 bsc#1174627
  bsc#1174645 bsc#1174689 bsc#1174699 bsc#1174737 bsc#1174748 bsc#1174757
  bsc#1174762 bsc#1174764 bsc#1174770 bsc#1174771 bsc#1174777 bsc#1174805
  bsc#1174824 bsc#1174825 bsc#1174852 bsc#1174865 bsc#1174880 bsc#1174897
  bsc#1174899 bsc#1174906 bsc#1174914 bsc#1174969 bsc#1174978 bsc#1175009
  bsc#1175010 bsc#1175011 bsc#1175012 bsc#1175013 bsc#1175014 bsc#1175015
  bsc#1175016 bsc#1175017 bsc#1175018 bsc#1175019 bsc#1175020 bsc#1175021
  bsc#1175052 bsc#1175079 bsc#1175112 bsc#1175116 bsc#1175128 bsc#1175149
  bsc#1175175 bsc#1175176 bsc#1175180 bsc#1175181 bsc#1175182 bsc#1175183
  bsc#1175184 bsc#1175185 bsc#1175186 bsc#1175187 bsc#1175188 bsc#1175189
  bsc#1175190 bsc#1175191 bsc#1175192 bsc#1175195 bsc#1175199 bsc#1175213
  bsc#1175232 bsc#1175263 bsc#1175284 bsc#1175296 bsc#1175306 bsc#1175344
  bsc#1175345 bsc#1175346 bsc#1175347 bsc#1175367 bsc#1175377 bsc#1175389
  bsc#1175440 bsc#1175480 bsc#1175493 bsc#1175499 bsc#1175543 bsc#1175546
  bsc#1175550 bsc#1175599 bsc#1175621 bsc#1175654 bsc#1175667 bsc#1175691
  bsc#1175697 bsc#1175713 bsc#1175718 bsc#1175721 bsc#1175746 bsc#1175749
  bsc#1175768 bsc#1175769 bsc#1175770 bsc#1175771 bsc#1175772 bsc#1175774
  bsc#1175775 bsc#1175787 bsc#1175807 bsc#1175834 bsc#1175873 boo#1175882
  bsc#1175898 bsc#1175918 bsc#1175952 bsc#1175995 bsc#1175996 bsc#1175997
  bsc#1175998 bsc#1175999 bsc#1176000 bsc#1176001 bsc#1176019 bsc#1176022
  bsc#1176038 bsc#1176063 bsc#1176069 bsc#1176109 bsc#1176137 bsc#1176180
  bsc#1176200 bsc#1176235 bsc#1176236 bsc#1176237 bsc#1176242 bsc#1176248
  bsc#1176354 bsc#1176357 bsc#1176358 bsc#1176359 bsc#1176360 bsc#1176361
  bsc#1176362 bsc#1176363 bsc#1176364 bsc#1176365 bsc#1176366 bsc#1176367
  bsc#1176381 bsc#1176395 bsc#1176396 bsc#1176400 bsc#1176423 bsc#1176447
  bsc#1176449 bsc#1176481 bsc#1176485 bsc#1176486 bsc#1176507 bsc#1176536
  bsc#1176537 bsc#1176538 bsc#1176539 bsc#1176540 bsc#1176541 bsc#1176542
  bsc#1176543 bsc#1176544 bsc#1176545 bsc#1176546 bsc#1176548 bsc#1176558
  bsc#1176559 bnc#1176586 bsc#1176587 bnc#1176588 bsc#1176647 bsc#1176659
  bsc#1176695 bsc#1176698 bsc#1176699 bsc#1176700 bsc#1176713 bsc#1176721
  bsc#1176722 bsc#1176725 bsc#1176732 bsc#1176741 bsc#1176763 bsc#1176771
  bsc#1176774 bsc#1176775 bsc#1176788 bsc#1176789 bsc#1176792 bsc#1176831
  bsc#1176833 bsc#1176846 bsc#1176855 bsc#1176869 bsc#1176877 bsc#1176907
  bsc#1176912 bsc#1176914 bsc#1176916 bsc#1176918 bsc#1176919 bsc#1176925
  bsc#1176940 bsc#1176942 bsc#1176956 bsc#1176961 bsc#1176962 bsc#1176979
  bsc#1176980 bsc#1176983 bsc#1176990 bsc#1177002 bsc#1177020 bsc#1177021
  bsc#1177028 bsc#1177030 bsc#1177066 bsc#1177070 bsc#1177075 bsc#1177086
  bsc#1177090 bsc#1177095 bsc#1177109 bsc#1177116 bsc#1177117 bsc#1177121
  bsc#1177142 bsc#1177154 bsc#1177185 bsc#1177193 bsc#1177194 bsc#1177206
  bsc#1177240 bsc#1177258 bsc#1177271 bsc#1177277 bsc#1177278 bsc#1177279
  bsc#1177280 bsc#1177281 bsc#1177283 bsc#1177284 bsc#1177285 bsc#1177286
  bsc#1177287 bsc#1177297 bsc#1177326 bsc#1177353 bsc#1177384 bsc#1177385
  bsc#1177393 bsc#1177397 bsc#1177399 bsc#1177403 bsc#1177410 bsc#1177411
  bsc#1177434 bsc#1177437 bsc#1177440 bsc#1177470 bsc#1177471 bsc#1177476
  bsc#1177500 bsc#1177511 bsc#1177529 bsc#1177547 bsc#1177591 bsc#1177599
  bsc#1177617 bsc#1177666 bsc#1177678 bsc#1177679 bsc#1177681 bsc#1177683
  bsc#1177686 bsc#1177687 bsc#1177694 bsc#1177697 bsc#1177703 bsc#1177709
  bnc#1177710 bsc#1177710 bsc#1177719 bsc#1177724 bsc#1177725 bsc#1177726
  bsc#1177733 bsc#1177739 bsc#1177749 bsc#1177750 bsc#1177754 bsc#1177755
  bsc#1177765 bnc#1177766 bnc#1177788 bsc#1177799 bsc#1177801 bsc#1177814
  bsc#1177817 bsc#1177820 bsc#1177854 bsc#1177855 bsc#1177856 bsc#1177861
  bsc#1177889 bsc#1177971 bsc#1178002 bsc#1178049 bsc#1178079 bsc#1178089
  bsc#1178123 bsc#1178134 bsc#1178142 bsc#1178163 bsc#1178166 bsc#1178173
  bsc#1178175 bsc#1178176 bsc#1178177 bsc#1178181 bsc#1178182 bsc#1178183
  bsc#1178184 bsc#1178185 bsc#1178186 bsc#1178190 bsc#1178191 bsc#1178203
  bsc#1178226 bnc#1178227 bsc#1178246 bsc#1178255 bsc#1178270 bsc#1178286
  bsc#1178307 bsc#1178325 bsc#1178330 bsc#1178366 bsc#1178367 bsc#1178372
  bsc#1178378 bsc#1178393 bsc#1178395 bsc#1178401 bsc#1178402 bsc#1178404
  bsc#1178418 bsc#1178420 bsc#1178426 bsc#1178431 bsc#1178461 bsc#1178464
  bsc#1178579 bsc#1178581 bsc#1178584 bsc#1178585 bsc#1178589 bsc#1178590
  bsc#1178609 bsc#1178612 bsc#1178631 bsc#1178634 bsc#1178635 bsc#1178648
  bsc#1178653 bsc#1178659 bsc#1178660 bsc#1178661 bsc#1178669 bsc#1178686
  bsc#1178740 bsc#1178755 bsc#1178756 bsc#1178760 bsc#1178762 bsc#1178780
  bsc#1178838 bsc#1178852 bsc#1178853 bsc#1178886 bsc#1178901 bsc#1178908
  bsc#1178995 bsc#1179001 bsc#1179012 bsc#1179014 boo#1179015 bsc#1179045
  bsc#1179076 boo#1179082 bsc#1179082 bsc#1179090 bsc#1179107 bsc#1179137
  bsc#1179140 bsc#1179141 bsc#1179142 bsc#1179160 bsc#1179201 bsc#1179204
  bsc#1179205 bsc#1179211 bsc#1179217 bsc#1179243 bsc#1179344 bsc#1179365
  bsc#1179396 bsc#1179419 bsc#1179424 bsc#1179425 bsc#1179426 bsc#1179427
  bsc#1179429 bsc#1179432 bsc#1179434 bsc#1179435 bsc#1179439 bsc#1179442
  bsc#1179446 bsc#1179454 bsc#1179508 bsc#1179509 bsc#1179519 bsc#1179531
  bsc#1179550 bsc#1179565 bsc#1179567 bsc#1179572 bsc#1179575 bsc#1179578
  bsc#1179585 bsc#1179597 bsc#1179599 bsc#1179601 bsc#1179603 bsc#1179604
  bsc#1179611 bsc#1179639 bsc#1179652 bsc#1179656 bsc#1179660 bsc#1179670
  bsc#1179671 bsc#1179672 bsc#1179673 bsc#1179675 bsc#1179676 bsc#1179677
  bsc#1179678 bsc#1179679 bsc#1179680 bsc#1179681 bsc#1179682 bsc#1179683
  bsc#1179684 bsc#1179685 bsc#1179687 bsc#1179688 bsc#1179689 bsc#1179690
  bsc#1179703 bsc#1179704 bsc#1179707 bsc#1179709 bsc#1179710 bsc#1179711
  bsc#1179712 bsc#1179713 bsc#1179714 bsc#1179715 bsc#1179716 bsc#1179745
  bsc#1179763 bsc#1179814 bsc#1179815 bsc#1179819 bsc#1179825 bsc#1179827
  bsc#1179851 bsc#1179863 bsc#1179878 bsc#1179882 bsc#1179887 bsc#1179888
  bsc#1179892 bsc#1179896 bsc#1179929 bsc#1179950 bsc#1179960 bsc#1179963
  bsc#1180027 bsc#1180029 bsc#1180031 bsc#1180052 bsc#1180056 bsc#1180058
  bsc#1180072 bsc#1180086 bsc#1180092 bsc#1180100 bsc#1180103 bsc#1180114
  bsc#1180117 bsc#1180130 bsc#1180141 bsc#1180197 bsc#1180214 bsc#1180221
  bsc#1180258 bsc#1180261 bsc#1180264 bsc#1180334 bsc#1180336 bsc#1180347
  bsc#1180412 bsc#1180506 bsc#1180541 bsc#1180543 bsc#1180559 bsc#1180566
  bsc#1180567 bsc#1180581 bsc#1180598 bsc#1180682 bsc#1180731 bsc#1180744
  bsc#1180749 bsc#1180759 bsc#1180765 bsc#1180773 bsc#1180809 bsc#1180812
  bsc#1180814 bsc#1180846 bsc#1180848 bsc#1180870 bsc#1180889 bsc#1180891
  bsc#1180945 bsc#1180964 bsc#1180971 bsc#1180980 bsc#1180989 bsc#1181006
  bsc#1181014 boo#1181018 bsc#1181070 bsc#1181076 bsc#1181077 bsc#1181104
  bsc#1181133 bsc#1181147 bsc#1181148 bsc#1181158 bsc#1181161 bsc#1181169
  bsc#1181203 bsc#1181206 bsc#1181207 bsc#1181208 bsc#1181209 bsc#1181210
  bsc#1181211 bsc#1181212 bsc#1181213 bsc#1181214 bsc#1181215 bsc#1181217
  bsc#1181218 bsc#1181219 bsc#1181220 bsc#1181237 bsc#1181259 bsc#1181284
  bsc#1181318 bsc#1181335 bsc#1181346 bsc#1181349 bsc#1181383 bsc#1181425
  bsc#1181494 bsc#1181504 bsc#1181507 bsc#1181511 bsc#1181538 bsc#1181544
  bsc#1181572 bsc#1181574 bsc#1181584 bsc#1181637 bsc#1181655 bsc#1181671
  bsc#1181674 bsc#1181710 bsc#1181719 bsc#1181720 bsc#1181735 bsc#1181736
  bsc#1181738 bsc#1181747 bsc#1181753 bsc#1181785 bsc#1181787 bsc#1181795
  bsc#1181818 bsc#1181843 bsc#1181854 bsc#1181862 bsc#1181896 bsc#1181928
  bsc#1181958 bsc#1181960 bsc#1181972 bsc#1181985 bsc#1182011 bsc#1182035
  bsc#1182047 bsc#1182077 bsc#1182114 bsc#1182118 bsc#1182128 bsc#1182140
  bsc#1182161 bsc#1182171 bsc#1182175 bsc#1182217 bsc#1182257 bsc#1182259
  bsc#1182265 bsc#1182266 bsc#1182267 bsc#1182268 bsc#1182271 bsc#1182272
  bsc#1182273 bsc#1182275 bsc#1182276 bsc#1182278 bsc#1182283 bsc#1182374
  bsc#1182377 bsc#1182378 bsc#1182380 bsc#1182381 bsc#1182406 bsc#1182430
  bsc#1182439 bsc#1182441 bsc#1182442 bsc#1182443 bsc#1182444 bsc#1182445
  bsc#1182446 bsc#1182447 bsc#1182449 bsc#1182454 bsc#1182455 bsc#1182456
  bsc#1182457 bsc#1182458 bsc#1182459 bsc#1182460 bsc#1182461 bsc#1182462
  bsc#1182463 bsc#1182464 bsc#1182465 bsc#1182466 bsc#1182470 bsc#1182485
  bsc#1182489 bsc#1182490 bsc#1182547 bsc#1182552 bsc#1182558 bsc#1182560
  bsc#1182561 bsc#1182571 bsc#1182574 bsc#1182591 bsc#1182595 bsc#1182599
  bsc#1182602 bsc#1182613 bsc#1182616 bsc#1182626 bsc#1182632 bsc#1182650
  boo#1182672 bsc#1182676 bsc#1182683 bsc#1182684 bsc#1182686 bsc#1182697
  bsc#1182715 bsc#1182716 bsc#1182717 bsc#1182743 bsc#1182770 bsc#1182798
  bsc#1182800 bsc#1182801 bsc#1182853 bsc#1182854 bsc#1182856 bsc#1182857
  bsc#1182989 bsc#1182992 bsc#1182999 bsc#1183002 bsc#1183009 bsc#1183015
  bsc#1183018 bsc#1183022 bsc#1183023 bsc#1183030 bsc#1183033 bsc#1183048
  boo#1183063 bsc#1183077 bsc#1183203 bsc#1183225 bsc#1183249 bsc#1183252
  bsc#1183277 bsc#1183278 bsc#1183279 bsc#1183280 bsc#1183281 bsc#1183282
  bsc#1183283 bsc#1183284 bsc#1183285 bsc#1183286 bsc#1183287 bsc#1183288
  bsc#1183289 bsc#1183310 bsc#1183311 bsc#1183312 bsc#1183313 bsc#1183314
  bsc#1183315 bsc#1183316 bsc#1183317 bsc#1183318 bsc#1183319 bsc#1183320
  bsc#1183321 bsc#1183322 bsc#1183323 bsc#1183324 bsc#1183325 bsc#1183326
  bsc#1183346 bsc#1183366 bsc#1183369 bsc#1183386 bsc#1183392 bsc#1183405
  bsc#1183412 bsc#1183416 bsc#1183427 bsc#1183428 bsc#1183440 bsc#1183445
  bsc#1183447 bsc#1183501 bsc#1183509 bsc#1183530 bsc#1183534 bsc#1183540
  bsc#1183551 bsc#1183552 bsc#1183553 bsc#1183593 bsc#1183596 bsc#1183598
  bsc#1183637 bsc#1183646 bsc#1183662 bsc#1183682 bsc#1183686 bsc#1183692
  bsc#1183696 bsc#1183712 bsc#1183746 bsc#1183750 bsc#1183756 bsc#1183757
  bsc#1183773 bsc#1183775 bsc#1183815 bsc#1183843 bsc#1183850 bsc#1183859
  bsc#1183860 bsc#1183868 bsc#1183871 bsc#1183872 bsc#1183873 bsc#1183897
  bsc#1183932 bsc#1183947 bsc#1183976 bsc#1184074 bsc#1184081 bsc#1184082
  bsc#1184111 bsc#1184114 bsc#1184120 bsc#1184129 bsc#1184134 bsc#1184167
  bsc#1184168 bsc#1184170 bsc#1184176 bsc#1184180 bsc#1184192 bsc#1184193
  bsc#1184196 bsc#1184197 bsc#1184198 bsc#1184208 bsc#1184209 bsc#1184211
  bsc#1184212 bsc#1184217 bsc#1184218 bsc#1184219 bsc#1184220 bsc#1184224
  bsc#1184259 bsc#1184264 bsc#1184318 bsc#1184350 bsc#1184386 bsc#1184388
  bsc#1184391 bsc#1184393 bsc#1184436 bsc#1184485 bsc#1184509 bsc#1184511
  bsc#1184512 bsc#1184514 bsc#1184570 bsc#1184583 bsc#1184585 bsc#1184615
  bsc#1184631 bsc#1184647 bsc#1184650 bsc#1184673 bsc#1184685 bsc#1184724
  bsc#1184728 bsc#1184730 bsc#1184731 bsc#1184736 bsc#1184737 bsc#1184738
  bsc#1184740 bsc#1184741 bsc#1184742 bsc#1184760 bsc#1184769 boo#1184804
  bsc#1184811 bsc#1184855 bsc#1184893 bsc#1184924 bsc#1184934 bsc#1184942
  bsc#1184943 bsc#1184957 bsc#1184969 bsc#1184984 bsc#1185010 bsc#1185032
  bsc#1185038 bsc#1185041 bsc#1185110 bsc#1185113 bsc#1185195 bsc#1185233
  bsc#1185244 bsc#1185269 bsc#1185308 bsc#1185365 bsc#1185377 bsc#1185428
  bsc#1185454 bsc#1185472 bsc#1185486 bsc#1185491 bsc#1185495 bsc#1185497
  bsc#1185549 bsc#1185550 bsc#1185558 bsc#1185570 bsc#1185573 bsc#1185581
  bsc#1185586 bsc#1185587 bsc#1185589 bsc#1185606 bsc#1185640 bsc#1185641
  bsc#1185642 bsc#1185645 bsc#1185670 bsc#1185675 bsc#1185677 bsc#1185680
  bsc#1185701 bsc#1185703 bsc#1185725 bsc#1185726 bsc#1185758 bsc#1185762
  bsc#1185791 bsc#1185840 bsc#1185857 bsc#1185859 bsc#1185860 bsc#1185861
  bsc#1185862 bsc#1185863 bsc#1185898 bsc#1185902 bsc#1185911 bsc#1185927
  bsc#1185938 bsc#1185950 bsc#1185954 bsc#1185980 bsc#1185982 bsc#1185987
  bsc#1185988 bsc#1186009 bsc#1186060 bsc#1186062 bsc#1186071 bsc#1186111
  bsc#1186155 bsc#1186194 bsc#1186206 bsc#1186219 bnc#1186264 bsc#1186286
  bsc#1186320 bsc#1186349 bsc#1186352 bsc#1186353 bsc#1186354 bsc#1186355
  bsc#1186356 bsc#1186357 bsc#1186416 bsc#1186439 bsc#1186441 bsc#1186449
  bsc#1186451 bsc#1186460 bsc#1186463 bsc#1186467 bsc#1186472 bsc#1186479
  bsc#1186482 bsc#1186484 bsc#1186501 bsc#1186512 bsc#1186573 bsc#1186666
  bsc#1186672 bsc#1186677 bsc#1186681 bsc#1186731 bsc#1186752 bsc#1186885
  boo#1186928 bsc#1186949 bsc#1186950 bsc#1186951 bsc#1186952 bsc#1186953
  bsc#1186954 bsc#1186955 bsc#1186956 bsc#1186957 bsc#1186958 bsc#1186959
  bsc#1186960 bsc#1186961 bsc#1186962 bsc#1186963 bsc#1186964 bsc#1186965
  bsc#1186966 bsc#1186967 bsc#1186968 bsc#1186969 bsc#1186970 bsc#1186971
  bsc#1186972 bsc#1186973 bsc#1186974 bsc#1186976 bsc#1186977 bsc#1186978
  bsc#1186979 bsc#1186980 bsc#1186981 bsc#1186982 bsc#1186983 bsc#1186984
  bsc#1186985 bsc#1186986 bsc#1186987 bsc#1186988 bsc#1186989 bsc#1186990
  bsc#1186991 bsc#1186992 bsc#1186993 bsc#1186994 bsc#1186995 bsc#1186996
  bsc#1186997 bsc#1186998 bsc#1186999 bsc#1187000 bsc#1187001 bsc#1187002
  bsc#1187003 bsc#1187038 bsc#1187039 bsc#1187050 bsc#1187067 bsc#1187068
  bsc#1187069 bsc#1187072 bsc#1187143 bsc#1187144 bsc#1187167 bsc#1187171
  bsc#1187211 bsc#1187215 bsc#1187263 bsc#1187334 bsc#1187344 bsc#1187345
  bsc#1187346 bsc#1187347 bsc#1187348 bsc#1187349 bsc#1187350 bsc#1187351
  bsc#1187356 bsc#1187357 bsc#1187402 bsc#1187403 bsc#1187404 bsc#1187407
  bsc#1187408 bsc#1187409 bsc#1187410 bsc#1187411 bsc#1187412 bsc#1187413
  bsc#1187428 bsc#1187452 bsc#1187455 bsc#1187468 bsc#1187476 bsc#1187483
  bsc#1187495 bsc#1187541 bsc#1187554 bsc#1187585 bsc#1187591 bsc#1187595
  bsc#1187601 bsc#1187619 bsc#1187711 bsc#1187716 bsc#1187795 bsc#1187829
  bsc#1187867 bsc#1187883 bsc#1187886 bsc#1187927 bsc#1187959 bsc#1187972
  bsc#1187980 bsc#1188036 bsc#1188062 bsc#1188064 bsc#1188067 bsc#1188080
  bsc#1188101 bsc#1188116 bsc#1188121 bsc#1188130 bsc#1188172 bsc#1188176
  bsc#1188231 bsc#1188234 bsc#1188238 bsc#1188267 bsc#1188268 bsc#1188269
  bsc#1188270 bsc#1188303 bsc#1188366 bsc#1188404 bsc#1188405 bsc#1188412
  bsc#1188418 bsc#1188439 bsc#1188445 bsc#1188504 bsc#1188605 bsc#1188616
  bsc#1188620 bsc#1188651 bsc#1188683 bsc#1188694 bsc#1188700 bsc#1188703
  bsc#1188746 bsc#1188747 bsc#1188748 bsc#1188752 bsc#1188770 bsc#1188771
  bsc#1188772 bsc#1188773 bsc#1188774 bsc#1188777 bsc#1188780 bsc#1188781
  bsc#1188782 bsc#1188783 bsc#1188784 bsc#1188786 bsc#1188787 bsc#1188788
  bsc#1188790 bsc#1188838 bsc#1188876 bsc#1188878 bsc#1188885 bsc#1188893
  bsc#1188896 bsc#1188924 bsc#1188973 bsc#1188982 bsc#1188983 bsc#1188985
  bnc#1189021 bsc#1189057 bsc#1189074 bsc#1189076 bsc#1189077 bsc#1189111
  bsc#1189126 bsc#1189153 bsc#1189158 bsc#1189197 bsc#1189209 bsc#1189210
  bsc#1189212 bsc#1189213 bsc#1189214 bsc#1189215 bsc#1189216 bsc#1189217
  bsc#1189218 bsc#1189219 bsc#1189220 bsc#1189221 bsc#1189222 bsc#1189225
  bsc#1189229 bsc#1189233 bsc#1189262 bsc#1189291 bsc#1189292 bsc#1189296
  bsc#1189297 bsc#1189298 bsc#1189301 bsc#1189305 bsc#1189323 bsc#1189384
  bsc#1189385 bsc#1189392 bsc#1189393 bsc#1189399 bsc#1189400 bsc#1189427
  bsc#1189449 bsc#1189503 bsc#1189504 bsc#1189505 bsc#1189506 bsc#1189507
  bsc#1189562 bsc#1189563 bsc#1189564 bsc#1189565 bsc#1189566 bsc#1189567
  bsc#1189568 bsc#1189569 bsc#1189573 bsc#1189574 bsc#1189575 bsc#1189576
  bsc#1189577 bsc#1189579 bsc#1189581 bsc#1189582 bsc#1189583 bsc#1189584
  bsc#1189585 bsc#1189586 bsc#1189587 bsc#1189671 bsc#1189685 bsc#1189689
  bsc#1189690 bsc#1189693 bsc#1189694 bsc#1189695 bsc#1189696 bsc#1189706
  bsc#1189760 bsc#1189762 bsc#1189832 bsc#1189841 bsc#1189870 bsc#1189872
  bsc#1189883 bsc#1189884 bsc#1189922 bsc#1189964 bsc#1189965 bnc#1189998
  bsc#1189998 bnc#1189999 bsc#1189999 bsc#1190003 bsc#1190022 bsc#1190025
  bsc#1190050 bsc#1190067 bsc#1190068 bsc#1190093 bsc#1190111 bsc#1190115
  bsc#1190117 bsc#1190120 bsc#1190131 bsc#1190137 bsc#1190138 bsc#1190181
  bsc#1190187 bnc#1190208 bsc#1190208 bsc#1190209 bsc#1190232 bsc#1190256
  bsc#1190277 bsc#1190282 bsc#1190336 bsc#1190351 bsc#1190358 bsc#1190366
  bsc#1190378 bsc#1190406 bsc#1190412 bsc#1190413 bsc#1190418 bsc#1190424
  bsc#1190428 bsc#1190449 bsc#1190450 bsc#1190451 bsc#1190469 bsc#1190479
  bsc#1190497 bsc#1190506 bsc#1190523 bsc#1190534 bsc#1190543 bsc#1190544
  bsc#1190569 bsc#1190576 bsc#1190620 bsc#1190661 bsc#1190664 bsc#1190758
  bsc#1190759 bsc#1190768 bsc#1190786 bsc#1190801 bsc#1190812 bsc#1190923
  bsc#1190941 bsc#1190969 bsc#1191026 bsc#1191229 bsc#1191256 bsc#1191259
  bsc#1191261 bsc#1191269 bsc#1191270 bsc#1191271 bsc#1191279 bsc#1191292
  bsc#1191317 bsc#1191321 bsc#1191349 boo#1191384 bsc#1191396 boo#1191417
  bsc#1191428 bsc#1191540 bsc#1191580 bsc#1191647 bsc#1191649 bsc#1191663
  bsc#1191731 bsc#1191738 bsc#1191740 bsc#1191793 bsc#1191867 bsc#1191876
  bsc#1191949 bsc#1191958 bsc#1191980 bsc#1192069 bsc#1192107 bsc#1192120
  bsc#1192145 bsc#1192202 bsc#1192258 bsc#1192260 bsc#1192267 bsc#1192273
  bsc#1192295 bsc#1192327 bsc#1192341 bsc#1192354 bsc#1192375 bsc#1192456
  bsc#1192473 bsc#1192483 bsc#1192507 bsc#1192547 bsc#1192569 bsc#1192590
  bsc#1192611 bsc#1192644 bsc#1192700 bsc#1192718 bsc#1192720 bsc#1192724
  bsc#1192740 bsc#1192745 bsc#1192750 bsc#1192761 bsc#1192825 bsc#1192837
  bsc#1192845 bsc#1192847 bsc#1192891 bsc#1192894 bsc#1192896 bsc#1192913
  bsc#1192946 bsc#1192968 bsc#1192969 bsc#1192974 bsc#1192987 bsc#1192988
  bsc#1192990 bsc#1193000 bsc#1193039 bsc#1193064 bsc#1193088 bsc#1193124
  bsc#1193136 bnc#1193175 bnc#1193199 bsc#1193200 bnc#1193239 bsc#1193244
  bsc#1193255 bsc#1193277 bsc#1193289 bsc#1193302 bsc#1193306 bsc#1193318
  bsc#1193328 bnc#1193329 bsc#1193349 bnc#1193353 bsc#1193377 bnc#1193431
  bsc#1193440 bsc#1193442 bsc#1193470 bsc#1193482 bsc#1193490 bsc#1193506
  bsc#1193524 bsc#1193554 bsc#1193556 bsc#1193629 bsc#1193640 bsc#1193655
  bsc#1193660 bnc#1193663 bsc#1193669 bsc#1193674 bsc#1193727 bsc#1193767
  bsc#1193787 bsc#1193791 bsc#1193802 bsc#1193823 bsc#1193852 bsc#1193867
  bsc#1193883 bsc#1193901 bsc#1193924 bsc#1193925 bsc#1193927 bsc#1193976
  bsc#1193983 bsc#1194023 bsc#1194027 bsc#1194048 bsc#1194086 bsc#1194090
  bsc#1194111 bsc#1194163 bsc#1194191 bsc#1194266 bsc#1194272 bsc#1194298
  bsc#1194302 bsc#1194305 bsc#1194316 bsc#1194317 bsc#1194324 bsc#1194346
  bsc#1194396 bsc#1194409 bsc#1194501 bsc#1194516 bsc#1194517 bsc#1194523
  bsc#1194526 bsc#1194529 bsc#1194578 bsc#1194583 bsc#1194585 bsc#1194586
  bsc#1194592 bsc#1194595 bsc#1194625 bsc#1194628 bsc#1194636 bsc#1194638
  bsc#1194639 bsc#1194641 bsc#1194644 bsc#1194647 bsc#1194650 bsc#1194656
  bsc#1194659 bsc#1194667 bsc#1194765 bsc#1194773 bsc#1194774 bsc#1194777
  bsc#1194778 bnc#1194825 bsc#1194826 bsc#1194839 bsc#1194850 bsc#1194858
  bsc#1194869 bsc#1194880 bsc#1194887 bsc#1194889 bsc#1194904 bsc#1194943
  bsc#1194959 bsc#1194966 bsc#1194975 bsc#1194985 bsc#1195012 bsc#1195051
  bsc#1195056 bsc#1195065 bsc#1195073 bsc#1195082 bsc#1195099 bsc#1195142
  bsc#1195160 bsc#1195175 bsc#1195183 bsc#1195184 bsc#1195187 bsc#1195195
  bsc#1195199 bsc#1195224 bsc#1195254 bsc#1195275 bsc#1195276 bsc#1195287
  bsc#1195293 bsc#1195306 bsc#1195341 bsc#1195342 bsc#1195346 bsc#1195349
  bsc#1195352 boo#1195353 bsc#1195357 bsc#1195376 bsc#1195400 bnc#1195403
  bsc#1195464 bsc#1195478 bsc#1195480 bsc#1195482 bsc#1195501 bsc#1195504
  bsc#1195516 bsc#1195543 bsc#1195612 bsc#1195639 bsc#1195651 bsc#1195655
  bsc#1195668 bsc#1195669 bsc#1195752 bsc#1195774 bsc#1195775 bsc#1195823
  bsc#1195826 bsc#1195897 bsc#1195905 bsc#1195913 bsc#1195915 bsc#1195917
  bsc#1195921 bsc#1195926 bsc#1195927 bsc#1195944 bsc#1195953 bsc#1195957
  bsc#1195987 bsc#1195993 bsc#1195995 bsc#1196018 bsc#1196058 bsc#1196079
  bsc#1196095 bsc#1196114 bsc#1196130 bsc#1196155 bsc#1196213 bsc#1196235
  bsc#1196248 bsc#1196261 bsc#1196261 bsc#1196299 bsc#1196306 bsc#1196346
  bsc#1196367 bsc#1196400 bsc#1196403 bsc#1196426 bsc#1196444 bsc#1196478
  bsc#1196488 bsc#1196514 bsc#1196516 bsc#1196570 bsc#1196584 bsc#1196589
  bsc#1196591 bsc#1196616 bsc#1196627 bsc#1196632 bsc#1196723 bsc#1196746
  bsc#1196779 bsc#1196802 bsc#1196806 bsc#1196823 bsc#1196830 bsc#1196836
  bsc#1196848 bsc#1196849 bsc#1196866 bsc#1196868 bsc#1196869 bsc#1196894
  bsc#1196930 bsc#1196942 bsc#1196956 bsc#1196960 bsc#1196961 bsc#1197016
  bsc#1197035 bsc#1197082 bsc#1197128 bsc#1197131 bsc#1197146 bsc#1197157
  bsc#1197158 bsc#1197174 bsc#1197227 bsc#1197243 bsc#1197245 bsc#1197246
  bsc#1197247 bsc#1197287 bsc#1197291 bsc#1197292 bsc#1197302 bsc#1197303
  bsc#1197304 bsc#1197331 bsc#1197343 bsc#1197362 bsc#1197366 bsc#1197386
  bsc#1197391 bsc#1197446 bsc#1197460 bsc#1197472 bsc#1197501 bsc#1197534
  bsc#1197601 bsc#1197617 bsc#1197658 bsc#1197659 bsc#1197660 bsc#1197661
  bsc#1197675 bsc#1197685 bsc#1197702 bsc#1197755 bsc#1197756 bsc#1197757
  bsc#1197761 bsc#1197762 bsc#1197763 bsc#1197801 bsc#1197817 bsc#1197819
  bsc#1197820 bsc#1197888 bsc#1197889 bsc#1197894 bsc#1197914 bsc#1197915
  bsc#1197917 bsc#1197918 bsc#1197920 bsc#1197921 bsc#1197922 bsc#1197926
  bsc#1198009 bsc#1198010 bsc#1198012 bsc#1198013 bsc#1198014 bsc#1198015
  bsc#1198016 bsc#1198017 bsc#1198018 bsc#1198019 bsc#1198020 bsc#1198021
  bsc#1198022 bsc#1198023 bsc#1198024 bsc#1198025 bsc#1198027 bsc#1198028
  bsc#1198029 bsc#1198030 bsc#1198031 bsc#1198032 bsc#1198033 bsc#1198034
  bsc#1198058 bsc#1198101 bsc#1198110 bsc#1198189 bsc#1198217 bsc#1198228
  bsc#1198240 bsc#1198330 bsc#1198379 bsc#1198400 bsc#1198402 bsc#1198410
  bsc#1198412 bsc#1198413 bsc#1198417 bsc#1198438 bsc#1198484 bsc#1198515
  bsc#1198577 bsc#1198585 bsc#1198602 bsc#1198660 bsc#1198702 bsc#1198802
  bsc#1198803 bsc#1198806 bsc#1198811 bsc#1198826 bsc#1198829 bsc#1198835
  bsc#1198866 bsc#1198968 bsc#1198971 bsc#1199011 bsc#1199012 bsc#1199024
  bsc#1199035 bsc#1199046 bsc#1199052 bsc#1199063 bsc#1199086 bsc#1199124
  bsc#1199163 bsc#1199173 bsc#1199260 bsc#1199291 bsc#1199294 bsc#1199295
  bsc#1199304 bsc#1199314 bnc#1199356 bsc#1199364 bsc#1199390 bsc#1199405
  bsc#1199426 bsc#1199433 bsc#1199439 bsc#1199482 bsc#1199487 bsc#1199505
  bsc#1199507 bsc#1199509 bsc#1199515 bsc#1199564 bsc#1199605 bsc#1199611
  bsc#1199626 bsc#1199631 bsc#1199650 bsc#1199657 bsc#1199665 bsc#1199670
  bsc#1199674 bsc#1199701 bsc#1199736 bsc#1199793 bsc#1199839 bsc#1199875
  bsc#1199904 bsc#1199909 bsc#1200015 bsc#1200019 bsc#1200045 bsc#1200046
  bsc#1200054 bsc#1200143 bsc#1200144 bsc#1200205 bsc#1200211 bsc#1200259
  bsc#1200263 bsc#1200288 bsc#1200301 bsc#1200313 bsc#1200315 bsc#1200343
  bnc#1200420 bsc#1200431 bsc#1200442 bsc#1200465 bsc#1200475 bsc#1200502
  bsc#1200544 bsc#1200567 bsc#1200569 bsc#1200571 bsc#1200599 bsc#1200600
  bsc#1200611 bsc#1200619 bsc#1200622 bsc#1200644 bsc#1200651 bsc#1200692
  bsc#1200762 bsc#1200763 bsc#1200788 bsc#1200806 bsc#1200807 bsc#1200808
  bsc#1200809 bsc#1200810 bsc#1200812 bsc#1200813 bsc#1200815 bsc#1200816
  bsc#1200820 bsc#1200821 bsc#1200822 bsc#1200824 bsc#1200825 bsc#1200827
  bsc#1200828 bsc#1200829 bsc#1200830 bsc#1200845 bsc#1200868 bsc#1200869
  bsc#1200870 bsc#1200871 bsc#1200872 bsc#1200873 bsc#1200882 bsc#1200925
  bsc#1201019 bsc#1201050 bsc#1201068 bsc#1201160 bsc#1201171 bsc#1201193
  bsc#1201196 bsc#1201218 bsc#1201228 bsc#1201251 bsc#1201258 bsc#1201308
  bsc#1201323 bsc#1201361 bsc#1201381 bsc#1201391 bsc#1201427 bsc#1201442
  bsc#1201455 bsc#1201458 bsc#1201471 bsc#1201489 bsc#1201524 bsc#1201592
  bsc#1201593 bsc#1201595 bsc#1201596 bsc#1201610 bsc#1201635 bsc#1201651
  bsc#1201675 bsc#1201691 boo#1201705 bsc#1201725 bsc#1201726 bsc#1201768
  bsc#1201846 bsc#1201855 bsc#1201865 bsc#1201930 bsc#1201940 bsc#1201948
  bsc#1201954 bsc#1201956 bsc#1201958 bsc#1201987 bsc#1202094 bsc#1202095
  bsc#1202096 bsc#1202097 bsc#1202113 bsc#1202131 bsc#1202154 bsc#1202187
  bsc#1202262 bsc#1202265 bsc#1202341 bsc#1202346 bsc#1202347 bsc#1202353
  bsc#1202385 bsc#1202393 bsc#1202447 bsc#1202471 bnc#1202494 bsc#1202558
  bsc#1202564 bsc#1202623 bsc#1202633 bsc#1202636 bsc#1202672 bsc#1202681
  bsc#1202686 bsc#1202700 bsc#1202710 bsc#1202711 bsc#1202712 bsc#1202713
  bsc#1202715 bsc#1202716 bsc#1202757 bsc#1202758 bsc#1202759 bsc#1202761
  bsc#1202762 bsc#1202763 bsc#1202764 bsc#1202765 bsc#1202766 bsc#1202767
  bsc#1202768 bsc#1202769 bsc#1202770 bsc#1202771 bsc#1202772 bsc#1202773
  bsc#1202774 bsc#1202775 bsc#1202776 bsc#1202778 bsc#1202779 bsc#1202780
  bsc#1202781 bsc#1202782 bsc#1202783 bsc#1202822 bsc#1202823 bsc#1202824
  bsc#1202860 bsc#1202867 bsc#1202872 bsc#1202898 bsc#1202914 bsc#1202960
  bsc#1202989 bsc#1203036 bsc#1203039 bsc#1203041 bsc#1203063 bsc#1203066
  bsc#1203098 bsc#1203101 bsc#1203107 bsc#1203117 bsc#1203138 bsc#1203139
  bsc#1203159 bsc#1203183 bsc#1203197 bsc#1203200 bsc#1203219 bsc#1203229
  bsc#1203263 bsc#1203290 bsc#1203325 bsc#1203331 bsc#1203332 bsc#1203338
  bsc#1203360 bsc#1203361 bsc#1203389 bsc#1203391 bsc#1203410 bsc#1203435
  bsc#1203479 bsc#1203505 bsc#1203514 bsc#1203552 bsc#1203664 bsc#1203693
  bsc#1203699 bsc#1203739 bsc#1203740 bsc#1203767 bsc#1203769 bsc#1203770
  bsc#1203794 bsc#1203798 bsc#1203802 bnc#1203829 bsc#1203836 bsc#1203893
  bsc#1203902 bsc#1203906 bsc#1203908 bsc#1203922 bsc#1203935 bsc#1203939
  bsc#1203960 bsc#1203969 bsc#1203987 bsc#1203992 bsc#1204017 bsc#1204051
  bsc#1204059 bsc#1204060 boo#1204063 bsc#1204125 bsc#1204142 bsc#1204166
  bsc#1204168 bsc#1204171 bsc#1204228 bsc#1204241 bsc#1204353 bsc#1204354
  bsc#1204355 bsc#1204356 bsc#1204363 bsc#1204402 bsc#1204405 bsc#1204413
  bsc#1204414 bsc#1204415 bsc#1204417 bsc#1204428 bsc#1204431 bsc#1204433
  bsc#1204439 bsc#1204470 bsc#1204479 bnc#1204498 bsc#1204533 bsc#1204569
  bsc#1204570 bsc#1204574 bsc#1204575 bsc#1204614 bsc#1204619 bsc#1204631
  bsc#1204635 bsc#1204637 bsc#1204646 bsc#1204647 bsc#1204650 bsc#1204652
  bsc#1204653 bsc#1204662 bsc#1204693 bsc#1204705 bsc#1204719 bsc#1204728
  bsc#1204753 bsc#1204760 bsc#1204780 bsc#1204799 bsc#1204810 bsc#1204850
  bsc#1204868 bsc#1204877 bsc#1204911 bsc#1204926 bsc#1204933 bsc#1204934
  bsc#1204947 bsc#1204957 bsc#1204963 bsc#1204970 bsc#1204989 bsc#1204993
  bsc#1204996 bsc#1205007 bsc#1205100 bsc#1205111 bnc#1205113 bsc#1205128
  boo#1205149 bsc#1205153 bsc#1205173 bsc#1205191 bnc#1205205 bsc#1205205
  bsc#1205220 bsc#1205257 bsc#1205263 bsc#1205264 bnc#1205282 bsc#1205331
  bsc#1205332 bsc#1205381 bsc#1205427 bsc#1205428 bsc#1205473 bsc#1205485
  bsc#1205493 bsc#1205495 bsc#1205496 bsc#1205507 bsc#1205514 bsc#1205521
  bsc#1205544 bsc#1205567 bsc#1205572 bsc#1205588 bsc#1205601 bsc#1205616
  bsc#1205617 bsc#1205635 bsc#1205650 bnc#1205653 bsc#1205670 bsc#1205671
  bsc#1205679 bsc#1205683 bsc#1205695 bsc#1205700 bsc#1205701 bsc#1205705
  bsc#1205709 bsc#1205711 bsc#1205744 bsc#1205756 bsc#1205758 bsc#1205760
  bsc#1205762 bsc#1205764 bsc#1205796 bsc#1205803 bsc#1205846 bsc#1205882
  bsc#1205993 bsc#1206006 bsc#1206024 bsc#1206035 bsc#1206036 bsc#1206037
  bsc#1206045 bsc#1206046 bsc#1206047 bsc#1206048 bsc#1206049 bsc#1206050
  bsc#1206051 bsc#1206056 bsc#1206057 bsc#1206073 bsc#1206098 bsc#1206101
  bsc#1206103 bsc#1206113 bsc#1206114 bsc#1206147 bsc#1206149 bsc#1206188
  bsc#1206207 bsc#1206209 bsc#1206224 bsc#1206232 bsc#1206258 bsc#1206273
  bsc#1206340 bsc#1206344 bsc#1206376 bsc#1206389 bsc#1206390 bsc#1206391
  bsc#1206393 bsc#1206394 bsc#1206395 bsc#1206396 bsc#1206397 bsc#1206398
  bsc#1206399 bsc#1206418 bsc#1206451 bsc#1206456 bsc#1206459 bsc#1206468
  bsc#1206476 bsc#1206492 bsc#1206493 bsc#1206515 bsc#1206536 bsc#1206552
  bsc#1206554 bsc#1206578 bsc#1206602 bsc#1206616 bsc#1206619 bsc#1206640
  bsc#1206649 bsc#1206664 bsc#1206677 bsc#1206703 bsc#1206784 bsc#1206794
  bsc#1206824 bsc#1206843 bsc#1206876 bsc#1206877 bsc#1206878 bsc#1206880
  bsc#1206881 bsc#1206882 bsc#1206883 bsc#1206884 bsc#1206885 bsc#1206886
  bsc#1206887 bsc#1206888 bsc#1206889 bsc#1206890 bsc#1206891 bsc#1206893
  bsc#1206894 bsc#1206896 bsc#1206912 boo#1206935 bsc#1206992 bsc#1207010
  bsc#1207016 bsc#1207034 bsc#1207036 bsc#1207050 bsc#1207051 bsc#1207088
  bsc#1207100 bsc#1207125 bsc#1207129 bsc#1207134 bsc#1207149 bsc#1207158
  bsc#1207168 bsc#1207184 bsc#1207185 bsc#1207186 bsc#1207210 bsc#1207237
  bsc#1207263 bsc#1207269 bsc#1207270 bsc#1207284 bsc#1207301 bsc#1207315
  bsc#1207328 bsc#1207333 bsc#1207345 bsc#1207361 bsc#1207439 bsc#1207497
  bsc#1207500 bsc#1207501 bsc#1207506 bsc#1207507 bsc#1207511 bsc#1207521
  bsc#1207529 bsc#1207553 bsc#1207560 bsc#1207574 bsc#1207588 bsc#1207589
  bsc#1207590 bsc#1207591 bsc#1207592 bsc#1207593 bsc#1207594 bsc#1207602
  bsc#1207603 bsc#1207605 bsc#1207606 bsc#1207607 bsc#1207608 bsc#1207609
  bsc#1207610 bsc#1207611 bsc#1207612 bsc#1207613 bsc#1207614 bsc#1207615
  bsc#1207616 bsc#1207617 bsc#1207618 bsc#1207619 bsc#1207620 bsc#1207621
  bsc#1207622 bsc#1207623 bsc#1207624 bsc#1207625 bsc#1207626 bsc#1207627
  bsc#1207628 bsc#1207629 bsc#1207630 bsc#1207631 bsc#1207632 bsc#1207633
  bsc#1207634 bsc#1207635 bsc#1207636 bsc#1207637 bsc#1207638 bsc#1207639
  bsc#1207640 bsc#1207641 bsc#1207642 bsc#1207643 bsc#1207644 bsc#1207645
  bsc#1207646 bsc#1207647 bsc#1207648 bsc#1207649 bsc#1207650 bsc#1207651
  bsc#1207652 bsc#1207653 bsc#1207734 bsc#1207768 bsc#1207769 bsc#1207770
  bsc#1207771 bsc#1207773 bsc#1207795 bsc#1207827 bsc#1207842 bsc#1207845
  bsc#1207875 bsc#1207878 bsc#1207894 bsc#1207933 bsc#1207935 bsc#1207948
  bsc#1208050 bsc#1208076 bsc#1208081 bsc#1208105 bsc#1208107 bsc#1208128
  bsc#1208130 bsc#1208149 bsc#1208153 bsc#1208179 bsc#1208183 bsc#1208203
  bsc#1208209 bsc#1208212 bsc#1208219 bsc#1208266 bsc#1208290 bsc#1208368
  bsc#1208376 bsc#1208410 bsc#1208420 bsc#1208428 bsc#1208429 bsc#1208449
  bsc#1208534 bsc#1208541 bsc#1208542 bsc#1208565 bsc#1208570 bsc#1208588
  bsc#1208598 bsc#1208599 bsc#1208600 bsc#1208601 bsc#1208602 bsc#1208604
  bsc#1208605 bsc#1208607 bsc#1208619 bsc#1208628 bsc#1208700 bsc#1208741
  bsc#1208757 bsc#1208758 bsc#1208759 bsc#1208776 bsc#1208777 bsc#1208784
  bsc#1208787 bsc#1208788 bsc#1208815 bsc#1208816 bsc#1208829 bsc#1208837
  bsc#1208843 bsc#1208845 bsc#1208848 bsc#1208864 bsc#1208902 bsc#1208921
  bsc#1208948 bsc#1208976 bsc#1209008 bsc#1209039 bsc#1209052 bsc#1209079
  bsc#1209092 bsc#1209118 bsc#1209159 bsc#1209256 bsc#1209258 bsc#1209262
  bsc#1209287 bsc#1209288 bsc#1209290 bsc#1209291 bsc#1209292 bsc#1209366
  bsc#1209367 bsc#1209436 bsc#1209457 bsc#1209504 bsc#1209532 bsc#1209547
  bsc#1209556 bsc#1209572 bsc#1209600 bsc#1209615 bsc#1209634 bsc#1209635
  bsc#1209636 bsc#1209637 bsc#1209681 bsc#1209684 bsc#1209687 bsc#1209693
  bsc#1209739 bsc#1209779 bsc#1209780 bsc#1209788 bsc#1209798 bsc#1209799
  bsc#1209801 bsc#1209804 bsc#1209805 bsc#1209841 bsc#1209856 bsc#1209858
  bsc#1209871 bsc#1209927 bsc#1209965 bsc#1209980 bsc#1209982 bsc#1209999
  bsc#1210034 bsc#1210050 bsc#1210158 bsc#1210165 bsc#1210202 bsc#1210203
  bsc#1210206 bsc#1210216 bsc#1210230 bsc#1210294 bsc#1210301 bsc#1210329
  bsc#1210335 bsc#1210336 bsc#1210337 bsc#1210409 bsc#1210439 bsc#1210449
  bsc#1210450 bsc#1210453 bsc#1210454 bsc#1210469 bsc#1210498 bsc#1210506
  bsc#1210533 bsc#1210551 bsc#1210565 bsc#1210584 bsc#1210627 bsc#1210629
  bsc#1210644 bsc#1210647 bsc#1210725 bsc#1210741 bsc#1210762 bsc#1210763
  bsc#1210764 bsc#1210765 bsc#1210766 bsc#1210767 bsc#1210768 bsc#1210769
  bsc#1210770 bsc#1210771 bsc#1210775 bsc#1210780 bsc#1210783 boo#1210791
  bsc#1210793 bsc#1210806 bsc#1210816 bsc#1210817 bsc#1210825 bsc#1210827
  bsc#1210853 bsc#1210940 bsc#1210943 bsc#1210947 bsc#1210953 bsc#1210986
  bsc#1211014 bsc#1211025 bsc#1211037 bsc#1211043 bsc#1211044 bsc#1211089
  bsc#1211105 bsc#1211113 bsc#1211131 bsc#1211140 bsc#1211205 bsc#1211243
  bsc#1211263 bsc#1211280 bsc#1211281 bsc#1211299 bsc#1211346 bsc#1211387
  bsc#1211400 bsc#1211410 bsc#1211414 bsc#1211449 bsc#1211465 bsc#1211519
  bsc#1211564 bsc#1211590 bsc#1211592 bsc#1211593 bsc#1211595 bsc#1211654
  bsc#1211686 bsc#1211687 bsc#1211688 bsc#1211689 bsc#1211690 bsc#1211691
  bsc#1211692 bsc#1211693 bsc#1211714 bsc#1211738 bsc#1211794 boo#1211796
  bsc#1211804 bsc#1211807 bsc#1211808 bsc#1211811 bsc#1211820 bsc#1211836
  bsc#1211847 bsc#1211852 bsc#1211855 bsc#1211867 bsc#1211960 bsc#1212051
  bsc#1212129 bsc#1212142 bsc#1212154 bsc#1212155 bsc#1212158 bsc#1212256
  bsc#1212265 bsc#1212301 bsc#1212350 bsc#1212405 bsc#1212423 bsc#1212445
  bsc#1212448 bsc#1212456 bsc#1212494 bsc#1212495 bsc#1212502 bsc#1212504
  bsc#1212513 bsc#1212525 bsc#1212540 bsc#1212561 bsc#1212563 bsc#1212564
  bsc#1212584 bsc#1212592 bsc#1212603 bsc#1212604 bsc#1212605 bsc#1212606
  bsc#1212619 bsc#1212685 bsc#1212701 bsc#1212741 bsc#1212766 bsc#1212835
  bsc#1212838 bsc#1212842 bsc#1212846 bsc#1212848 bsc#1212861 bsc#1212869
  bsc#1212892 bsc#1212901 bsc#1212905 bsc#1212961 bsc#1213010 bsc#1213011
  bsc#1213012 bsc#1213013 bsc#1213014 bsc#1213015 bsc#1213016 bsc#1213017
  bsc#1213018 bsc#1213019 bsc#1213020 bsc#1213021 bsc#1213024 bsc#1213025
  bsc#1213032 bsc#1213034 bsc#1213035 bsc#1213036 bsc#1213037 bsc#1213038
  bsc#1213039 bsc#1213040 bsc#1213041 bsc#1213059 bsc#1213061 bsc#1213087
  bsc#1213088 bsc#1213089 bsc#1213090 bsc#1213092 bsc#1213093 bsc#1213094
  bsc#1213095 bsc#1213096 bsc#1213098 bsc#1213099 bsc#1213100 bsc#1213102
  bsc#1213103 bsc#1213104 bsc#1213105 bsc#1213106 bsc#1213107 bsc#1213108
  bsc#1213109 bsc#1213110 bsc#1213111 bsc#1213112 bsc#1213113 bsc#1213114
  bsc#1213116 bsc#1213134 bsc#1213167 bsc#1213205 bsc#1213206 bsc#1213226
  bsc#1213233 bsc#1213245 bsc#1213247 bsc#1213252 bsc#1213258 bsc#1213259
  bsc#1213263 bsc#1213264 bsc#1213272 bsc#1213286 bsc#1213287 bsc#1213304
  bsc#1213311 bsc#1213417 bsc#1213493 bsc#1213523 bsc#1213524 bsc#1213533
  bsc#1213543 bsc#1213546 bsc#1213578 bsc#1213580 bsc#1213585 bsc#1213586
  bsc#1213588 bsc#1213601 bsc#1213620 bsc#1213632 bsc#1213653 bsc#1213705
  bsc#1213713 bsc#1213715 bsc#1213733 bsc#1213747 bsc#1213756 bsc#1213757
  bsc#1213759 bsc#1213777 bsc#1213810 bsc#1213812 bsc#1213856 bsc#1213857
  bsc#1213863 bsc#1213867 bsc#1213870 bsc#1213871 bsc#1213872 bsc#1213968
  bsc#1213970 bsc#1214000 bsc#1214019 bsc#1214073
  CVE-2016-3695 CVE-2017-5715 CVE-2017-5753 CVE-2017-5754 CVE-2017-12153
  CVE-2017-13080 CVE-2017-14051 CVE-2017-16536 CVE-2017-16537 CVE-2017-16646
  CVE-2017-16648 CVE-2017-1000251 CVE-2018-10323 CVE-2018-12232
  CVE-2018-13053 CVE-2018-20669 CVE-2019-0154 CVE-2019-0155 CVE-2019-3016
  CVE-2019-8912 CVE-2019-10220 CVE-2019-11477 CVE-2019-11478 CVE-2019-11479
  CVE-2019-12456 CVE-2019-14615 CVE-2019-14814 CVE-2019-14815 CVE-2019-14816
  CVE-2019-14895 CVE-2019-14896 CVE-2019-14897 CVE-2019-14901 CVE-2019-15030
  CVE-2019-15031 CVE-2019-15098 CVE-2019-15099 CVE-2019-15290 CVE-2019-15291
  CVE-2019-15504 CVE-2019-16231 CVE-2019-16232 CVE-2019-16233 CVE-2019-16234
  CVE-2019-17133 CVE-2019-17666 CVE-2019-18198 CVE-2019-18660 CVE-2019-18683
  CVE-2019-18786 CVE-2019-18808 CVE-2019-18809 CVE-2019-18811 CVE-2019-18812
  CVE-2019-18813 CVE-2019-18814 CVE-2019-19037 CVE-2019-19043 CVE-2019-19044
  CVE-2019-19045 CVE-2019-19046 CVE-2019-19047 CVE-2019-19048 CVE-2019-19049
  CVE-2019-19050 CVE-2019-19051 CVE-2019-19052 CVE-2019-19053 CVE-2019-19054
  CVE-2019-19055 CVE-2019-19056 CVE-2019-19057 CVE-2019-19058 CVE-2019-19060
  CVE-2019-19061 CVE-2019-19062 CVE-2019-19063 CVE-2019-19064 CVE-2019-19065
  CVE-2019-19066 CVE-2019-19067 CVE-2019-19068 CVE-2019-19069 CVE-2019-19070
  CVE-2019-19071 CVE-2019-19072 CVE-2019-19073 CVE-2019-19074 CVE-2019-19075
  CVE-2019-19077 CVE-2019-19078 CVE-2019-19080 CVE-2019-19081 CVE-2019-19082
  CVE-2019-19083 CVE-2019-19241 CVE-2019-19252 CVE-2019-19332 CVE-2019-19338
  CVE-2019-19447 CVE-2019-19462 CVE-2019-19523 CVE-2019-19524 CVE-2019-19525
  CVE-2019-19526 CVE-2019-19528 CVE-2019-19529 CVE-2019-19532 CVE-2019-19533
  CVE-2019-19534 CVE-2019-19602 CVE-2019-19767 CVE-2019-19768 CVE-2019-19769
  CVE-2019-19770 CVE-2019-19807 CVE-2019-19922 CVE-2019-19947 CVE-2019-19965
  CVE-2019-20422 CVE-2019-20810 CVE-2019-20812 CVE-2020-0110 CVE-2020-0305
  CVE-2020-0404 CVE-2020-0427 CVE-2020-0431 CVE-2020-0432 CVE-2020-0444
  CVE-2020-0465 CVE-2020-0466 CVE-2020-0543 CVE-2020-1749 CVE-2020-2521
  CVE-2020-2732 CVE-2020-4788 CVE-2020-8428 CVE-2020-8647 CVE-2020-8648
  CVE-2020-8649 CVE-2020-8694 CVE-2020-8835 CVE-2020-8992 CVE-2020-9383
  CVE-2020-10135 CVE-2020-10690 CVE-2020-10711 CVE-2020-10732 CVE-2020-10751
  CVE-2020-10757 CVE-2020-10766 CVE-2020-10767 CVE-2020-10768 CVE-2020-10773
  CVE-2020-10781 CVE-2020-10942 CVE-2020-11494 CVE-2020-11608 CVE-2020-11668
  CVE-2020-11884 CVE-2020-12351 CVE-2020-12352 CVE-2020-12362 CVE-2020-12363
  CVE-2020-12364 CVE-2020-12373 CVE-2020-12464 CVE-2020-12465 CVE-2020-12652
  CVE-2020-12653 CVE-2020-12654 CVE-2020-12655 CVE-2020-12656 CVE-2020-12657
  CVE-2020-12659 CVE-2020-12769 CVE-2020-12770 CVE-2020-12771 CVE-2020-12888
  CVE-2020-13143 CVE-2020-13974 CVE-2020-14314 CVE-2020-14331 CVE-2020-14351
  CVE-2020-14356 CVE-2020-14385 CVE-2020-14386 CVE-2020-14390 CVE-2020-14416
  CVE-2020-15393 CVE-2020-15436 CVE-2020-15437 CVE-2020-15780 CVE-2020-16119
  CVE-2020-16120 CVE-2020-16166 CVE-2020-24490 CVE-2020-24586 CVE-2020-24587
  CVE-2020-24588 CVE-2020-25211 CVE-2020-25212 CVE-2020-25284 CVE-2020-25285
  CVE-2020-25639 CVE-2020-25641 CVE-2020-25643 CVE-2020-25645 CVE-2020-25656
  CVE-2020-25668 CVE-2020-25669 CVE-2020-25670 CVE-2020-25671 CVE-2020-25672
  CVE-2020-25673 CVE-2020-25704 CVE-2020-25705 CVE-2020-26088 CVE-2020-26139
  CVE-2020-26141 CVE-2020-26145 CVE-2020-26147 CVE-2020-26558 CVE-2020-27068
  CVE-2020-27170 CVE-2020-27171 CVE-2020-27194 CVE-2020-27673 CVE-2020-27675
  CVE-2020-27777 CVE-2020-27786 CVE-2020-27815 CVE-2020-27820 CVE-2020-27825
  CVE-2020-27830 CVE-2020-27835 CVE-2020-28374 CVE-2020-28915 CVE-2020-28941
  CVE-2020-28974 CVE-2020-29368 CVE-2020-29369 CVE-2020-29370 CVE-2020-29371
  CVE-2020-29373 CVE-2020-29568 CVE-2020-29569 CVE-2020-29660 CVE-2020-29661
  CVE-2020-35519 CVE-2020-36158 CVE-2020-36310 CVE-2020-36311 CVE-2020-36312
  CVE-2020-36322 CVE-2020-36385 CVE-2020-36386 CVE-2020-36516 CVE-2021-0129
  CVE-2021-0342 CVE-2021-0512 CVE-2021-0605 CVE-2021-3347 CVE-2021-3348
  CVE-2021-3428 CVE-2021-3444 CVE-2021-3483 CVE-2021-3489 CVE-2021-3490
  CVE-2021-3491 CVE-2021-3542 CVE-2021-3573 CVE-2021-3609 CVE-2021-3612
  CVE-2021-3640 CVE-2021-3653 CVE-2021-3656 CVE-2021-3659 CVE-2021-3679
  CVE-2021-3732 CVE-2021-3739 CVE-2021-3743 CVE-2021-3744 CVE-2021-3753
  CVE-2021-3759 CVE-2021-3760 CVE-2021-3764 CVE-2021-3772 CVE-2021-3896
  CVE-2021-4001 CVE-2021-4002 CVE-2021-4037 CVE-2021-4083 CVE-2021-4090
  CVE-2021-4135 CVE-2021-4148 CVE-2021-4155 CVE-2021-4197 CVE-2021-4202
  CVE-2021-4204 CVE-2021-20177 CVE-2021-20268 CVE-2021-20321 CVE-2021-21781
  CVE-2021-22543 CVE-2021-22555 CVE-2021-22600 CVE-2021-23134 CVE-2021-26341
  CVE-2021-26930 CVE-2021-26931 CVE-2021-26932 CVE-2021-27363 CVE-2021-27364
  CVE-2021-27365 CVE-2021-28038 CVE-2021-28375 CVE-2021-28660 CVE-2021-28688
  CVE-2021-28711 CVE-2021-28712 CVE-2021-28713 CVE-2021-28714 CVE-2021-28715
  CVE-2021-28950 CVE-2021-28952 CVE-2021-28964 CVE-2021-28971 CVE-2021-28972
  CVE-2021-29154 CVE-2021-29155 CVE-2021-29264 CVE-2021-29265 CVE-2021-29647
  CVE-2021-29650 CVE-2021-30002 CVE-2021-32399 CVE-2021-33034 CVE-2021-33061
  CVE-2021-33135 CVE-2021-33200 CVE-2021-33624 CVE-2021-33655 CVE-2021-33909
  CVE-2021-34556 CVE-2021-34693 CVE-2021-35039 CVE-2021-35477 CVE-2021-37576
  CVE-2021-38160 CVE-2021-38166 CVE-2021-38198 CVE-2021-38204 CVE-2021-38205
  CVE-2021-38206 CVE-2021-38207 CVE-2021-38209 CVE-2021-39685 CVE-2021-39698
  CVE-2021-41073 CVE-2021-41864 CVE-2021-42252 CVE-2021-42327 CVE-2021-42739
  CVE-2021-43056 CVE-2021-43057 CVE-2021-43267 CVE-2021-43389 CVE-2021-43975
  CVE-2021-43976 CVE-2021-44733 CVE-2021-44879 CVE-2021-45095 CVE-2021-45402
  CVE-2021-45480 CVE-2021-45868 CVE-2022-0001 CVE-2022-0002 CVE-2022-0168
  CVE-2022-0171 CVE-2022-0185 CVE-2022-0264 CVE-2022-0322 CVE-2022-0330
  CVE-2022-0382 CVE-2022-0435 CVE-2022-0487 CVE-2022-0492 CVE-2022-0494
  CVE-2022-0500 CVE-2022-0516 CVE-2022-0617 CVE-2022-0644 CVE-2022-0742
  CVE-2022-0847 CVE-2022-0854 CVE-2022-0886 CVE-2022-0995 CVE-2022-0998
  CVE-2022-1011 CVE-2022-1012 CVE-2022-1015 CVE-2022-1016 CVE-2022-1048
  CVE-2022-1055 CVE-2022-1158 CVE-2022-1184 CVE-2022-1195 CVE-2022-1198
  CVE-2022-1199 CVE-2022-1204 CVE-2022-1205 CVE-2022-1263 CVE-2022-1280
  CVE-2022-1462 CVE-2022-1508 CVE-2022-1516 CVE-2022-1651 CVE-2022-1652
  CVE-2022-1671 CVE-2022-1679 CVE-2022-1729 CVE-2022-1734 CVE-2022-1789
  CVE-2022-1836 CVE-2022-1852 CVE-2022-1882 CVE-2022-1966 CVE-2022-1972
  CVE-2022-1974 CVE-2022-1975 CVE-2022-1998 CVE-2022-2153 CVE-2022-2196
  CVE-2022-2318 CVE-2022-2585 CVE-2022-2586 CVE-2022-2588 CVE-2022-2602
  CVE-2022-2639 CVE-2022-2663 CVE-2022-2873 CVE-2022-2905 CVE-2022-2938
  CVE-2022-2959 CVE-2022-2964 CVE-2022-2977 CVE-2022-2978 CVE-2022-3028
  CVE-2022-3078 CVE-2022-3104 CVE-2022-3105 CVE-2022-3106 CVE-2022-3107
  CVE-2022-3108 CVE-2022-3111 CVE-2022-3112 CVE-2022-3113 CVE-2022-3114
  CVE-2022-3115 CVE-2022-3169 CVE-2022-3176 CVE-2022-3202 CVE-2022-3239
  CVE-2022-3303 CVE-2022-3344 CVE-2022-3424 CVE-2022-3435 CVE-2022-3521
  CVE-2022-3523 CVE-2022-3524 CVE-2022-3526 CVE-2022-3535 CVE-2022-3542
  CVE-2022-3545 CVE-2022-3564 CVE-2022-3565 CVE-2022-3566 CVE-2022-3567
  CVE-2022-3577 CVE-2022-3586 CVE-2022-3594 CVE-2022-3619 CVE-2022-3621
  CVE-2022-3625 CVE-2022-3628 CVE-2022-3629 CVE-2022-3633 CVE-2022-3635
  CVE-2022-3640 CVE-2022-3643 CVE-2022-3646 CVE-2022-3649 CVE-2022-3707
  CVE-2022-3903 CVE-2022-4095 CVE-2022-4129 CVE-2022-4139 CVE-2022-4269
  CVE-2022-4378 CVE-2022-4379 CVE-2022-4382 CVE-2022-4662 CVE-2022-4744
  CVE-2022-20008 CVE-2022-20132 CVE-2022-20154 CVE-2022-20368 CVE-2022-20369
  CVE-2022-21123 CVE-2022-21125 CVE-2022-21127 CVE-2022-21166 CVE-2022-21180
  CVE-2022-21499 CVE-2022-21505 CVE-2022-22942 CVE-2022-23036 CVE-2022-23037
  CVE-2022-23038 CVE-2022-23039 CVE-2022-23040 CVE-2022-23041 CVE-2022-23042
  CVE-2022-23222 CVE-2022-23960 CVE-2022-24122 CVE-2022-24448 CVE-2022-24958
  CVE-2022-24959 CVE-2022-25258 CVE-2022-25375 CVE-2022-25636 CVE-2022-26365
  CVE-2022-26373 CVE-2022-26490 CVE-2022-26878 CVE-2022-26966 CVE-2022-27223
  CVE-2022-28356 CVE-2022-28388 CVE-2022-28389 CVE-2022-28390 CVE-2022-28693
  CVE-2022-28748 CVE-2022-28893 CVE-2022-29156 CVE-2022-29581 CVE-2022-29582
  CVE-2022-29900 CVE-2022-29901 CVE-2022-30594 CVE-2022-32250 CVE-2022-32296
  CVE-2022-33740 CVE-2022-33741 CVE-2022-33742 CVE-2022-33743 CVE-2022-33981
  CVE-2022-34918 CVE-2022-36280 CVE-2022-36879 CVE-2022-36946 CVE-2022-38096
  CVE-2022-39188 CVE-2022-39189 CVE-2022-39190 CVE-2022-40476 CVE-2022-40768
  CVE-2022-40982 CVE-2022-41218 CVE-2022-41674 CVE-2022-41848 CVE-2022-41849
  CVE-2022-41850 CVE-2022-41858 CVE-2022-42328 CVE-2022-42329 CVE-2022-42703
  CVE-2022-42719 CVE-2022-42720 CVE-2022-42721 CVE-2022-42722 CVE-2022-42895
  CVE-2022-42896 CVE-2022-43750 CVE-2022-43945 CVE-2022-45869 CVE-2022-45884
  CVE-2022-45885 CVE-2022-45886 CVE-2022-45887 CVE-2022-45888 CVE-2022-45919
  CVE-2022-45934 CVE-2022-47520 CVE-2022-47929 CVE-2023-0045 CVE-2023-0122
  CVE-2023-0179 CVE-2023-0266 CVE-2023-0386 CVE-2023-0394 CVE-2023-0459
  CVE-2023-0461 CVE-2023-0468 CVE-2023-0469 CVE-2023-0590 CVE-2023-0597
  CVE-2023-1075 CVE-2023-1076 CVE-2023-1077 CVE-2023-1078 CVE-2023-1079
  CVE-2023-1095 CVE-2023-1118 CVE-2023-1249 CVE-2023-1281 CVE-2023-1380
  CVE-2023-1382 CVE-2023-1513 CVE-2023-1582 CVE-2023-1583 CVE-2023-1611
  CVE-2023-1637 CVE-2023-1652 CVE-2023-1670 CVE-2023-1829 CVE-2023-1838
  CVE-2023-1855 CVE-2023-1989 CVE-2023-1990 CVE-2023-1998 CVE-2023-2002
  CVE-2023-2008 CVE-2023-2019 CVE-2023-2124 CVE-2023-2156 CVE-2023-2162
  CVE-2023-2166 CVE-2023-2176 CVE-2023-2235 CVE-2023-2269 CVE-2023-2430
  CVE-2023-2483 CVE-2023-2513 CVE-2023-2985 CVE-2023-3006 CVE-2023-3090
  CVE-2023-3111 CVE-2023-3117 CVE-2023-3141 CVE-2023-3161 CVE-2023-3212
  CVE-2023-3220 CVE-2023-3268 CVE-2023-3357 CVE-2023-3358 CVE-2023-3389
  CVE-2023-3390 CVE-2023-3567 CVE-2023-3609 CVE-2023-3610 CVE-2023-3611
  CVE-2023-3776 CVE-2023-3812 CVE-2023-3863 CVE-2023-4004 CVE-2023-4133
  CVE-2023-4147 CVE-2023-4194 CVE-2023-20569 CVE-2023-20593 CVE-2023-21102
  CVE-2023-21106 CVE-2023-21400 CVE-2023-22995 CVE-2023-22998 CVE-2023-23000
  CVE-2023-23001 CVE-2023-23004 CVE-2023-23006 CVE-2023-23454 CVE-2023-23455
  CVE-2023-23559 CVE-2023-25012 CVE-2023-26545 CVE-2023-28327 CVE-2023-28328
  CVE-2023-28410 CVE-2023-28464 CVE-2023-28466 CVE-2023-28866 CVE-2023-30456
  CVE-2023-30772 CVE-2023-31083 CVE-2023-31084 CVE-2023-31248 CVE-2023-31436
  CVE-2023-32233 CVE-2023-33288 CVE-2023-33951 CVE-2023-33952 CVE-2023-34319
  CVE-2023-35001 CVE-2023-35788 CVE-2023-35823 CVE-2023-35828 CVE-2023-35829
  CVE-2023-38409
  JSC#PED-1711 JSC#SLE-13586 JSC#SLE-15234 JSC#SLE-9489 jsc#11529 jsc#13212
  jsc#13318 jsc#13356 jsc#13365 jsc#13475 jsc#13575 jsc#13695 jsc#13705
  jsc#13716 jsc#16232 jsc#ECO-1386 jsc#ECO-3191 jsc#ECO-3482 jsc#ECO-3666
  jsc#ECO-3691 jsc#IBM-458 jsc#IBM-463 jsc#IBM-505 jsc#INTEL-233
  jsc#INTEL-549 jsc#PED-1033 jsc#PED-1035 jsc#PED-1036 jsc#PED-1038
  jsc#PED-1040 jsc#PED-1044 jsc#PED-1046 jsc#PED-1052 jsc#PED-1054
  jsc#PED-1063 jsc#PED-1072 jsc#PED-1073 jsc#PED-1082 jsc#PED-1084
  jsc#PED-1085 jsc#PED-1096 jsc#PED-1109 jsc#PED-1111 jsc#PED-1113
  jsc#PED-1118 jsc#PED-1159 jsc#PED-1163 jsc#PED-1164 jsc#PED-1165
  jsc#PED-1166 jsc#PED-1168 jsc#PED-1170 jsc#PED-1176 jsc#PED-1183
  jsc#PED-1185 jsc#PED-1187 jsc#PED-1211 jsc#PED-1213 jsc#PED-1218
  jsc#PED-1220 jsc#PED-1222 jsc#PED-1223 jsc#PED-1225 jsc#PED-1247
  jsc#PED-1248 jsc#PED-1263 jsc#PED-1266 jsc#PED-1294 jsc#PED-1295
  jsc#PED-1302 jsc#PED-1368 jsc#PED-1377 jsc#PED-1379 jsc#PED-1407
  jsc#PED-1408 jsc#PED-1409 jsc#PED-1444 jsc#PED-1445 jsc#PED-1446
  jsc#PED-1465 jsc#PED-1490 jsc#PED-1491 jsc#PED-1492 jsc#PED-1494
  jsc#PED-1495 jsc#PED-1496 jsc#PED-1497 jsc#PED-1503 jsc#PED-1504
  jsc#PED-1506 jsc#PED-1508 jsc#PED-1509 jsc#PED-1516 jsc#PED-1517
  jsc#PED-1521 jsc#PED-1523 jsc#PED-1524 jsc#PED-1525 jsc#PED-1526
  jsc#PED-1529 jsc#PED-1530 jsc#PED-1547 jsc#PED-1548 jsc#PED-1549
  jsc#PED-1552 jsc#PED-1557 jsc#PED-1558 jsc#PED-1559 jsc#PED-1560
  jsc#PED-1561 jsc#PED-1565 jsc#PED-1573 jsc#PED-1599 jsc#PED-1649
  jsc#PED-1689 jsc#PED-1690 jsc#PED-1694 jsc#PED-1695 jsc#PED-1706
  jsc#PED-1715 jsc#PED-1752 jsc#PED-1754 jsc#PED-1755 jsc#PED-1756
  jsc#PED-1763 jsc#PED-1765 jsc#PED-1812 jsc#PED-1815 jsc#PED-1816
  jsc#PED-1817 jsc#PED-1819 jsc#PED-1820 jsc#PED-1917 jsc#PED-1925
  jsc#PED-1936 jsc#PED-1973 jsc#PED-1981 jsc#PED-2064 jsc#PED-2322
  jsc#PED-2639 jsc#PED-2681 jsc#PED-2684 jsc#PED-2765 jsc#PED-2766
  jsc#PED-2849 jsc#PED-3210 jsc#PED-3259 jsc#PED-342 jsc#PED-3692 jsc#PED-370
  jsc#PED-372 jsc#PED-373 jsc#PED-375 jsc#PED-3750 jsc#PED-3759 jsc#PED-376
  jsc#PED-377 jsc#PED-387 jsc#PED-3931 jsc#PED-4022 jsc#PED-448 jsc#PED-455
  jsc#PED-4718 jsc#PED-4758 jsc#PED-529 jsc#PED-531 jsc#PED-535 jsc#PED-542
  jsc#PED-548 jsc#PED-549 jsc#PED-551 jsc#PED-557 jsc#PED-568 jsc#PED-573
  jsc#PED-579 jsc#PED-588 jsc#PED-589 jsc#PED-592 jsc#PED-593 jsc#PED-594
  jsc#PED-596 jsc#PED-598 jsc#PED-599 jsc#PED-600 jsc#PED-603 jsc#PED-606
  jsc#PED-610 jsc#PED-611 jsc#PED-612 jsc#PED-613 jsc#PED-622 jsc#PED-623
  jsc#PED-628 jsc#PED-633 jsc#PED-634 jsc#PED-637 jsc#PED-648 jsc#PED-652
  jsc#PED-664 jsc#PED-667 jsc#PED-676 jsc#PED-678 jsc#PED-679 jsc#PED-681
  jsc#PED-682 jsc#PED-686 jsc#PED-688 jsc#PED-690 jsc#PED-692 jsc#PED-695
  jsc#PED-707 jsc#PED-716 jsc#PED-720 jsc#PED-729 jsc#PED-732 jsc#PED-740
  jsc#PED-743 jsc#PED-755 jsc#PED-763 jsc#PED-769 jsc#PED-808 jsc#PED-812
  jsc#PED-813 jsc#PED-817 jsc#PED-818 jsc#PED-820 jsc#PED-822 jsc#PED-823
  jsc#PED-824 jsc#PED-825 jsc#PED-826 jsc#PED-827 jsc#PED-828 jsc#PED-829
  jsc#PED-831 jsc#PED-832 jsc#PED-833 jsc#PED-835 jsc#PED-837 jsc#PED-840
  jsc#PED-842 jsc#PED-846 jsc#PED-849 jsc#PED-850 jsc#PED-851 jsc#PED-855
  jsc#PED-856 jsc#PED-857 jsc#PED-858 jsc#PED-859 jsc#PED-868 jsc#PED-956
  jsc#PED-972 jsc#PED-975 jsc#PED-990 jsc#PEd-1211 jsc#PEd-1817 jsc#PM-1318
  jsc#PM-1333 jsc#PM-1334 jsc#PM-1588 jsc#SES-1080 jsc#SES-1134 jsc#SES-1880
  jsc#SLE-10031 jsc#SLE-10146 jsc#SLE-10158 jsc#SLE-10207 jsc#SLE-10218
  jsc#SLE-10259 jsc#SLE-10262 jsc#SLE-10289 jsc#SLE-10327 jsc#SLE-10334
  jsc#SLE-10427 jsc#SLE-10505 jsc#SLE-10562 jsc#SLE-10565 jsc#SLE-10608
  jsc#SLE-10621 jsc#SLE-10687 jsc#SLE-10690 jsc#SLE-10700 jsc#SLE-10717
  jsc#SLE-10720 jsc#SLE-10790 jsc#SLE-10886 jsc#SLE-11050 jsc#SLE-11070
  jsc#SLE-11112 jsc#SLE-11113 jsc#SLE-11117 jsc#SLE-11309 jsc#SLE-11312
  jsc#SLE-11493 jsc#SLE-11598 jsc#SLE-11796 jsc#SLE-11831 jsc#SLE-11833
  jsc#SLE-12152 jsc#SLE-12203 jsc#SLE-12226 jsc#SLE-12250 jsc#SLE-12251
  jsc#SLE-12300 jsc#SLE-12424 jsc#SLE-12599 jsc#SLE-12602 jsc#SLE-12668
  jsc#SLE-12677 jsc#SLE-12679 jsc#SLE-12680 jsc#SLE-12681 jsc#SLE-12682
  jsc#SLE-12683 jsc#SLE-12688 jsc#SLE-12692 jsc#SLE-12699 jsc#SLE-12700
  jsc#SLE-12705 jsc#SLE-12710 jsc#SLE-12717 jsc#SLE-12718 jsc#SLE-12730
  jsc#SLE-12732 jsc#SLE-12734 jsc#SLE-12735 jsc#SLE-12737 jsc#SLE-12769
  jsc#SLE-12860 jsc#SLE-12866 jsc#SLE-12877 jsc#SLE-12878 jsc#SLE-12880
  jsc#SLE-12882 jsc#SLE-12883 jsc#SLE-12921 jsc#SLE-12936 jsc#SLE-12943
  jsc#SLE-12982 jsc#SLE-12983 jsc#SLE-12984 jsc#SLE-12985 jsc#SLE-13078
  jsc#SLE-13135 jsc#SLE-13172 jsc#SLE-13202 jsc#SLE-13205 jsc#SLE-13208
  jsc#SLE-13222 jsc#SLE-13261 jsc#SLE-13285 jsc#SLE-13294 jsc#SLE-13316
  jsc#SLE-13318 jsc#SLE-13338 jsc#SLE-13340 jsc#SLE-13343 jsc#SLE-13346
  jsc#SLE-13352 jsc#SLE-13356 jsc#SLE-13358 jsc#SLE-13360 jsc#SLE-13361
  jsc#SLE-13363 jsc#SLE-13371 jsc#SLE-13380 jsc#SLE-13387 jsc#SLE-13391
  jsc#SLE-13393 jsc#SLE-13398 jsc#SLE-13409 jsc#SLE-13411 jsc#SLE-13413
  jsc#SLE-13430 jsc#SLE-13436 jsc#SLE-13441 jsc#SLE-13445 jsc#SLE-13446
  jsc#SLE-13447 jsc#SLE-13451 jsc#SLE-13489 jsc#SLE-13496 jsc#SLE-13503
  jsc#SLE-13512 jsc#SLE-13513 jsc#SLE-13521 jsc#SLE-13522 jsc#SLE-13532
  jsc#SLE-13533 jsc#SLE-13535 jsc#SLE-13536 jsc#SLE-13537 jsc#SLE-13557
  jsc#SLE-13565 jsc#SLE-13573 jsc#SLE-13593 jsc#SLE-13596 jsc#SLE-13597
  jsc#SLE-13610 jsc#SLE-13614 jsc#SLE-13615 jsc#SLE-13616 jsc#SLE-13617
  jsc#SLE-13618 jsc#SLE-13628 jsc#SLE-13629 jsc#SLE-13630 jsc#SLE-13640
  jsc#SLE-13644 jsc#SLE-13654 jsc#SLE-13661 jsc#SLE-13665 jsc#SLE-13690
  jsc#SLE-13697 jsc#SLE-13701 jsc#SLE-13702 jsc#SLE-13706 jsc#SLE-13718
  jsc#SLE-13722 jsc#SLE-13726 jsc#SLE-13727 jsc#SLE-13731 jsc#SLE-13736
  jsc#SLE-13740 jsc#SLE-13746 jsc#SLE-13750 jsc#SLE-13761 jsc#SLE-13763
  jsc#SLE-13764 jsc#SLE-13766 jsc#SLE-13767 jsc#SLE-13778 jsc#SLE-13782
  jsc#SLE-13815 jsc#SLE-13818 jsc#SLE-13821 jsc#SLE-13823 jsc#SLE-13830
  jsc#SLE-13841 jsc#SLE-13847 jsc#SLE-13848 jsc#SLE-13898 jsc#SLE-13918
  jsc#SLE-13984 jsc#SLE-14018 jsc#SLE-14042 jsc#SLE-14130 jsc#SLE-14166
  jsc#SLE-14214 jsc#SLE-14262 jsc#SLE-14337 jsc#SLE-14344 jsc#SLE-14368
  jsc#SLE-14407 jsc#SLE-14454 jsc#SLE-14457 jsc#SLE-14458 jsc#SLE-14459
  jsc#SLE-14727 jsc#SLE-14763 jsc#SLE-14766 jsc#SLE-14771 jsc#SLE-14773
  jsc#SLE-14776 jsc#SLE-14777 jsc#SLE-14811 jsc#SLE-14845 jsc#SLE-14846
  jsc#SLE-14859 jsc#SLE-14911 jsc#SLE-15020 jsc#SLE-15070 jsc#SLE-15075
  jsc#SLE-15076 jsc#SLE-15082 jsc#SLE-15083 jsc#SLE-15111 jsc#SLE-15118
  jsc#SLE-15129 jsc#SLE-15131 jsc#SLE-15135 jsc#SLE-15139 jsc#SLE-15143
  jsc#SLE-15146 jsc#SLE-15148 jsc#SLE-15150 jsc#SLE-15151 jsc#SLE-15152
  jsc#SLE-15171 jsc#SLE-15172 jsc#SLE-15175 jsc#SLE-15176 jsc#SLE-15188
  jsc#SLE-15207 jsc#SLE-15209 jsc#SLE-15232 jsc#SLE-15271 jsc#SLE-15318
  jsc#SLE-15322 jsc#SLE-15356 jsc#SLE-15368 jsc#SLE-15373 jsc#SLE-15391
  jsc#SLE-15406 jsc#SLE-15442 jsc#SLE-15449 jsc#SLE-15608 jsc#SLE-15796
  jsc#SLE-15835 jsc#SLE-15847 jsc#SLE-15848 jsc#SLE-15857 jsc#SLE-15862
  jsc#SLE-15869 jsc#SLE-15871 jsc#SLE-15887 jsc#SLE-15898 jsc#SLE-15946
  jsc#SLE-16008 jsc#SLE-16056 jsc#SLE-16098 jsc#SLE-16106 jsc#SLE-16108
  jsc#SLE-16200 jsc#SLE-16259 jsc#SLE-16304 jsc#SLE-16321 jsc#SLE-16360
  jsc#SLE-16387 jsc#SLE-16402 jsc#SLE-16407 jsc#SLE-16497 jsc#SLE-16507
  jsc#SLE-16518 jsc#SLE-16543 jsc#SLE-16556 jsc#SLE-16574 jsc#SLE-1660
  jsc#SLE-16606 jsc#SLE-16610 jsc#SLE-16612 jsc#SLE-16614 jsc#SLE-16616
  jsc#SLE-16649 jsc#SLE-16683 jsc#SLE-16742 jsc#SLE-16756 jsc#SLE-16775
  jsc#SLE-16823 jsc#SLE-16869 jsc#SLE-16874 jsc#SLE-16914 jsc#SLE-16915
  jsc#SLE-17042 jsc#SLE-17043 jsc#SLE-17068 jsc#SLE-17122 jsc#SLE-17153
  jsc#SLE-17212 jsc#SLE-17227 jsc#SLE-17267 jsc#SLE-17268 jsc#SLE-17288
  jsc#SLE-17310 jsc#SLE-17337 jsc#SLE-17360 jsc#SLE-17612 jsc#SLE-17674
  jsc#SLE-17681 jsc#SLE-17823 jsc#SLE-17855 jsc#SLE-17882 jsc#SLE-17900
  jsc#SLE-18121 jsc#SLE-18128 jsc#SLE-18130 jsc#SLE-18138 jsc#SLE-18145
  jsc#SLE-18194 jsc#SLE-18234 jsc#SLE-18274 jsc#SLE-18329 jsc#SLE-18330
  jsc#SLE-18331 jsc#SLE-18375 jsc#SLE-18377 jsc#SLE-18378 jsc#SLE-18379
  jsc#SLE-18382 jsc#SLE-18383 jsc#SLE-18384 jsc#SLE-18385 jsc#SLE-18516
  jsc#SLE-18522 jsc#SLE-18523 jsc#SLE-18634 jsc#SLE-18701 jsc#SLE-18766
  jsc#SLE-18779 jsc#SLE-18805 jsc#SLE-18823 jsc#SLE-18857 jsc#SLE-18879
  jsc#SLE-18889 jsc#SLE-18899 jsc#SLE-18901 jsc#SLE-18931 jsc#SLE-18938
  jsc#SLE-18939 jsc#SLE-18967 jsc#SLE-18968 jsc#SLE-18970 jsc#SLE-18973
  jsc#SLE-18977 jsc#SLE-18978 jsc#SLE-18989 jsc#SLE-18992 jsc#SLE-18998
  jsc#SLE-19001 jsc#SLE-19002 jsc#SLE-19003 jsc#SLE-19010 jsc#SLE-19026
  jsc#SLE-19031 jsc#SLE-19033 jsc#SLE-19035 jsc#SLE-19041 jsc#SLE-19046
  jsc#SLE-19094 jsc#SLE-19223 jsc#SLE-19242 jsc#SLE-19248 jsc#SLE-19249
  jsc#SLE-19250 jsc#SLE-19253 jsc#SLE-19255 jsc#SLE-19256 jsc#SLE-19274
  jsc#SLE-19277 jsc#SLE-19282 jsc#SLE-19284 jsc#SLE-19299 jsc#SLE-19355
  jsc#SLE-19356 jsc#SLE-19357 jsc#SLE-19358 jsc#SLE-19359 jsc#SLE-19360
  jsc#SLE-19430 jsc#SLE-19436 jsc#SLE-19438 jsc#SLE-19556 jsc#SLE-19704
  jsc#SLE-19733 jsc#SLE-19789 jsc#SLE-19855 jsc#SLE-19875 jsc#SLE-19924
  jsc#SLE-20043 jsc#SLE-20056 jsc#SLE-20148 jsc#SLE-20163 jsc#SLE-20183
  jsc#SLE-20497 jsc#SLE-20498 jsc#SLE-20721 jsc#SLE-21132 jsc#SLE-21166
  jsc#SLE-21213 jsc#SLE-21256 jsc#SLE-21315 jsc#SLE-21844 jsc#SLE-21874
  jsc#SLE-22489 jsc#SLE-22496 jsc#SLE-22573 jsc#SLE-22575 jsc#SLE-22601
  jsc#SLE-22616 jsc#SLE-22690 jsc#SLE-22724 jsc#SLE-22725 jsc#SLE-23098
  jsc#SLE-23099 jsc#SLE-23139 jsc#SLE-23643 jsc#SLE-23766 jsc#SLE-24072
  jsc#SLE-24093 jsc#SLE-24350 jsc#SLE-24549 jsc#SLE-24569 jsc#SLE-24570
  jsc#SLE-24571 jsc#SLE-24572 jsc#SLE-24578 jsc#SLE-24635 jsc#SLE-24682
  jsc#SLE-24814 jsc#SLE-3853 jsc#SLE-4117 jsc#SLE-5640 jsc#SLE-6138
  jsc#SLE-7395 jsc#SLE-7474 jsc#SLE-7506 jsc#SLE-7512 jsc#SLE-7521
  jsc#SLE-7524 jsc#SLE-7533 jsc#SLE-7542 jsc#SLE-7545 jsc#SLE-7702
  jsc#SLE-7730 jsc#SLE-7741 jsc#SLE-7772 jsc#SLE-7795 jsc#SLE-7885
  jsc#SLE-7925 jsc#SLE-7926 jsc#SLE-7930 jsc#SLE-7935 jsc#SLE-7940
  jsc#SLE-7946 jsc#SLE-7953 jsc#SLE-7966 jsc#SLE-7967 jsc#SLE-7979
  jsc#SLE-7981 jsc#SLE-8009 jsc#SLE-8010 jsc#SLE-8014 jsc#SLE-8025
  jsc#SLE-8032 jsc#SLE-8100 jsc#SLE-8133 jsc#SLE-8176 jsc#SLE-8184
  jsc#SLE-8203 jsc#SLE-8215 jsc#SLE-8281 jsc#SLE-8284 jsc#SLE-8314
  jsc#SLE-8330 jsc#SLE-8371 jsc#SLE-8372 jsc#SLE-8375 jsc#SLE-8381
  jsc#SLE-8389 jsc#SLE-8392 jsc#SLE-8401 jsc#SLE-8446 jsc#SLE-8449
  jsc#SLE-8460 jsc#SLE-8461 jsc#SLE-8464 jsc#SLE-8633 jsc#SLE-8654
  jsc#SLE-8714 jsc#SLE-8896 jsc#SLE-8898 jsc#SLE-8923 jsc#SLE-8944
  jsc#SLE-8959 jsc#SLE-9099 jsc#SLE-9120 jsc#SLE-9176 jsc#SLE-9228
  jsc#SLE-9246 jsc#SLE-9251 jsc#SLE-9255 jsc#SLE-9263 jsc#SLE-9308
  jsc#SLE-9316 jsc#SLE-9326 jsc#SLE-9388 jsc#SLE-9391 jsc#SLE-9416
  jsc#SLE-9418 jsc#SLE-9457 jsc#SLE-9482 jsc#SLE-9527 jsc#SLE-95282
  jsc#SLE-9582 jsc#SLE-9619 jsc#SLE-9687 jsc#SLE-9696 jsc#SLE-9711
  jsc#SLE-9714 jsc#SLE-9858 jsc#SLE-9870 jsc#SLE-9943 jsc#SLE-9968
  jsc#SLE-9971 jsc#SLE10540 jsc#SLE14454 jsc#SLE19356 jsc#SLE19359
  jsc#sle-12891 jsc#sle-15113 jsc#sle-15116 jsc#sle-15119 jsc#sle-19733
  FATE#300516 FATE#314508 FATE#316531 FATE#322021 FATE#322022 FATE#322447
  FATE#323247 FATE#323286 FATE#323394 FATE#323406 FATE#323821 FATE#324143
  FATE#324503 FATE#324825 FATE#324970 FATE#325281 FATE#325281 FATE#325312
  FATE#325581 FATE#325617 FATE#326394 FATE#326579 FATE#326628 FATE#327775
  fate#315712 fate#316350 fate#316531 fate#317919 fate#318836 fate#322438
  fate#322786 fate#323189 fate#323487 fate#323682 fate#323887 fate#325592
  fate#326572 fate#326668
  ltc#153436 ltc#155067 ltc#155231 ltc#155423 ltc#155681 ltc#159753
  ltc#160943 ltc#163882 ltc#164363 ltc#164631 ltc#165122 ltc#165544
  ltC#165630 ltc#166495 ltc#167098 ltc#168122 ltc#169177 ltc#169948
  ltc#171067 ltc#171853 ltc#173734 ltc#174432 ltc#174633 ltc#175530
  ltc#176086 ltc#176097 ltc#177197 ltc#177449 LTC#178106 ltc#178199
  ltc#178840 LTC#178844 LTC#178852 LTC#178859 ltc#178925 LTC#178954
  LTC#178970 LTC#179078 LTC#179220 ltc#179509 ltc#179635 ltc#179958
  ltc#181028 ltc#181472 LTC#181532 ltc#181664 ltc#181740 ltc#181778
  ltc#181798 ltc#182047 LTC#182406 LTC#182407 ltc#182435 ltc#182459
  ltc#182520 ltc#182579 ltc#182612 LTC#182629 ltc#182902 ltc#182983
  ltc#182993 ltc#183000 ltc#183002 ltc#183046 LTC#183076 LTC#183077
  ltc#183498 ltc#183501 ltc#183538 ltc#183551 ltc#183834 ltc#183850
  ltc#183929 ltc#183935 LTC#183960 ltc#184087 ltc#184091 LTC#184104
  LTC#184105 ltc#184149 ltc#184171 ltc#184239 ltc#184375 LTC#184504
  LTC#184507 ltc#184611 ltc#184616 ltc#184617 ltc#184630 LTC#184760
  ltc#184814 ltc#185010 LTC#185029 LTC#185092 ltc#185128 LTC#185152
  LTC#185290 ltc#185369 ltc#185686 ltc#185738 LTC#185786 LTC#185911
  LTC#186069 ltc#186099 ltc#186162 ltc#186249 ltc#186322 LTC#186340
  LTC#186349 ltc#186394 ltc#186397 ltc#186474 LTC#186574 ltc#186863
  ltc#187090 ltc#187208 ltc#187293 ltc#187459 ltc#187461 ltc#187506
  ltc#187574 ltc#187588 LTC#187760 ltc#187922 LTC#187935 ltc#187962
  ltc#187964 ltc#188074 ltc#188130 ltc#188140 ltc#188226 LTC#188235
  ltc#188243 ltc#188252 ltc#188304 LTC#188341 LTC#188342 ltc#188522
  ltc#188629 LTC#188733 LTC#188735 ltc#188897 ltc#189002 ltc#189159
  ltc#189290 ltc#189313 ltc#189835 ltc#189960 LTC#189977 ltc#190030
  ltc#190038 ltc#190092 LTC#190110 LTC#190111 LTC#190112 LTC#190151
  LTC#190152 LTC#190155 ltc#190174 ltc#190253 ltc#190255 ltc#190257
  ltc#190285 ltc#190309 LTC#190383 ltc#190572 ltc#190579 ltc#190612
  ltc#190624 ltc#190702 ltc#190851 ltc#190855 LTC#190858 LTC#190860
  ltc#190900 ltc#190909 LTC#190914 ltc#190917 ltc#190924 ltc#190997
  ltc#191041 ltc#191079 ltc#191080 ltc#191222 ltc#191231 ltc#191273
  ltc#191345 LTC#191375 ltc#191460 ltc#191464 ltc#191533 ltc#191591
  ltc#191637 ltc#191791 ltc#191844 ltc#191922 ltc#191943 ltc#191963
  ltc#192043 ltc#192075 ltc#192091 ltc#192129 ltc#192139 LTC#192153
  ltc#192221 ltc#192232 ltc#192237 ltc#192244 ltc#192356 LTC#192526
  ltc#192531 ltc#192576 ltc#192610 ltc#192641 LTC#192679 LTC#193282
  ltc#193451 ltc#193509 ltc#193581 ltc#193646 ltc#193722 ltc#193771
  LTC#193817 ltc#193865 ltc#193906 ltc#193985 ltc#194498 ltc#194510
  ltc#194520 ltc#194523 ltc#194629 ltc#194757 LTC#194817 ltc#194976
  LTC#195546 ltc#195566 ltc#195568 ltc#195599 ltc#195600 ltc#195634
  ltc#195651 ltc#195662 ltc#195713 ltc#195733 ltc#195810 ltc#195811
  ltc#195815 LTC#196029 LTC#196087 ltc#196102 ltc#196198 LTC#196353
  ltc#196362 ltc#196391 ltc#196394 LTC#196420 ltc#197256 ltc#197259
  ltc#197388 ltc#197803 ltc#197920 LTC#198456 LTC#198457 LTC#198473
  ltc#198477 LTC#198619 LTC#198623 ltc#198761 ltc#199236 LTC#199322
  LTC#199895 ltc#199904 LTC#199905 ltc#200074 ltc#200103 ltc#200162
  ltc#200176 ltc#200177 ltc#200179 ltc#200180 LTC#200451 LTC#200501
  LTC#200502 ltc#200603 ltc#201076 ltc#201108 ltc#201363 ltc#201367
  ltc#201368 ltc#201370 ltc#201535 ltc#201612 ltc#201720 ltc#202140
  ltc#202189 ltc#202604 ltc#202861 ltc#1195655
  XSA-331 XSA-332 XSA-349 XSA-350 XSA-361 XSA-362 XSA-365 XSA-367 XSA-371
  XSA-391 XSA-392 XSA-396 XSA-403 XSA-405 XSA-423 XSA-424 XSA-432
